#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 2715
#define LARGE_STATE_COUNT 560
#define SYMBOL_COUNT 371
#define ALIAS_COUNT 0
#define TOKEN_COUNT 180
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 38
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 240

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_COLON = 3,
  anon_sym_COMMA = 4,
  aux_sym_asmBody_token1 = 5,
  aux_sym_asmBody_token2 = 6,
  aux_sym_asmBody_token3 = 7,
  anon_sym_LBRACK = 8,
  anon_sym_RBRACK = 9,
  anon_sym_LPAREN = 10,
  anon_sym_RPAREN = 11,
  aux_sym_type_token1 = 12,
  aux_sym_type_token2 = 13,
  aux_sym_type_token3 = 14,
  aux_sym__literalString_token1 = 15,
  anon_sym_POUND = 16,
  aux_sym__literalInt_token1 = 17,
  aux_sym__literalInt_token2 = 18,
  aux_sym__literalFloat_token1 = 19,
  anon_sym_DOT_DOT = 20,
  sym_kProgram = 21,
  sym_kLibrary = 22,
  sym_kUnit = 23,
  sym_kUses = 24,
  sym_kInterface = 25,
  sym_kDispInterface = 26,
  sym_kImplementation = 27,
  sym_kInitialization = 28,
  sym_kFinalization = 29,
  anon_sym_DOT = 30,
  sym_kBegin = 31,
  sym_kEnd = 32,
  sym_kAsm = 33,
  sym_kVar = 34,
  sym_kThreadvar = 35,
  sym_kConst = 36,
  sym_kConstref = 37,
  sym_kResourcestring = 38,
  sym_kOut = 39,
  sym_kType = 40,
  sym_kLabel = 41,
  sym_kExports = 42,
  sym_kAbsolute = 43,
  sym_kProperty = 44,
  sym_kRead = 45,
  sym_kWrite = 46,
  sym_kImplements = 47,
  sym_kDefault = 48,
  sym_kNodefault = 49,
  sym_kStored = 50,
  sym_kIndex = 51,
  sym_kDispId = 52,
  sym_kClass = 53,
  sym_kObject = 54,
  sym_kRecord = 55,
  sym_kObjcclass = 56,
  sym_kObjccategory = 57,
  sym_kObjcprotocol = 58,
  sym_kArray = 59,
  sym_kFile = 60,
  sym_kString = 61,
  sym_kSet = 62,
  sym_kOf = 63,
  sym_kHelper = 64,
  sym_kPacked = 65,
  sym_kGeneric = 66,
  sym_kSpecialize = 67,
  sym_kLt = 68,
  sym_kEq = 69,
  sym_kNeq = 70,
  sym_kGt = 71,
  sym_kLte = 72,
  sym_kGte = 73,
  sym_kAdd = 74,
  sym_kSub = 75,
  sym_kMul = 76,
  sym_kFdiv = 77,
  sym_kAt = 78,
  sym_kHat = 79,
  sym_kAssign = 80,
  sym_kAssignAdd = 81,
  sym_kAssignSub = 82,
  sym_kAssignMul = 83,
  sym_kAssignDiv = 84,
  sym_kOr = 85,
  sym_kXor = 86,
  sym_kDiv = 87,
  sym_kMod = 88,
  sym_kAnd = 89,
  sym_kShl = 90,
  sym_kShr = 91,
  sym_kNot = 92,
  sym_kIs = 93,
  sym_kAs = 94,
  sym_kIn = 95,
  sym_kFor = 96,
  sym_kTo = 97,
  sym_kDownto = 98,
  sym_kIf = 99,
  sym_kThen = 100,
  sym_kElse = 101,
  sym_kDo = 102,
  sym_kWhile = 103,
  sym_kRepeat = 104,
  sym_kUntil = 105,
  sym_kTry = 106,
  sym_kExcept = 107,
  sym_kFinally = 108,
  sym_kRaise = 109,
  sym_kOn = 110,
  sym_kCase = 111,
  sym_kWith = 112,
  sym_kGoto = 113,
  sym_kFunction = 114,
  sym_kProcedure = 115,
  sym_kConstructor = 116,
  sym_kDestructor = 117,
  sym_kOperator = 118,
  sym_kReference = 119,
  sym_kPublished = 120,
  sym_kPublic = 121,
  sym_kProtected = 122,
  sym_kPrivate = 123,
  sym_kStrict = 124,
  sym_kRequired = 125,
  sym_kOptional = 126,
  sym_kForward = 127,
  sym_kStatic = 128,
  sym_kVirtual = 129,
  sym_kAbstract = 130,
  sym_kSealed = 131,
  sym_kDynamic = 132,
  sym_kOverride = 133,
  sym_kOverload = 134,
  sym_kReintroduce = 135,
  sym_kInherited = 136,
  sym_kInline = 137,
  sym_kStdcall = 138,
  sym_kCdecl = 139,
  sym_kCppdecl = 140,
  sym_kPascal = 141,
  sym_kRegister = 142,
  sym_kMwpascal = 143,
  sym_kExternal = 144,
  sym_kName = 145,
  sym_kMessage = 146,
  sym_kDeprecated = 147,
  sym_kExperimental = 148,
  sym_kPlatform = 149,
  sym_kUnimplemented = 150,
  sym_kCvar = 151,
  sym_kExport = 152,
  sym_kFar = 153,
  sym_kNear = 154,
  sym_kSafecall = 155,
  sym_kAssembler = 156,
  sym_kNostackframe = 157,
  sym_kInterrupt = 158,
  sym_kNoreturn = 159,
  sym_kIocheck = 160,
  sym_kLocal = 161,
  sym_kHardfloat = 162,
  sym_kSoftfloat = 163,
  sym_kMs_abi_default = 164,
  sym_kMs_abi_cdecl = 165,
  sym_kSaveregisters = 166,
  sym_kSysv_abi_default = 167,
  sym_kSysv_abi_cdecl = 168,
  sym_kVectorcall = 169,
  sym_kVarargs = 170,
  sym_kWinapi = 171,
  sym_kAlias = 172,
  sym_kDelayed = 173,
  sym_kNil = 174,
  sym_kTrue = 175,
  sym_kFalse = 176,
  sym__space = 177,
  sym_pp = 178,
  sym_comment = 179,
  sym_root = 180,
  sym_program = 181,
  sym_library = 182,
  sym_unit = 183,
  sym_interface = 184,
  sym_implementation = 185,
  sym_initialization = 186,
  sym_finalization = 187,
  sym_moduleName = 188,
  sym_if = 189,
  sym_ifElse = 190,
  sym_while = 191,
  sym_repeat = 192,
  sym_for = 193,
  sym_foreach = 194,
  sym_exceptionHandler = 195,
  sym_exceptionElse = 196,
  sym_try = 197,
  sym_caseCase = 198,
  sym_case = 199,
  sym_block = 200,
  sym_asm = 201,
  sym_with = 202,
  sym_raise = 203,
  sym_statement = 204,
  sym_goto = 205,
  sym__statement = 206,
  sym_ifTr = 207,
  sym_ifElseTr = 208,
  sym_whileTr = 209,
  sym_repeatTr = 210,
  sym_forTr = 211,
  sym_foreachTr = 212,
  sym_exceptionHandlerTr = 213,
  sym__exceptionHandlersTr = 214,
  sym_tryTr = 215,
  sym_caseCaseTr = 216,
  sym_caseTr = 217,
  sym_blockTr = 218,
  sym_asmTr = 219,
  sym_withTr = 220,
  sym_raiseTr = 221,
  sym_statementTr = 222,
  sym_gotoTr = 223,
  sym__statementTr = 224,
  sym_assignment = 225,
  sym_varAssignDef = 226,
  sym_varDef = 227,
  sym_label = 228,
  sym_caseLabel = 229,
  sym__statementsTr = 230,
  sym_statementsTr = 231,
  sym_asmBody = 232,
  sym__expr = 233,
  sym__ref = 234,
  sym_lambda = 235,
  sym_inherited = 236,
  sym_exprDot = 237,
  sym_exprDeref = 238,
  sym_exprAs = 239,
  sym_exprTpl = 240,
  sym_exprSubscript = 241,
  sym_exprCall = 242,
  sym_legacyFormat = 243,
  sym_exprArgs = 244,
  sym_exprBinary = 245,
  sym_exprUnary = 246,
  sym_exprParens = 247,
  sym_exprBrackets = 248,
  sym_type = 249,
  sym_typeref = 250,
  sym__typeref = 251,
  sym_typerefDot = 252,
  sym_typerefTpl = 253,
  sym_typerefPtr = 254,
  sym_typerefArgs = 255,
  sym_genericDot = 256,
  sym_genericTpl = 257,
  sym__genericName = 258,
  sym_genericArgs = 259,
  sym_genericArg = 260,
  sym__literal = 261,
  sym_literalString = 262,
  sym__literalString = 263,
  sym_literalChar = 264,
  sym_literalNumber = 265,
  sym__literalInt = 266,
  sym__literalFloat = 267,
  sym_range = 268,
  aux_sym__definitions = 269,
  sym__definition = 270,
  sym_defProc = 271,
  sym_declProcFwd = 272,
  sym__visibility = 273,
  aux_sym__declarations = 274,
  aux_sym__classDeclarations = 275,
  sym_defaultValue = 276,
  sym_declUses = 277,
  sym_declExports = 278,
  sym_declTypes = 279,
  sym_declVars = 280,
  sym_declConsts = 281,
  sym_declType = 282,
  sym_declProc = 283,
  sym_declVar = 284,
  sym_declConst = 285,
  sym_declLabels = 286,
  sym_declLabel = 287,
  sym_declExport = 288,
  sym_declEnum = 289,
  sym_declEnumValue = 290,
  sym_declSet = 291,
  sym_declArray = 292,
  sym_declFile = 293,
  sym_declString = 294,
  sym_declProcRef = 295,
  sym_declMetaClass = 296,
  sym_declClass = 297,
  sym_declIntf = 298,
  sym_declHelper = 299,
  sym_guid = 300,
  sym__declClass = 301,
  sym_declSection = 302,
  aux_sym__declFields = 303,
  sym_declField = 304,
  sym_declProp = 305,
  sym_declPropArgs = 306,
  sym_declVariant = 307,
  sym_declVariantClause = 308,
  sym_declVariantField = 309,
  sym__declProc = 310,
  sym__declOperator = 311,
  sym_operatorDot = 312,
  sym__operatorName = 313,
  sym_operatorName = 314,
  sym_declArgs = 315,
  sym_declArg = 316,
  sym__procAttribute = 317,
  sym__procAttributeNoExt = 318,
  sym_procAttribute = 319,
  sym_rttiAttributes = 320,
  sym_procExternal = 321,
  sym__initializer = 322,
  sym_recInitializer = 323,
  sym_recInitializerField = 324,
  sym_arrInitializer = 325,
  sym_kEndDot = 326,
  sym_kDot = 327,
  aux_sym_unit_repeat1 = 328,
  aux_sym_moduleName_repeat1 = 329,
  aux_sym_exceptionElse_repeat1 = 330,
  aux_sym_case_repeat1 = 331,
  aux_sym_with_repeat1 = 332,
  aux_sym__exceptionHandlersTr_repeat1 = 333,
  aux_sym_caseLabel_repeat1 = 334,
  aux_sym__statementsTr_repeat1 = 335,
  aux_sym_asmBody_repeat1 = 336,
  aux_sym_exprTpl_repeat1 = 337,
  aux_sym_legacyFormat_repeat1 = 338,
  aux_sym_exprArgs_repeat1 = 339,
  aux_sym_type_repeat1 = 340,
  aux_sym_typerefArgs_repeat1 = 341,
  aux_sym_genericArgs_repeat1 = 342,
  aux_sym_genericArg_repeat1 = 343,
  aux_sym_literalString_repeat1 = 344,
  aux_sym_defProc_repeat1 = 345,
  aux_sym_declProcFwd_repeat1 = 346,
  aux_sym_declUses_repeat1 = 347,
  aux_sym_declExports_repeat1 = 348,
  aux_sym_declTypes_repeat1 = 349,
  aux_sym_declVars_repeat1 = 350,
  aux_sym_declConsts_repeat1 = 351,
  aux_sym_declVar_repeat1 = 352,
  aux_sym_declLabels_repeat1 = 353,
  aux_sym_declExport_repeat1 = 354,
  aux_sym_declEnum_repeat1 = 355,
  aux_sym_declArray_repeat1 = 356,
  aux_sym_declClass_repeat1 = 357,
  aux_sym__declClass_repeat1 = 358,
  aux_sym_declProp_repeat1 = 359,
  aux_sym_declProp_repeat2 = 360,
  aux_sym_declPropArgs_repeat1 = 361,
  aux_sym_declVariant_repeat1 = 362,
  aux_sym_declVariantClause_repeat1 = 363,
  aux_sym__declProc_repeat1 = 364,
  aux_sym__procAttribute_repeat1 = 365,
  aux_sym__procAttributeNoExt_repeat1 = 366,
  aux_sym_rttiAttributes_repeat1 = 367,
  aux_sym_rttiAttributes_repeat2 = 368,
  aux_sym_recInitializer_repeat1 = 369,
  aux_sym_arrInitializer_repeat1 = 370,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_COLON] = ":",
  [anon_sym_COMMA] = ",",
  [aux_sym_asmBody_token1] = "asmBody_token1",
  [aux_sym_asmBody_token2] = "asmBody_token2",
  [aux_sym_asmBody_token3] = "asmBody_token3",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [aux_sym_type_token1] = "pp",
  [aux_sym_type_token2] = "pp",
  [aux_sym_type_token3] = "pp",
  [aux_sym__literalString_token1] = "_literalString_token1",
  [anon_sym_POUND] = "#",
  [aux_sym__literalInt_token1] = "_literalInt_token1",
  [aux_sym__literalInt_token2] = "_literalInt_token2",
  [aux_sym__literalFloat_token1] = "_literalFloat_token1",
  [anon_sym_DOT_DOT] = "..",
  [sym_kProgram] = "kProgram",
  [sym_kLibrary] = "kLibrary",
  [sym_kUnit] = "kUnit",
  [sym_kUses] = "kUses",
  [sym_kInterface] = "kInterface",
  [sym_kDispInterface] = "kDispInterface",
  [sym_kImplementation] = "kImplementation",
  [sym_kInitialization] = "kInitialization",
  [sym_kFinalization] = "kFinalization",
  [anon_sym_DOT] = ".",
  [sym_kBegin] = "kBegin",
  [sym_kEnd] = "kEnd",
  [sym_kAsm] = "kAsm",
  [sym_kVar] = "kVar",
  [sym_kThreadvar] = "kThreadvar",
  [sym_kConst] = "kConst",
  [sym_kConstref] = "kConstref",
  [sym_kResourcestring] = "kResourcestring",
  [sym_kOut] = "kOut",
  [sym_kType] = "kType",
  [sym_kLabel] = "kLabel",
  [sym_kExports] = "kExports",
  [sym_kAbsolute] = "kAbsolute",
  [sym_kProperty] = "kProperty",
  [sym_kRead] = "kRead",
  [sym_kWrite] = "kWrite",
  [sym_kImplements] = "kImplements",
  [sym_kDefault] = "kDefault",
  [sym_kNodefault] = "kNodefault",
  [sym_kStored] = "kStored",
  [sym_kIndex] = "kIndex",
  [sym_kDispId] = "kDispId",
  [sym_kClass] = "kClass",
  [sym_kObject] = "kObject",
  [sym_kRecord] = "kRecord",
  [sym_kObjcclass] = "kObjcclass",
  [sym_kObjccategory] = "kObjccategory",
  [sym_kObjcprotocol] = "kObjcprotocol",
  [sym_kArray] = "kArray",
  [sym_kFile] = "kFile",
  [sym_kString] = "kString",
  [sym_kSet] = "kSet",
  [sym_kOf] = "kOf",
  [sym_kHelper] = "kHelper",
  [sym_kPacked] = "kPacked",
  [sym_kGeneric] = "kGeneric",
  [sym_kSpecialize] = "kSpecialize",
  [sym_kLt] = "kLt",
  [sym_kEq] = "kEq",
  [sym_kNeq] = "kNeq",
  [sym_kGt] = "kGt",
  [sym_kLte] = "kLte",
  [sym_kGte] = "kGte",
  [sym_kAdd] = "kAdd",
  [sym_kSub] = "kSub",
  [sym_kMul] = "kMul",
  [sym_kFdiv] = "kFdiv",
  [sym_kAt] = "kAt",
  [sym_kHat] = "kHat",
  [sym_kAssign] = "kAssign",
  [sym_kAssignAdd] = "kAssignAdd",
  [sym_kAssignSub] = "kAssignSub",
  [sym_kAssignMul] = "kAssignMul",
  [sym_kAssignDiv] = "kAssignDiv",
  [sym_kOr] = "kOr",
  [sym_kXor] = "kXor",
  [sym_kDiv] = "kDiv",
  [sym_kMod] = "kMod",
  [sym_kAnd] = "kAnd",
  [sym_kShl] = "kShl",
  [sym_kShr] = "kShr",
  [sym_kNot] = "kNot",
  [sym_kIs] = "kIs",
  [sym_kAs] = "kAs",
  [sym_kIn] = "kIn",
  [sym_kFor] = "kFor",
  [sym_kTo] = "kTo",
  [sym_kDownto] = "kDownto",
  [sym_kIf] = "kIf",
  [sym_kThen] = "kThen",
  [sym_kElse] = "kElse",
  [sym_kDo] = "kDo",
  [sym_kWhile] = "kWhile",
  [sym_kRepeat] = "kRepeat",
  [sym_kUntil] = "kUntil",
  [sym_kTry] = "kTry",
  [sym_kExcept] = "kExcept",
  [sym_kFinally] = "kFinally",
  [sym_kRaise] = "kRaise",
  [sym_kOn] = "kOn",
  [sym_kCase] = "kCase",
  [sym_kWith] = "kWith",
  [sym_kGoto] = "kGoto",
  [sym_kFunction] = "kFunction",
  [sym_kProcedure] = "kProcedure",
  [sym_kConstructor] = "kConstructor",
  [sym_kDestructor] = "kDestructor",
  [sym_kOperator] = "kOperator",
  [sym_kReference] = "kReference",
  [sym_kPublished] = "kPublished",
  [sym_kPublic] = "kPublic",
  [sym_kProtected] = "kProtected",
  [sym_kPrivate] = "kPrivate",
  [sym_kStrict] = "kStrict",
  [sym_kRequired] = "kRequired",
  [sym_kOptional] = "kOptional",
  [sym_kForward] = "kForward",
  [sym_kStatic] = "kStatic",
  [sym_kVirtual] = "kVirtual",
  [sym_kAbstract] = "kAbstract",
  [sym_kSealed] = "kSealed",
  [sym_kDynamic] = "kDynamic",
  [sym_kOverride] = "kOverride",
  [sym_kOverload] = "kOverload",
  [sym_kReintroduce] = "kReintroduce",
  [sym_kInherited] = "kInherited",
  [sym_kInline] = "kInline",
  [sym_kStdcall] = "kStdcall",
  [sym_kCdecl] = "kCdecl",
  [sym_kCppdecl] = "kCppdecl",
  [sym_kPascal] = "kPascal",
  [sym_kRegister] = "kRegister",
  [sym_kMwpascal] = "kMwpascal",
  [sym_kExternal] = "kExternal",
  [sym_kName] = "kName",
  [sym_kMessage] = "kMessage",
  [sym_kDeprecated] = "kDeprecated",
  [sym_kExperimental] = "kExperimental",
  [sym_kPlatform] = "kPlatform",
  [sym_kUnimplemented] = "kUnimplemented",
  [sym_kCvar] = "kCvar",
  [sym_kExport] = "kExport",
  [sym_kFar] = "kFar",
  [sym_kNear] = "kNear",
  [sym_kSafecall] = "kSafecall",
  [sym_kAssembler] = "kAssembler",
  [sym_kNostackframe] = "kNostackframe",
  [sym_kInterrupt] = "kInterrupt",
  [sym_kNoreturn] = "kNoreturn",
  [sym_kIocheck] = "kIocheck",
  [sym_kLocal] = "kLocal",
  [sym_kHardfloat] = "kHardfloat",
  [sym_kSoftfloat] = "kSoftfloat",
  [sym_kMs_abi_default] = "kMs_abi_default",
  [sym_kMs_abi_cdecl] = "kMs_abi_cdecl",
  [sym_kSaveregisters] = "kSaveregisters",
  [sym_kSysv_abi_default] = "kSysv_abi_default",
  [sym_kSysv_abi_cdecl] = "kSysv_abi_cdecl",
  [sym_kVectorcall] = "kVectorcall",
  [sym_kVarargs] = "kVarargs",
  [sym_kWinapi] = "kWinapi",
  [sym_kAlias] = "kAlias",
  [sym_kDelayed] = "kDelayed",
  [sym_kNil] = "kNil",
  [sym_kTrue] = "kTrue",
  [sym_kFalse] = "kFalse",
  [sym__space] = "_space",
  [sym_pp] = "pp",
  [sym_comment] = "comment",
  [sym_root] = "root",
  [sym_program] = "program",
  [sym_library] = "library",
  [sym_unit] = "unit",
  [sym_interface] = "interface",
  [sym_implementation] = "implementation",
  [sym_initialization] = "initialization",
  [sym_finalization] = "finalization",
  [sym_moduleName] = "moduleName",
  [sym_if] = "if",
  [sym_ifElse] = "ifElse",
  [sym_while] = "while",
  [sym_repeat] = "repeat",
  [sym_for] = "for",
  [sym_foreach] = "foreach",
  [sym_exceptionHandler] = "exceptionHandler",
  [sym_exceptionElse] = "exceptionElse",
  [sym_try] = "try",
  [sym_caseCase] = "caseCase",
  [sym_case] = "case",
  [sym_block] = "block",
  [sym_asm] = "asm",
  [sym_with] = "with",
  [sym_raise] = "raise",
  [sym_statement] = "statement",
  [sym_goto] = "goto",
  [sym__statement] = "_statement",
  [sym_ifTr] = "if",
  [sym_ifElseTr] = "ifElse",
  [sym_whileTr] = "while",
  [sym_repeatTr] = "repeat",
  [sym_forTr] = "for",
  [sym_foreachTr] = "foreach",
  [sym_exceptionHandlerTr] = "exceptionHandler",
  [sym__exceptionHandlersTr] = "_exceptionHandlersTr",
  [sym_tryTr] = "try",
  [sym_caseCaseTr] = "caseCase",
  [sym_caseTr] = "case",
  [sym_blockTr] = "blockTr",
  [sym_asmTr] = "asm",
  [sym_withTr] = "with",
  [sym_raiseTr] = "raise",
  [sym_statementTr] = "statement",
  [sym_gotoTr] = "goto",
  [sym__statementTr] = "_statementTr",
  [sym_assignment] = "assignment",
  [sym_varAssignDef] = "varAssignDef",
  [sym_varDef] = "varDef",
  [sym_label] = "label",
  [sym_caseLabel] = "caseLabel",
  [sym__statementsTr] = "_statementsTr",
  [sym_statementsTr] = "statements",
  [sym_asmBody] = "asmBody",
  [sym__expr] = "_expr",
  [sym__ref] = "_ref",
  [sym_lambda] = "lambda",
  [sym_inherited] = "inherited",
  [sym_exprDot] = "exprDot",
  [sym_exprDeref] = "exprUnary",
  [sym_exprAs] = "exprBinary",
  [sym_exprTpl] = "exprTpl",
  [sym_exprSubscript] = "exprSubscript",
  [sym_exprCall] = "exprCall",
  [sym_legacyFormat] = "legacyFormat",
  [sym_exprArgs] = "exprArgs",
  [sym_exprBinary] = "exprBinary",
  [sym_exprUnary] = "exprUnary",
  [sym_exprParens] = "exprParens",
  [sym_exprBrackets] = "exprBrackets",
  [sym_type] = "type",
  [sym_typeref] = "typeref",
  [sym__typeref] = "_typeref",
  [sym_typerefDot] = "typerefDot",
  [sym_typerefTpl] = "typerefTpl",
  [sym_typerefPtr] = "typerefPtr",
  [sym_typerefArgs] = "typerefArgs",
  [sym_genericDot] = "genericDot",
  [sym_genericTpl] = "genericTpl",
  [sym__genericName] = "_genericName",
  [sym_genericArgs] = "genericArgs",
  [sym_genericArg] = "genericArg",
  [sym__literal] = "_literal",
  [sym_literalString] = "literalString",
  [sym__literalString] = "_literalString",
  [sym_literalChar] = "literalChar",
  [sym_literalNumber] = "literalNumber",
  [sym__literalInt] = "_literalInt",
  [sym__literalFloat] = "_literalFloat",
  [sym_range] = "range",
  [aux_sym__definitions] = "_definitions",
  [sym__definition] = "_definition",
  [sym_defProc] = "defProc",
  [sym_declProcFwd] = "declProc",
  [sym__visibility] = "_visibility",
  [aux_sym__declarations] = "_declarations",
  [aux_sym__classDeclarations] = "_classDeclarations",
  [sym_defaultValue] = "defaultValue",
  [sym_declUses] = "declUses",
  [sym_declExports] = "declExports",
  [sym_declTypes] = "declTypes",
  [sym_declVars] = "declVars",
  [sym_declConsts] = "declConsts",
  [sym_declType] = "declType",
  [sym_declProc] = "declProc",
  [sym_declVar] = "declVar",
  [sym_declConst] = "declConst",
  [sym_declLabels] = "declLabels",
  [sym_declLabel] = "declLabel",
  [sym_declExport] = "declExport",
  [sym_declEnum] = "declEnum",
  [sym_declEnumValue] = "declEnumValue",
  [sym_declSet] = "declSet",
  [sym_declArray] = "declArray",
  [sym_declFile] = "declFile",
  [sym_declString] = "declString",
  [sym_declProcRef] = "declProcRef",
  [sym_declMetaClass] = "declMetaClass",
  [sym_declClass] = "declClass",
  [sym_declIntf] = "declIntf",
  [sym_declHelper] = "declHelper",
  [sym_guid] = "guid",
  [sym__declClass] = "_declClass",
  [sym_declSection] = "declSection",
  [aux_sym__declFields] = "_declFields",
  [sym_declField] = "declField",
  [sym_declProp] = "declProp",
  [sym_declPropArgs] = "declPropArgs",
  [sym_declVariant] = "declVariant",
  [sym_declVariantClause] = "declVariantClause",
  [sym_declVariantField] = "declField",
  [sym__declProc] = "_declProc",
  [sym__declOperator] = "_declOperator",
  [sym_operatorDot] = "genericDot",
  [sym__operatorName] = "_operatorName",
  [sym_operatorName] = "operatorName",
  [sym_declArgs] = "declArgs",
  [sym_declArg] = "declArg",
  [sym__procAttribute] = "_procAttribute",
  [sym__procAttributeNoExt] = "_procAttributeNoExt",
  [sym_procAttribute] = "procAttribute",
  [sym_rttiAttributes] = "rttiAttributes",
  [sym_procExternal] = "procExternal",
  [sym__initializer] = "_initializer",
  [sym_recInitializer] = "recInitializer",
  [sym_recInitializerField] = "recInitializerField",
  [sym_arrInitializer] = "arrInitializer",
  [sym_kEndDot] = "kEndDot",
  [sym_kDot] = "kDot",
  [aux_sym_unit_repeat1] = "unit_repeat1",
  [aux_sym_moduleName_repeat1] = "moduleName_repeat1",
  [aux_sym_exceptionElse_repeat1] = "exceptionElse_repeat1",
  [aux_sym_case_repeat1] = "case_repeat1",
  [aux_sym_with_repeat1] = "with_repeat1",
  [aux_sym__exceptionHandlersTr_repeat1] = "_exceptionHandlersTr_repeat1",
  [aux_sym_caseLabel_repeat1] = "caseLabel_repeat1",
  [aux_sym__statementsTr_repeat1] = "_statementsTr_repeat1",
  [aux_sym_asmBody_repeat1] = "asmBody_repeat1",
  [aux_sym_exprTpl_repeat1] = "exprTpl_repeat1",
  [aux_sym_legacyFormat_repeat1] = "legacyFormat_repeat1",
  [aux_sym_exprArgs_repeat1] = "exprArgs_repeat1",
  [aux_sym_type_repeat1] = "type_repeat1",
  [aux_sym_typerefArgs_repeat1] = "typerefArgs_repeat1",
  [aux_sym_genericArgs_repeat1] = "genericArgs_repeat1",
  [aux_sym_genericArg_repeat1] = "genericArg_repeat1",
  [aux_sym_literalString_repeat1] = "literalString_repeat1",
  [aux_sym_defProc_repeat1] = "defProc_repeat1",
  [aux_sym_declProcFwd_repeat1] = "declProcFwd_repeat1",
  [aux_sym_declUses_repeat1] = "declUses_repeat1",
  [aux_sym_declExports_repeat1] = "declExports_repeat1",
  [aux_sym_declTypes_repeat1] = "declTypes_repeat1",
  [aux_sym_declVars_repeat1] = "declVars_repeat1",
  [aux_sym_declConsts_repeat1] = "declConsts_repeat1",
  [aux_sym_declVar_repeat1] = "declVar_repeat1",
  [aux_sym_declLabels_repeat1] = "declLabels_repeat1",
  [aux_sym_declExport_repeat1] = "declExport_repeat1",
  [aux_sym_declEnum_repeat1] = "declEnum_repeat1",
  [aux_sym_declArray_repeat1] = "declArray_repeat1",
  [aux_sym_declClass_repeat1] = "declClass_repeat1",
  [aux_sym__declClass_repeat1] = "_declClass_repeat1",
  [aux_sym_declProp_repeat1] = "declProp_repeat1",
  [aux_sym_declProp_repeat2] = "declProp_repeat2",
  [aux_sym_declPropArgs_repeat1] = "declPropArgs_repeat1",
  [aux_sym_declVariant_repeat1] = "declVariant_repeat1",
  [aux_sym_declVariantClause_repeat1] = "declVariantClause_repeat1",
  [aux_sym__declProc_repeat1] = "_declProc_repeat1",
  [aux_sym__procAttribute_repeat1] = "_procAttribute_repeat1",
  [aux_sym__procAttributeNoExt_repeat1] = "_procAttributeNoExt_repeat1",
  [aux_sym_rttiAttributes_repeat1] = "rttiAttributes_repeat1",
  [aux_sym_rttiAttributes_repeat2] = "rttiAttributes_repeat2",
  [aux_sym_recInitializer_repeat1] = "recInitializer_repeat1",
  [aux_sym_arrInitializer_repeat1] = "arrInitializer_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [aux_sym_asmBody_token1] = aux_sym_asmBody_token1,
  [aux_sym_asmBody_token2] = aux_sym_asmBody_token2,
  [aux_sym_asmBody_token3] = aux_sym_asmBody_token3,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_type_token1] = sym_pp,
  [aux_sym_type_token2] = sym_pp,
  [aux_sym_type_token3] = sym_pp,
  [aux_sym__literalString_token1] = aux_sym__literalString_token1,
  [anon_sym_POUND] = anon_sym_POUND,
  [aux_sym__literalInt_token1] = aux_sym__literalInt_token1,
  [aux_sym__literalInt_token2] = aux_sym__literalInt_token2,
  [aux_sym__literalFloat_token1] = aux_sym__literalFloat_token1,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [sym_kProgram] = sym_kProgram,
  [sym_kLibrary] = sym_kLibrary,
  [sym_kUnit] = sym_kUnit,
  [sym_kUses] = sym_kUses,
  [sym_kInterface] = sym_kInterface,
  [sym_kDispInterface] = sym_kDispInterface,
  [sym_kImplementation] = sym_kImplementation,
  [sym_kInitialization] = sym_kInitialization,
  [sym_kFinalization] = sym_kFinalization,
  [anon_sym_DOT] = anon_sym_DOT,
  [sym_kBegin] = sym_kBegin,
  [sym_kEnd] = sym_kEnd,
  [sym_kAsm] = sym_kAsm,
  [sym_kVar] = sym_kVar,
  [sym_kThreadvar] = sym_kThreadvar,
  [sym_kConst] = sym_kConst,
  [sym_kConstref] = sym_kConstref,
  [sym_kResourcestring] = sym_kResourcestring,
  [sym_kOut] = sym_kOut,
  [sym_kType] = sym_kType,
  [sym_kLabel] = sym_kLabel,
  [sym_kExports] = sym_kExports,
  [sym_kAbsolute] = sym_kAbsolute,
  [sym_kProperty] = sym_kProperty,
  [sym_kRead] = sym_kRead,
  [sym_kWrite] = sym_kWrite,
  [sym_kImplements] = sym_kImplements,
  [sym_kDefault] = sym_kDefault,
  [sym_kNodefault] = sym_kNodefault,
  [sym_kStored] = sym_kStored,
  [sym_kIndex] = sym_kIndex,
  [sym_kDispId] = sym_kDispId,
  [sym_kClass] = sym_kClass,
  [sym_kObject] = sym_kObject,
  [sym_kRecord] = sym_kRecord,
  [sym_kObjcclass] = sym_kObjcclass,
  [sym_kObjccategory] = sym_kObjccategory,
  [sym_kObjcprotocol] = sym_kObjcprotocol,
  [sym_kArray] = sym_kArray,
  [sym_kFile] = sym_kFile,
  [sym_kString] = sym_kString,
  [sym_kSet] = sym_kSet,
  [sym_kOf] = sym_kOf,
  [sym_kHelper] = sym_kHelper,
  [sym_kPacked] = sym_kPacked,
  [sym_kGeneric] = sym_kGeneric,
  [sym_kSpecialize] = sym_kSpecialize,
  [sym_kLt] = sym_kLt,
  [sym_kEq] = sym_kEq,
  [sym_kNeq] = sym_kNeq,
  [sym_kGt] = sym_kGt,
  [sym_kLte] = sym_kLte,
  [sym_kGte] = sym_kGte,
  [sym_kAdd] = sym_kAdd,
  [sym_kSub] = sym_kSub,
  [sym_kMul] = sym_kMul,
  [sym_kFdiv] = sym_kFdiv,
  [sym_kAt] = sym_kAt,
  [sym_kHat] = sym_kHat,
  [sym_kAssign] = sym_kAssign,
  [sym_kAssignAdd] = sym_kAssignAdd,
  [sym_kAssignSub] = sym_kAssignSub,
  [sym_kAssignMul] = sym_kAssignMul,
  [sym_kAssignDiv] = sym_kAssignDiv,
  [sym_kOr] = sym_kOr,
  [sym_kXor] = sym_kXor,
  [sym_kDiv] = sym_kDiv,
  [sym_kMod] = sym_kMod,
  [sym_kAnd] = sym_kAnd,
  [sym_kShl] = sym_kShl,
  [sym_kShr] = sym_kShr,
  [sym_kNot] = sym_kNot,
  [sym_kIs] = sym_kIs,
  [sym_kAs] = sym_kAs,
  [sym_kIn] = sym_kIn,
  [sym_kFor] = sym_kFor,
  [sym_kTo] = sym_kTo,
  [sym_kDownto] = sym_kDownto,
  [sym_kIf] = sym_kIf,
  [sym_kThen] = sym_kThen,
  [sym_kElse] = sym_kElse,
  [sym_kDo] = sym_kDo,
  [sym_kWhile] = sym_kWhile,
  [sym_kRepeat] = sym_kRepeat,
  [sym_kUntil] = sym_kUntil,
  [sym_kTry] = sym_kTry,
  [sym_kExcept] = sym_kExcept,
  [sym_kFinally] = sym_kFinally,
  [sym_kRaise] = sym_kRaise,
  [sym_kOn] = sym_kOn,
  [sym_kCase] = sym_kCase,
  [sym_kWith] = sym_kWith,
  [sym_kGoto] = sym_kGoto,
  [sym_kFunction] = sym_kFunction,
  [sym_kProcedure] = sym_kProcedure,
  [sym_kConstructor] = sym_kConstructor,
  [sym_kDestructor] = sym_kDestructor,
  [sym_kOperator] = sym_kOperator,
  [sym_kReference] = sym_kReference,
  [sym_kPublished] = sym_kPublished,
  [sym_kPublic] = sym_kPublic,
  [sym_kProtected] = sym_kProtected,
  [sym_kPrivate] = sym_kPrivate,
  [sym_kStrict] = sym_kStrict,
  [sym_kRequired] = sym_kRequired,
  [sym_kOptional] = sym_kOptional,
  [sym_kForward] = sym_kForward,
  [sym_kStatic] = sym_kStatic,
  [sym_kVirtual] = sym_kVirtual,
  [sym_kAbstract] = sym_kAbstract,
  [sym_kSealed] = sym_kSealed,
  [sym_kDynamic] = sym_kDynamic,
  [sym_kOverride] = sym_kOverride,
  [sym_kOverload] = sym_kOverload,
  [sym_kReintroduce] = sym_kReintroduce,
  [sym_kInherited] = sym_kInherited,
  [sym_kInline] = sym_kInline,
  [sym_kStdcall] = sym_kStdcall,
  [sym_kCdecl] = sym_kCdecl,
  [sym_kCppdecl] = sym_kCppdecl,
  [sym_kPascal] = sym_kPascal,
  [sym_kRegister] = sym_kRegister,
  [sym_kMwpascal] = sym_kMwpascal,
  [sym_kExternal] = sym_kExternal,
  [sym_kName] = sym_kName,
  [sym_kMessage] = sym_kMessage,
  [sym_kDeprecated] = sym_kDeprecated,
  [sym_kExperimental] = sym_kExperimental,
  [sym_kPlatform] = sym_kPlatform,
  [sym_kUnimplemented] = sym_kUnimplemented,
  [sym_kCvar] = sym_kCvar,
  [sym_kExport] = sym_kExport,
  [sym_kFar] = sym_kFar,
  [sym_kNear] = sym_kNear,
  [sym_kSafecall] = sym_kSafecall,
  [sym_kAssembler] = sym_kAssembler,
  [sym_kNostackframe] = sym_kNostackframe,
  [sym_kInterrupt] = sym_kInterrupt,
  [sym_kNoreturn] = sym_kNoreturn,
  [sym_kIocheck] = sym_kIocheck,
  [sym_kLocal] = sym_kLocal,
  [sym_kHardfloat] = sym_kHardfloat,
  [sym_kSoftfloat] = sym_kSoftfloat,
  [sym_kMs_abi_default] = sym_kMs_abi_default,
  [sym_kMs_abi_cdecl] = sym_kMs_abi_cdecl,
  [sym_kSaveregisters] = sym_kSaveregisters,
  [sym_kSysv_abi_default] = sym_kSysv_abi_default,
  [sym_kSysv_abi_cdecl] = sym_kSysv_abi_cdecl,
  [sym_kVectorcall] = sym_kVectorcall,
  [sym_kVarargs] = sym_kVarargs,
  [sym_kWinapi] = sym_kWinapi,
  [sym_kAlias] = sym_kAlias,
  [sym_kDelayed] = sym_kDelayed,
  [sym_kNil] = sym_kNil,
  [sym_kTrue] = sym_kTrue,
  [sym_kFalse] = sym_kFalse,
  [sym__space] = sym__space,
  [sym_pp] = sym_pp,
  [sym_comment] = sym_comment,
  [sym_root] = sym_root,
  [sym_program] = sym_program,
  [sym_library] = sym_library,
  [sym_unit] = sym_unit,
  [sym_interface] = sym_interface,
  [sym_implementation] = sym_implementation,
  [sym_initialization] = sym_initialization,
  [sym_finalization] = sym_finalization,
  [sym_moduleName] = sym_moduleName,
  [sym_if] = sym_if,
  [sym_ifElse] = sym_ifElse,
  [sym_while] = sym_while,
  [sym_repeat] = sym_repeat,
  [sym_for] = sym_for,
  [sym_foreach] = sym_foreach,
  [sym_exceptionHandler] = sym_exceptionHandler,
  [sym_exceptionElse] = sym_exceptionElse,
  [sym_try] = sym_try,
  [sym_caseCase] = sym_caseCase,
  [sym_case] = sym_case,
  [sym_block] = sym_block,
  [sym_asm] = sym_asm,
  [sym_with] = sym_with,
  [sym_raise] = sym_raise,
  [sym_statement] = sym_statement,
  [sym_goto] = sym_goto,
  [sym__statement] = sym__statement,
  [sym_ifTr] = sym_if,
  [sym_ifElseTr] = sym_ifElse,
  [sym_whileTr] = sym_while,
  [sym_repeatTr] = sym_repeat,
  [sym_forTr] = sym_for,
  [sym_foreachTr] = sym_foreach,
  [sym_exceptionHandlerTr] = sym_exceptionHandler,
  [sym__exceptionHandlersTr] = sym__exceptionHandlersTr,
  [sym_tryTr] = sym_try,
  [sym_caseCaseTr] = sym_caseCase,
  [sym_caseTr] = sym_case,
  [sym_blockTr] = sym_blockTr,
  [sym_asmTr] = sym_asm,
  [sym_withTr] = sym_with,
  [sym_raiseTr] = sym_raise,
  [sym_statementTr] = sym_statement,
  [sym_gotoTr] = sym_goto,
  [sym__statementTr] = sym__statementTr,
  [sym_assignment] = sym_assignment,
  [sym_varAssignDef] = sym_varAssignDef,
  [sym_varDef] = sym_varDef,
  [sym_label] = sym_label,
  [sym_caseLabel] = sym_caseLabel,
  [sym__statementsTr] = sym__statementsTr,
  [sym_statementsTr] = sym_statementsTr,
  [sym_asmBody] = sym_asmBody,
  [sym__expr] = sym__expr,
  [sym__ref] = sym__ref,
  [sym_lambda] = sym_lambda,
  [sym_inherited] = sym_inherited,
  [sym_exprDot] = sym_exprDot,
  [sym_exprDeref] = sym_exprUnary,
  [sym_exprAs] = sym_exprBinary,
  [sym_exprTpl] = sym_exprTpl,
  [sym_exprSubscript] = sym_exprSubscript,
  [sym_exprCall] = sym_exprCall,
  [sym_legacyFormat] = sym_legacyFormat,
  [sym_exprArgs] = sym_exprArgs,
  [sym_exprBinary] = sym_exprBinary,
  [sym_exprUnary] = sym_exprUnary,
  [sym_exprParens] = sym_exprParens,
  [sym_exprBrackets] = sym_exprBrackets,
  [sym_type] = sym_type,
  [sym_typeref] = sym_typeref,
  [sym__typeref] = sym__typeref,
  [sym_typerefDot] = sym_typerefDot,
  [sym_typerefTpl] = sym_typerefTpl,
  [sym_typerefPtr] = sym_typerefPtr,
  [sym_typerefArgs] = sym_typerefArgs,
  [sym_genericDot] = sym_genericDot,
  [sym_genericTpl] = sym_genericTpl,
  [sym__genericName] = sym__genericName,
  [sym_genericArgs] = sym_genericArgs,
  [sym_genericArg] = sym_genericArg,
  [sym__literal] = sym__literal,
  [sym_literalString] = sym_literalString,
  [sym__literalString] = sym__literalString,
  [sym_literalChar] = sym_literalChar,
  [sym_literalNumber] = sym_literalNumber,
  [sym__literalInt] = sym__literalInt,
  [sym__literalFloat] = sym__literalFloat,
  [sym_range] = sym_range,
  [aux_sym__definitions] = aux_sym__definitions,
  [sym__definition] = sym__definition,
  [sym_defProc] = sym_defProc,
  [sym_declProcFwd] = sym_declProc,
  [sym__visibility] = sym__visibility,
  [aux_sym__declarations] = aux_sym__declarations,
  [aux_sym__classDeclarations] = aux_sym__classDeclarations,
  [sym_defaultValue] = sym_defaultValue,
  [sym_declUses] = sym_declUses,
  [sym_declExports] = sym_declExports,
  [sym_declTypes] = sym_declTypes,
  [sym_declVars] = sym_declVars,
  [sym_declConsts] = sym_declConsts,
  [sym_declType] = sym_declType,
  [sym_declProc] = sym_declProc,
  [sym_declVar] = sym_declVar,
  [sym_declConst] = sym_declConst,
  [sym_declLabels] = sym_declLabels,
  [sym_declLabel] = sym_declLabel,
  [sym_declExport] = sym_declExport,
  [sym_declEnum] = sym_declEnum,
  [sym_declEnumValue] = sym_declEnumValue,
  [sym_declSet] = sym_declSet,
  [sym_declArray] = sym_declArray,
  [sym_declFile] = sym_declFile,
  [sym_declString] = sym_declString,
  [sym_declProcRef] = sym_declProcRef,
  [sym_declMetaClass] = sym_declMetaClass,
  [sym_declClass] = sym_declClass,
  [sym_declIntf] = sym_declIntf,
  [sym_declHelper] = sym_declHelper,
  [sym_guid] = sym_guid,
  [sym__declClass] = sym__declClass,
  [sym_declSection] = sym_declSection,
  [aux_sym__declFields] = aux_sym__declFields,
  [sym_declField] = sym_declField,
  [sym_declProp] = sym_declProp,
  [sym_declPropArgs] = sym_declPropArgs,
  [sym_declVariant] = sym_declVariant,
  [sym_declVariantClause] = sym_declVariantClause,
  [sym_declVariantField] = sym_declField,
  [sym__declProc] = sym__declProc,
  [sym__declOperator] = sym__declOperator,
  [sym_operatorDot] = sym_genericDot,
  [sym__operatorName] = sym__operatorName,
  [sym_operatorName] = sym_operatorName,
  [sym_declArgs] = sym_declArgs,
  [sym_declArg] = sym_declArg,
  [sym__procAttribute] = sym__procAttribute,
  [sym__procAttributeNoExt] = sym__procAttributeNoExt,
  [sym_procAttribute] = sym_procAttribute,
  [sym_rttiAttributes] = sym_rttiAttributes,
  [sym_procExternal] = sym_procExternal,
  [sym__initializer] = sym__initializer,
  [sym_recInitializer] = sym_recInitializer,
  [sym_recInitializerField] = sym_recInitializerField,
  [sym_arrInitializer] = sym_arrInitializer,
  [sym_kEndDot] = sym_kEndDot,
  [sym_kDot] = sym_kDot,
  [aux_sym_unit_repeat1] = aux_sym_unit_repeat1,
  [aux_sym_moduleName_repeat1] = aux_sym_moduleName_repeat1,
  [aux_sym_exceptionElse_repeat1] = aux_sym_exceptionElse_repeat1,
  [aux_sym_case_repeat1] = aux_sym_case_repeat1,
  [aux_sym_with_repeat1] = aux_sym_with_repeat1,
  [aux_sym__exceptionHandlersTr_repeat1] = aux_sym__exceptionHandlersTr_repeat1,
  [aux_sym_caseLabel_repeat1] = aux_sym_caseLabel_repeat1,
  [aux_sym__statementsTr_repeat1] = aux_sym__statementsTr_repeat1,
  [aux_sym_asmBody_repeat1] = aux_sym_asmBody_repeat1,
  [aux_sym_exprTpl_repeat1] = aux_sym_exprTpl_repeat1,
  [aux_sym_legacyFormat_repeat1] = aux_sym_legacyFormat_repeat1,
  [aux_sym_exprArgs_repeat1] = aux_sym_exprArgs_repeat1,
  [aux_sym_type_repeat1] = aux_sym_type_repeat1,
  [aux_sym_typerefArgs_repeat1] = aux_sym_typerefArgs_repeat1,
  [aux_sym_genericArgs_repeat1] = aux_sym_genericArgs_repeat1,
  [aux_sym_genericArg_repeat1] = aux_sym_genericArg_repeat1,
  [aux_sym_literalString_repeat1] = aux_sym_literalString_repeat1,
  [aux_sym_defProc_repeat1] = aux_sym_defProc_repeat1,
  [aux_sym_declProcFwd_repeat1] = aux_sym_declProcFwd_repeat1,
  [aux_sym_declUses_repeat1] = aux_sym_declUses_repeat1,
  [aux_sym_declExports_repeat1] = aux_sym_declExports_repeat1,
  [aux_sym_declTypes_repeat1] = aux_sym_declTypes_repeat1,
  [aux_sym_declVars_repeat1] = aux_sym_declVars_repeat1,
  [aux_sym_declConsts_repeat1] = aux_sym_declConsts_repeat1,
  [aux_sym_declVar_repeat1] = aux_sym_declVar_repeat1,
  [aux_sym_declLabels_repeat1] = aux_sym_declLabels_repeat1,
  [aux_sym_declExport_repeat1] = aux_sym_declExport_repeat1,
  [aux_sym_declEnum_repeat1] = aux_sym_declEnum_repeat1,
  [aux_sym_declArray_repeat1] = aux_sym_declArray_repeat1,
  [aux_sym_declClass_repeat1] = aux_sym_declClass_repeat1,
  [aux_sym__declClass_repeat1] = aux_sym__declClass_repeat1,
  [aux_sym_declProp_repeat1] = aux_sym_declProp_repeat1,
  [aux_sym_declProp_repeat2] = aux_sym_declProp_repeat2,
  [aux_sym_declPropArgs_repeat1] = aux_sym_declPropArgs_repeat1,
  [aux_sym_declVariant_repeat1] = aux_sym_declVariant_repeat1,
  [aux_sym_declVariantClause_repeat1] = aux_sym_declVariantClause_repeat1,
  [aux_sym__declProc_repeat1] = aux_sym__declProc_repeat1,
  [aux_sym__procAttribute_repeat1] = aux_sym__procAttribute_repeat1,
  [aux_sym__procAttributeNoExt_repeat1] = aux_sym__procAttributeNoExt_repeat1,
  [aux_sym_rttiAttributes_repeat1] = aux_sym_rttiAttributes_repeat1,
  [aux_sym_rttiAttributes_repeat2] = aux_sym_rttiAttributes_repeat2,
  [aux_sym_recInitializer_repeat1] = aux_sym_recInitializer_repeat1,
  [aux_sym_arrInitializer_repeat1] = aux_sym_arrInitializer_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_asmBody_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_asmBody_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_asmBody_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_type_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_type_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_type_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__literalString_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__literalInt_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__literalInt_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__literalFloat_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_kProgram] = {
    .visible = true,
    .named = true,
  },
  [sym_kLibrary] = {
    .visible = true,
    .named = true,
  },
  [sym_kUnit] = {
    .visible = true,
    .named = true,
  },
  [sym_kUses] = {
    .visible = true,
    .named = true,
  },
  [sym_kInterface] = {
    .visible = true,
    .named = true,
  },
  [sym_kDispInterface] = {
    .visible = true,
    .named = true,
  },
  [sym_kImplementation] = {
    .visible = true,
    .named = true,
  },
  [sym_kInitialization] = {
    .visible = true,
    .named = true,
  },
  [sym_kFinalization] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_kBegin] = {
    .visible = true,
    .named = true,
  },
  [sym_kEnd] = {
    .visible = true,
    .named = true,
  },
  [sym_kAsm] = {
    .visible = true,
    .named = true,
  },
  [sym_kVar] = {
    .visible = true,
    .named = true,
  },
  [sym_kThreadvar] = {
    .visible = true,
    .named = true,
  },
  [sym_kConst] = {
    .visible = true,
    .named = true,
  },
  [sym_kConstref] = {
    .visible = true,
    .named = true,
  },
  [sym_kResourcestring] = {
    .visible = true,
    .named = true,
  },
  [sym_kOut] = {
    .visible = true,
    .named = true,
  },
  [sym_kType] = {
    .visible = true,
    .named = true,
  },
  [sym_kLabel] = {
    .visible = true,
    .named = true,
  },
  [sym_kExports] = {
    .visible = true,
    .named = true,
  },
  [sym_kAbsolute] = {
    .visible = true,
    .named = true,
  },
  [sym_kProperty] = {
    .visible = true,
    .named = true,
  },
  [sym_kRead] = {
    .visible = true,
    .named = true,
  },
  [sym_kWrite] = {
    .visible = true,
    .named = true,
  },
  [sym_kImplements] = {
    .visible = true,
    .named = true,
  },
  [sym_kDefault] = {
    .visible = true,
    .named = true,
  },
  [sym_kNodefault] = {
    .visible = true,
    .named = true,
  },
  [sym_kStored] = {
    .visible = true,
    .named = true,
  },
  [sym_kIndex] = {
    .visible = true,
    .named = true,
  },
  [sym_kDispId] = {
    .visible = true,
    .named = true,
  },
  [sym_kClass] = {
    .visible = true,
    .named = true,
  },
  [sym_kObject] = {
    .visible = true,
    .named = true,
  },
  [sym_kRecord] = {
    .visible = true,
    .named = true,
  },
  [sym_kObjcclass] = {
    .visible = true,
    .named = true,
  },
  [sym_kObjccategory] = {
    .visible = true,
    .named = true,
  },
  [sym_kObjcprotocol] = {
    .visible = true,
    .named = true,
  },
  [sym_kArray] = {
    .visible = true,
    .named = true,
  },
  [sym_kFile] = {
    .visible = true,
    .named = true,
  },
  [sym_kString] = {
    .visible = true,
    .named = true,
  },
  [sym_kSet] = {
    .visible = true,
    .named = true,
  },
  [sym_kOf] = {
    .visible = true,
    .named = true,
  },
  [sym_kHelper] = {
    .visible = true,
    .named = true,
  },
  [sym_kPacked] = {
    .visible = true,
    .named = true,
  },
  [sym_kGeneric] = {
    .visible = true,
    .named = true,
  },
  [sym_kSpecialize] = {
    .visible = true,
    .named = true,
  },
  [sym_kLt] = {
    .visible = true,
    .named = true,
  },
  [sym_kEq] = {
    .visible = true,
    .named = true,
  },
  [sym_kNeq] = {
    .visible = true,
    .named = true,
  },
  [sym_kGt] = {
    .visible = true,
    .named = true,
  },
  [sym_kLte] = {
    .visible = true,
    .named = true,
  },
  [sym_kGte] = {
    .visible = true,
    .named = true,
  },
  [sym_kAdd] = {
    .visible = true,
    .named = true,
  },
  [sym_kSub] = {
    .visible = true,
    .named = true,
  },
  [sym_kMul] = {
    .visible = true,
    .named = true,
  },
  [sym_kFdiv] = {
    .visible = true,
    .named = true,
  },
  [sym_kAt] = {
    .visible = true,
    .named = true,
  },
  [sym_kHat] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssign] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssignAdd] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssignSub] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssignMul] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssignDiv] = {
    .visible = true,
    .named = true,
  },
  [sym_kOr] = {
    .visible = true,
    .named = true,
  },
  [sym_kXor] = {
    .visible = true,
    .named = true,
  },
  [sym_kDiv] = {
    .visible = true,
    .named = true,
  },
  [sym_kMod] = {
    .visible = true,
    .named = true,
  },
  [sym_kAnd] = {
    .visible = true,
    .named = true,
  },
  [sym_kShl] = {
    .visible = true,
    .named = true,
  },
  [sym_kShr] = {
    .visible = true,
    .named = true,
  },
  [sym_kNot] = {
    .visible = true,
    .named = true,
  },
  [sym_kIs] = {
    .visible = true,
    .named = true,
  },
  [sym_kAs] = {
    .visible = true,
    .named = true,
  },
  [sym_kIn] = {
    .visible = true,
    .named = true,
  },
  [sym_kFor] = {
    .visible = true,
    .named = true,
  },
  [sym_kTo] = {
    .visible = true,
    .named = true,
  },
  [sym_kDownto] = {
    .visible = true,
    .named = true,
  },
  [sym_kIf] = {
    .visible = true,
    .named = true,
  },
  [sym_kThen] = {
    .visible = true,
    .named = true,
  },
  [sym_kElse] = {
    .visible = true,
    .named = true,
  },
  [sym_kDo] = {
    .visible = true,
    .named = true,
  },
  [sym_kWhile] = {
    .visible = true,
    .named = true,
  },
  [sym_kRepeat] = {
    .visible = true,
    .named = true,
  },
  [sym_kUntil] = {
    .visible = true,
    .named = true,
  },
  [sym_kTry] = {
    .visible = true,
    .named = true,
  },
  [sym_kExcept] = {
    .visible = true,
    .named = true,
  },
  [sym_kFinally] = {
    .visible = true,
    .named = true,
  },
  [sym_kRaise] = {
    .visible = true,
    .named = true,
  },
  [sym_kOn] = {
    .visible = true,
    .named = true,
  },
  [sym_kCase] = {
    .visible = true,
    .named = true,
  },
  [sym_kWith] = {
    .visible = true,
    .named = true,
  },
  [sym_kGoto] = {
    .visible = true,
    .named = true,
  },
  [sym_kFunction] = {
    .visible = true,
    .named = true,
  },
  [sym_kProcedure] = {
    .visible = true,
    .named = true,
  },
  [sym_kConstructor] = {
    .visible = true,
    .named = true,
  },
  [sym_kDestructor] = {
    .visible = true,
    .named = true,
  },
  [sym_kOperator] = {
    .visible = true,
    .named = true,
  },
  [sym_kReference] = {
    .visible = true,
    .named = true,
  },
  [sym_kPublished] = {
    .visible = true,
    .named = true,
  },
  [sym_kPublic] = {
    .visible = true,
    .named = true,
  },
  [sym_kProtected] = {
    .visible = true,
    .named = true,
  },
  [sym_kPrivate] = {
    .visible = true,
    .named = true,
  },
  [sym_kStrict] = {
    .visible = true,
    .named = true,
  },
  [sym_kRequired] = {
    .visible = true,
    .named = true,
  },
  [sym_kOptional] = {
    .visible = true,
    .named = true,
  },
  [sym_kForward] = {
    .visible = true,
    .named = true,
  },
  [sym_kStatic] = {
    .visible = true,
    .named = true,
  },
  [sym_kVirtual] = {
    .visible = true,
    .named = true,
  },
  [sym_kAbstract] = {
    .visible = true,
    .named = true,
  },
  [sym_kSealed] = {
    .visible = true,
    .named = true,
  },
  [sym_kDynamic] = {
    .visible = true,
    .named = true,
  },
  [sym_kOverride] = {
    .visible = true,
    .named = true,
  },
  [sym_kOverload] = {
    .visible = true,
    .named = true,
  },
  [sym_kReintroduce] = {
    .visible = true,
    .named = true,
  },
  [sym_kInherited] = {
    .visible = true,
    .named = true,
  },
  [sym_kInline] = {
    .visible = true,
    .named = true,
  },
  [sym_kStdcall] = {
    .visible = true,
    .named = true,
  },
  [sym_kCdecl] = {
    .visible = true,
    .named = true,
  },
  [sym_kCppdecl] = {
    .visible = true,
    .named = true,
  },
  [sym_kPascal] = {
    .visible = true,
    .named = true,
  },
  [sym_kRegister] = {
    .visible = true,
    .named = true,
  },
  [sym_kMwpascal] = {
    .visible = true,
    .named = true,
  },
  [sym_kExternal] = {
    .visible = true,
    .named = true,
  },
  [sym_kName] = {
    .visible = true,
    .named = true,
  },
  [sym_kMessage] = {
    .visible = true,
    .named = true,
  },
  [sym_kDeprecated] = {
    .visible = true,
    .named = true,
  },
  [sym_kExperimental] = {
    .visible = true,
    .named = true,
  },
  [sym_kPlatform] = {
    .visible = true,
    .named = true,
  },
  [sym_kUnimplemented] = {
    .visible = true,
    .named = true,
  },
  [sym_kCvar] = {
    .visible = true,
    .named = true,
  },
  [sym_kExport] = {
    .visible = true,
    .named = true,
  },
  [sym_kFar] = {
    .visible = true,
    .named = true,
  },
  [sym_kNear] = {
    .visible = true,
    .named = true,
  },
  [sym_kSafecall] = {
    .visible = true,
    .named = true,
  },
  [sym_kAssembler] = {
    .visible = true,
    .named = true,
  },
  [sym_kNostackframe] = {
    .visible = true,
    .named = true,
  },
  [sym_kInterrupt] = {
    .visible = true,
    .named = true,
  },
  [sym_kNoreturn] = {
    .visible = true,
    .named = true,
  },
  [sym_kIocheck] = {
    .visible = true,
    .named = true,
  },
  [sym_kLocal] = {
    .visible = true,
    .named = true,
  },
  [sym_kHardfloat] = {
    .visible = true,
    .named = true,
  },
  [sym_kSoftfloat] = {
    .visible = true,
    .named = true,
  },
  [sym_kMs_abi_default] = {
    .visible = true,
    .named = true,
  },
  [sym_kMs_abi_cdecl] = {
    .visible = true,
    .named = true,
  },
  [sym_kSaveregisters] = {
    .visible = true,
    .named = true,
  },
  [sym_kSysv_abi_default] = {
    .visible = true,
    .named = true,
  },
  [sym_kSysv_abi_cdecl] = {
    .visible = true,
    .named = true,
  },
  [sym_kVectorcall] = {
    .visible = true,
    .named = true,
  },
  [sym_kVarargs] = {
    .visible = true,
    .named = true,
  },
  [sym_kWinapi] = {
    .visible = true,
    .named = true,
  },
  [sym_kAlias] = {
    .visible = true,
    .named = true,
  },
  [sym_kDelayed] = {
    .visible = true,
    .named = true,
  },
  [sym_kNil] = {
    .visible = true,
    .named = true,
  },
  [sym_kTrue] = {
    .visible = true,
    .named = true,
  },
  [sym_kFalse] = {
    .visible = true,
    .named = true,
  },
  [sym__space] = {
    .visible = false,
    .named = true,
  },
  [sym_pp] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_root] = {
    .visible = true,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_library] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_interface] = {
    .visible = true,
    .named = true,
  },
  [sym_implementation] = {
    .visible = true,
    .named = true,
  },
  [sym_initialization] = {
    .visible = true,
    .named = true,
  },
  [sym_finalization] = {
    .visible = true,
    .named = true,
  },
  [sym_moduleName] = {
    .visible = true,
    .named = true,
  },
  [sym_if] = {
    .visible = true,
    .named = true,
  },
  [sym_ifElse] = {
    .visible = true,
    .named = true,
  },
  [sym_while] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat] = {
    .visible = true,
    .named = true,
  },
  [sym_for] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach] = {
    .visible = true,
    .named = true,
  },
  [sym_exceptionHandler] = {
    .visible = true,
    .named = true,
  },
  [sym_exceptionElse] = {
    .visible = true,
    .named = true,
  },
  [sym_try] = {
    .visible = true,
    .named = true,
  },
  [sym_caseCase] = {
    .visible = true,
    .named = true,
  },
  [sym_case] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_asm] = {
    .visible = true,
    .named = true,
  },
  [sym_with] = {
    .visible = true,
    .named = true,
  },
  [sym_raise] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_ifTr] = {
    .visible = true,
    .named = true,
  },
  [sym_ifElseTr] = {
    .visible = true,
    .named = true,
  },
  [sym_whileTr] = {
    .visible = true,
    .named = true,
  },
  [sym_repeatTr] = {
    .visible = true,
    .named = true,
  },
  [sym_forTr] = {
    .visible = true,
    .named = true,
  },
  [sym_foreachTr] = {
    .visible = true,
    .named = true,
  },
  [sym_exceptionHandlerTr] = {
    .visible = true,
    .named = true,
  },
  [sym__exceptionHandlersTr] = {
    .visible = false,
    .named = true,
  },
  [sym_tryTr] = {
    .visible = true,
    .named = true,
  },
  [sym_caseCaseTr] = {
    .visible = true,
    .named = true,
  },
  [sym_caseTr] = {
    .visible = true,
    .named = true,
  },
  [sym_blockTr] = {
    .visible = true,
    .named = true,
  },
  [sym_asmTr] = {
    .visible = true,
    .named = true,
  },
  [sym_withTr] = {
    .visible = true,
    .named = true,
  },
  [sym_raiseTr] = {
    .visible = true,
    .named = true,
  },
  [sym_statementTr] = {
    .visible = true,
    .named = true,
  },
  [sym_gotoTr] = {
    .visible = true,
    .named = true,
  },
  [sym__statementTr] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_varAssignDef] = {
    .visible = true,
    .named = true,
  },
  [sym_varDef] = {
    .visible = true,
    .named = true,
  },
  [sym_label] = {
    .visible = true,
    .named = true,
  },
  [sym_caseLabel] = {
    .visible = true,
    .named = true,
  },
  [sym__statementsTr] = {
    .visible = false,
    .named = true,
  },
  [sym_statementsTr] = {
    .visible = true,
    .named = true,
  },
  [sym_asmBody] = {
    .visible = true,
    .named = true,
  },
  [sym__expr] = {
    .visible = false,
    .named = true,
  },
  [sym__ref] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_inherited] = {
    .visible = true,
    .named = true,
  },
  [sym_exprDot] = {
    .visible = true,
    .named = true,
  },
  [sym_exprDeref] = {
    .visible = true,
    .named = true,
  },
  [sym_exprAs] = {
    .visible = true,
    .named = true,
  },
  [sym_exprTpl] = {
    .visible = true,
    .named = true,
  },
  [sym_exprSubscript] = {
    .visible = true,
    .named = true,
  },
  [sym_exprCall] = {
    .visible = true,
    .named = true,
  },
  [sym_legacyFormat] = {
    .visible = true,
    .named = true,
  },
  [sym_exprArgs] = {
    .visible = true,
    .named = true,
  },
  [sym_exprBinary] = {
    .visible = true,
    .named = true,
  },
  [sym_exprUnary] = {
    .visible = true,
    .named = true,
  },
  [sym_exprParens] = {
    .visible = true,
    .named = true,
  },
  [sym_exprBrackets] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_typeref] = {
    .visible = true,
    .named = true,
  },
  [sym__typeref] = {
    .visible = false,
    .named = true,
  },
  [sym_typerefDot] = {
    .visible = true,
    .named = true,
  },
  [sym_typerefTpl] = {
    .visible = true,
    .named = true,
  },
  [sym_typerefPtr] = {
    .visible = true,
    .named = true,
  },
  [sym_typerefArgs] = {
    .visible = true,
    .named = true,
  },
  [sym_genericDot] = {
    .visible = true,
    .named = true,
  },
  [sym_genericTpl] = {
    .visible = true,
    .named = true,
  },
  [sym__genericName] = {
    .visible = false,
    .named = true,
  },
  [sym_genericArgs] = {
    .visible = true,
    .named = true,
  },
  [sym_genericArg] = {
    .visible = true,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym_literalString] = {
    .visible = true,
    .named = true,
  },
  [sym__literalString] = {
    .visible = false,
    .named = true,
  },
  [sym_literalChar] = {
    .visible = true,
    .named = true,
  },
  [sym_literalNumber] = {
    .visible = true,
    .named = true,
  },
  [sym__literalInt] = {
    .visible = false,
    .named = true,
  },
  [sym__literalFloat] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__definitions] = {
    .visible = false,
    .named = false,
  },
  [sym__definition] = {
    .visible = false,
    .named = true,
  },
  [sym_defProc] = {
    .visible = true,
    .named = true,
  },
  [sym_declProcFwd] = {
    .visible = true,
    .named = true,
  },
  [sym__visibility] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__declarations] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__classDeclarations] = {
    .visible = false,
    .named = false,
  },
  [sym_defaultValue] = {
    .visible = true,
    .named = true,
  },
  [sym_declUses] = {
    .visible = true,
    .named = true,
  },
  [sym_declExports] = {
    .visible = true,
    .named = true,
  },
  [sym_declTypes] = {
    .visible = true,
    .named = true,
  },
  [sym_declVars] = {
    .visible = true,
    .named = true,
  },
  [sym_declConsts] = {
    .visible = true,
    .named = true,
  },
  [sym_declType] = {
    .visible = true,
    .named = true,
  },
  [sym_declProc] = {
    .visible = true,
    .named = true,
  },
  [sym_declVar] = {
    .visible = true,
    .named = true,
  },
  [sym_declConst] = {
    .visible = true,
    .named = true,
  },
  [sym_declLabels] = {
    .visible = true,
    .named = true,
  },
  [sym_declLabel] = {
    .visible = true,
    .named = true,
  },
  [sym_declExport] = {
    .visible = true,
    .named = true,
  },
  [sym_declEnum] = {
    .visible = true,
    .named = true,
  },
  [sym_declEnumValue] = {
    .visible = true,
    .named = true,
  },
  [sym_declSet] = {
    .visible = true,
    .named = true,
  },
  [sym_declArray] = {
    .visible = true,
    .named = true,
  },
  [sym_declFile] = {
    .visible = true,
    .named = true,
  },
  [sym_declString] = {
    .visible = true,
    .named = true,
  },
  [sym_declProcRef] = {
    .visible = true,
    .named = true,
  },
  [sym_declMetaClass] = {
    .visible = true,
    .named = true,
  },
  [sym_declClass] = {
    .visible = true,
    .named = true,
  },
  [sym_declIntf] = {
    .visible = true,
    .named = true,
  },
  [sym_declHelper] = {
    .visible = true,
    .named = true,
  },
  [sym_guid] = {
    .visible = true,
    .named = true,
  },
  [sym__declClass] = {
    .visible = false,
    .named = true,
  },
  [sym_declSection] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__declFields] = {
    .visible = false,
    .named = false,
  },
  [sym_declField] = {
    .visible = true,
    .named = true,
  },
  [sym_declProp] = {
    .visible = true,
    .named = true,
  },
  [sym_declPropArgs] = {
    .visible = true,
    .named = true,
  },
  [sym_declVariant] = {
    .visible = true,
    .named = true,
  },
  [sym_declVariantClause] = {
    .visible = true,
    .named = true,
  },
  [sym_declVariantField] = {
    .visible = true,
    .named = true,
  },
  [sym__declProc] = {
    .visible = false,
    .named = true,
  },
  [sym__declOperator] = {
    .visible = false,
    .named = true,
  },
  [sym_operatorDot] = {
    .visible = true,
    .named = true,
  },
  [sym__operatorName] = {
    .visible = false,
    .named = true,
  },
  [sym_operatorName] = {
    .visible = true,
    .named = true,
  },
  [sym_declArgs] = {
    .visible = true,
    .named = true,
  },
  [sym_declArg] = {
    .visible = true,
    .named = true,
  },
  [sym__procAttribute] = {
    .visible = false,
    .named = true,
  },
  [sym__procAttributeNoExt] = {
    .visible = false,
    .named = true,
  },
  [sym_procAttribute] = {
    .visible = true,
    .named = true,
  },
  [sym_rttiAttributes] = {
    .visible = true,
    .named = true,
  },
  [sym_procExternal] = {
    .visible = true,
    .named = true,
  },
  [sym__initializer] = {
    .visible = false,
    .named = true,
  },
  [sym_recInitializer] = {
    .visible = true,
    .named = true,
  },
  [sym_recInitializerField] = {
    .visible = true,
    .named = true,
  },
  [sym_arrInitializer] = {
    .visible = true,
    .named = true,
  },
  [sym_kEndDot] = {
    .visible = true,
    .named = true,
  },
  [sym_kDot] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_moduleName_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_exceptionElse_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_with_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__exceptionHandlersTr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_caseLabel_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__statementsTr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_asmBody_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_exprTpl_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_legacyFormat_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_exprArgs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_typerefArgs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_genericArgs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_genericArg_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_literalString_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_defProc_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declProcFwd_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declUses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declExports_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declTypes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declVars_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declConsts_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declVar_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declLabels_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declExport_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declEnum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declArray_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declClass_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__declClass_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declProp_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declProp_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declPropArgs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declVariant_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declVariantClause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__declProc_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__procAttribute_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__procAttributeNoExt_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rttiAttributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rttiAttributes_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_recInitializer_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arrInitializer_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field__dummy = 1,
  field_args = 2,
  field_assign = 3,
  field_attribute = 4,
  field_body = 5,
  field_condition = 6,
  field_defaultValue = 7,
  field_dispid = 8,
  field_else = 9,
  field_end = 10,
  field_entity = 11,
  field_except = 12,
  field_exception = 13,
  field_finally = 14,
  field_getter = 15,
  field_guid = 16,
  field_header = 17,
  field_implements = 18,
  field_index = 19,
  field_iterable = 20,
  field_iterator = 21,
  field_label = 22,
  field_lhs = 23,
  field_local = 24,
  field_name = 25,
  field_operand = 26,
  field_operator = 27,
  field_parent = 28,
  field_resultName = 29,
  field_rhs = 30,
  field_setter = 31,
  field_start = 32,
  field_stored = 33,
  field_then = 34,
  field_try = 35,
  field_type = 36,
  field_value = 37,
  field_variable = 38,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field__dummy] = "_dummy",
  [field_args] = "args",
  [field_assign] = "assign",
  [field_attribute] = "attribute",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_defaultValue] = "defaultValue",
  [field_dispid] = "dispid",
  [field_else] = "else",
  [field_end] = "end",
  [field_entity] = "entity",
  [field_except] = "except",
  [field_exception] = "exception",
  [field_finally] = "finally",
  [field_getter] = "getter",
  [field_guid] = "guid",
  [field_header] = "header",
  [field_implements] = "implements",
  [field_index] = "index",
  [field_iterable] = "iterable",
  [field_iterator] = "iterator",
  [field_label] = "label",
  [field_lhs] = "lhs",
  [field_local] = "local",
  [field_name] = "name",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_parent] = "parent",
  [field_resultName] = "resultName",
  [field_rhs] = "rhs",
  [field_setter] = "setter",
  [field_start] = "start",
  [field_stored] = "stored",
  [field_then] = "then",
  [field_try] = "try",
  [field_type] = "type",
  [field_value] = "value",
  [field_variable] = "variable",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 5},
  [2] = {.index = 5, .length = 6},
  [6] = {.index = 11, .length = 1},
  [7] = {.index = 12, .length = 5},
  [8] = {.index = 17, .length = 6},
  [9] = {.index = 23, .length = 2},
  [10] = {.index = 25, .length = 1},
  [11] = {.index = 25, .length = 1},
  [12] = {.index = 26, .length = 2},
  [13] = {.index = 28, .length = 1},
  [14] = {.index = 29, .length = 1},
  [15] = {.index = 30, .length = 2},
  [16] = {.index = 30, .length = 2},
  [17] = {.index = 32, .length = 1},
  [18] = {.index = 33, .length = 6},
  [19] = {.index = 39, .length = 2},
  [20] = {.index = 39, .length = 2},
  [21] = {.index = 41, .length = 2},
  [22] = {.index = 41, .length = 2},
  [23] = {.index = 43, .length = 3},
  [24] = {.index = 46, .length = 1},
  [25] = {.index = 47, .length = 1},
  [26] = {.index = 48, .length = 1},
  [27] = {.index = 49, .length = 1},
  [28] = {.index = 50, .length = 1},
  [29] = {.index = 51, .length = 1},
  [30] = {.index = 52, .length = 2},
  [31] = {.index = 54, .length = 2},
  [32] = {.index = 56, .length = 1},
  [33] = {.index = 57, .length = 2},
  [34] = {.index = 59, .length = 2},
  [35] = {.index = 61, .length = 2},
  [36] = {.index = 63, .length = 3},
  [37] = {.index = 63, .length = 3},
  [38] = {.index = 66, .length = 6},
  [39] = {.index = 72, .length = 2},
  [40] = {.index = 74, .length = 1},
  [41] = {.index = 75, .length = 2},
  [42] = {.index = 77, .length = 1},
  [43] = {.index = 78, .length = 2},
  [44] = {.index = 78, .length = 2},
  [45] = {.index = 80, .length = 3},
  [46] = {.index = 80, .length = 3},
  [47] = {.index = 83, .length = 2},
  [49] = {.index = 85, .length = 1},
  [50] = {.index = 86, .length = 2},
  [51] = {.index = 88, .length = 2},
  [52] = {.index = 90, .length = 2},
  [53] = {.index = 92, .length = 2},
  [54] = {.index = 94, .length = 2},
  [55] = {.index = 96, .length = 2},
  [56] = {.index = 98, .length = 2},
  [57] = {.index = 100, .length = 1},
  [58] = {.index = 101, .length = 2},
  [59] = {.index = 103, .length = 2},
  [60] = {.index = 105, .length = 1},
  [61] = {.index = 106, .length = 2},
  [62] = {.index = 108, .length = 1},
  [63] = {.index = 109, .length = 3},
  [64] = {.index = 112, .length = 2},
  [65] = {.index = 114, .length = 2},
  [66] = {.index = 116, .length = 1},
  [67] = {.index = 117, .length = 2},
  [68] = {.index = 119, .length = 2},
  [69] = {.index = 121, .length = 2},
  [70] = {.index = 123, .length = 1},
  [71] = {.index = 124, .length = 2},
  [72] = {.index = 126, .length = 3},
  [73] = {.index = 129, .length = 3},
  [74] = {.index = 132, .length = 3},
  [75] = {.index = 135, .length = 2},
  [76] = {.index = 135, .length = 2},
  [77] = {.index = 137, .length = 3},
  [78] = {.index = 137, .length = 3},
  [79] = {.index = 140, .length = 2},
  [80] = {.index = 142, .length = 3},
  [81] = {.index = 142, .length = 3},
  [82] = {.index = 145, .length = 3},
  [84] = {.index = 148, .length = 2},
  [85] = {.index = 150, .length = 2},
  [86] = {.index = 152, .length = 2},
  [87] = {.index = 154, .length = 3},
  [88] = {.index = 157, .length = 3},
  [89] = {.index = 160, .length = 2},
  [90] = {.index = 162, .length = 3},
  [91] = {.index = 165, .length = 2},
  [92] = {.index = 167, .length = 1},
  [93] = {.index = 168, .length = 3},
  [94] = {.index = 171, .length = 3},
  [95] = {.index = 174, .length = 3},
  [96] = {.index = 177, .length = 3},
  [97] = {.index = 180, .length = 3},
  [98] = {.index = 183, .length = 3},
  [99] = {.index = 186, .length = 2},
  [100] = {.index = 188, .length = 3},
  [101] = {.index = 191, .length = 1},
  [102] = {.index = 192, .length = 2},
  [103] = {.index = 194, .length = 3},
  [104] = {.index = 197, .length = 3},
  [105] = {.index = 200, .length = 3},
  [106] = {.index = 203, .length = 2},
  [107] = {.index = 205, .length = 2},
  [108] = {.index = 207, .length = 2},
  [109] = {.index = 209, .length = 3},
  [110] = {.index = 212, .length = 3},
  [111] = {.index = 215, .length = 3},
  [112] = {.index = 218, .length = 4},
  [113] = {.index = 222, .length = 3},
  [114] = {.index = 225, .length = 4},
  [115] = {.index = 229, .length = 4},
  [116] = {.index = 225, .length = 4},
  [117] = {.index = 233, .length = 3},
  [118] = {.index = 233, .length = 3},
  [119] = {.index = 236, .length = 1},
  [120] = {.index = 237, .length = 4},
  [121] = {.index = 237, .length = 4},
  [122] = {.index = 241, .length = 3},
  [123] = {.index = 244, .length = 3},
  [124] = {.index = 247, .length = 3},
  [125] = {.index = 250, .length = 2},
  [126] = {.index = 252, .length = 2},
  [127] = {.index = 254, .length = 1},
  [128] = {.index = 255, .length = 4},
  [129] = {.index = 259, .length = 3},
  [130] = {.index = 262, .length = 3},
  [131] = {.index = 265, .length = 4},
  [132] = {.index = 269, .length = 4},
  [133] = {.index = 273, .length = 2},
  [134] = {.index = 275, .length = 3},
  [135] = {.index = 278, .length = 4},
  [136] = {.index = 282, .length = 4},
  [137] = {.index = 286, .length = 3},
  [138] = {.index = 289, .length = 3},
  [139] = {.index = 292, .length = 4},
  [140] = {.index = 296, .length = 2},
  [141] = {.index = 298, .length = 3},
  [142] = {.index = 301, .length = 3},
  [143] = {.index = 304, .length = 3},
  [144] = {.index = 307, .length = 4},
  [145] = {.index = 311, .length = 3},
  [146] = {.index = 314, .length = 2},
  [147] = {.index = 316, .length = 3},
  [148] = {.index = 319, .length = 3},
  [149] = {.index = 322, .length = 3},
  [150] = {.index = 325, .length = 4},
  [151] = {.index = 329, .length = 4},
  [152] = {.index = 333, .length = 4},
  [153] = {.index = 337, .length = 4},
  [154] = {.index = 341, .length = 4},
  [155] = {.index = 345, .length = 4},
  [156] = {.index = 349, .length = 5},
  [157] = {.index = 349, .length = 5},
  [158] = {.index = 354, .length = 2},
  [159] = {.index = 356, .length = 3},
  [160] = {.index = 359, .length = 1},
  [161] = {.index = 360, .length = 3},
  [162] = {.index = 363, .length = 4},
  [163] = {.index = 367, .length = 4},
  [164] = {.index = 371, .length = 4},
  [165] = {.index = 375, .length = 5},
  [166] = {.index = 380, .length = 4},
  [167] = {.index = 384, .length = 5},
  [168] = {.index = 389, .length = 4},
  [169] = {.index = 393, .length = 4},
  [170] = {.index = 397, .length = 1},
  [171] = {.index = 398, .length = 3},
  [172] = {.index = 401, .length = 3},
  [173] = {.index = 404, .length = 2},
  [174] = {.index = 406, .length = 3},
  [175] = {.index = 409, .length = 4},
  [176] = {.index = 413, .length = 4},
  [177] = {.index = 417, .length = 4},
  [178] = {.index = 421, .length = 4},
  [179] = {.index = 425, .length = 4},
  [180] = {.index = 429, .length = 4},
  [181] = {.index = 433, .length = 3},
  [182] = {.index = 436, .length = 3},
  [183] = {.index = 439, .length = 3},
  [184] = {.index = 442, .length = 4},
  [185] = {.index = 446, .length = 5},
  [186] = {.index = 451, .length = 5},
  [187] = {.index = 456, .length = 5},
  [188] = {.index = 461, .length = 5},
  [189] = {.index = 466, .length = 4},
  [190] = {.index = 470, .length = 2},
  [191] = {.index = 472, .length = 3},
  [192] = {.index = 475, .length = 5},
  [193] = {.index = 480, .length = 4},
  [194] = {.index = 484, .length = 5},
  [195] = {.index = 489, .length = 4},
  [196] = {.index = 493, .length = 2},
  [197] = {.index = 495, .length = 4},
  [198] = {.index = 499, .length = 3},
  [199] = {.index = 502, .length = 4},
  [200] = {.index = 506, .length = 5},
  [201] = {.index = 511, .length = 5},
  [202] = {.index = 516, .length = 5},
  [203] = {.index = 521, .length = 5},
  [204] = {.index = 526, .length = 4},
  [205] = {.index = 530, .length = 4},
  [206] = {.index = 534, .length = 4},
  [207] = {.index = 538, .length = 6},
  [208] = {.index = 544, .length = 1},
  [209] = {.index = 545, .length = 1},
  [210] = {.index = 546, .length = 1},
  [211] = {.index = 547, .length = 1},
  [212] = {.index = 548, .length = 1},
  [213] = {.index = 549, .length = 1},
  [214] = {.index = 550, .length = 1},
  [215] = {.index = 551, .length = 9},
  [216] = {.index = 560, .length = 14},
  [217] = {.index = 574, .length = 4},
  [218] = {.index = 578, .length = 3},
  [219] = {.index = 581, .length = 3},
  [220] = {.index = 584, .length = 5},
  [221] = {.index = 589, .length = 4},
  [222] = {.index = 593, .length = 2},
  [223] = {.index = 595, .length = 6},
  [224] = {.index = 601, .length = 5},
  [225] = {.index = 606, .length = 2},
  [226] = {.index = 608, .length = 10},
  [227] = {.index = 618, .length = 10},
  [228] = {.index = 628, .length = 9},
  [229] = {.index = 637, .length = 4},
  [230] = {.index = 641, .length = 3},
  [231] = {.index = 644, .length = 11},
  [232] = {.index = 655, .length = 10},
  [233] = {.index = 665, .length = 10},
  [234] = {.index = 675, .length = 9},
  [235] = {.index = 684, .length = 4},
  [236] = {.index = 688, .length = 11},
  [237] = {.index = 699, .length = 10},
  [238] = {.index = 709, .length = 10},
  [239] = {.index = 719, .length = 11},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_args, 0, .inherited = true},
    {field_assign, 0, .inherited = true},
    {field_attribute, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type, 0, .inherited = true},
  [5] =
    {field_args, 0, .inherited = true},
    {field_assign, 0, .inherited = true},
    {field_attribute, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_resultName, 0, .inherited = true},
    {field_type, 0, .inherited = true},
  [11] =
    {field_name, 0},
  [12] =
    {field_args, 1, .inherited = true},
    {field_assign, 1, .inherited = true},
    {field_attribute, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 1, .inherited = true},
  [17] =
    {field_args, 1, .inherited = true},
    {field_assign, 1, .inherited = true},
    {field_attribute, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_resultName, 1, .inherited = true},
    {field_type, 1, .inherited = true},
  [23] =
    {field_operand, 1},
    {field_operator, 0},
  [25] =
    {field_body, 1},
  [26] =
    {field_operand, 0},
    {field_operator, 1},
  [28] =
    {field_exception, 1},
  [29] =
    {field_name, 1},
  [30] =
    {field_body, 1},
    {field_header, 0},
  [32] =
    {field_attribute, 0, .inherited = true},
  [33] =
    {field_args, 0, .inherited = true},
    {field_assign, 0, .inherited = true},
    {field_attribute, 0, .inherited = true},
    {field_attribute, 2, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type, 0, .inherited = true},
  [39] =
    {field_body, 2},
    {field_local, 1},
  [41] =
    {field_args, 1},
    {field_body, 2},
  [43] =
    {field_lhs, 0},
    {field_operator, 1},
    {field_rhs, 2},
  [46] =
    {field_entity, 0},
  [47] =
    {field_condition, 1},
  [48] =
    {field_condition, 2},
  [49] =
    {field_except, 1},
  [50] =
    {field_finally, 1},
  [51] =
    {field_entity, 1},
  [52] =
    {field_entity, 0, .inherited = true},
    {field_entity, 1, .inherited = true},
  [54] =
    {field_defaultValue, 1},
    {field_name, 0},
  [56] =
    {field_name, 2},
  [57] =
    {field_attribute, 3, .inherited = true},
    {field_name, 1},
  [59] =
    {field_assign, 2},
    {field_name, 1},
  [61] =
    {field_args, 2},
    {field_name, 1},
  [63] =
    {field_body, 2},
    {field_header, 0},
    {field_local, 1},
  [66] =
    {field_args, 0, .inherited = true},
    {field_assign, 0, .inherited = true},
    {field_attribute, 0, .inherited = true},
    {field_attribute, 3, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type, 0, .inherited = true},
  [72] =
    {field_dispid, 0},
    {field_dispid, 1},
  [74] =
    {field_attribute, 0},
  [75] =
    {field_attribute, 0, .inherited = true},
    {field_attribute, 1, .inherited = true},
  [77] =
    {field__dummy, 0},
  [78] =
    {field_body, 3},
    {field_type, 2},
  [80] =
    {field_args, 1},
    {field_body, 3},
    {field_local, 2},
  [83] =
    {field_args, 2},
    {field_entity, 0},
  [85] =
    {field_type, 3},
  [86] =
    {field_condition, 1},
    {field_then, 3},
  [88] =
    {field_body, 3},
    {field_condition, 1},
  [90] =
    {field_body, 1},
    {field_condition, 3},
  [92] =
    {field_except, 1},
    {field_except, 2},
  [94] =
    {field_finally, 1},
    {field_finally, 2},
  [96] =
    {field_except, 2},
    {field_try, 1},
  [98] =
    {field_finally, 2},
    {field_try, 1},
  [100] =
    {field_label, 0},
  [101] =
    {field_body, 3},
    {field_entity, 1},
  [103] =
    {field_entity, 1, .inherited = true},
    {field_entity, 2},
  [105] =
    {field_args, 1},
  [106] =
    {field_name, 0},
    {field_type, 2},
  [108] =
    {field_value, 0},
  [109] =
    {field_attribute, 3, .inherited = true},
    {field_defaultValue, 1},
    {field_name, 0},
  [112] =
    {field_defaultValue, 2},
    {field_name, 1},
  [114] =
    {field_name, 0},
    {field_name, 1},
  [116] =
    {field_guid, 1},
  [117] =
    {field_attribute, 4, .inherited = true},
    {field_name, 2},
  [119] =
    {field_assign, 3},
    {field_name, 2},
  [121] =
    {field_args, 3},
    {field_name, 2},
  [123] =
    {field_name, 3},
  [124] =
    {field_name, 1},
    {field_type, 3},
  [126] =
    {field_assign, 2},
    {field_attribute, 4, .inherited = true},
    {field_name, 1},
  [129] =
    {field_args, 2},
    {field_attribute, 4, .inherited = true},
    {field_name, 1},
  [132] =
    {field_args, 2},
    {field_assign, 3},
    {field_name, 1},
  [135] =
    {field_body, 2},
    {field_header, 0},
  [137] =
    {field_body, 4},
    {field_local, 3},
    {field_type, 2},
  [140] =
    {field_name, 1},
    {field_name, 2},
  [142] =
    {field_args, 1},
    {field_body, 4},
    {field_type, 3},
  [145] =
    {field_args, 2},
    {field_args, 3},
    {field_entity, 0},
  [148] =
    {field_end, 3},
    {field_start, 1},
  [150] =
    {field_iterable, 3},
    {field_iterator, 1},
  [152] =
    {field_condition, 1},
    {field_else, 4},
  [154] =
    {field_except, 2},
    {field_except, 3},
    {field_try, 1},
  [157] =
    {field_finally, 2},
    {field_finally, 3},
    {field_try, 1},
  [160] =
    {field_body, 1},
    {field_label, 0},
  [162] =
    {field_body, 4},
    {field_entity, 1, .inherited = true},
    {field_entity, 2},
  [165] =
    {field_name, 0},
    {field_value, 1},
  [167] =
    {field_type, 2},
  [168] =
    {field_attribute, 4, .inherited = true},
    {field_name, 0},
    {field_type, 2},
  [171] =
    {field_defaultValue, 3},
    {field_name, 0},
    {field_type, 2},
  [174] =
    {field_name, 0},
    {field_name, 1},
    {field_type, 3},
  [177] =
    {field_attribute, 4, .inherited = true},
    {field_defaultValue, 2},
    {field_name, 1},
  [180] =
    {field_name, 0},
    {field_type, 1},
    {field_type, 2},
  [183] =
    {field_defaultValue, 2},
    {field_name, 0},
    {field_name, 1},
  [186] =
    {field_parent, 1},
    {field_parent, 2},
  [188] =
    {field_name, 0},
    {field_type, 2},
    {field_type, 3},
  [191] =
    {field_guid, 2},
  [192] =
    {field_name, 2},
    {field_type, 4},
  [194] =
    {field_assign, 3},
    {field_attribute, 5, .inherited = true},
    {field_name, 2},
  [197] =
    {field_args, 3},
    {field_attribute, 5, .inherited = true},
    {field_name, 2},
  [200] =
    {field_args, 3},
    {field_assign, 4},
    {field_name, 2},
  [203] =
    {field_attribute, 5, .inherited = true},
    {field_name, 3},
  [205] =
    {field_assign, 4},
    {field_name, 3},
  [207] =
    {field_args, 4},
    {field_name, 3},
  [209] =
    {field_attribute, 5, .inherited = true},
    {field_name, 1},
    {field_type, 3},
  [212] =
    {field_assign, 4},
    {field_name, 1},
    {field_type, 3},
  [215] =
    {field_args, 2},
    {field_name, 1},
    {field_type, 4},
  [218] =
    {field_args, 2},
    {field_assign, 3},
    {field_attribute, 5, .inherited = true},
    {field_name, 1},
  [222] =
    {field_name, 1},
    {field_resultName, 2},
    {field_type, 4},
  [225] =
    {field_body, 2},
    {field_body, 4, .inherited = true},
    {field_header, 0},
    {field_local, 4, .inherited = true},
  [229] =
    {field_body, 0, .inherited = true},
    {field_body, 1, .inherited = true},
    {field_local, 0, .inherited = true},
    {field_local, 1, .inherited = true},
  [233] =
    {field_body, 3},
    {field_header, 0},
    {field_local, 2},
  [236] =
    {field_attribute, 1},
  [237] =
    {field_args, 1},
    {field_body, 5},
    {field_local, 4},
    {field_type, 3},
  [241] =
    {field_body, 5},
    {field_end, 3},
    {field_start, 1},
  [244] =
    {field_body, 5},
    {field_iterable, 3},
    {field_iterator, 1},
  [247] =
    {field_condition, 1},
    {field_else, 5},
    {field_then, 3},
  [250] =
    {field_body, 3},
    {field_exception, 1},
  [252] =
    {field_args, 1},
    {field_type, 3},
  [254] =
    {field_args, 3},
  [255] =
    {field_attribute, 5, .inherited = true},
    {field_defaultValue, 3},
    {field_name, 0},
    {field_type, 2},
  [259] =
    {field_defaultValue, 4},
    {field_name, 1},
    {field_type, 3},
  [262] =
    {field_name, 1},
    {field_name, 2},
    {field_type, 4},
  [265] =
    {field_attribute, 5, .inherited = true},
    {field_name, 0},
    {field_name, 1},
    {field_type, 3},
  [269] =
    {field_defaultValue, 4},
    {field_name, 0},
    {field_name, 1},
    {field_type, 3},
  [273] =
    {field_name, 0},
    {field_value, 2},
  [275] =
    {field_name, 1},
    {field_type, 3},
    {field_type, 4},
  [278] =
    {field_defaultValue, 3},
    {field_name, 0},
    {field_type, 1},
    {field_type, 2},
  [282] =
    {field_name, 0},
    {field_name, 1},
    {field_type, 2},
    {field_type, 3},
  [286] =
    {field_guid, 3},
    {field_parent, 1},
    {field_parent, 2},
  [289] =
    {field_parent, 1},
    {field_parent, 2},
    {field_parent, 3},
  [292] =
    {field_attribute, 5, .inherited = true},
    {field_name, 0},
    {field_type, 2},
    {field_type, 3},
  [296] =
    {field_parent, 2},
    {field_parent, 3},
  [298] =
    {field_attribute, 6, .inherited = true},
    {field_name, 2},
    {field_type, 4},
  [301] =
    {field_assign, 5},
    {field_name, 2},
    {field_type, 4},
  [304] =
    {field_args, 3},
    {field_name, 2},
    {field_type, 5},
  [307] =
    {field_args, 3},
    {field_assign, 4},
    {field_attribute, 6, .inherited = true},
    {field_name, 2},
  [311] =
    {field_name, 2},
    {field_resultName, 3},
    {field_type, 5},
  [314] =
    {field_name, 3},
    {field_type, 5},
  [316] =
    {field_assign, 4},
    {field_attribute, 6, .inherited = true},
    {field_name, 3},
  [319] =
    {field_args, 4},
    {field_attribute, 6, .inherited = true},
    {field_name, 3},
  [322] =
    {field_args, 4},
    {field_assign, 5},
    {field_name, 3},
  [325] =
    {field_assign, 4},
    {field_attribute, 6, .inherited = true},
    {field_name, 1},
    {field_type, 3},
  [329] =
    {field_args, 2},
    {field_attribute, 6, .inherited = true},
    {field_name, 1},
    {field_type, 4},
  [333] =
    {field_args, 2},
    {field_assign, 5},
    {field_name, 1},
    {field_type, 4},
  [337] =
    {field_attribute, 6, .inherited = true},
    {field_name, 1},
    {field_resultName, 2},
    {field_type, 4},
  [341] =
    {field_assign, 5},
    {field_name, 1},
    {field_resultName, 2},
    {field_type, 4},
  [345] =
    {field_args, 2},
    {field_name, 1},
    {field_resultName, 3},
    {field_type, 5},
  [349] =
    {field_body, 3},
    {field_body, 5, .inherited = true},
    {field_header, 0},
    {field_local, 2},
    {field_local, 5, .inherited = true},
  [354] =
    {field_attribute, 1, .inherited = true},
    {field_attribute, 2},
  [356] =
    {field_exception, 3},
    {field_variable, 1},
    {field_variable, 2},
  [359] =
    {field_type, 4},
  [360] =
    {field_attribute, 6, .inherited = true},
    {field_name, 0},
    {field_type, 2},
  [363] =
    {field_attribute, 6, .inherited = true},
    {field_defaultValue, 4},
    {field_name, 1},
    {field_type, 3},
  [367] =
    {field_attribute, 6, .inherited = true},
    {field_name, 1},
    {field_name, 2},
    {field_type, 4},
  [371] =
    {field_defaultValue, 5},
    {field_name, 1},
    {field_name, 2},
    {field_type, 4},
  [375] =
    {field_attribute, 6, .inherited = true},
    {field_defaultValue, 4},
    {field_name, 0},
    {field_name, 1},
    {field_type, 3},
  [380] =
    {field_attribute, 6, .inherited = true},
    {field_name, 1},
    {field_type, 3},
    {field_type, 4},
  [384] =
    {field_defaultValue, 4},
    {field_name, 0},
    {field_name, 1},
    {field_type, 2},
    {field_type, 3},
  [389] =
    {field_guid, 4},
    {field_parent, 1},
    {field_parent, 2},
    {field_parent, 3},
  [393] =
    {field_parent, 1},
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
  [397] =
    {field_type, 1},
  [398] =
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
  [401] =
    {field_guid, 4},
    {field_parent, 2},
    {field_parent, 3},
  [404] =
    {field_parent, 3},
    {field_parent, 4},
  [406] =
    {field_name, 2},
    {field_type, 4},
    {field_type, 5},
  [409] =
    {field_assign, 5},
    {field_attribute, 7, .inherited = true},
    {field_name, 2},
    {field_type, 4},
  [413] =
    {field_args, 3},
    {field_attribute, 7, .inherited = true},
    {field_name, 2},
    {field_type, 5},
  [417] =
    {field_args, 3},
    {field_assign, 6},
    {field_name, 2},
    {field_type, 5},
  [421] =
    {field_attribute, 7, .inherited = true},
    {field_name, 2},
    {field_resultName, 3},
    {field_type, 5},
  [425] =
    {field_assign, 6},
    {field_name, 2},
    {field_resultName, 3},
    {field_type, 5},
  [429] =
    {field_args, 3},
    {field_name, 2},
    {field_resultName, 4},
    {field_type, 6},
  [433] =
    {field_attribute, 7, .inherited = true},
    {field_name, 3},
    {field_type, 5},
  [436] =
    {field_assign, 6},
    {field_name, 3},
    {field_type, 5},
  [439] =
    {field_args, 4},
    {field_name, 3},
    {field_type, 6},
  [442] =
    {field_args, 4},
    {field_assign, 5},
    {field_attribute, 7, .inherited = true},
    {field_name, 3},
  [446] =
    {field_args, 2},
    {field_assign, 5},
    {field_attribute, 7, .inherited = true},
    {field_name, 1},
    {field_type, 4},
  [451] =
    {field_assign, 5},
    {field_attribute, 7, .inherited = true},
    {field_name, 1},
    {field_resultName, 2},
    {field_type, 4},
  [456] =
    {field_args, 2},
    {field_attribute, 7, .inherited = true},
    {field_name, 1},
    {field_resultName, 3},
    {field_type, 5},
  [461] =
    {field_args, 2},
    {field_assign, 6},
    {field_name, 1},
    {field_resultName, 3},
    {field_type, 5},
  [466] =
    {field_body, 5},
    {field_exception, 3},
    {field_variable, 1},
    {field_variable, 2},
  [470] =
    {field_args, 3},
    {field_type, 5},
  [472] =
    {field_attribute, 7, .inherited = true},
    {field_name, 1},
    {field_type, 3},
  [475] =
    {field_attribute, 7, .inherited = true},
    {field_defaultValue, 5},
    {field_name, 1},
    {field_name, 2},
    {field_type, 4},
  [480] =
    {field_attribute, 7, .inherited = true},
    {field_name, 0},
    {field_name, 1},
    {field_type, 3},
  [484] =
    {field_guid, 5},
    {field_parent, 1},
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
  [489] =
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
    {field_parent, 5},
  [493] =
    {field_parent, 4},
    {field_parent, 5},
  [495] =
    {field_guid, 5},
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
  [499] =
    {field_parent, 3},
    {field_parent, 4},
    {field_parent, 5},
  [502] =
    {field_attribute, 7, .inherited = true},
    {field_name, 2},
    {field_type, 4},
    {field_type, 5},
  [506] =
    {field_args, 3},
    {field_assign, 6},
    {field_attribute, 8, .inherited = true},
    {field_name, 2},
    {field_type, 5},
  [511] =
    {field_assign, 6},
    {field_attribute, 8, .inherited = true},
    {field_name, 2},
    {field_resultName, 3},
    {field_type, 5},
  [516] =
    {field_args, 3},
    {field_attribute, 8, .inherited = true},
    {field_name, 2},
    {field_resultName, 4},
    {field_type, 6},
  [521] =
    {field_args, 3},
    {field_assign, 7},
    {field_name, 2},
    {field_resultName, 4},
    {field_type, 6},
  [526] =
    {field_assign, 6},
    {field_attribute, 8, .inherited = true},
    {field_name, 3},
    {field_type, 5},
  [530] =
    {field_args, 4},
    {field_attribute, 8, .inherited = true},
    {field_name, 3},
    {field_type, 6},
  [534] =
    {field_args, 4},
    {field_assign, 7},
    {field_name, 3},
    {field_type, 6},
  [538] =
    {field_args, 2},
    {field_assign, 6},
    {field_attribute, 8, .inherited = true},
    {field_name, 1},
    {field_resultName, 3},
    {field_type, 5},
  [544] =
    {field_getter, 1},
  [545] =
    {field_setter, 1},
  [546] =
    {field_implements, 1},
  [547] =
    {field_defaultValue, 1},
  [548] =
    {field_stored, 1},
  [549] =
    {field_index, 1},
  [550] =
    {field_dispid, 1},
  [551] =
    {field_defaultValue, 4, .inherited = true},
    {field_dispid, 4, .inherited = true},
    {field_getter, 4, .inherited = true},
    {field_implements, 4, .inherited = true},
    {field_index, 4, .inherited = true},
    {field_name, 1},
    {field_setter, 4, .inherited = true},
    {field_stored, 4, .inherited = true},
    {field_type, 3},
  [560] =
    {field_defaultValue, 0, .inherited = true},
    {field_defaultValue, 1, .inherited = true},
    {field_dispid, 0, .inherited = true},
    {field_dispid, 1, .inherited = true},
    {field_getter, 0, .inherited = true},
    {field_getter, 1, .inherited = true},
    {field_implements, 0, .inherited = true},
    {field_implements, 1, .inherited = true},
    {field_index, 0, .inherited = true},
    {field_index, 1, .inherited = true},
    {field_setter, 0, .inherited = true},
    {field_setter, 1, .inherited = true},
    {field_stored, 0, .inherited = true},
    {field_stored, 1, .inherited = true},
  [574] =
    {field_attribute, 8, .inherited = true},
    {field_name, 1},
    {field_name, 2},
    {field_type, 4},
  [578] =
    {field_name, 1},
    {field_name, 2},
    {field_type, 3},
  [581] =
    {field_parent, 4},
    {field_parent, 5},
    {field_parent, 6},
  [584] =
    {field_guid, 6},
    {field_parent, 2},
    {field_parent, 3},
    {field_parent, 4},
    {field_parent, 5},
  [589] =
    {field_parent, 3},
    {field_parent, 4},
    {field_parent, 5},
    {field_parent, 6},
  [593] =
    {field_parent, 5},
    {field_parent, 6},
  [595] =
    {field_args, 3},
    {field_assign, 7},
    {field_attribute, 9, .inherited = true},
    {field_name, 2},
    {field_resultName, 4},
    {field_type, 6},
  [601] =
    {field_args, 4},
    {field_assign, 7},
    {field_attribute, 9, .inherited = true},
    {field_name, 3},
    {field_type, 6},
  [606] =
    {field_implements, 1},
    {field_implements, 2},
  [608] =
    {field_attribute, 6, .inherited = true},
    {field_defaultValue, 4, .inherited = true},
    {field_dispid, 4, .inherited = true},
    {field_getter, 4, .inherited = true},
    {field_implements, 4, .inherited = true},
    {field_index, 4, .inherited = true},
    {field_name, 1},
    {field_setter, 4, .inherited = true},
    {field_stored, 4, .inherited = true},
    {field_type, 3},
  [618] =
    {field_args, 2},
    {field_defaultValue, 5, .inherited = true},
    {field_dispid, 5, .inherited = true},
    {field_getter, 5, .inherited = true},
    {field_implements, 5, .inherited = true},
    {field_index, 5, .inherited = true},
    {field_name, 1},
    {field_setter, 5, .inherited = true},
    {field_stored, 5, .inherited = true},
    {field_type, 4},
  [628] =
    {field_defaultValue, 5, .inherited = true},
    {field_dispid, 5, .inherited = true},
    {field_getter, 5, .inherited = true},
    {field_implements, 5, .inherited = true},
    {field_index, 5, .inherited = true},
    {field_name, 2},
    {field_setter, 5, .inherited = true},
    {field_stored, 5, .inherited = true},
    {field_type, 4},
  [637] =
    {field_parent, 4},
    {field_parent, 5},
    {field_parent, 6},
    {field_parent, 7},
  [641] =
    {field_parent, 5},
    {field_parent, 6},
    {field_parent, 7},
  [644] =
    {field_args, 2},
    {field_attribute, 7, .inherited = true},
    {field_defaultValue, 5, .inherited = true},
    {field_dispid, 5, .inherited = true},
    {field_getter, 5, .inherited = true},
    {field_implements, 5, .inherited = true},
    {field_index, 5, .inherited = true},
    {field_name, 1},
    {field_setter, 5, .inherited = true},
    {field_stored, 5, .inherited = true},
    {field_type, 4},
  [655] =
    {field_attribute, 7, .inherited = true},
    {field_defaultValue, 5, .inherited = true},
    {field_dispid, 5, .inherited = true},
    {field_getter, 5, .inherited = true},
    {field_implements, 5, .inherited = true},
    {field_index, 5, .inherited = true},
    {field_name, 2},
    {field_setter, 5, .inherited = true},
    {field_stored, 5, .inherited = true},
    {field_type, 4},
  [665] =
    {field_args, 3},
    {field_defaultValue, 6, .inherited = true},
    {field_dispid, 6, .inherited = true},
    {field_getter, 6, .inherited = true},
    {field_implements, 6, .inherited = true},
    {field_index, 6, .inherited = true},
    {field_name, 2},
    {field_setter, 6, .inherited = true},
    {field_stored, 6, .inherited = true},
    {field_type, 5},
  [675] =
    {field_defaultValue, 6, .inherited = true},
    {field_dispid, 6, .inherited = true},
    {field_getter, 6, .inherited = true},
    {field_implements, 6, .inherited = true},
    {field_index, 6, .inherited = true},
    {field_name, 3},
    {field_setter, 6, .inherited = true},
    {field_stored, 6, .inherited = true},
    {field_type, 5},
  [684] =
    {field_parent, 5},
    {field_parent, 6},
    {field_parent, 7},
    {field_parent, 8},
  [688] =
    {field_args, 3},
    {field_attribute, 8, .inherited = true},
    {field_defaultValue, 6, .inherited = true},
    {field_dispid, 6, .inherited = true},
    {field_getter, 6, .inherited = true},
    {field_implements, 6, .inherited = true},
    {field_index, 6, .inherited = true},
    {field_name, 2},
    {field_setter, 6, .inherited = true},
    {field_stored, 6, .inherited = true},
    {field_type, 5},
  [699] =
    {field_attribute, 8, .inherited = true},
    {field_defaultValue, 6, .inherited = true},
    {field_dispid, 6, .inherited = true},
    {field_getter, 6, .inherited = true},
    {field_implements, 6, .inherited = true},
    {field_index, 6, .inherited = true},
    {field_name, 3},
    {field_setter, 6, .inherited = true},
    {field_stored, 6, .inherited = true},
    {field_type, 5},
  [709] =
    {field_args, 4},
    {field_defaultValue, 7, .inherited = true},
    {field_dispid, 7, .inherited = true},
    {field_getter, 7, .inherited = true},
    {field_implements, 7, .inherited = true},
    {field_index, 7, .inherited = true},
    {field_name, 3},
    {field_setter, 7, .inherited = true},
    {field_stored, 7, .inherited = true},
    {field_type, 6},
  [719] =
    {field_args, 4},
    {field_attribute, 9, .inherited = true},
    {field_defaultValue, 7, .inherited = true},
    {field_dispid, 7, .inherited = true},
    {field_getter, 7, .inherited = true},
    {field_implements, 7, .inherited = true},
    {field_index, 7, .inherited = true},
    {field_name, 3},
    {field_setter, 7, .inherited = true},
    {field_stored, 7, .inherited = true},
    {field_type, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [3] = {
    [0] = sym_identifier,
  },
  [4] = {
    [0] = sym_if,
  },
  [5] = {
    [0] = sym_block,
  },
  [10] = {
    [1] = sym_block,
  },
  [15] = {
    [1] = sym_block,
  },
  [19] = {
    [2] = sym_block,
  },
  [21] = {
    [2] = sym_block,
  },
  [36] = {
    [2] = sym_block,
  },
  [43] = {
    [3] = sym_block,
  },
  [45] = {
    [3] = sym_block,
  },
  [48] = {
    [3] = sym_block,
  },
  [75] = {
    [2] = sym_block,
  },
  [77] = {
    [4] = sym_block,
  },
  [80] = {
    [4] = sym_block,
  },
  [83] = {
    [4] = sym_block,
  },
  [114] = {
    [2] = sym_block,
  },
  [117] = {
    [3] = sym_block,
  },
  [120] = {
    [5] = sym_block,
  },
  [156] = {
    [3] = sym_block,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_if, 2,
    sym_if,
    sym_if,
  sym_blockTr, 2,
    sym_blockTr,
    sym_block,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 15,
  [21] = 16,
  [22] = 17,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 12,
  [32] = 32,
  [33] = 10,
  [34] = 13,
  [35] = 19,
  [36] = 14,
  [37] = 11,
  [38] = 38,
  [39] = 39,
  [40] = 39,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 39,
  [49] = 49,
  [50] = 39,
  [51] = 39,
  [52] = 39,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 53,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 59,
  [62] = 59,
  [63] = 60,
  [64] = 59,
  [65] = 59,
  [66] = 59,
  [67] = 60,
  [68] = 59,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 60,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 59,
  [114] = 60,
  [115] = 115,
  [116] = 59,
  [117] = 117,
  [118] = 59,
  [119] = 119,
  [120] = 120,
  [121] = 59,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 84,
  [130] = 130,
  [131] = 131,
  [132] = 90,
  [133] = 73,
  [134] = 79,
  [135] = 85,
  [136] = 89,
  [137] = 92,
  [138] = 93,
  [139] = 69,
  [140] = 86,
  [141] = 83,
  [142] = 81,
  [143] = 82,
  [144] = 87,
  [145] = 88,
  [146] = 91,
  [147] = 74,
  [148] = 70,
  [149] = 71,
  [150] = 72,
  [151] = 75,
  [152] = 76,
  [153] = 77,
  [154] = 78,
  [155] = 80,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 112,
  [227] = 108,
  [228] = 228,
  [229] = 109,
  [230] = 97,
  [231] = 95,
  [232] = 100,
  [233] = 96,
  [234] = 98,
  [235] = 99,
  [236] = 126,
  [237] = 101,
  [238] = 117,
  [239] = 119,
  [240] = 120,
  [241] = 122,
  [242] = 123,
  [243] = 124,
  [244] = 103,
  [245] = 104,
  [246] = 105,
  [247] = 106,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 259,
  [306] = 260,
  [307] = 261,
  [308] = 262,
  [309] = 309,
  [310] = 268,
  [311] = 269,
  [312] = 270,
  [313] = 271,
  [314] = 297,
  [315] = 283,
  [316] = 284,
  [317] = 285,
  [318] = 286,
  [319] = 287,
  [320] = 298,
  [321] = 299,
  [322] = 251,
  [323] = 252,
  [324] = 253,
  [325] = 254,
  [326] = 255,
  [327] = 256,
  [328] = 257,
  [329] = 215,
  [330] = 219,
  [331] = 195,
  [332] = 181,
  [333] = 182,
  [334] = 184,
  [335] = 185,
  [336] = 161,
  [337] = 162,
  [338] = 163,
  [339] = 164,
  [340] = 165,
  [341] = 166,
  [342] = 167,
  [343] = 258,
  [344] = 186,
  [345] = 196,
  [346] = 197,
  [347] = 198,
  [348] = 263,
  [349] = 199,
  [350] = 204,
  [351] = 216,
  [352] = 217,
  [353] = 222,
  [354] = 224,
  [355] = 160,
  [356] = 264,
  [357] = 265,
  [358] = 266,
  [359] = 267,
  [360] = 169,
  [361] = 170,
  [362] = 171,
  [363] = 172,
  [364] = 273,
  [365] = 274,
  [366] = 275,
  [367] = 276,
  [368] = 173,
  [369] = 174,
  [370] = 175,
  [371] = 176,
  [372] = 177,
  [373] = 159,
  [374] = 179,
  [375] = 277,
  [376] = 278,
  [377] = 279,
  [378] = 280,
  [379] = 281,
  [380] = 282,
  [381] = 187,
  [382] = 188,
  [383] = 189,
  [384] = 288,
  [385] = 289,
  [386] = 290,
  [387] = 291,
  [388] = 292,
  [389] = 293,
  [390] = 190,
  [391] = 191,
  [392] = 192,
  [393] = 193,
  [394] = 194,
  [395] = 294,
  [396] = 295,
  [397] = 296,
  [398] = 250,
  [399] = 200,
  [400] = 300,
  [401] = 301,
  [402] = 302,
  [403] = 303,
  [404] = 201,
  [405] = 202,
  [406] = 203,
  [407] = 304,
  [408] = 309,
  [409] = 205,
  [410] = 272,
  [411] = 411,
  [412] = 412,
  [413] = 215,
  [414] = 216,
  [415] = 219,
  [416] = 102,
  [417] = 214,
  [418] = 166,
  [419] = 167,
  [420] = 195,
  [421] = 181,
  [422] = 169,
  [423] = 170,
  [424] = 171,
  [425] = 172,
  [426] = 205,
  [427] = 182,
  [428] = 217,
  [429] = 107,
  [430] = 208,
  [431] = 201,
  [432] = 222,
  [433] = 173,
  [434] = 224,
  [435] = 160,
  [436] = 202,
  [437] = 203,
  [438] = 174,
  [439] = 175,
  [440] = 176,
  [441] = 441,
  [442] = 177,
  [443] = 159,
  [444] = 179,
  [445] = 194,
  [446] = 204,
  [447] = 115,
  [448] = 212,
  [449] = 183,
  [450] = 197,
  [451] = 125,
  [452] = 220,
  [453] = 221,
  [454] = 111,
  [455] = 198,
  [456] = 186,
  [457] = 184,
  [458] = 199,
  [459] = 185,
  [460] = 161,
  [461] = 162,
  [462] = 462,
  [463] = 163,
  [464] = 464,
  [465] = 164,
  [466] = 165,
  [467] = 200,
  [468] = 187,
  [469] = 188,
  [470] = 189,
  [471] = 190,
  [472] = 191,
  [473] = 192,
  [474] = 193,
  [475] = 196,
  [476] = 476,
  [477] = 228,
  [478] = 304,
  [479] = 296,
  [480] = 273,
  [481] = 462,
  [482] = 263,
  [483] = 274,
  [484] = 275,
  [485] = 276,
  [486] = 441,
  [487] = 309,
  [488] = 300,
  [489] = 301,
  [490] = 302,
  [491] = 303,
  [492] = 250,
  [493] = 277,
  [494] = 294,
  [495] = 279,
  [496] = 280,
  [497] = 281,
  [498] = 282,
  [499] = 258,
  [500] = 464,
  [501] = 264,
  [502] = 412,
  [503] = 265,
  [504] = 266,
  [505] = 267,
  [506] = 506,
  [507] = 411,
  [508] = 295,
  [509] = 288,
  [510] = 289,
  [511] = 290,
  [512] = 291,
  [513] = 292,
  [514] = 293,
  [515] = 278,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 411,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 412,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 506,
  [537] = 537,
  [538] = 538,
  [539] = 441,
  [540] = 462,
  [541] = 541,
  [542] = 542,
  [543] = 464,
  [544] = 544,
  [545] = 545,
  [546] = 59,
  [547] = 60,
  [548] = 60,
  [549] = 59,
  [550] = 550,
  [551] = 59,
  [552] = 552,
  [553] = 59,
  [554] = 59,
  [555] = 59,
  [556] = 60,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 566,
  [569] = 567,
  [570] = 218,
  [571] = 561,
  [572] = 565,
  [573] = 563,
  [574] = 560,
  [575] = 562,
  [576] = 560,
  [577] = 567,
  [578] = 567,
  [579] = 562,
  [580] = 564,
  [581] = 564,
  [582] = 561,
  [583] = 180,
  [584] = 564,
  [585] = 565,
  [586] = 180,
  [587] = 561,
  [588] = 563,
  [589] = 218,
  [590] = 565,
  [591] = 563,
  [592] = 560,
  [593] = 562,
  [594] = 566,
  [595] = 566,
  [596] = 596,
  [597] = 597,
  [598] = 597,
  [599] = 599,
  [600] = 600,
  [601] = 599,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 606,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 607,
  [618] = 616,
  [619] = 612,
  [620] = 608,
  [621] = 616,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 249,
  [626] = 624,
  [627] = 248,
  [628] = 624,
  [629] = 629,
  [630] = 630,
  [631] = 631,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 599,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 561,
  [644] = 564,
  [645] = 565,
  [646] = 563,
  [647] = 560,
  [648] = 562,
  [649] = 566,
  [650] = 567,
  [651] = 564,
  [652] = 600,
  [653] = 218,
  [654] = 565,
  [655] = 560,
  [656] = 180,
  [657] = 218,
  [658] = 563,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 566,
  [663] = 663,
  [664] = 567,
  [665] = 665,
  [666] = 666,
  [667] = 562,
  [668] = 660,
  [669] = 599,
  [670] = 604,
  [671] = 180,
  [672] = 561,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 476,
  [679] = 180,
  [680] = 680,
  [681] = 218,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 561,
  [687] = 565,
  [688] = 563,
  [689] = 689,
  [690] = 560,
  [691] = 562,
  [692] = 566,
  [693] = 567,
  [694] = 564,
  [695] = 685,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 607,
  [701] = 612,
  [702] = 608,
  [703] = 699,
  [704] = 685,
  [705] = 705,
  [706] = 676,
  [707] = 685,
  [708] = 676,
  [709] = 685,
  [710] = 676,
  [711] = 685,
  [712] = 676,
  [713] = 685,
  [714] = 676,
  [715] = 683,
  [716] = 716,
  [717] = 717,
  [718] = 716,
  [719] = 683,
  [720] = 716,
  [721] = 677,
  [722] = 676,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 723,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 723,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 604,
  [754] = 748,
  [755] = 723,
  [756] = 531,
  [757] = 748,
  [758] = 723,
  [759] = 748,
  [760] = 723,
  [761] = 748,
  [762] = 599,
  [763] = 748,
  [764] = 723,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 746,
  [769] = 748,
  [770] = 737,
  [771] = 771,
  [772] = 600,
  [773] = 746,
  [774] = 737,
  [775] = 775,
  [776] = 534,
  [777] = 533,
  [778] = 566,
  [779] = 542,
  [780] = 567,
  [781] = 518,
  [782] = 782,
  [783] = 564,
  [784] = 516,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 782,
  [789] = 789,
  [790] = 790,
  [791] = 521,
  [792] = 792,
  [793] = 793,
  [794] = 607,
  [795] = 612,
  [796] = 530,
  [797] = 532,
  [798] = 608,
  [799] = 541,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 782,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 782,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 782,
  [832] = 538,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 249,
  [844] = 844,
  [845] = 506,
  [846] = 782,
  [847] = 248,
  [848] = 809,
  [849] = 849,
  [850] = 782,
  [851] = 249,
  [852] = 803,
  [853] = 853,
  [854] = 841,
  [855] = 855,
  [856] = 523,
  [857] = 782,
  [858] = 519,
  [859] = 248,
  [860] = 841,
  [861] = 524,
  [862] = 561,
  [863] = 544,
  [864] = 841,
  [865] = 545,
  [866] = 517,
  [867] = 841,
  [868] = 782,
  [869] = 537,
  [870] = 841,
  [871] = 525,
  [872] = 565,
  [873] = 841,
  [874] = 841,
  [875] = 522,
  [876] = 563,
  [877] = 529,
  [878] = 878,
  [879] = 879,
  [880] = 528,
  [881] = 560,
  [882] = 526,
  [883] = 562,
  [884] = 535,
  [885] = 782,
  [886] = 607,
  [887] = 608,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 892,
  [896] = 896,
  [897] = 897,
  [898] = 890,
  [899] = 899,
  [900] = 890,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 889,
  [907] = 902,
  [908] = 903,
  [909] = 909,
  [910] = 890,
  [911] = 904,
  [912] = 612,
  [913] = 913,
  [914] = 914,
  [915] = 902,
  [916] = 903,
  [917] = 904,
  [918] = 905,
  [919] = 889,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 905,
  [928] = 890,
  [929] = 929,
  [930] = 930,
  [931] = 889,
  [932] = 902,
  [933] = 903,
  [934] = 904,
  [935] = 905,
  [936] = 890,
  [937] = 889,
  [938] = 902,
  [939] = 903,
  [940] = 904,
  [941] = 896,
  [942] = 905,
  [943] = 890,
  [944] = 902,
  [945] = 903,
  [946] = 904,
  [947] = 905,
  [948] = 889,
  [949] = 913,
  [950] = 889,
  [951] = 951,
  [952] = 952,
  [953] = 905,
  [954] = 890,
  [955] = 903,
  [956] = 904,
  [957] = 957,
  [958] = 958,
  [959] = 892,
  [960] = 960,
  [961] = 922,
  [962] = 913,
  [963] = 890,
  [964] = 902,
  [965] = 903,
  [966] = 904,
  [967] = 905,
  [968] = 889,
  [969] = 890,
  [970] = 903,
  [971] = 904,
  [972] = 972,
  [973] = 892,
  [974] = 888,
  [975] = 975,
  [976] = 892,
  [977] = 922,
  [978] = 892,
  [979] = 922,
  [980] = 980,
  [981] = 894,
  [982] = 897,
  [983] = 901,
  [984] = 984,
  [985] = 922,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 925,
  [992] = 926,
  [993] = 929,
  [994] = 984,
  [995] = 995,
  [996] = 894,
  [997] = 902,
  [998] = 899,
  [999] = 999,
  [1000] = 894,
  [1001] = 987,
  [1002] = 894,
  [1003] = 986,
  [1004] = 988,
  [1005] = 903,
  [1006] = 894,
  [1007] = 922,
  [1008] = 894,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 904,
  [1012] = 990,
  [1013] = 1013,
  [1014] = 995,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 641,
  [1018] = 476,
  [1019] = 640,
  [1020] = 476,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 531,
  [1024] = 640,
  [1025] = 599,
  [1026] = 604,
  [1027] = 604,
  [1028] = 531,
  [1029] = 599,
  [1030] = 1021,
  [1031] = 1031,
  [1032] = 1022,
  [1033] = 1033,
  [1034] = 600,
  [1035] = 1035,
  [1036] = 600,
  [1037] = 1031,
  [1038] = 1022,
  [1039] = 1022,
  [1040] = 1040,
  [1041] = 1022,
  [1042] = 1022,
  [1043] = 1022,
  [1044] = 1022,
  [1045] = 1045,
  [1046] = 1040,
  [1047] = 641,
  [1048] = 1048,
  [1049] = 1035,
  [1050] = 519,
  [1051] = 544,
  [1052] = 523,
  [1053] = 519,
  [1054] = 545,
  [1055] = 524,
  [1056] = 506,
  [1057] = 544,
  [1058] = 545,
  [1059] = 517,
  [1060] = 517,
  [1061] = 1061,
  [1062] = 521,
  [1063] = 537,
  [1064] = 525,
  [1065] = 522,
  [1066] = 537,
  [1067] = 525,
  [1068] = 529,
  [1069] = 522,
  [1070] = 529,
  [1071] = 607,
  [1072] = 612,
  [1073] = 530,
  [1074] = 532,
  [1075] = 607,
  [1076] = 534,
  [1077] = 1077,
  [1078] = 608,
  [1079] = 612,
  [1080] = 530,
  [1081] = 1081,
  [1082] = 532,
  [1083] = 534,
  [1084] = 608,
  [1085] = 523,
  [1086] = 541,
  [1087] = 528,
  [1088] = 524,
  [1089] = 506,
  [1090] = 535,
  [1091] = 538,
  [1092] = 533,
  [1093] = 542,
  [1094] = 528,
  [1095] = 526,
  [1096] = 518,
  [1097] = 535,
  [1098] = 538,
  [1099] = 533,
  [1100] = 516,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 542,
  [1104] = 1104,
  [1105] = 518,
  [1106] = 521,
  [1107] = 516,
  [1108] = 541,
  [1109] = 526,
  [1110] = 1110,
  [1111] = 1110,
  [1112] = 1110,
  [1113] = 1110,
  [1114] = 1114,
  [1115] = 1110,
  [1116] = 1116,
  [1117] = 1110,
  [1118] = 1118,
  [1119] = 1033,
  [1120] = 1110,
  [1121] = 1110,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1125,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1124,
  [1131] = 1131,
  [1132] = 1127,
  [1133] = 1133,
  [1134] = 1131,
  [1135] = 1125,
  [1136] = 1127,
  [1137] = 1128,
  [1138] = 1129,
  [1139] = 1124,
  [1140] = 1129,
  [1141] = 1131,
  [1142] = 1142,
  [1143] = 1125,
  [1144] = 1127,
  [1145] = 1128,
  [1146] = 1129,
  [1147] = 1124,
  [1148] = 1131,
  [1149] = 1128,
  [1150] = 1125,
  [1151] = 1128,
  [1152] = 1129,
  [1153] = 1124,
  [1154] = 1131,
  [1155] = 1125,
  [1156] = 1127,
  [1157] = 1128,
  [1158] = 1129,
  [1159] = 1124,
  [1160] = 1131,
  [1161] = 1125,
  [1162] = 1127,
  [1163] = 1128,
  [1164] = 1129,
  [1165] = 1124,
  [1166] = 1131,
  [1167] = 1125,
  [1168] = 1127,
  [1169] = 1128,
  [1170] = 1129,
  [1171] = 1124,
  [1172] = 1131,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1122,
  [1177] = 1177,
  [1178] = 1127,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 248,
  [1190] = 641,
  [1191] = 1191,
  [1192] = 640,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 249,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 249,
  [1204] = 248,
  [1205] = 249,
  [1206] = 1206,
  [1207] = 1188,
  [1208] = 248,
  [1209] = 641,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1202,
  [1216] = 1200,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 640,
  [1220] = 1187,
  [1221] = 1221,
  [1222] = 476,
  [1223] = 1223,
  [1224] = 476,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1217,
  [1236] = 476,
  [1237] = 1237,
  [1238] = 600,
  [1239] = 1237,
  [1240] = 1218,
  [1241] = 1211,
  [1242] = 600,
  [1243] = 1212,
  [1244] = 1244,
  [1245] = 531,
  [1246] = 604,
  [1247] = 604,
  [1248] = 531,
  [1249] = 1214,
  [1250] = 599,
  [1251] = 1251,
  [1252] = 1251,
  [1253] = 1237,
  [1254] = 599,
  [1255] = 1251,
  [1256] = 524,
  [1257] = 599,
  [1258] = 1230,
  [1259] = 1225,
  [1260] = 612,
  [1261] = 541,
  [1262] = 542,
  [1263] = 1232,
  [1264] = 533,
  [1265] = 1234,
  [1266] = 526,
  [1267] = 607,
  [1268] = 544,
  [1269] = 544,
  [1270] = 535,
  [1271] = 506,
  [1272] = 1272,
  [1273] = 537,
  [1274] = 530,
  [1275] = 525,
  [1276] = 545,
  [1277] = 1272,
  [1278] = 1278,
  [1279] = 542,
  [1280] = 604,
  [1281] = 1281,
  [1282] = 612,
  [1283] = 1283,
  [1284] = 541,
  [1285] = 516,
  [1286] = 1286,
  [1287] = 530,
  [1288] = 545,
  [1289] = 523,
  [1290] = 1290,
  [1291] = 517,
  [1292] = 532,
  [1293] = 608,
  [1294] = 519,
  [1295] = 532,
  [1296] = 1278,
  [1297] = 534,
  [1298] = 538,
  [1299] = 523,
  [1300] = 529,
  [1301] = 608,
  [1302] = 1302,
  [1303] = 522,
  [1304] = 518,
  [1305] = 1305,
  [1306] = 518,
  [1307] = 1226,
  [1308] = 1308,
  [1309] = 535,
  [1310] = 528,
  [1311] = 537,
  [1312] = 522,
  [1313] = 538,
  [1314] = 516,
  [1315] = 1283,
  [1316] = 521,
  [1317] = 534,
  [1318] = 533,
  [1319] = 521,
  [1320] = 526,
  [1321] = 524,
  [1322] = 517,
  [1323] = 519,
  [1324] = 529,
  [1325] = 531,
  [1326] = 525,
  [1327] = 528,
  [1328] = 607,
  [1329] = 1329,
  [1330] = 600,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1334,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1342,
  [1343] = 1335,
  [1344] = 1336,
  [1345] = 1337,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1347,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1290,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1286,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1350,
  [1370] = 1332,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 607,
  [1374] = 612,
  [1375] = 530,
  [1376] = 532,
  [1377] = 608,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1281,
  [1384] = 1353,
  [1385] = 523,
  [1386] = 519,
  [1387] = 524,
  [1388] = 506,
  [1389] = 544,
  [1390] = 545,
  [1391] = 1391,
  [1392] = 521,
  [1393] = 537,
  [1394] = 525,
  [1395] = 522,
  [1396] = 529,
  [1397] = 534,
  [1398] = 541,
  [1399] = 528,
  [1400] = 526,
  [1401] = 535,
  [1402] = 538,
  [1403] = 533,
  [1404] = 542,
  [1405] = 518,
  [1406] = 516,
  [1407] = 1407,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1335,
  [1413] = 1336,
  [1414] = 1337,
  [1415] = 1415,
  [1416] = 1347,
  [1417] = 1350,
  [1418] = 1353,
  [1419] = 1331,
  [1420] = 1355,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1331,
  [1425] = 1411,
  [1426] = 1302,
  [1427] = 1409,
  [1428] = 1340,
  [1429] = 1429,
  [1430] = 1367,
  [1431] = 1368,
  [1432] = 1378,
  [1433] = 1379,
  [1434] = 1380,
  [1435] = 1338,
  [1436] = 1355,
  [1437] = 1341,
  [1438] = 1342,
  [1439] = 1346,
  [1440] = 1359,
  [1441] = 1365,
  [1442] = 1381,
  [1443] = 1382,
  [1444] = 1422,
  [1445] = 1423,
  [1446] = 1429,
  [1447] = 1340,
  [1448] = 1378,
  [1449] = 1379,
  [1450] = 1380,
  [1451] = 1341,
  [1452] = 1342,
  [1453] = 1346,
  [1454] = 1359,
  [1455] = 1421,
  [1456] = 517,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1459,
  [1460] = 1460,
  [1461] = 1461,
  [1462] = 1461,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1459,
  [1466] = 1463,
  [1467] = 1464,
  [1468] = 1457,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1469,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1479,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1488,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 640,
  [1499] = 1499,
  [1500] = 1488,
  [1501] = 1501,
  [1502] = 1499,
  [1503] = 1488,
  [1504] = 1499,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1508,
  [1509] = 1499,
  [1510] = 1488,
  [1511] = 1499,
  [1512] = 1488,
  [1513] = 1513,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1499,
  [1517] = 1517,
  [1518] = 1488,
  [1519] = 641,
  [1520] = 1520,
  [1521] = 1521,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1523,
  [1525] = 1497,
  [1526] = 1520,
  [1527] = 1527,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1499,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 1497,
  [1535] = 1535,
  [1536] = 1520,
  [1537] = 1523,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 1541,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 1540,
  [1547] = 1308,
  [1548] = 1548,
  [1549] = 1286,
  [1550] = 1544,
  [1551] = 1551,
  [1552] = 1551,
  [1553] = 1553,
  [1554] = 1305,
  [1555] = 1553,
  [1556] = 1556,
  [1557] = 608,
  [1558] = 1558,
  [1559] = 1308,
  [1560] = 1560,
  [1561] = 608,
  [1562] = 1558,
  [1563] = 1563,
  [1564] = 1305,
  [1565] = 1560,
  [1566] = 1560,
  [1567] = 1560,
  [1568] = 608,
  [1569] = 1569,
  [1570] = 1558,
  [1571] = 1571,
  [1572] = 1560,
  [1573] = 1573,
  [1574] = 608,
  [1575] = 1558,
  [1576] = 1560,
  [1577] = 1571,
  [1578] = 608,
  [1579] = 1558,
  [1580] = 1580,
  [1581] = 608,
  [1582] = 1558,
  [1583] = 608,
  [1584] = 1573,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1558,
  [1591] = 1591,
  [1592] = 1580,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1482,
  [1596] = 1481,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 1601,
  [1602] = 1558,
  [1603] = 1597,
  [1604] = 1560,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1606,
  [1608] = 1608,
  [1609] = 1606,
  [1610] = 1606,
  [1611] = 1606,
  [1612] = 1606,
  [1613] = 1606,
  [1614] = 1598,
  [1615] = 1606,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1233,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1223,
  [1631] = 1631,
  [1632] = 1229,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1639,
  [1640] = 1305,
  [1641] = 1308,
  [1642] = 1642,
  [1643] = 1308,
  [1644] = 1644,
  [1645] = 1645,
  [1646] = 1646,
  [1647] = 1305,
  [1648] = 1648,
  [1649] = 1649,
  [1650] = 1650,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1655,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1674,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1693,
  [1705] = 1694,
  [1706] = 1695,
  [1707] = 1703,
  [1708] = 1708,
  [1709] = 1709,
  [1710] = 1710,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 1718,
  [1719] = 1719,
  [1720] = 1720,
  [1721] = 1721,
  [1722] = 1722,
  [1723] = 1723,
  [1724] = 1724,
  [1725] = 1725,
  [1726] = 1726,
  [1727] = 1696,
  [1728] = 1697,
  [1729] = 1698,
  [1730] = 1699,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1713,
  [1735] = 1735,
  [1736] = 1736,
  [1737] = 1737,
  [1738] = 1738,
  [1739] = 1739,
  [1740] = 1691,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1702,
  [1744] = 1744,
  [1745] = 1714,
  [1746] = 1746,
  [1747] = 1747,
  [1748] = 1748,
  [1749] = 1700,
  [1750] = 1701,
  [1751] = 1751,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1754,
  [1755] = 1755,
  [1756] = 1752,
  [1757] = 1755,
  [1758] = 1758,
  [1759] = 1759,
  [1760] = 1760,
  [1761] = 1761,
  [1762] = 1762,
  [1763] = 1754,
  [1764] = 1752,
  [1765] = 1765,
  [1766] = 1766,
  [1767] = 1767,
  [1768] = 1674,
  [1769] = 1769,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1765,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1754,
  [1776] = 1776,
  [1777] = 1777,
  [1778] = 1778,
  [1779] = 1765,
  [1780] = 1780,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1671,
  [1786] = 1786,
  [1787] = 1787,
  [1788] = 1788,
  [1789] = 1789,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1794,
  [1795] = 1795,
  [1796] = 1796,
  [1797] = 1797,
  [1798] = 1798,
  [1799] = 1799,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 1802,
  [1803] = 1803,
  [1804] = 1804,
  [1805] = 1792,
  [1806] = 1802,
  [1807] = 1807,
  [1808] = 1788,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1811,
  [1812] = 1812,
  [1813] = 1793,
  [1814] = 1814,
  [1815] = 1797,
  [1816] = 1816,
  [1817] = 1792,
  [1818] = 1818,
  [1819] = 1810,
  [1820] = 1801,
  [1821] = 1790,
  [1822] = 1809,
  [1823] = 1823,
  [1824] = 1816,
  [1825] = 1790,
  [1826] = 1796,
  [1827] = 1802,
  [1828] = 1804,
  [1829] = 1807,
  [1830] = 1788,
  [1831] = 1811,
  [1832] = 1812,
  [1833] = 1814,
  [1834] = 1834,
  [1835] = 1797,
  [1836] = 1836,
  [1837] = 1816,
  [1838] = 1834,
  [1839] = 1839,
  [1840] = 1809,
  [1841] = 1802,
  [1842] = 1788,
  [1843] = 1788,
  [1844] = 1802,
  [1845] = 1788,
  [1846] = 1811,
  [1847] = 1802,
  [1848] = 1848,
  [1849] = 1788,
  [1850] = 1850,
  [1851] = 1802,
  [1852] = 1788,
  [1853] = 1802,
  [1854] = 1834,
  [1855] = 1796,
  [1856] = 1856,
  [1857] = 1812,
  [1858] = 1818,
  [1859] = 1804,
  [1860] = 1818,
  [1861] = 1861,
  [1862] = 1862,
  [1863] = 1863,
  [1864] = 557,
  [1865] = 1865,
  [1866] = 558,
  [1867] = 1865,
  [1868] = 1865,
  [1869] = 1869,
  [1870] = 1683,
  [1871] = 1865,
  [1872] = 1681,
  [1873] = 1873,
  [1874] = 1874,
  [1875] = 1865,
  [1876] = 1876,
  [1877] = 1865,
  [1878] = 1308,
  [1879] = 1879,
  [1880] = 1305,
  [1881] = 1865,
  [1882] = 1882,
  [1883] = 1883,
  [1884] = 1884,
  [1885] = 1885,
  [1886] = 1886,
  [1887] = 1887,
  [1888] = 1888,
  [1889] = 1889,
  [1890] = 1890,
  [1891] = 1891,
  [1892] = 1892,
  [1893] = 1893,
  [1894] = 1886,
  [1895] = 1885,
  [1896] = 1889,
  [1897] = 1884,
  [1898] = 1732,
  [1899] = 1899,
  [1900] = 1899,
  [1901] = 1674,
  [1902] = 1671,
  [1903] = 1903,
  [1904] = 1885,
  [1905] = 1885,
  [1906] = 1885,
  [1907] = 1885,
  [1908] = 559,
  [1909] = 1909,
  [1910] = 1910,
  [1911] = 1911,
  [1912] = 1887,
  [1913] = 1913,
  [1914] = 1914,
  [1915] = 1915,
  [1916] = 1916,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 1919,
  [1920] = 1920,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 1923,
  [1924] = 1924,
  [1925] = 1925,
  [1926] = 1926,
  [1927] = 1927,
  [1928] = 1928,
  [1929] = 1883,
  [1930] = 1903,
  [1931] = 1931,
  [1932] = 1932,
  [1933] = 1933,
  [1934] = 1934,
  [1935] = 1916,
  [1936] = 1936,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 1916,
  [1940] = 1940,
  [1941] = 1941,
  [1942] = 1925,
  [1943] = 1936,
  [1944] = 1944,
  [1945] = 1945,
  [1946] = 1925,
  [1947] = 1947,
  [1948] = 1948,
  [1949] = 1949,
  [1950] = 1184,
  [1951] = 1951,
  [1952] = 1952,
  [1953] = 1953,
  [1954] = 1683,
  [1955] = 1955,
  [1956] = 1681,
  [1957] = 1957,
  [1958] = 1958,
  [1959] = 1959,
  [1960] = 1960,
  [1961] = 1961,
  [1962] = 1962,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1182,
  [1966] = 1966,
  [1967] = 1967,
  [1968] = 1964,
  [1969] = 1969,
  [1970] = 1183,
  [1971] = 1971,
  [1972] = 1952,
  [1973] = 1973,
  [1974] = 1967,
  [1975] = 1957,
  [1976] = 1976,
  [1977] = 1960,
  [1978] = 1969,
  [1979] = 1979,
  [1980] = 1964,
  [1981] = 1981,
  [1982] = 1955,
  [1983] = 1955,
  [1984] = 1981,
  [1985] = 1985,
  [1986] = 1953,
  [1987] = 1987,
  [1988] = 1952,
  [1989] = 1989,
  [1990] = 1948,
  [1991] = 1991,
  [1992] = 1992,
  [1993] = 1993,
  [1994] = 1994,
  [1995] = 1995,
  [1996] = 1996,
  [1997] = 1985,
  [1998] = 1998,
  [1999] = 1999,
  [2000] = 2000,
  [2001] = 1987,
  [2002] = 2002,
  [2003] = 2003,
  [2004] = 1992,
  [2005] = 2005,
  [2006] = 1953,
  [2007] = 1987,
  [2008] = 1992,
  [2009] = 2009,
  [2010] = 1963,
  [2011] = 1995,
  [2012] = 1969,
  [2013] = 1979,
  [2014] = 1967,
  [2015] = 1962,
  [2016] = 1957,
  [2017] = 2017,
  [2018] = 2003,
  [2019] = 2019,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 2023,
  [2024] = 2024,
  [2025] = 2025,
  [2026] = 2026,
  [2027] = 2027,
  [2028] = 1649,
  [2029] = 2029,
  [2030] = 2030,
  [2031] = 2031,
  [2032] = 2032,
  [2033] = 2033,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 2037,
  [2038] = 2038,
  [2039] = 2039,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 2019,
  [2043] = 2043,
  [2044] = 2044,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 1973,
  [2049] = 2031,
  [2050] = 2033,
  [2051] = 2036,
  [2052] = 2038,
  [2053] = 2053,
  [2054] = 2053,
  [2055] = 1949,
  [2056] = 2056,
  [2057] = 2057,
  [2058] = 2058,
  [2059] = 2059,
  [2060] = 2060,
  [2061] = 1644,
  [2062] = 2062,
  [2063] = 2063,
  [2064] = 1732,
  [2065] = 2065,
  [2066] = 2029,
  [2067] = 2067,
  [2068] = 2068,
  [2069] = 2069,
  [2070] = 2070,
  [2071] = 1648,
  [2072] = 2034,
  [2073] = 2035,
  [2074] = 2074,
  [2075] = 2041,
  [2076] = 2019,
  [2077] = 2043,
  [2078] = 2044,
  [2079] = 2045,
  [2080] = 2031,
  [2081] = 2033,
  [2082] = 2036,
  [2083] = 2083,
  [2084] = 2053,
  [2085] = 2056,
  [2086] = 2057,
  [2087] = 2029,
  [2088] = 2088,
  [2089] = 2029,
  [2090] = 2090,
  [2091] = 2091,
  [2092] = 2092,
  [2093] = 2093,
  [2094] = 2029,
  [2095] = 2095,
  [2096] = 2040,
  [2097] = 2029,
  [2098] = 2098,
  [2099] = 2099,
  [2100] = 2100,
  [2101] = 2041,
  [2102] = 2102,
  [2103] = 2021,
  [2104] = 1646,
  [2105] = 2091,
  [2106] = 2106,
  [2107] = 2107,
  [2108] = 2070,
  [2109] = 2109,
  [2110] = 2110,
  [2111] = 2111,
  [2112] = 2093,
  [2113] = 2113,
  [2114] = 2114,
  [2115] = 2115,
  [2116] = 2046,
  [2117] = 2056,
  [2118] = 2118,
  [2119] = 2119,
  [2120] = 2057,
  [2121] = 2034,
  [2122] = 2122,
  [2123] = 2035,
  [2124] = 2124,
  [2125] = 1645,
  [2126] = 2126,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 2129,
  [2130] = 2130,
  [2131] = 2131,
  [2132] = 2043,
  [2133] = 2133,
  [2134] = 2067,
  [2135] = 2068,
  [2136] = 2044,
  [2137] = 2130,
  [2138] = 2045,
  [2139] = 2139,
  [2140] = 2029,
  [2141] = 2038,
  [2142] = 2142,
  [2143] = 2143,
  [2144] = 2144,
  [2145] = 2145,
  [2146] = 2146,
  [2147] = 2147,
  [2148] = 2148,
  [2149] = 2149,
  [2150] = 2150,
  [2151] = 2151,
  [2152] = 2152,
  [2153] = 2153,
  [2154] = 2154,
  [2155] = 2155,
  [2156] = 2156,
  [2157] = 1654,
  [2158] = 1655,
  [2159] = 2159,
  [2160] = 1656,
  [2161] = 2161,
  [2162] = 1657,
  [2163] = 1650,
  [2164] = 2164,
  [2165] = 1658,
  [2166] = 1666,
  [2167] = 1667,
  [2168] = 2168,
  [2169] = 2169,
  [2170] = 1668,
  [2171] = 1669,
  [2172] = 2172,
  [2173] = 2173,
  [2174] = 2174,
  [2175] = 2175,
  [2176] = 1664,
  [2177] = 1670,
  [2178] = 1659,
  [2179] = 2179,
  [2180] = 2180,
  [2181] = 2181,
  [2182] = 2182,
  [2183] = 2183,
  [2184] = 2184,
  [2185] = 2185,
  [2186] = 2186,
  [2187] = 2187,
  [2188] = 2188,
  [2189] = 1660,
  [2190] = 2190,
  [2191] = 2191,
  [2192] = 2192,
  [2193] = 2193,
  [2194] = 2194,
  [2195] = 2195,
  [2196] = 2196,
  [2197] = 2197,
  [2198] = 2198,
  [2199] = 2199,
  [2200] = 2200,
  [2201] = 2183,
  [2202] = 1665,
  [2203] = 2203,
  [2204] = 2204,
  [2205] = 2186,
  [2206] = 2206,
  [2207] = 2207,
  [2208] = 2208,
  [2209] = 2147,
  [2210] = 2210,
  [2211] = 2183,
  [2212] = 2212,
  [2213] = 2186,
  [2214] = 2183,
  [2215] = 2215,
  [2216] = 2216,
  [2217] = 2217,
  [2218] = 2183,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2186,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2183,
  [2228] = 2183,
  [2229] = 2229,
  [2230] = 2230,
  [2231] = 2143,
  [2232] = 2186,
  [2233] = 2233,
  [2234] = 2234,
  [2235] = 2235,
  [2236] = 2150,
  [2237] = 1651,
  [2238] = 2238,
  [2239] = 2239,
  [2240] = 1652,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 2243,
  [2244] = 2244,
  [2245] = 2186,
  [2246] = 2246,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 2192,
  [2250] = 2250,
  [2251] = 2217,
  [2252] = 2238,
  [2253] = 2253,
  [2254] = 2242,
  [2255] = 2255,
  [2256] = 2256,
  [2257] = 2257,
  [2258] = 2150,
  [2259] = 2161,
  [2260] = 2260,
  [2261] = 2151,
  [2262] = 2262,
  [2263] = 2216,
  [2264] = 2220,
  [2265] = 2265,
  [2266] = 2266,
  [2267] = 2267,
  [2268] = 2155,
  [2269] = 2149,
  [2270] = 2226,
  [2271] = 2271,
  [2272] = 2186,
  [2273] = 2273,
  [2274] = 2274,
  [2275] = 2275,
  [2276] = 2276,
  [2277] = 2198,
  [2278] = 2278,
  [2279] = 2279,
  [2280] = 2280,
  [2281] = 2281,
  [2282] = 1662,
  [2283] = 2266,
  [2284] = 2262,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2149,
  [2288] = 2288,
  [2289] = 1663,
  [2290] = 1677,
  [2291] = 2291,
  [2292] = 2262,
  [2293] = 2293,
  [2294] = 2294,
  [2295] = 2295,
  [2296] = 2296,
  [2297] = 2297,
  [2298] = 2274,
  [2299] = 2299,
  [2300] = 2300,
  [2301] = 2301,
  [2302] = 2246,
  [2303] = 2281,
  [2304] = 2146,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2192,
  [2309] = 2142,
  [2310] = 2210,
  [2311] = 2271,
  [2312] = 2312,
  [2313] = 2151,
  [2314] = 2266,
  [2315] = 2315,
  [2316] = 2316,
  [2317] = 2226,
  [2318] = 2318,
  [2319] = 2273,
  [2320] = 2273,
  [2321] = 2142,
  [2322] = 1672,
  [2323] = 2271,
  [2324] = 2324,
  [2325] = 2325,
  [2326] = 1673,
  [2327] = 2279,
  [2328] = 2300,
  [2329] = 2294,
  [2330] = 2330,
  [2331] = 1653,
  [2332] = 2332,
  [2333] = 2333,
  [2334] = 2334,
  [2335] = 2335,
  [2336] = 2336,
  [2337] = 2337,
  [2338] = 2338,
  [2339] = 2339,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 2343,
  [2344] = 2344,
  [2345] = 2345,
  [2346] = 2346,
  [2347] = 2347,
  [2348] = 2348,
  [2349] = 2349,
  [2350] = 2350,
  [2351] = 2351,
  [2352] = 2352,
  [2353] = 2353,
  [2354] = 2354,
  [2355] = 2355,
  [2356] = 2356,
  [2357] = 2357,
  [2358] = 2358,
  [2359] = 2359,
  [2360] = 2360,
  [2361] = 2361,
  [2362] = 2362,
  [2363] = 2353,
  [2364] = 2345,
  [2365] = 2365,
  [2366] = 2366,
  [2367] = 2367,
  [2368] = 2368,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 2347,
  [2372] = 2372,
  [2373] = 2373,
  [2374] = 2374,
  [2375] = 2375,
  [2376] = 2376,
  [2377] = 2377,
  [2378] = 2342,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 2381,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2336,
  [2385] = 2385,
  [2386] = 2338,
  [2387] = 2387,
  [2388] = 2388,
  [2389] = 2389,
  [2390] = 2353,
  [2391] = 2391,
  [2392] = 2392,
  [2393] = 2393,
  [2394] = 2394,
  [2395] = 2395,
  [2396] = 2396,
  [2397] = 2397,
  [2398] = 2347,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 2402,
  [2403] = 2376,
  [2404] = 2377,
  [2405] = 2405,
  [2406] = 2406,
  [2407] = 2407,
  [2408] = 2342,
  [2409] = 2409,
  [2410] = 2343,
  [2411] = 2411,
  [2412] = 2344,
  [2413] = 2413,
  [2414] = 2345,
  [2415] = 2353,
  [2416] = 2416,
  [2417] = 2417,
  [2418] = 2346,
  [2419] = 2419,
  [2420] = 2420,
  [2421] = 2421,
  [2422] = 2422,
  [2423] = 2347,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2426,
  [2427] = 2427,
  [2428] = 2376,
  [2429] = 2377,
  [2430] = 2346,
  [2431] = 2431,
  [2432] = 2432,
  [2433] = 2431,
  [2434] = 2434,
  [2435] = 2435,
  [2436] = 2436,
  [2437] = 2437,
  [2438] = 2438,
  [2439] = 2439,
  [2440] = 2440,
  [2441] = 2441,
  [2442] = 2442,
  [2443] = 2443,
  [2444] = 2444,
  [2445] = 2445,
  [2446] = 2347,
  [2447] = 2447,
  [2448] = 2448,
  [2449] = 2434,
  [2450] = 2450,
  [2451] = 2376,
  [2452] = 2377,
  [2453] = 2453,
  [2454] = 2454,
  [2455] = 2455,
  [2456] = 2440,
  [2457] = 2457,
  [2458] = 2458,
  [2459] = 2348,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2349,
  [2463] = 2463,
  [2464] = 2464,
  [2465] = 2465,
  [2466] = 2444,
  [2467] = 2350,
  [2468] = 2468,
  [2469] = 2352,
  [2470] = 2343,
  [2471] = 2354,
  [2472] = 2472,
  [2473] = 2473,
  [2474] = 2355,
  [2475] = 2475,
  [2476] = 2476,
  [2477] = 2477,
  [2478] = 2478,
  [2479] = 2357,
  [2480] = 2480,
  [2481] = 2481,
  [2482] = 2482,
  [2483] = 2483,
  [2484] = 2484,
  [2485] = 2485,
  [2486] = 2353,
  [2487] = 2487,
  [2488] = 2488,
  [2489] = 2489,
  [2490] = 2490,
  [2491] = 2376,
  [2492] = 2492,
  [2493] = 2493,
  [2494] = 2494,
  [2495] = 2495,
  [2496] = 2496,
  [2497] = 2497,
  [2498] = 2381,
  [2499] = 2499,
  [2500] = 2500,
  [2501] = 2501,
  [2502] = 2502,
  [2503] = 2356,
  [2504] = 2504,
  [2505] = 2357,
  [2506] = 2377,
  [2507] = 2365,
  [2508] = 2369,
  [2509] = 2509,
  [2510] = 2374,
  [2511] = 2509,
  [2512] = 2512,
  [2513] = 2513,
  [2514] = 2514,
  [2515] = 2515,
  [2516] = 2516,
  [2517] = 2517,
  [2518] = 2518,
  [2519] = 2347,
  [2520] = 2520,
  [2521] = 2521,
  [2522] = 2522,
  [2523] = 2523,
  [2524] = 2358,
  [2525] = 2361,
  [2526] = 2526,
  [2527] = 2527,
  [2528] = 2458,
  [2529] = 2529,
  [2530] = 2424,
  [2531] = 2531,
  [2532] = 2532,
  [2533] = 2533,
  [2534] = 2534,
  [2535] = 2425,
  [2536] = 2536,
  [2537] = 2537,
  [2538] = 2538,
  [2539] = 2333,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 2542,
  [2543] = 2427,
  [2544] = 2527,
  [2545] = 2545,
  [2546] = 2546,
  [2547] = 2341,
  [2548] = 2548,
  [2549] = 2540,
  [2550] = 2537,
  [2551] = 2551,
  [2552] = 2448,
  [2553] = 2553,
  [2554] = 2554,
  [2555] = 2555,
  [2556] = 2379,
  [2557] = 2557,
  [2558] = 2558,
  [2559] = 2559,
  [2560] = 2431,
  [2561] = 2561,
  [2562] = 2562,
  [2563] = 2348,
  [2564] = 2564,
  [2565] = 2565,
  [2566] = 2566,
  [2567] = 2483,
  [2568] = 2568,
  [2569] = 2484,
  [2570] = 2349,
  [2571] = 2571,
  [2572] = 2358,
  [2573] = 2350,
  [2574] = 2574,
  [2575] = 2382,
  [2576] = 2576,
  [2577] = 2577,
  [2578] = 2352,
  [2579] = 2564,
  [2580] = 2465,
  [2581] = 2341,
  [2582] = 2582,
  [2583] = 2583,
  [2584] = 2477,
  [2585] = 2354,
  [2586] = 2344,
  [2587] = 2587,
  [2588] = 2588,
  [2589] = 2589,
  [2590] = 2589,
  [2591] = 2515,
  [2592] = 2488,
  [2593] = 2356,
  [2594] = 2594,
  [2595] = 2595,
  [2596] = 2596,
  [2597] = 2336,
  [2598] = 2598,
  [2599] = 2355,
  [2600] = 2600,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2353,
  [2604] = 2604,
  [2605] = 2605,
  [2606] = 2376,
  [2607] = 2607,
  [2608] = 2608,
  [2609] = 2377,
  [2610] = 2610,
  [2611] = 2611,
  [2612] = 2612,
  [2613] = 2613,
  [2614] = 2614,
  [2615] = 2615,
  [2616] = 2616,
  [2617] = 2617,
  [2618] = 2618,
  [2619] = 2548,
  [2620] = 2620,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2514,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2497,
  [2633] = 2633,
  [2634] = 2634,
  [2635] = 2337,
  [2636] = 2514,
  [2637] = 2637,
  [2638] = 2504,
  [2639] = 2610,
  [2640] = 2347,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2637,
  [2645] = 2645,
  [2646] = 2360,
  [2647] = 2647,
  [2648] = 2648,
  [2649] = 2376,
  [2650] = 2377,
  [2651] = 2558,
  [2652] = 2504,
  [2653] = 2653,
  [2654] = 2369,
  [2655] = 2559,
  [2656] = 2365,
  [2657] = 2657,
  [2658] = 2565,
  [2659] = 2659,
  [2660] = 2596,
  [2661] = 2661,
  [2662] = 2662,
  [2663] = 2359,
  [2664] = 2465,
  [2665] = 2518,
  [2666] = 2666,
  [2667] = 2667,
  [2668] = 2668,
  [2669] = 2395,
  [2670] = 2670,
  [2671] = 2515,
  [2672] = 2672,
  [2673] = 2613,
  [2674] = 2461,
  [2675] = 2624,
  [2676] = 2676,
  [2677] = 2677,
  [2678] = 2631,
  [2679] = 2496,
  [2680] = 2483,
  [2681] = 2681,
  [2682] = 2604,
  [2683] = 2559,
  [2684] = 2684,
  [2685] = 2338,
  [2686] = 2686,
  [2687] = 2558,
  [2688] = 2406,
  [2689] = 2689,
  [2690] = 2565,
  [2691] = 2484,
  [2692] = 2596,
  [2693] = 2518,
  [2694] = 2694,
  [2695] = 2695,
  [2696] = 2564,
  [2697] = 2485,
  [2698] = 2373,
  [2699] = 2589,
  [2700] = 2610,
  [2701] = 2366,
  [2702] = 2555,
  [2703] = 2703,
  [2704] = 2704,
  [2705] = 2372,
  [2706] = 2374,
  [2707] = 2375,
  [2708] = 2641,
  [2709] = 2624,
  [2710] = 2633,
  [2711] = 2370,
  [2712] = 2712,
  [2713] = 2713,
  [2714] = 2714,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(42);
      ADVANCE_MAP(
        '#', 60,
        '&', 50,
        '\'', 12,
        '(', 54,
        ')', 55,
        '*', 89,
        '+', 83,
        ',', 46,
        '-', 87,
        '.', 67,
        '/', 91,
        ':', 45,
        ';', 43,
        '<', 72,
        '=', 74,
        '>', 77,
        '@', 92,
        '[', 52,
        ']', 53,
        '^', 93,
        '{', 5,
        '$', 49,
        '%', 49,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(48);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '#', 60,
        '$', 38,
        '&', 39,
        '\'', 12,
        '(', 54,
        '*', 88,
        '+', 82,
        ',', 46,
        '-', 86,
        '.', 70,
        '/', 90,
        ':', 44,
        '<', 73,
        '=', 74,
        '>', 77,
        '@', 92,
        '[', 52,
        '^', 93,
        '{', 9,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '#', 60,
        '$', 38,
        '&', 39,
        '\'', 12,
        '(', 54,
        '*', 88,
        '+', 82,
        ',', 46,
        '-', 86,
        '.', 69,
        '/', 90,
        ':', 44,
        '<', 73,
        '=', 74,
        '>', 77,
        '@', 92,
        '[', 52,
        ']', 53,
        '^', 93,
        '{', 8,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '#', 60,
        '&', 39,
        '\'', 12,
        '(', 54,
        ')', 55,
        '*', 89,
        '+', 83,
        ',', 46,
        '-', 87,
        '.', 68,
        '/', 91,
        ':', 45,
        ';', 43,
        '<', 73,
        '=', 74,
        '>', 77,
        '[', 52,
        ']', 53,
        '^', 93,
        '{', 8,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '#', 60,
        '&', 39,
        '\'', 12,
        '(', 54,
        '*', 88,
        '+', 80,
        ',', 46,
        '-', 84,
        '.', 67,
        '/', 90,
        '<', 73,
        '=', 74,
        '>', 77,
        '[', 52,
        '^', 93,
        '{', 9,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 5:
      if (lookahead == '$') ADVANCE(24);
      if (lookahead == '}') ADVANCE(103);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '$', 38,
        '&', 39,
        '(', 14,
        ')', 55,
        '*', 19,
        '+', 20,
        ',', 46,
        '-', 21,
        '.', 67,
        '/', 18,
        ':', 45,
        ';', 43,
        '<', 71,
        '=', 74,
        '>', 76,
        '[', 52,
        ']', 53,
        '{', 8,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(62);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 7:
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == '}') ADVANCE(103);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 8:
      if (lookahead == '$') ADVANCE(31);
      if (lookahead == '}') ADVANCE(103);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 9:
      if (lookahead == '$') ADVANCE(25);
      if (lookahead == '}') ADVANCE(103);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 10:
      if (lookahead == '&') ADVANCE(50);
      if (lookahead == '(') ADVANCE(15);
      if (lookahead == ')') ADVANCE(51);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '{') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(48);
      if (lookahead == '$' ||
          lookahead == '%' ||
          ('*' <= lookahead && lookahead <= '<') ||
          lookahead == '>' ||
          lookahead == '[' ||
          lookahead == ']') ADVANCE(49);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 11:
      if (lookahead == '&') ADVANCE(39);
      if (lookahead == '(') ADVANCE(54);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '[') ADVANCE(52);
      if (lookahead == '^') ADVANCE(93);
      if (lookahead == '{') ADVANCE(7);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 12:
      if (lookahead == '\'') ADVANCE(59);
      if (lookahead != 0) ADVANCE(12);
      END_STATE();
    case 13:
      if (lookahead == ')') ADVANCE(103);
      if (lookahead == '*') ADVANCE(13);
      if (lookahead != 0) ADVANCE(16);
      END_STATE();
    case 14:
      if (lookahead == '*') ADVANCE(16);
      END_STATE();
    case 15:
      if (lookahead == '*') ADVANCE(16);
      if (lookahead != 0) ADVANCE(51);
      END_STATE();
    case 16:
      if (lookahead == '*') ADVANCE(13);
      if (lookahead != 0) ADVANCE(16);
      END_STATE();
    case 17:
      if (lookahead == '/') ADVANCE(104);
      END_STATE();
    case 18:
      if (lookahead == '/') ADVANCE(104);
      if (lookahead == '=') ADVANCE(98);
      END_STATE();
    case 19:
      if (lookahead == '=') ADVANCE(97);
      END_STATE();
    case 20:
      if (lookahead == '=') ADVANCE(95);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(62);
      END_STATE();
    case 21:
      if (lookahead == '=') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(62);
      END_STATE();
    case 22:
      if (lookahead == '}') ADVANCE(103);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 23:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(33);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 24:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(27);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 25:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 26:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(34);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 27:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(32);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 28:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(27);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 29:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(30);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(23);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 30:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(26);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 31:
      if (lookahead == '}') ADVANCE(102);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 32:
      if (lookahead == '}') ADVANCE(56);
      if (lookahead != 0) ADVANCE(32);
      END_STATE();
    case 33:
      if (lookahead == '}') ADVANCE(58);
      if (lookahead != 0) ADVANCE(33);
      END_STATE();
    case 34:
      if (lookahead == '}') ADVANCE(57);
      if (lookahead != 0) ADVANCE(34);
      END_STATE();
    case 35:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(37);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 36:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 37:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 38:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(63);
      END_STATE();
    case 39:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 40:
      if (eof) ADVANCE(42);
      ADVANCE_MAP(
        '#', 60,
        '$', 38,
        '&', 39,
        '\'', 12,
        '(', 54,
        ')', 55,
        '*', 89,
        '+', 81,
        ',', 46,
        '-', 85,
        '.', 70,
        '/', 91,
        ':', 45,
        ';', 43,
        '<', 73,
        '=', 74,
        '>', 77,
        '@', 92,
        '[', 52,
        ']', 53,
        '^', 93,
        '{', 8,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 41:
      if (eof) ADVANCE(42);
      ADVANCE_MAP(
        '#', 60,
        '&', 39,
        '\'', 12,
        '(', 54,
        ')', 55,
        '*', 89,
        '+', 83,
        ',', 46,
        '-', 87,
        '.', 67,
        '/', 91,
        ':', 45,
        ';', 43,
        '<', 73,
        '=', 74,
        '>', 77,
        '[', 52,
        ']', 53,
        '^', 93,
        '{', 8,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(94);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym_asmBody_token1);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(aux_sym_asmBody_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(aux_sym_asmBody_token2);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(aux_sym_asmBody_token2);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(aux_sym_asmBody_token3);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '*') ADVANCE(16);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(aux_sym_type_token1);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(aux_sym_type_token2);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(aux_sym_type_token3);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(aux_sym__literalString_token1);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(aux_sym__literalInt_token1);
      if (lookahead == '.') ADVANCE(36);
      if (lookahead == 'e') ADVANCE(35);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(aux_sym__literalInt_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(62);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(aux_sym__literalInt_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(63);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(aux_sym__literalFloat_token1);
      if (lookahead == 'e') ADVANCE(35);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(aux_sym__literalFloat_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(66);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(66);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_kLt);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_kLt);
      if (lookahead == '=') ADVANCE(78);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_kLt);
      if (lookahead == '=') ADVANCE(78);
      if (lookahead == '>') ADVANCE(75);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_kEq);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym_kNeq);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_kGt);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_kGt);
      if (lookahead == '=') ADVANCE(79);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym_kLte);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_kGte);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(sym_kAdd);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_kAdd);
      if (lookahead == '.') ADVANCE(36);
      if (lookahead == '=') ADVANCE(95);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_kAdd);
      if (lookahead == '.') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(sym_kAdd);
      if (lookahead == '=') ADVANCE(95);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_kSub);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_kSub);
      if (lookahead == '.') ADVANCE(36);
      if (lookahead == '=') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_kSub);
      if (lookahead == '.') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_kSub);
      if (lookahead == '=') ADVANCE(96);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_kMul);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_kMul);
      if (lookahead == '=') ADVANCE(97);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_kFdiv);
      if (lookahead == '/') ADVANCE(104);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_kFdiv);
      if (lookahead == '/') ADVANCE(104);
      if (lookahead == '=') ADVANCE(98);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_kAt);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_kHat);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_kAssign);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_kAssignAdd);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_kAssignSub);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_kAssignMul);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(sym_kAssignDiv);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(99);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(100);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym__space);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(101);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_pp);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(104);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'A', 1,
        'a', 1,
        'B', 2,
        'b', 2,
        'C', 3,
        'c', 3,
        'D', 4,
        'd', 4,
        'E', 5,
        'e', 5,
        'F', 6,
        'f', 6,
        'G', 7,
        'g', 7,
        'H', 8,
        'h', 8,
        'I', 9,
        'i', 9,
        'L', 10,
        'l', 10,
        'M', 11,
        'm', 11,
        'N', 12,
        'n', 12,
        'O', 13,
        'o', 13,
        'P', 14,
        'p', 14,
        'R', 15,
        'r', 15,
        'S', 16,
        's', 16,
        'T', 17,
        't', 17,
        'U', 18,
        'u', 18,
        'V', 19,
        'v', 19,
        'W', 20,
        'w', 20,
        'X', 21,
        'x', 21,
      );
      END_STATE();
    case 1:
      ADVANCE_MAP(
        'B', 22,
        'b', 22,
        'L', 23,
        'l', 23,
        'N', 24,
        'n', 24,
        'R', 25,
        'r', 25,
        'S', 26,
        's', 26,
      );
      END_STATE();
    case 2:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        'A', 28,
        'a', 28,
        'D', 29,
        'd', 29,
        'L', 30,
        'l', 30,
        'O', 31,
        'o', 31,
        'P', 32,
        'p', 32,
        'V', 33,
        'v', 33,
      );
      END_STATE();
    case 4:
      ADVANCE_MAP(
        'E', 34,
        'e', 34,
        'I', 35,
        'i', 35,
        'O', 36,
        'o', 36,
        'Y', 37,
        'y', 37,
      );
      END_STATE();
    case 5:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(38);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(39);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(40);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        'A', 41,
        'a', 41,
        'I', 42,
        'i', 42,
        'O', 43,
        'o', 43,
        'U', 44,
        'u', 44,
      );
      END_STATE();
    case 7:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(45);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(46);
      END_STATE();
    case 8:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(47);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        'F', 49,
        'f', 49,
        'M', 50,
        'm', 50,
        'N', 51,
        'n', 51,
        'O', 52,
        'o', 52,
        'S', 53,
        's', 53,
      );
      END_STATE();
    case 10:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(54);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(55);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(56);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        'E', 57,
        'e', 57,
        'O', 58,
        'o', 58,
        'S', 59,
        's', 59,
        'W', 60,
        'w', 60,
      );
      END_STATE();
    case 12:
      ADVANCE_MAP(
        'A', 61,
        'a', 61,
        'E', 62,
        'e', 62,
        'I', 63,
        'i', 63,
        'O', 64,
        'o', 64,
      );
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'B', 65,
        'b', 65,
        'F', 66,
        'f', 66,
        'N', 67,
        'n', 67,
        'P', 68,
        'p', 68,
        'R', 69,
        'r', 69,
        'U', 70,
        'u', 70,
        'V', 71,
        'v', 71,
      );
      END_STATE();
    case 14:
      ADVANCE_MAP(
        'A', 72,
        'a', 72,
        'L', 73,
        'l', 73,
        'R', 74,
        'r', 74,
        'U', 75,
        'u', 75,
      );
      END_STATE();
    case 15:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(76);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(77);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        'A', 78,
        'a', 78,
        'E', 79,
        'e', 79,
        'H', 80,
        'h', 80,
        'O', 81,
        'o', 81,
        'P', 82,
        'p', 82,
        'T', 83,
        't', 83,
        'Y', 84,
        'y', 84,
      );
      END_STATE();
    case 17:
      ADVANCE_MAP(
        'H', 85,
        'h', 85,
        'O', 86,
        'o', 86,
        'R', 87,
        'r', 87,
        'Y', 88,
        'y', 88,
      );
      END_STATE();
    case 18:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(89);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(90);
      END_STATE();
    case 19:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(91);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(93);
      END_STATE();
    case 20:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(94);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(95);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(96);
      END_STATE();
    case 21:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 22:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(98);
      END_STATE();
    case 23:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(99);
      END_STATE();
    case 24:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(100);
      END_STATE();
    case 25:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(101);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(sym_kAs);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(102);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(103);
      END_STATE();
    case 27:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(104);
      END_STATE();
    case 28:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(105);
      END_STATE();
    case 29:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 30:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(107);
      END_STATE();
    case 31:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 32:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(109);
      END_STATE();
    case 33:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(110);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        'F', 111,
        'f', 111,
        'L', 112,
        'l', 112,
        'P', 113,
        'p', 113,
        'S', 114,
        's', 114,
      );
      END_STATE();
    case 35:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(115);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(116);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(sym_kDo);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(117);
      END_STATE();
    case 37:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(118);
      END_STATE();
    case 38:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(119);
      END_STATE();
    case 39:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(120);
      END_STATE();
    case 40:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(121);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(122);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(123);
      END_STATE();
    case 41:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(124);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(125);
      END_STATE();
    case 42:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(126);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(127);
      END_STATE();
    case 43:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(128);
      END_STATE();
    case 44:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(129);
      END_STATE();
    case 45:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 46:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(131);
      END_STATE();
    case 47:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(132);
      END_STATE();
    case 48:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(133);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_kIf);
      END_STATE();
    case 50:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(134);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_kIn);
      ADVANCE_MAP(
        'D', 135,
        'd', 135,
        'H', 136,
        'h', 136,
        'I', 137,
        'i', 137,
        'L', 138,
        'l', 138,
        'T', 139,
        't', 139,
      );
      END_STATE();
    case 52:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(140);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_kIs);
      END_STATE();
    case 54:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(141);
      END_STATE();
    case 55:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(142);
      END_STATE();
    case 56:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(143);
      END_STATE();
    case 57:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(144);
      END_STATE();
    case 58:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(145);
      END_STATE();
    case 59:
      if (lookahead == '_') ADVANCE(146);
      END_STATE();
    case 60:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(147);
      END_STATE();
    case 61:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(148);
      END_STATE();
    case 62:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(149);
      END_STATE();
    case 63:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(150);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        'D', 151,
        'd', 151,
        'R', 152,
        'r', 152,
        'S', 153,
        's', 153,
        'T', 154,
        't', 154,
      );
      END_STATE();
    case 65:
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(155);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_kOf);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_kOn);
      END_STATE();
    case 68:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(156);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(157);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_kOr);
      END_STATE();
    case 70:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(158);
      END_STATE();
    case 71:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(159);
      END_STATE();
    case 72:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(160);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(161);
      END_STATE();
    case 73:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(162);
      END_STATE();
    case 74:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(163);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(164);
      END_STATE();
    case 75:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(165);
      END_STATE();
    case 76:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(166);
      END_STATE();
    case 77:
      ADVANCE_MAP(
        'A', 167,
        'a', 167,
        'C', 168,
        'c', 168,
        'F', 169,
        'f', 169,
        'G', 170,
        'g', 170,
        'I', 171,
        'i', 171,
        'P', 172,
        'p', 172,
        'Q', 173,
        'q', 173,
        'S', 174,
        's', 174,
      );
      END_STATE();
    case 78:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(175);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(176);
      END_STATE();
    case 79:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(177);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(178);
      END_STATE();
    case 80:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(179);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(180);
      END_STATE();
    case 81:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(181);
      END_STATE();
    case 82:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 83:
      ADVANCE_MAP(
        'A', 183,
        'a', 183,
        'D', 184,
        'd', 184,
        'O', 185,
        'o', 185,
        'R', 186,
        'r', 186,
      );
      END_STATE();
    case 84:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(187);
      END_STATE();
    case 85:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(188);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(189);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_kTo);
      END_STATE();
    case 87:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(190);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(191);
      END_STATE();
    case 88:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(192);
      END_STATE();
    case 89:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(193);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(194);
      END_STATE();
    case 90:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(195);
      END_STATE();
    case 91:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(196);
      END_STATE();
    case 92:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(197);
      END_STATE();
    case 93:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(198);
      END_STATE();
    case 94:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 95:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(200);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(201);
      END_STATE();
    case 96:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(202);
      END_STATE();
    case 97:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(203);
      END_STATE();
    case 98:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(204);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(205);
      END_STATE();
    case 99:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(206);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(sym_kAnd);
      END_STATE();
    case 101:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(207);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_kAsm);
      END_STATE();
    case 103:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 104:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(209);
      END_STATE();
    case 105:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(210);
      END_STATE();
    case 106:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(211);
      END_STATE();
    case 107:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(212);
      END_STATE();
    case 108:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(213);
      END_STATE();
    case 109:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(214);
      END_STATE();
    case 110:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(215);
      END_STATE();
    case 111:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(216);
      END_STATE();
    case 112:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(217);
      END_STATE();
    case 113:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(218);
      END_STATE();
    case 114:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(219);
      END_STATE();
    case 115:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(220);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym_kDiv);
      END_STATE();
    case 117:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(221);
      END_STATE();
    case 118:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 119:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_kEnd);
      END_STATE();
    case 121:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(224);
      END_STATE();
    case 122:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(225);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(226);
      END_STATE();
    case 123:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(227);
      END_STATE();
    case 124:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(228);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_kFar);
      END_STATE();
    case 126:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(229);
      END_STATE();
    case 127:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(230);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_kFor);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(231);
      END_STATE();
    case 129:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(232);
      END_STATE();
    case 130:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 131:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(234);
      END_STATE();
    case 132:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(235);
      END_STATE();
    case 133:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(236);
      END_STATE();
    case 134:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(237);
      END_STATE();
    case 135:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 136:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 137:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 138:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(241);
      END_STATE();
    case 139:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 140:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(243);
      END_STATE();
    case 141:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(244);
      END_STATE();
    case 142:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(245);
      END_STATE();
    case 143:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(246);
      END_STATE();
    case 144:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(247);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_kMod);
      END_STATE();
    case 146:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(248);
      END_STATE();
    case 147:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(249);
      END_STATE();
    case 148:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(250);
      END_STATE();
    case 149:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(251);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym_kNil);
      END_STATE();
    case 151:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(252);
      END_STATE();
    case 152:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(253);
      END_STATE();
    case 153:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(254);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_kNot);
      END_STATE();
    case 155:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(255);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 156:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(257);
      END_STATE();
    case 157:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(258);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_kOut);
      END_STATE();
    case 159:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(259);
      END_STATE();
    case 160:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(260);
      END_STATE();
    case 161:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(261);
      END_STATE();
    case 162:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(262);
      END_STATE();
    case 163:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(263);
      END_STATE();
    case 164:
      ADVANCE_MAP(
        'C', 264,
        'c', 264,
        'G', 265,
        'g', 265,
        'P', 266,
        'p', 266,
        'T', 267,
        't', 267,
      );
      END_STATE();
    case 165:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(268);
      END_STATE();
    case 166:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(269);
      END_STATE();
    case 167:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 168:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(271);
      END_STATE();
    case 169:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(272);
      END_STATE();
    case 170:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(273);
      END_STATE();
    case 171:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(274);
      END_STATE();
    case 172:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(275);
      END_STATE();
    case 173:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(276);
      END_STATE();
    case 174:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(277);
      END_STATE();
    case 175:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(278);
      END_STATE();
    case 176:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(279);
      END_STATE();
    case 177:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(280);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_kSet);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_kShl);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_kShr);
      END_STATE();
    case 181:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(281);
      END_STATE();
    case 182:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(282);
      END_STATE();
    case 183:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(283);
      END_STATE();
    case 184:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(284);
      END_STATE();
    case 185:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(285);
      END_STATE();
    case 186:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(286);
      END_STATE();
    case 187:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(287);
      END_STATE();
    case 188:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(288);
      END_STATE();
    case 189:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(289);
      END_STATE();
    case 190:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(290);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_kTry);
      END_STATE();
    case 192:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 193:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(292);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(293);
      END_STATE();
    case 194:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(294);
      END_STATE();
    case 195:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(295);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_kVar);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(296);
      END_STATE();
    case 197:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(297);
      END_STATE();
    case 198:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(298);
      END_STATE();
    case 199:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(299);
      END_STATE();
    case 200:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(300);
      END_STATE();
    case 201:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(301);
      END_STATE();
    case 202:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(302);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_kXor);
      END_STATE();
    case 204:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(303);
      END_STATE();
    case 205:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(304);
      END_STATE();
    case 206:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(305);
      END_STATE();
    case 207:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(306);
      END_STATE();
    case 208:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(307);
      END_STATE();
    case 209:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(308);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(sym_kCase);
      END_STATE();
    case 211:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(309);
      END_STATE();
    case 212:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(310);
      END_STATE();
    case 213:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(311);
      END_STATE();
    case 214:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(312);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(sym_kCvar);
      END_STATE();
    case 216:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(313);
      END_STATE();
    case 217:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(314);
      END_STATE();
    case 218:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(315);
      END_STATE();
    case 219:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(316);
      END_STATE();
    case 220:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(317);
      END_STATE();
    case 221:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(318);
      END_STATE();
    case 222:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(319);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_kElse);
      END_STATE();
    case 224:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(320);
      END_STATE();
    case 225:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(321);
      END_STATE();
    case 226:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(322);
      END_STATE();
    case 227:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(323);
      END_STATE();
    case 228:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(324);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_kFile);
      END_STATE();
    case 230:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(325);
      END_STATE();
    case 231:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(326);
      END_STATE();
    case 232:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(327);
      END_STATE();
    case 233:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(328);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(sym_kGoto);
      END_STATE();
    case 235:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(329);
      END_STATE();
    case 236:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(330);
      END_STATE();
    case 237:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(331);
      END_STATE();
    case 238:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(332);
      END_STATE();
    case 239:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(333);
      END_STATE();
    case 240:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(334);
      END_STATE();
    case 241:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(335);
      END_STATE();
    case 242:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(336);
      END_STATE();
    case 243:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(337);
      END_STATE();
    case 244:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(338);
      END_STATE();
    case 245:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(339);
      END_STATE();
    case 246:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(340);
      END_STATE();
    case 247:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(341);
      END_STATE();
    case 248:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(342);
      END_STATE();
    case 249:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(343);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(sym_kName);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(sym_kNear);
      END_STATE();
    case 252:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(344);
      END_STATE();
    case 253:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(345);
      END_STATE();
    case 254:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(346);
      END_STATE();
    case 255:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(347);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(348);
      END_STATE();
    case 256:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(349);
      END_STATE();
    case 257:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(350);
      END_STATE();
    case 258:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(351);
      END_STATE();
    case 259:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(352);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(353);
      END_STATE();
    case 260:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(354);
      END_STATE();
    case 261:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(355);
      END_STATE();
    case 262:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(356);
      END_STATE();
    case 263:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(357);
      END_STATE();
    case 264:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(358);
      END_STATE();
    case 265:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(359);
      END_STATE();
    case 266:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(360);
      END_STATE();
    case 267:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      END_STATE();
    case 268:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(362);
      END_STATE();
    case 269:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(363);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_kRead);
      END_STATE();
    case 271:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(364);
      END_STATE();
    case 272:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(365);
      END_STATE();
    case 273:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(366);
      END_STATE();
    case 274:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(367);
      END_STATE();
    case 275:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(368);
      END_STATE();
    case 276:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(369);
      END_STATE();
    case 277:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(370);
      END_STATE();
    case 278:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(371);
      END_STATE();
    case 279:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(372);
      END_STATE();
    case 280:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(373);
      END_STATE();
    case 281:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(374);
      END_STATE();
    case 282:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(375);
      END_STATE();
    case 283:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(376);
      END_STATE();
    case 284:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(377);
      END_STATE();
    case 285:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(378);
      END_STATE();
    case 286:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(379);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(380);
      END_STATE();
    case 287:
      if (lookahead == '_') ADVANCE(381);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(sym_kThen);
      END_STATE();
    case 289:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(382);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(sym_kTrue);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(sym_kType);
      END_STATE();
    case 292:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(383);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(sym_kUnit);
      END_STATE();
    case 294:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(384);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(sym_kUses);
      END_STATE();
    case 296:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(385);
      END_STATE();
    case 297:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(386);
      END_STATE();
    case 298:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(387);
      END_STATE();
    case 299:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(388);
      END_STATE();
    case 300:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(389);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(sym_kWith);
      END_STATE();
    case 302:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(390);
      END_STATE();
    case 303:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(391);
      END_STATE();
    case 304:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(392);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(sym_kAlias);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(sym_kArray);
      END_STATE();
    case 307:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(393);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(sym_kBegin);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(sym_kCdecl);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(sym_kClass);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(sym_kConst);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(394);
      END_STATE();
    case 312:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(395);
      END_STATE();
    case 313:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(396);
      END_STATE();
    case 314:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(397);
      END_STATE();
    case 315:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(398);
      END_STATE();
    case 316:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(399);
      END_STATE();
    case 317:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(400);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(401);
      END_STATE();
    case 318:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(402);
      END_STATE();
    case 319:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(403);
      END_STATE();
    case 320:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(404);
      END_STATE();
    case 321:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(405);
      END_STATE();
    case 322:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(406);
      END_STATE();
    case 323:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(407);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_kFalse);
      END_STATE();
    case 325:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(408);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(409);
      END_STATE();
    case 326:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(410);
      END_STATE();
    case 327:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(411);
      END_STATE();
    case 328:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(412);
      END_STATE();
    case 329:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(413);
      END_STATE();
    case 330:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(414);
      END_STATE();
    case 331:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(415);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym_kIndex);
      END_STATE();
    case 333:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(416);
      END_STATE();
    case 334:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(417);
      END_STATE();
    case 335:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 336:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(419);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(420);
      END_STATE();
    case 337:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(421);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(sym_kLabel);
      END_STATE();
    case 339:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(422);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_kLocal);
      END_STATE();
    case 341:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(423);
      END_STATE();
    case 342:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(424);
      END_STATE();
    case 343:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(425);
      END_STATE();
    case 344:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(426);
      END_STATE();
    case 345:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(427);
      END_STATE();
    case 346:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(428);
      END_STATE();
    case 347:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(429);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(430);
      END_STATE();
    case 348:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(431);
      END_STATE();
    case 349:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(432);
      END_STATE();
    case 350:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(433);
      END_STATE();
    case 351:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(434);
      END_STATE();
    case 352:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(435);
      END_STATE();
    case 353:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      END_STATE();
    case 354:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(437);
      END_STATE();
    case 355:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(438);
      END_STATE();
    case 356:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(439);
      END_STATE();
    case 357:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(440);
      END_STATE();
    case 358:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(441);
      END_STATE();
    case 359:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(442);
      END_STATE();
    case 360:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(443);
      END_STATE();
    case 361:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(444);
      END_STATE();
    case 362:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(445);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(446);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_kRaise);
      END_STATE();
    case 364:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(447);
      END_STATE();
    case 365:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 366:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(449);
      END_STATE();
    case 367:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(450);
      END_STATE();
    case 368:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(451);
      END_STATE();
    case 369:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(452);
      END_STATE();
    case 370:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(453);
      END_STATE();
    case 371:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(454);
      END_STATE();
    case 372:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(455);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_kSealed);
      END_STATE();
    case 374:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(456);
      END_STATE();
    case 375:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(457);
      END_STATE();
    case 376:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(458);
      END_STATE();
    case 377:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(459);
      END_STATE();
    case 378:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(460);
      END_STATE();
    case 379:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(461);
      END_STATE();
    case 380:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(462);
      END_STATE();
    case 381:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(463);
      END_STATE();
    case 382:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(464);
      END_STATE();
    case 383:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(465);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(sym_kUntil);
      END_STATE();
    case 385:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(466);
      END_STATE();
    case 386:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(467);
      END_STATE();
    case 387:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(468);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(sym_kWhile);
      END_STATE();
    case 389:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(469);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(sym_kWrite);
      END_STATE();
    case 391:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(470);
      END_STATE();
    case 392:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(471);
      END_STATE();
    case 393:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(472);
      END_STATE();
    case 394:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(473);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(474);
      END_STATE();
    case 395:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(475);
      END_STATE();
    case 396:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(476);
      END_STATE();
    case 397:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(477);
      END_STATE();
    case 398:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(478);
      END_STATE();
    case 399:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(479);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(sym_kDispId);
      END_STATE();
    case 401:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(480);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(sym_kDownto);
      END_STATE();
    case 403:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(481);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(sym_kExcept);
      END_STATE();
    case 405:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(482);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(sym_kExport);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(483);
      END_STATE();
    case 407:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(484);
      END_STATE();
    case 408:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(485);
      END_STATE();
    case 409:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(486);
      END_STATE();
    case 410:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(487);
      END_STATE();
    case 411:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(488);
      END_STATE();
    case 412:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(489);
      END_STATE();
    case 413:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(490);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(sym_kHelper);
      END_STATE();
    case 415:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(491);
      END_STATE();
    case 416:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(492);
      END_STATE();
    case 417:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(493);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(sym_kInline);
      END_STATE();
    case 419:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(494);
      END_STATE();
    case 420:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(495);
      END_STATE();
    case 421:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(496);
      END_STATE();
    case 422:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(497);
      END_STATE();
    case 423:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(498);
      END_STATE();
    case 424:
      if (lookahead == '_') ADVANCE(499);
      END_STATE();
    case 425:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(500);
      END_STATE();
    case 426:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(501);
      END_STATE();
    case 427:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(502);
      END_STATE();
    case 428:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(503);
      END_STATE();
    case 429:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(504);
      END_STATE();
    case 430:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(505);
      END_STATE();
    case 431:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(506);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(sym_kObject);
      END_STATE();
    case 433:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(507);
      END_STATE();
    case 434:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(508);
      END_STATE();
    case 435:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(509);
      END_STATE();
    case 436:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(510);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(sym_kPacked);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(sym_kPascal);
      END_STATE();
    case 439:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(511);
      END_STATE();
    case 440:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(512);
      END_STATE();
    case 441:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(513);
      END_STATE();
    case 442:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(514);
      END_STATE();
    case 443:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(515);
      END_STATE();
    case 444:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(516);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(sym_kPublic);
      END_STATE();
    case 446:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(517);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_kRecord);
      END_STATE();
    case 448:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(518);
      END_STATE();
    case 449:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(519);
      END_STATE();
    case 450:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(520);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(sym_kRepeat);
      END_STATE();
    case 452:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(521);
      END_STATE();
    case 453:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(522);
      END_STATE();
    case 454:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(523);
      END_STATE();
    case 455:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(524);
      END_STATE();
    case 456:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(525);
      END_STATE();
    case 457:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(526);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(sym_kStatic);
      END_STATE();
    case 459:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(527);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(sym_kStored);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(sym_kStrict);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(sym_kString);
      END_STATE();
    case 463:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(528);
      END_STATE();
    case 464:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(529);
      END_STATE();
    case 465:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(530);
      END_STATE();
    case 466:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(531);
      END_STATE();
    case 467:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(532);
      END_STATE();
    case 468:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(533);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(sym_kWinapi);
      END_STATE();
    case 470:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(534);
      END_STATE();
    case 471:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(535);
      END_STATE();
    case 472:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(536);
      END_STATE();
    case 473:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(537);
      END_STATE();
    case 474:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(538);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(sym_kCppdecl);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(sym_kDefault);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(sym_kDelayed);
      END_STATE();
    case 478:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(539);
      END_STATE();
    case 479:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(540);
      END_STATE();
    case 480:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(541);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(sym_kDynamic);
      END_STATE();
    case 482:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(542);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(sym_kExports);
      END_STATE();
    case 484:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(543);
      END_STATE();
    case 485:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(544);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(sym_kFinally);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(sym_kForward);
      END_STATE();
    case 488:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(545);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(sym_kGeneric);
      END_STATE();
    case 490:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(546);
      END_STATE();
    case 491:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(547);
      END_STATE();
    case 492:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(548);
      END_STATE();
    case 493:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(549);
      END_STATE();
    case 494:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(550);
      END_STATE();
    case 495:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(551);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_kIocheck);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_kLibrary);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_kMessage);
      END_STATE();
    case 499:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(552);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(553);
      END_STATE();
    case 500:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(554);
      END_STATE();
    case 501:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(555);
      END_STATE();
    case 502:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(556);
      END_STATE();
    case 503:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(557);
      END_STATE();
    case 504:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(558);
      END_STATE();
    case 505:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(559);
      END_STATE();
    case 506:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(560);
      END_STATE();
    case 507:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(561);
      END_STATE();
    case 508:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(562);
      END_STATE();
    case 509:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(563);
      END_STATE();
    case 510:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(564);
      END_STATE();
    case 511:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(565);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_kPrivate);
      END_STATE();
    case 513:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(566);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_kProgram);
      END_STATE();
    case 515:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(567);
      END_STATE();
    case 516:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 517:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(569);
      END_STATE();
    case 518:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(570);
      END_STATE();
    case 519:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(571);
      END_STATE();
    case 520:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(572);
      END_STATE();
    case 521:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(573);
      END_STATE();
    case 522:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(574);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(sym_kSafecall);
      END_STATE();
    case 524:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(575);
      END_STATE();
    case 525:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(576);
      END_STATE();
    case 526:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(577);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(sym_kStdcall);
      END_STATE();
    case 528:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(578);
      END_STATE();
    case 529:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(579);
      END_STATE();
    case 530:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(580);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_kVarargs);
      END_STATE();
    case 532:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(581);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_kVirtual);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_kAbsolute);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_kAbstract);
      END_STATE();
    case 536:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(582);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_kConstref);
      END_STATE();
    case 538:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(583);
      END_STATE();
    case 539:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(584);
      END_STATE();
    case 540:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(585);
      END_STATE();
    case 541:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(586);
      END_STATE();
    case 542:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(587);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_kExternal);
      END_STATE();
    case 544:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(588);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_kFunction);
      END_STATE();
    case 546:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(589);
      END_STATE();
    case 547:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(590);
      END_STATE();
    case 548:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(591);
      END_STATE();
    case 549:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(592);
      END_STATE();
    case 550:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(593);
      END_STATE();
    case 551:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(594);
      END_STATE();
    case 552:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(595);
      END_STATE();
    case 553:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(596);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_kMwpascal);
      END_STATE();
    case 555:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(597);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_kNoreturn);
      END_STATE();
    case 557:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(598);
      END_STATE();
    case 558:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(599);
      END_STATE();
    case 559:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(600);
      END_STATE();
    case 560:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(601);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_kOperator);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_kOptional);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_kOverload);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_kOverride);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_kPlatform);
      END_STATE();
    case 566:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(602);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_kProperty);
      END_STATE();
    case 568:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(603);
      END_STATE();
    case 569:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(604);
      END_STATE();
    case 570:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(605);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_kRegister);
      END_STATE();
    case 572:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(606);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_kRequired);
      END_STATE();
    case 574:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(607);
      END_STATE();
    case 575:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(608);
      END_STATE();
    case 576:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(609);
      END_STATE();
    case 577:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(610);
      END_STATE();
    case 578:
      if (lookahead == '_') ADVANCE(611);
      END_STATE();
    case 579:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(612);
      END_STATE();
    case 580:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(613);
      END_STATE();
    case 581:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(614);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_kAssembler);
      END_STATE();
    case 583:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(615);
      END_STATE();
    case 584:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(616);
      END_STATE();
    case 585:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(617);
      END_STATE();
    case 586:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(618);
      END_STATE();
    case 587:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(619);
      END_STATE();
    case 588:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(620);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_kHardfloat);
      END_STATE();
    case 590:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(621);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(622);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_kInherited);
      END_STATE();
    case 592:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(623);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_kInterface);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_kInterrupt);
      END_STATE();
    case 595:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(624);
      END_STATE();
    case 596:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(625);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_kNodefault);
      END_STATE();
    case 598:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(626);
      END_STATE();
    case 599:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(627);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_kObjcclass);
      END_STATE();
    case 601:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(628);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_kProcedure);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_kProtected);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_kPublished);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_kReference);
      END_STATE();
    case 606:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(629);
      END_STATE();
    case 607:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(630);
      END_STATE();
    case 608:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(631);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym_kSoftfloat);
      END_STATE();
    case 610:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(632);
      END_STATE();
    case 611:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(633);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(634);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_kThreadvar);
      END_STATE();
    case 613:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(635);
      END_STATE();
    case 614:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(636);
      END_STATE();
    case 615:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(637);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_kDeprecated);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_kDestructor);
      END_STATE();
    case 618:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(638);
      END_STATE();
    case 619:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(639);
      END_STATE();
    case 620:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(640);
      END_STATE();
    case 621:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(641);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_kImplements);
      END_STATE();
    case 623:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(642);
      END_STATE();
    case 624:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(643);
      END_STATE();
    case 625:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(644);
      END_STATE();
    case 626:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      END_STATE();
    case 627:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(646);
      END_STATE();
    case 628:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(647);
      END_STATE();
    case 629:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(648);
      END_STATE();
    case 630:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(649);
      END_STATE();
    case 631:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(650);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_kSpecialize);
      END_STATE();
    case 633:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(651);
      END_STATE();
    case 634:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(652);
      END_STATE();
    case 635:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(653);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_kVectorcall);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_kConstructor);
      END_STATE();
    case 638:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(654);
      END_STATE();
    case 639:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(655);
      END_STATE();
    case 640:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(656);
      END_STATE();
    case 641:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(657);
      END_STATE();
    case 642:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(658);
      END_STATE();
    case 643:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(659);
      END_STATE();
    case 644:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(660);
      END_STATE();
    case 645:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(661);
      END_STATE();
    case 646:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(662);
      END_STATE();
    case 647:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(663);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_kReintroduce);
      END_STATE();
    case 649:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(664);
      END_STATE();
    case 650:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(665);
      END_STATE();
    case 651:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(666);
      END_STATE();
    case 652:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(667);
      END_STATE();
    case 653:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(668);
      END_STATE();
    case 654:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(669);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_kExperimental);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_kFinalization);
      END_STATE();
    case 657:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(670);
      END_STATE();
    case 658:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(671);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_kMs_abi_cdecl);
      END_STATE();
    case 660:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(672);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_kNostackframe);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_kObjccategory);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_kObjcprotocol);
      END_STATE();
    case 664:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(673);
      END_STATE();
    case 665:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(674);
      END_STATE();
    case 666:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(675);
      END_STATE();
    case 667:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(676);
      END_STATE();
    case 668:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(677);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym_kDispInterface);
      END_STATE();
    case 670:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(678);
      END_STATE();
    case 671:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(679);
      END_STATE();
    case 672:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(680);
      END_STATE();
    case 673:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(681);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym_kSaveregisters);
      END_STATE();
    case 675:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(682);
      END_STATE();
    case 676:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(683);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym_kUnimplemented);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym_kImplementation);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym_kInitialization);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym_kMs_abi_default);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym_kResourcestring);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym_kSysv_abi_cdecl);
      END_STATE();
    case 683:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(684);
      END_STATE();
    case 684:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(685);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym_kSysv_abi_default);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 40},
  [2] = {.lex_state = 40},
  [3] = {.lex_state = 40},
  [4] = {.lex_state = 40},
  [5] = {.lex_state = 40},
  [6] = {.lex_state = 40},
  [7] = {.lex_state = 40},
  [8] = {.lex_state = 40},
  [9] = {.lex_state = 40},
  [10] = {.lex_state = 40},
  [11] = {.lex_state = 40},
  [12] = {.lex_state = 40},
  [13] = {.lex_state = 40},
  [14] = {.lex_state = 40},
  [15] = {.lex_state = 40},
  [16] = {.lex_state = 40},
  [17] = {.lex_state = 40},
  [18] = {.lex_state = 40},
  [19] = {.lex_state = 40},
  [20] = {.lex_state = 40},
  [21] = {.lex_state = 40},
  [22] = {.lex_state = 40},
  [23] = {.lex_state = 40},
  [24] = {.lex_state = 40},
  [25] = {.lex_state = 40},
  [26] = {.lex_state = 40},
  [27] = {.lex_state = 40},
  [28] = {.lex_state = 40},
  [29] = {.lex_state = 40},
  [30] = {.lex_state = 40},
  [31] = {.lex_state = 40},
  [32] = {.lex_state = 40},
  [33] = {.lex_state = 40},
  [34] = {.lex_state = 40},
  [35] = {.lex_state = 40},
  [36] = {.lex_state = 40},
  [37] = {.lex_state = 40},
  [38] = {.lex_state = 40},
  [39] = {.lex_state = 40},
  [40] = {.lex_state = 40},
  [41] = {.lex_state = 40},
  [42] = {.lex_state = 40},
  [43] = {.lex_state = 40},
  [44] = {.lex_state = 40},
  [45] = {.lex_state = 40},
  [46] = {.lex_state = 40},
  [47] = {.lex_state = 40},
  [48] = {.lex_state = 40},
  [49] = {.lex_state = 40},
  [50] = {.lex_state = 40},
  [51] = {.lex_state = 40},
  [52] = {.lex_state = 40},
  [53] = {.lex_state = 40},
  [54] = {.lex_state = 40},
  [55] = {.lex_state = 40},
  [56] = {.lex_state = 40},
  [57] = {.lex_state = 40},
  [58] = {.lex_state = 40},
  [59] = {.lex_state = 40},
  [60] = {.lex_state = 40},
  [61] = {.lex_state = 40},
  [62] = {.lex_state = 40},
  [63] = {.lex_state = 40},
  [64] = {.lex_state = 40},
  [65] = {.lex_state = 40},
  [66] = {.lex_state = 40},
  [67] = {.lex_state = 40},
  [68] = {.lex_state = 40},
  [69] = {.lex_state = 40},
  [70] = {.lex_state = 40},
  [71] = {.lex_state = 40},
  [72] = {.lex_state = 40},
  [73] = {.lex_state = 40},
  [74] = {.lex_state = 40},
  [75] = {.lex_state = 40},
  [76] = {.lex_state = 40},
  [77] = {.lex_state = 40},
  [78] = {.lex_state = 40},
  [79] = {.lex_state = 40},
  [80] = {.lex_state = 40},
  [81] = {.lex_state = 40},
  [82] = {.lex_state = 40},
  [83] = {.lex_state = 40},
  [84] = {.lex_state = 40},
  [85] = {.lex_state = 40},
  [86] = {.lex_state = 40},
  [87] = {.lex_state = 40},
  [88] = {.lex_state = 40},
  [89] = {.lex_state = 40},
  [90] = {.lex_state = 40},
  [91] = {.lex_state = 40},
  [92] = {.lex_state = 40},
  [93] = {.lex_state = 40},
  [94] = {.lex_state = 40},
  [95] = {.lex_state = 40},
  [96] = {.lex_state = 40},
  [97] = {.lex_state = 40},
  [98] = {.lex_state = 40},
  [99] = {.lex_state = 40},
  [100] = {.lex_state = 40},
  [101] = {.lex_state = 40},
  [102] = {.lex_state = 40},
  [103] = {.lex_state = 40},
  [104] = {.lex_state = 40},
  [105] = {.lex_state = 40},
  [106] = {.lex_state = 40},
  [107] = {.lex_state = 40},
  [108] = {.lex_state = 40},
  [109] = {.lex_state = 40},
  [110] = {.lex_state = 40},
  [111] = {.lex_state = 40},
  [112] = {.lex_state = 40},
  [113] = {.lex_state = 40},
  [114] = {.lex_state = 40},
  [115] = {.lex_state = 40},
  [116] = {.lex_state = 40},
  [117] = {.lex_state = 40},
  [118] = {.lex_state = 40},
  [119] = {.lex_state = 40},
  [120] = {.lex_state = 40},
  [121] = {.lex_state = 40},
  [122] = {.lex_state = 40},
  [123] = {.lex_state = 40},
  [124] = {.lex_state = 40},
  [125] = {.lex_state = 40},
  [126] = {.lex_state = 40},
  [127] = {.lex_state = 40},
  [128] = {.lex_state = 40},
  [129] = {.lex_state = 40},
  [130] = {.lex_state = 40},
  [131] = {.lex_state = 40},
  [132] = {.lex_state = 40},
  [133] = {.lex_state = 40},
  [134] = {.lex_state = 40},
  [135] = {.lex_state = 40},
  [136] = {.lex_state = 40},
  [137] = {.lex_state = 40},
  [138] = {.lex_state = 40},
  [139] = {.lex_state = 40},
  [140] = {.lex_state = 40},
  [141] = {.lex_state = 40},
  [142] = {.lex_state = 40},
  [143] = {.lex_state = 40},
  [144] = {.lex_state = 40},
  [145] = {.lex_state = 40},
  [146] = {.lex_state = 40},
  [147] = {.lex_state = 40},
  [148] = {.lex_state = 40},
  [149] = {.lex_state = 40},
  [150] = {.lex_state = 40},
  [151] = {.lex_state = 40},
  [152] = {.lex_state = 40},
  [153] = {.lex_state = 40},
  [154] = {.lex_state = 40},
  [155] = {.lex_state = 40},
  [156] = {.lex_state = 40},
  [157] = {.lex_state = 40},
  [158] = {.lex_state = 40},
  [159] = {.lex_state = 40},
  [160] = {.lex_state = 40},
  [161] = {.lex_state = 40},
  [162] = {.lex_state = 40},
  [163] = {.lex_state = 40},
  [164] = {.lex_state = 40},
  [165] = {.lex_state = 40},
  [166] = {.lex_state = 40},
  [167] = {.lex_state = 40},
  [168] = {.lex_state = 40},
  [169] = {.lex_state = 40},
  [170] = {.lex_state = 40},
  [171] = {.lex_state = 40},
  [172] = {.lex_state = 40},
  [173] = {.lex_state = 40},
  [174] = {.lex_state = 40},
  [175] = {.lex_state = 40},
  [176] = {.lex_state = 40},
  [177] = {.lex_state = 40},
  [178] = {.lex_state = 40},
  [179] = {.lex_state = 40},
  [180] = {.lex_state = 41},
  [181] = {.lex_state = 40},
  [182] = {.lex_state = 40},
  [183] = {.lex_state = 40},
  [184] = {.lex_state = 40},
  [185] = {.lex_state = 40},
  [186] = {.lex_state = 40},
  [187] = {.lex_state = 40},
  [188] = {.lex_state = 40},
  [189] = {.lex_state = 40},
  [190] = {.lex_state = 40},
  [191] = {.lex_state = 40},
  [192] = {.lex_state = 40},
  [193] = {.lex_state = 40},
  [194] = {.lex_state = 40},
  [195] = {.lex_state = 40},
  [196] = {.lex_state = 40},
  [197] = {.lex_state = 40},
  [198] = {.lex_state = 40},
  [199] = {.lex_state = 40},
  [200] = {.lex_state = 40},
  [201] = {.lex_state = 40},
  [202] = {.lex_state = 40},
  [203] = {.lex_state = 40},
  [204] = {.lex_state = 40},
  [205] = {.lex_state = 40},
  [206] = {.lex_state = 40},
  [207] = {.lex_state = 40},
  [208] = {.lex_state = 40},
  [209] = {.lex_state = 40},
  [210] = {.lex_state = 40},
  [211] = {.lex_state = 40},
  [212] = {.lex_state = 40},
  [213] = {.lex_state = 40},
  [214] = {.lex_state = 40},
  [215] = {.lex_state = 40},
  [216] = {.lex_state = 40},
  [217] = {.lex_state = 40},
  [218] = {.lex_state = 41},
  [219] = {.lex_state = 40},
  [220] = {.lex_state = 40},
  [221] = {.lex_state = 40},
  [222] = {.lex_state = 40},
  [223] = {.lex_state = 40},
  [224] = {.lex_state = 40},
  [225] = {.lex_state = 40},
  [226] = {.lex_state = 40},
  [227] = {.lex_state = 40},
  [228] = {.lex_state = 40},
  [229] = {.lex_state = 40},
  [230] = {.lex_state = 40},
  [231] = {.lex_state = 40},
  [232] = {.lex_state = 40},
  [233] = {.lex_state = 40},
  [234] = {.lex_state = 40},
  [235] = {.lex_state = 40},
  [236] = {.lex_state = 40},
  [237] = {.lex_state = 40},
  [238] = {.lex_state = 40},
  [239] = {.lex_state = 40},
  [240] = {.lex_state = 40},
  [241] = {.lex_state = 40},
  [242] = {.lex_state = 40},
  [243] = {.lex_state = 40},
  [244] = {.lex_state = 40},
  [245] = {.lex_state = 40},
  [246] = {.lex_state = 40},
  [247] = {.lex_state = 40},
  [248] = {.lex_state = 41},
  [249] = {.lex_state = 41},
  [250] = {.lex_state = 40},
  [251] = {.lex_state = 40},
  [252] = {.lex_state = 40},
  [253] = {.lex_state = 40},
  [254] = {.lex_state = 40},
  [255] = {.lex_state = 40},
  [256] = {.lex_state = 40},
  [257] = {.lex_state = 40},
  [258] = {.lex_state = 40},
  [259] = {.lex_state = 40},
  [260] = {.lex_state = 40},
  [261] = {.lex_state = 40},
  [262] = {.lex_state = 40},
  [263] = {.lex_state = 40},
  [264] = {.lex_state = 40},
  [265] = {.lex_state = 40},
  [266] = {.lex_state = 40},
  [267] = {.lex_state = 40},
  [268] = {.lex_state = 40},
  [269] = {.lex_state = 40},
  [270] = {.lex_state = 40},
  [271] = {.lex_state = 40},
  [272] = {.lex_state = 40},
  [273] = {.lex_state = 40},
  [274] = {.lex_state = 40},
  [275] = {.lex_state = 40},
  [276] = {.lex_state = 40},
  [277] = {.lex_state = 40},
  [278] = {.lex_state = 40},
  [279] = {.lex_state = 40},
  [280] = {.lex_state = 40},
  [281] = {.lex_state = 40},
  [282] = {.lex_state = 40},
  [283] = {.lex_state = 40},
  [284] = {.lex_state = 40},
  [285] = {.lex_state = 40},
  [286] = {.lex_state = 40},
  [287] = {.lex_state = 40},
  [288] = {.lex_state = 40},
  [289] = {.lex_state = 40},
  [290] = {.lex_state = 40},
  [291] = {.lex_state = 40},
  [292] = {.lex_state = 40},
  [293] = {.lex_state = 40},
  [294] = {.lex_state = 40},
  [295] = {.lex_state = 40},
  [296] = {.lex_state = 40},
  [297] = {.lex_state = 40},
  [298] = {.lex_state = 40},
  [299] = {.lex_state = 40},
  [300] = {.lex_state = 40},
  [301] = {.lex_state = 40},
  [302] = {.lex_state = 40},
  [303] = {.lex_state = 40},
  [304] = {.lex_state = 40},
  [305] = {.lex_state = 40},
  [306] = {.lex_state = 40},
  [307] = {.lex_state = 40},
  [308] = {.lex_state = 40},
  [309] = {.lex_state = 40},
  [310] = {.lex_state = 40},
  [311] = {.lex_state = 40},
  [312] = {.lex_state = 40},
  [313] = {.lex_state = 40},
  [314] = {.lex_state = 40},
  [315] = {.lex_state = 40},
  [316] = {.lex_state = 40},
  [317] = {.lex_state = 40},
  [318] = {.lex_state = 40},
  [319] = {.lex_state = 40},
  [320] = {.lex_state = 40},
  [321] = {.lex_state = 40},
  [322] = {.lex_state = 40},
  [323] = {.lex_state = 40},
  [324] = {.lex_state = 40},
  [325] = {.lex_state = 40},
  [326] = {.lex_state = 40},
  [327] = {.lex_state = 40},
  [328] = {.lex_state = 40},
  [329] = {.lex_state = 40},
  [330] = {.lex_state = 40},
  [331] = {.lex_state = 40},
  [332] = {.lex_state = 40},
  [333] = {.lex_state = 40},
  [334] = {.lex_state = 40},
  [335] = {.lex_state = 40},
  [336] = {.lex_state = 40},
  [337] = {.lex_state = 40},
  [338] = {.lex_state = 40},
  [339] = {.lex_state = 40},
  [340] = {.lex_state = 40},
  [341] = {.lex_state = 40},
  [342] = {.lex_state = 40},
  [343] = {.lex_state = 40},
  [344] = {.lex_state = 40},
  [345] = {.lex_state = 40},
  [346] = {.lex_state = 40},
  [347] = {.lex_state = 40},
  [348] = {.lex_state = 40},
  [349] = {.lex_state = 40},
  [350] = {.lex_state = 40},
  [351] = {.lex_state = 40},
  [352] = {.lex_state = 40},
  [353] = {.lex_state = 40},
  [354] = {.lex_state = 40},
  [355] = {.lex_state = 40},
  [356] = {.lex_state = 40},
  [357] = {.lex_state = 40},
  [358] = {.lex_state = 40},
  [359] = {.lex_state = 40},
  [360] = {.lex_state = 40},
  [361] = {.lex_state = 40},
  [362] = {.lex_state = 40},
  [363] = {.lex_state = 40},
  [364] = {.lex_state = 40},
  [365] = {.lex_state = 40},
  [366] = {.lex_state = 40},
  [367] = {.lex_state = 40},
  [368] = {.lex_state = 40},
  [369] = {.lex_state = 40},
  [370] = {.lex_state = 40},
  [371] = {.lex_state = 40},
  [372] = {.lex_state = 40},
  [373] = {.lex_state = 40},
  [374] = {.lex_state = 40},
  [375] = {.lex_state = 40},
  [376] = {.lex_state = 40},
  [377] = {.lex_state = 40},
  [378] = {.lex_state = 40},
  [379] = {.lex_state = 40},
  [380] = {.lex_state = 40},
  [381] = {.lex_state = 40},
  [382] = {.lex_state = 40},
  [383] = {.lex_state = 40},
  [384] = {.lex_state = 40},
  [385] = {.lex_state = 40},
  [386] = {.lex_state = 40},
  [387] = {.lex_state = 40},
  [388] = {.lex_state = 40},
  [389] = {.lex_state = 40},
  [390] = {.lex_state = 40},
  [391] = {.lex_state = 40},
  [392] = {.lex_state = 40},
  [393] = {.lex_state = 40},
  [394] = {.lex_state = 40},
  [395] = {.lex_state = 40},
  [396] = {.lex_state = 40},
  [397] = {.lex_state = 40},
  [398] = {.lex_state = 40},
  [399] = {.lex_state = 40},
  [400] = {.lex_state = 40},
  [401] = {.lex_state = 40},
  [402] = {.lex_state = 40},
  [403] = {.lex_state = 40},
  [404] = {.lex_state = 40},
  [405] = {.lex_state = 40},
  [406] = {.lex_state = 40},
  [407] = {.lex_state = 40},
  [408] = {.lex_state = 40},
  [409] = {.lex_state = 40},
  [410] = {.lex_state = 40},
  [411] = {.lex_state = 40},
  [412] = {.lex_state = 40},
  [413] = {.lex_state = 11},
  [414] = {.lex_state = 11},
  [415] = {.lex_state = 11},
  [416] = {.lex_state = 40},
  [417] = {.lex_state = 40},
  [418] = {.lex_state = 11},
  [419] = {.lex_state = 11},
  [420] = {.lex_state = 11},
  [421] = {.lex_state = 11},
  [422] = {.lex_state = 11},
  [423] = {.lex_state = 11},
  [424] = {.lex_state = 11},
  [425] = {.lex_state = 11},
  [426] = {.lex_state = 11},
  [427] = {.lex_state = 11},
  [428] = {.lex_state = 11},
  [429] = {.lex_state = 40},
  [430] = {.lex_state = 40},
  [431] = {.lex_state = 11},
  [432] = {.lex_state = 11},
  [433] = {.lex_state = 11},
  [434] = {.lex_state = 11},
  [435] = {.lex_state = 11},
  [436] = {.lex_state = 11},
  [437] = {.lex_state = 11},
  [438] = {.lex_state = 11},
  [439] = {.lex_state = 11},
  [440] = {.lex_state = 11},
  [441] = {.lex_state = 40},
  [442] = {.lex_state = 11},
  [443] = {.lex_state = 11},
  [444] = {.lex_state = 11},
  [445] = {.lex_state = 11},
  [446] = {.lex_state = 11},
  [447] = {.lex_state = 40},
  [448] = {.lex_state = 40},
  [449] = {.lex_state = 40},
  [450] = {.lex_state = 11},
  [451] = {.lex_state = 40},
  [452] = {.lex_state = 40},
  [453] = {.lex_state = 40},
  [454] = {.lex_state = 40},
  [455] = {.lex_state = 11},
  [456] = {.lex_state = 11},
  [457] = {.lex_state = 11},
  [458] = {.lex_state = 11},
  [459] = {.lex_state = 11},
  [460] = {.lex_state = 11},
  [461] = {.lex_state = 11},
  [462] = {.lex_state = 40},
  [463] = {.lex_state = 11},
  [464] = {.lex_state = 40},
  [465] = {.lex_state = 11},
  [466] = {.lex_state = 11},
  [467] = {.lex_state = 11},
  [468] = {.lex_state = 11},
  [469] = {.lex_state = 11},
  [470] = {.lex_state = 11},
  [471] = {.lex_state = 11},
  [472] = {.lex_state = 11},
  [473] = {.lex_state = 11},
  [474] = {.lex_state = 11},
  [475] = {.lex_state = 11},
  [476] = {.lex_state = 41},
  [477] = {.lex_state = 40},
  [478] = {.lex_state = 11},
  [479] = {.lex_state = 11},
  [480] = {.lex_state = 11},
  [481] = {.lex_state = 40},
  [482] = {.lex_state = 11},
  [483] = {.lex_state = 11},
  [484] = {.lex_state = 11},
  [485] = {.lex_state = 11},
  [486] = {.lex_state = 40},
  [487] = {.lex_state = 11},
  [488] = {.lex_state = 11},
  [489] = {.lex_state = 11},
  [490] = {.lex_state = 11},
  [491] = {.lex_state = 11},
  [492] = {.lex_state = 11},
  [493] = {.lex_state = 11},
  [494] = {.lex_state = 11},
  [495] = {.lex_state = 11},
  [496] = {.lex_state = 11},
  [497] = {.lex_state = 11},
  [498] = {.lex_state = 11},
  [499] = {.lex_state = 11},
  [500] = {.lex_state = 40},
  [501] = {.lex_state = 11},
  [502] = {.lex_state = 40},
  [503] = {.lex_state = 11},
  [504] = {.lex_state = 11},
  [505] = {.lex_state = 11},
  [506] = {.lex_state = 3},
  [507] = {.lex_state = 40},
  [508] = {.lex_state = 11},
  [509] = {.lex_state = 11},
  [510] = {.lex_state = 11},
  [511] = {.lex_state = 11},
  [512] = {.lex_state = 11},
  [513] = {.lex_state = 11},
  [514] = {.lex_state = 11},
  [515] = {.lex_state = 11},
  [516] = {.lex_state = 41},
  [517] = {.lex_state = 41},
  [518] = {.lex_state = 41},
  [519] = {.lex_state = 41},
  [520] = {.lex_state = 11},
  [521] = {.lex_state = 41},
  [522] = {.lex_state = 41},
  [523] = {.lex_state = 41},
  [524] = {.lex_state = 41},
  [525] = {.lex_state = 41},
  [526] = {.lex_state = 41},
  [527] = {.lex_state = 11},
  [528] = {.lex_state = 41},
  [529] = {.lex_state = 41},
  [530] = {.lex_state = 41},
  [531] = {.lex_state = 41},
  [532] = {.lex_state = 41},
  [533] = {.lex_state = 41},
  [534] = {.lex_state = 41},
  [535] = {.lex_state = 41},
  [536] = {.lex_state = 41},
  [537] = {.lex_state = 41},
  [538] = {.lex_state = 41},
  [539] = {.lex_state = 11},
  [540] = {.lex_state = 11},
  [541] = {.lex_state = 41},
  [542] = {.lex_state = 41},
  [543] = {.lex_state = 11},
  [544] = {.lex_state = 41},
  [545] = {.lex_state = 41},
  [546] = {.lex_state = 2},
  [547] = {.lex_state = 1},
  [548] = {.lex_state = 2},
  [549] = {.lex_state = 1},
  [550] = {.lex_state = 41},
  [551] = {.lex_state = 1},
  [552] = {.lex_state = 41},
  [553] = {.lex_state = 2},
  [554] = {.lex_state = 40},
  [555] = {.lex_state = 40},
  [556] = {.lex_state = 40},
  [557] = {.lex_state = 6},
  [558] = {.lex_state = 6},
  [559] = {.lex_state = 6},
  [560] = {.lex_state = 41},
  [561] = {.lex_state = 41},
  [562] = {.lex_state = 41},
  [563] = {.lex_state = 41},
  [564] = {.lex_state = 41},
  [565] = {.lex_state = 41},
  [566] = {.lex_state = 41},
  [567] = {.lex_state = 41},
  [568] = {.lex_state = 41},
  [569] = {.lex_state = 41},
  [570] = {.lex_state = 41},
  [571] = {.lex_state = 41},
  [572] = {.lex_state = 41},
  [573] = {.lex_state = 41},
  [574] = {.lex_state = 41},
  [575] = {.lex_state = 41},
  [576] = {.lex_state = 41},
  [577] = {.lex_state = 41},
  [578] = {.lex_state = 41},
  [579] = {.lex_state = 41},
  [580] = {.lex_state = 41},
  [581] = {.lex_state = 41},
  [582] = {.lex_state = 41},
  [583] = {.lex_state = 41},
  [584] = {.lex_state = 41},
  [585] = {.lex_state = 41},
  [586] = {.lex_state = 41},
  [587] = {.lex_state = 41},
  [588] = {.lex_state = 41},
  [589] = {.lex_state = 41},
  [590] = {.lex_state = 41},
  [591] = {.lex_state = 41},
  [592] = {.lex_state = 41},
  [593] = {.lex_state = 41},
  [594] = {.lex_state = 41},
  [595] = {.lex_state = 41},
  [596] = {.lex_state = 40},
  [597] = {.lex_state = 40},
  [598] = {.lex_state = 40},
  [599] = {.lex_state = 41},
  [600] = {.lex_state = 41},
  [601] = {.lex_state = 41},
  [602] = {.lex_state = 40},
  [603] = {.lex_state = 40},
  [604] = {.lex_state = 41},
  [605] = {.lex_state = 40},
  [606] = {.lex_state = 40},
  [607] = {.lex_state = 41},
  [608] = {.lex_state = 41},
  [609] = {.lex_state = 40},
  [610] = {.lex_state = 40},
  [611] = {.lex_state = 40},
  [612] = {.lex_state = 41},
  [613] = {.lex_state = 40},
  [614] = {.lex_state = 40},
  [615] = {.lex_state = 40},
  [616] = {.lex_state = 40},
  [617] = {.lex_state = 41},
  [618] = {.lex_state = 40},
  [619] = {.lex_state = 41},
  [620] = {.lex_state = 41},
  [621] = {.lex_state = 40},
  [622] = {.lex_state = 40},
  [623] = {.lex_state = 40},
  [624] = {.lex_state = 40},
  [625] = {.lex_state = 41},
  [626] = {.lex_state = 40},
  [627] = {.lex_state = 41},
  [628] = {.lex_state = 40},
  [629] = {.lex_state = 40},
  [630] = {.lex_state = 40},
  [631] = {.lex_state = 40},
  [632] = {.lex_state = 40},
  [633] = {.lex_state = 40},
  [634] = {.lex_state = 40},
  [635] = {.lex_state = 40},
  [636] = {.lex_state = 40},
  [637] = {.lex_state = 40},
  [638] = {.lex_state = 40},
  [639] = {.lex_state = 41},
  [640] = {.lex_state = 41},
  [641] = {.lex_state = 41},
  [642] = {.lex_state = 40},
  [643] = {.lex_state = 4},
  [644] = {.lex_state = 3},
  [645] = {.lex_state = 4},
  [646] = {.lex_state = 4},
  [647] = {.lex_state = 4},
  [648] = {.lex_state = 4},
  [649] = {.lex_state = 4},
  [650] = {.lex_state = 4},
  [651] = {.lex_state = 4},
  [652] = {.lex_state = 41},
  [653] = {.lex_state = 4},
  [654] = {.lex_state = 3},
  [655] = {.lex_state = 3},
  [656] = {.lex_state = 3},
  [657] = {.lex_state = 3},
  [658] = {.lex_state = 3},
  [659] = {.lex_state = 40},
  [660] = {.lex_state = 40},
  [661] = {.lex_state = 40},
  [662] = {.lex_state = 3},
  [663] = {.lex_state = 40},
  [664] = {.lex_state = 3},
  [665] = {.lex_state = 40},
  [666] = {.lex_state = 40},
  [667] = {.lex_state = 3},
  [668] = {.lex_state = 40},
  [669] = {.lex_state = 41},
  [670] = {.lex_state = 41},
  [671] = {.lex_state = 4},
  [672] = {.lex_state = 3},
  [673] = {.lex_state = 40},
  [674] = {.lex_state = 40},
  [675] = {.lex_state = 40},
  [676] = {.lex_state = 40},
  [677] = {.lex_state = 40},
  [678] = {.lex_state = 41},
  [679] = {.lex_state = 41},
  [680] = {.lex_state = 40},
  [681] = {.lex_state = 41},
  [682] = {.lex_state = 40},
  [683] = {.lex_state = 40},
  [684] = {.lex_state = 40},
  [685] = {.lex_state = 40},
  [686] = {.lex_state = 41},
  [687] = {.lex_state = 41},
  [688] = {.lex_state = 41},
  [689] = {.lex_state = 40},
  [690] = {.lex_state = 41},
  [691] = {.lex_state = 41},
  [692] = {.lex_state = 41},
  [693] = {.lex_state = 41},
  [694] = {.lex_state = 41},
  [695] = {.lex_state = 40},
  [696] = {.lex_state = 40},
  [697] = {.lex_state = 40},
  [698] = {.lex_state = 40},
  [699] = {.lex_state = 40},
  [700] = {.lex_state = 41},
  [701] = {.lex_state = 41},
  [702] = {.lex_state = 41},
  [703] = {.lex_state = 40},
  [704] = {.lex_state = 40},
  [705] = {.lex_state = 40},
  [706] = {.lex_state = 40},
  [707] = {.lex_state = 40},
  [708] = {.lex_state = 40},
  [709] = {.lex_state = 40},
  [710] = {.lex_state = 40},
  [711] = {.lex_state = 40},
  [712] = {.lex_state = 40},
  [713] = {.lex_state = 40},
  [714] = {.lex_state = 40},
  [715] = {.lex_state = 40},
  [716] = {.lex_state = 40},
  [717] = {.lex_state = 40},
  [718] = {.lex_state = 40},
  [719] = {.lex_state = 40},
  [720] = {.lex_state = 40},
  [721] = {.lex_state = 40},
  [722] = {.lex_state = 40},
  [723] = {.lex_state = 40},
  [724] = {.lex_state = 40},
  [725] = {.lex_state = 40},
  [726] = {.lex_state = 40},
  [727] = {.lex_state = 40},
  [728] = {.lex_state = 40},
  [729] = {.lex_state = 40},
  [730] = {.lex_state = 40},
  [731] = {.lex_state = 40},
  [732] = {.lex_state = 40},
  [733] = {.lex_state = 40},
  [734] = {.lex_state = 40},
  [735] = {.lex_state = 40},
  [736] = {.lex_state = 40},
  [737] = {.lex_state = 40},
  [738] = {.lex_state = 40},
  [739] = {.lex_state = 40},
  [740] = {.lex_state = 40},
  [741] = {.lex_state = 40},
  [742] = {.lex_state = 40},
  [743] = {.lex_state = 40},
  [744] = {.lex_state = 40},
  [745] = {.lex_state = 40},
  [746] = {.lex_state = 40},
  [747] = {.lex_state = 40},
  [748] = {.lex_state = 40},
  [749] = {.lex_state = 40},
  [750] = {.lex_state = 40},
  [751] = {.lex_state = 40},
  [752] = {.lex_state = 40},
  [753] = {.lex_state = 41},
  [754] = {.lex_state = 40},
  [755] = {.lex_state = 40},
  [756] = {.lex_state = 41},
  [757] = {.lex_state = 40},
  [758] = {.lex_state = 40},
  [759] = {.lex_state = 40},
  [760] = {.lex_state = 40},
  [761] = {.lex_state = 40},
  [762] = {.lex_state = 41},
  [763] = {.lex_state = 40},
  [764] = {.lex_state = 40},
  [765] = {.lex_state = 40},
  [766] = {.lex_state = 40},
  [767] = {.lex_state = 40},
  [768] = {.lex_state = 40},
  [769] = {.lex_state = 40},
  [770] = {.lex_state = 40},
  [771] = {.lex_state = 40},
  [772] = {.lex_state = 41},
  [773] = {.lex_state = 40},
  [774] = {.lex_state = 40},
  [775] = {.lex_state = 40},
  [776] = {.lex_state = 41},
  [777] = {.lex_state = 41},
  [778] = {.lex_state = 41},
  [779] = {.lex_state = 41},
  [780] = {.lex_state = 41},
  [781] = {.lex_state = 41},
  [782] = {.lex_state = 40},
  [783] = {.lex_state = 41},
  [784] = {.lex_state = 41},
  [785] = {.lex_state = 40},
  [786] = {.lex_state = 40},
  [787] = {.lex_state = 40},
  [788] = {.lex_state = 40},
  [789] = {.lex_state = 40},
  [790] = {.lex_state = 40},
  [791] = {.lex_state = 41},
  [792] = {.lex_state = 40},
  [793] = {.lex_state = 40},
  [794] = {.lex_state = 41},
  [795] = {.lex_state = 41},
  [796] = {.lex_state = 41},
  [797] = {.lex_state = 41},
  [798] = {.lex_state = 41},
  [799] = {.lex_state = 41},
  [800] = {.lex_state = 40},
  [801] = {.lex_state = 40},
  [802] = {.lex_state = 40},
  [803] = {.lex_state = 40},
  [804] = {.lex_state = 40},
  [805] = {.lex_state = 40},
  [806] = {.lex_state = 40},
  [807] = {.lex_state = 40},
  [808] = {.lex_state = 40},
  [809] = {.lex_state = 40},
  [810] = {.lex_state = 40},
  [811] = {.lex_state = 40},
  [812] = {.lex_state = 40},
  [813] = {.lex_state = 40},
  [814] = {.lex_state = 40},
  [815] = {.lex_state = 40},
  [816] = {.lex_state = 40},
  [817] = {.lex_state = 40},
  [818] = {.lex_state = 40},
  [819] = {.lex_state = 40},
  [820] = {.lex_state = 40},
  [821] = {.lex_state = 40},
  [822] = {.lex_state = 40},
  [823] = {.lex_state = 40},
  [824] = {.lex_state = 40},
  [825] = {.lex_state = 40},
  [826] = {.lex_state = 40},
  [827] = {.lex_state = 40},
  [828] = {.lex_state = 40},
  [829] = {.lex_state = 40},
  [830] = {.lex_state = 40},
  [831] = {.lex_state = 40},
  [832] = {.lex_state = 41},
  [833] = {.lex_state = 40},
  [834] = {.lex_state = 40},
  [835] = {.lex_state = 40},
  [836] = {.lex_state = 40},
  [837] = {.lex_state = 40},
  [838] = {.lex_state = 40},
  [839] = {.lex_state = 40},
  [840] = {.lex_state = 40},
  [841] = {.lex_state = 40},
  [842] = {.lex_state = 40},
  [843] = {.lex_state = 41},
  [844] = {.lex_state = 40},
  [845] = {.lex_state = 41},
  [846] = {.lex_state = 40},
  [847] = {.lex_state = 41},
  [848] = {.lex_state = 40},
  [849] = {.lex_state = 40},
  [850] = {.lex_state = 40},
  [851] = {.lex_state = 41},
  [852] = {.lex_state = 40},
  [853] = {.lex_state = 40},
  [854] = {.lex_state = 40},
  [855] = {.lex_state = 40},
  [856] = {.lex_state = 41},
  [857] = {.lex_state = 40},
  [858] = {.lex_state = 41},
  [859] = {.lex_state = 41},
  [860] = {.lex_state = 40},
  [861] = {.lex_state = 41},
  [862] = {.lex_state = 41},
  [863] = {.lex_state = 41},
  [864] = {.lex_state = 40},
  [865] = {.lex_state = 41},
  [866] = {.lex_state = 41},
  [867] = {.lex_state = 40},
  [868] = {.lex_state = 40},
  [869] = {.lex_state = 41},
  [870] = {.lex_state = 40},
  [871] = {.lex_state = 41},
  [872] = {.lex_state = 41},
  [873] = {.lex_state = 40},
  [874] = {.lex_state = 40},
  [875] = {.lex_state = 41},
  [876] = {.lex_state = 41},
  [877] = {.lex_state = 41},
  [878] = {.lex_state = 40},
  [879] = {.lex_state = 40},
  [880] = {.lex_state = 41},
  [881] = {.lex_state = 41},
  [882] = {.lex_state = 41},
  [883] = {.lex_state = 41},
  [884] = {.lex_state = 41},
  [885] = {.lex_state = 40},
  [886] = {.lex_state = 41},
  [887] = {.lex_state = 41},
  [888] = {.lex_state = 40},
  [889] = {.lex_state = 40},
  [890] = {.lex_state = 40},
  [891] = {.lex_state = 40},
  [892] = {.lex_state = 40},
  [893] = {.lex_state = 40},
  [894] = {.lex_state = 40},
  [895] = {.lex_state = 40},
  [896] = {.lex_state = 40},
  [897] = {.lex_state = 40},
  [898] = {.lex_state = 40},
  [899] = {.lex_state = 40},
  [900] = {.lex_state = 40},
  [901] = {.lex_state = 40},
  [902] = {.lex_state = 40},
  [903] = {.lex_state = 40},
  [904] = {.lex_state = 40},
  [905] = {.lex_state = 40},
  [906] = {.lex_state = 40},
  [907] = {.lex_state = 40},
  [908] = {.lex_state = 40},
  [909] = {.lex_state = 40},
  [910] = {.lex_state = 40},
  [911] = {.lex_state = 40},
  [912] = {.lex_state = 41},
  [913] = {.lex_state = 40},
  [914] = {.lex_state = 40},
  [915] = {.lex_state = 40},
  [916] = {.lex_state = 40},
  [917] = {.lex_state = 40},
  [918] = {.lex_state = 40},
  [919] = {.lex_state = 40},
  [920] = {.lex_state = 40},
  [921] = {.lex_state = 40},
  [922] = {.lex_state = 40},
  [923] = {.lex_state = 40},
  [924] = {.lex_state = 40},
  [925] = {.lex_state = 40},
  [926] = {.lex_state = 40},
  [927] = {.lex_state = 40},
  [928] = {.lex_state = 40},
  [929] = {.lex_state = 40},
  [930] = {.lex_state = 40},
  [931] = {.lex_state = 40},
  [932] = {.lex_state = 40},
  [933] = {.lex_state = 40},
  [934] = {.lex_state = 40},
  [935] = {.lex_state = 40},
  [936] = {.lex_state = 40},
  [937] = {.lex_state = 40},
  [938] = {.lex_state = 40},
  [939] = {.lex_state = 40},
  [940] = {.lex_state = 40},
  [941] = {.lex_state = 40},
  [942] = {.lex_state = 40},
  [943] = {.lex_state = 40},
  [944] = {.lex_state = 40},
  [945] = {.lex_state = 40},
  [946] = {.lex_state = 40},
  [947] = {.lex_state = 40},
  [948] = {.lex_state = 40},
  [949] = {.lex_state = 40},
  [950] = {.lex_state = 40},
  [951] = {.lex_state = 40},
  [952] = {.lex_state = 40},
  [953] = {.lex_state = 40},
  [954] = {.lex_state = 40},
  [955] = {.lex_state = 40},
  [956] = {.lex_state = 40},
  [957] = {.lex_state = 40},
  [958] = {.lex_state = 40},
  [959] = {.lex_state = 40},
  [960] = {.lex_state = 40},
  [961] = {.lex_state = 40},
  [962] = {.lex_state = 40},
  [963] = {.lex_state = 40},
  [964] = {.lex_state = 40},
  [965] = {.lex_state = 40},
  [966] = {.lex_state = 40},
  [967] = {.lex_state = 40},
  [968] = {.lex_state = 40},
  [969] = {.lex_state = 40},
  [970] = {.lex_state = 40},
  [971] = {.lex_state = 40},
  [972] = {.lex_state = 40},
  [973] = {.lex_state = 40},
  [974] = {.lex_state = 40},
  [975] = {.lex_state = 40},
  [976] = {.lex_state = 40},
  [977] = {.lex_state = 40},
  [978] = {.lex_state = 40},
  [979] = {.lex_state = 40},
  [980] = {.lex_state = 40},
  [981] = {.lex_state = 40},
  [982] = {.lex_state = 40},
  [983] = {.lex_state = 40},
  [984] = {.lex_state = 40},
  [985] = {.lex_state = 40},
  [986] = {.lex_state = 40},
  [987] = {.lex_state = 40},
  [988] = {.lex_state = 40},
  [989] = {.lex_state = 40},
  [990] = {.lex_state = 40},
  [991] = {.lex_state = 40},
  [992] = {.lex_state = 40},
  [993] = {.lex_state = 40},
  [994] = {.lex_state = 40},
  [995] = {.lex_state = 40},
  [996] = {.lex_state = 40},
  [997] = {.lex_state = 40},
  [998] = {.lex_state = 40},
  [999] = {.lex_state = 40},
  [1000] = {.lex_state = 40},
  [1001] = {.lex_state = 40},
  [1002] = {.lex_state = 40},
  [1003] = {.lex_state = 40},
  [1004] = {.lex_state = 40},
  [1005] = {.lex_state = 40},
  [1006] = {.lex_state = 40},
  [1007] = {.lex_state = 40},
  [1008] = {.lex_state = 40},
  [1009] = {.lex_state = 40},
  [1010] = {.lex_state = 40},
  [1011] = {.lex_state = 40},
  [1012] = {.lex_state = 40},
  [1013] = {.lex_state = 40},
  [1014] = {.lex_state = 40},
  [1015] = {.lex_state = 40},
  [1016] = {.lex_state = 40},
  [1017] = {.lex_state = 41},
  [1018] = {.lex_state = 41},
  [1019] = {.lex_state = 41},
  [1020] = {.lex_state = 41},
  [1021] = {.lex_state = 11},
  [1022] = {.lex_state = 40},
  [1023] = {.lex_state = 41},
  [1024] = {.lex_state = 41},
  [1025] = {.lex_state = 41},
  [1026] = {.lex_state = 41},
  [1027] = {.lex_state = 41},
  [1028] = {.lex_state = 41},
  [1029] = {.lex_state = 41},
  [1030] = {.lex_state = 11},
  [1031] = {.lex_state = 40},
  [1032] = {.lex_state = 40},
  [1033] = {.lex_state = 40},
  [1034] = {.lex_state = 41},
  [1035] = {.lex_state = 11},
  [1036] = {.lex_state = 41},
  [1037] = {.lex_state = 40},
  [1038] = {.lex_state = 40},
  [1039] = {.lex_state = 40},
  [1040] = {.lex_state = 11},
  [1041] = {.lex_state = 40},
  [1042] = {.lex_state = 40},
  [1043] = {.lex_state = 40},
  [1044] = {.lex_state = 40},
  [1045] = {.lex_state = 40},
  [1046] = {.lex_state = 11},
  [1047] = {.lex_state = 41},
  [1048] = {.lex_state = 40},
  [1049] = {.lex_state = 11},
  [1050] = {.lex_state = 41},
  [1051] = {.lex_state = 41},
  [1052] = {.lex_state = 41},
  [1053] = {.lex_state = 41},
  [1054] = {.lex_state = 41},
  [1055] = {.lex_state = 41},
  [1056] = {.lex_state = 41},
  [1057] = {.lex_state = 41},
  [1058] = {.lex_state = 41},
  [1059] = {.lex_state = 41},
  [1060] = {.lex_state = 41},
  [1061] = {.lex_state = 40},
  [1062] = {.lex_state = 41},
  [1063] = {.lex_state = 41},
  [1064] = {.lex_state = 41},
  [1065] = {.lex_state = 41},
  [1066] = {.lex_state = 41},
  [1067] = {.lex_state = 41},
  [1068] = {.lex_state = 41},
  [1069] = {.lex_state = 41},
  [1070] = {.lex_state = 41},
  [1071] = {.lex_state = 41},
  [1072] = {.lex_state = 41},
  [1073] = {.lex_state = 41},
  [1074] = {.lex_state = 41},
  [1075] = {.lex_state = 41},
  [1076] = {.lex_state = 41},
  [1077] = {.lex_state = 40},
  [1078] = {.lex_state = 41},
  [1079] = {.lex_state = 41},
  [1080] = {.lex_state = 41},
  [1081] = {.lex_state = 40},
  [1082] = {.lex_state = 41},
  [1083] = {.lex_state = 41},
  [1084] = {.lex_state = 41},
  [1085] = {.lex_state = 41},
  [1086] = {.lex_state = 41},
  [1087] = {.lex_state = 41},
  [1088] = {.lex_state = 41},
  [1089] = {.lex_state = 41},
  [1090] = {.lex_state = 41},
  [1091] = {.lex_state = 41},
  [1092] = {.lex_state = 41},
  [1093] = {.lex_state = 41},
  [1094] = {.lex_state = 41},
  [1095] = {.lex_state = 41},
  [1096] = {.lex_state = 41},
  [1097] = {.lex_state = 41},
  [1098] = {.lex_state = 41},
  [1099] = {.lex_state = 41},
  [1100] = {.lex_state = 41},
  [1101] = {.lex_state = 40},
  [1102] = {.lex_state = 40},
  [1103] = {.lex_state = 41},
  [1104] = {.lex_state = 40},
  [1105] = {.lex_state = 41},
  [1106] = {.lex_state = 41},
  [1107] = {.lex_state = 41},
  [1108] = {.lex_state = 41},
  [1109] = {.lex_state = 41},
  [1110] = {.lex_state = 40},
  [1111] = {.lex_state = 40},
  [1112] = {.lex_state = 40},
  [1113] = {.lex_state = 40},
  [1114] = {.lex_state = 40},
  [1115] = {.lex_state = 40},
  [1116] = {.lex_state = 40},
  [1117] = {.lex_state = 40},
  [1118] = {.lex_state = 11},
  [1119] = {.lex_state = 40},
  [1120] = {.lex_state = 40},
  [1121] = {.lex_state = 40},
  [1122] = {.lex_state = 41},
  [1123] = {.lex_state = 40},
  [1124] = {.lex_state = 40},
  [1125] = {.lex_state = 40},
  [1126] = {.lex_state = 40},
  [1127] = {.lex_state = 40},
  [1128] = {.lex_state = 40},
  [1129] = {.lex_state = 40},
  [1130] = {.lex_state = 40},
  [1131] = {.lex_state = 40},
  [1132] = {.lex_state = 40},
  [1133] = {.lex_state = 40},
  [1134] = {.lex_state = 40},
  [1135] = {.lex_state = 40},
  [1136] = {.lex_state = 40},
  [1137] = {.lex_state = 40},
  [1138] = {.lex_state = 40},
  [1139] = {.lex_state = 40},
  [1140] = {.lex_state = 40},
  [1141] = {.lex_state = 40},
  [1142] = {.lex_state = 40},
  [1143] = {.lex_state = 40},
  [1144] = {.lex_state = 40},
  [1145] = {.lex_state = 40},
  [1146] = {.lex_state = 40},
  [1147] = {.lex_state = 40},
  [1148] = {.lex_state = 40},
  [1149] = {.lex_state = 40},
  [1150] = {.lex_state = 40},
  [1151] = {.lex_state = 40},
  [1152] = {.lex_state = 40},
  [1153] = {.lex_state = 40},
  [1154] = {.lex_state = 40},
  [1155] = {.lex_state = 40},
  [1156] = {.lex_state = 40},
  [1157] = {.lex_state = 40},
  [1158] = {.lex_state = 40},
  [1159] = {.lex_state = 40},
  [1160] = {.lex_state = 40},
  [1161] = {.lex_state = 40},
  [1162] = {.lex_state = 40},
  [1163] = {.lex_state = 40},
  [1164] = {.lex_state = 40},
  [1165] = {.lex_state = 40},
  [1166] = {.lex_state = 40},
  [1167] = {.lex_state = 40},
  [1168] = {.lex_state = 40},
  [1169] = {.lex_state = 40},
  [1170] = {.lex_state = 40},
  [1171] = {.lex_state = 40},
  [1172] = {.lex_state = 40},
  [1173] = {.lex_state = 40},
  [1174] = {.lex_state = 40},
  [1175] = {.lex_state = 40},
  [1176] = {.lex_state = 41},
  [1177] = {.lex_state = 40},
  [1178] = {.lex_state = 40},
  [1179] = {.lex_state = 40},
  [1180] = {.lex_state = 40},
  [1181] = {.lex_state = 40},
  [1182] = {.lex_state = 40},
  [1183] = {.lex_state = 40},
  [1184] = {.lex_state = 40},
  [1185] = {.lex_state = 40},
  [1186] = {.lex_state = 40},
  [1187] = {.lex_state = 40},
  [1188] = {.lex_state = 41},
  [1189] = {.lex_state = 4},
  [1190] = {.lex_state = 41},
  [1191] = {.lex_state = 40},
  [1192] = {.lex_state = 41},
  [1193] = {.lex_state = 40},
  [1194] = {.lex_state = 40},
  [1195] = {.lex_state = 40},
  [1196] = {.lex_state = 3},
  [1197] = {.lex_state = 40},
  [1198] = {.lex_state = 40},
  [1199] = {.lex_state = 40},
  [1200] = {.lex_state = 40},
  [1201] = {.lex_state = 40},
  [1202] = {.lex_state = 40},
  [1203] = {.lex_state = 4},
  [1204] = {.lex_state = 3},
  [1205] = {.lex_state = 41},
  [1206] = {.lex_state = 40},
  [1207] = {.lex_state = 41},
  [1208] = {.lex_state = 41},
  [1209] = {.lex_state = 41},
  [1210] = {.lex_state = 41},
  [1211] = {.lex_state = 40},
  [1212] = {.lex_state = 40},
  [1213] = {.lex_state = 41},
  [1214] = {.lex_state = 40},
  [1215] = {.lex_state = 40},
  [1216] = {.lex_state = 40},
  [1217] = {.lex_state = 40},
  [1218] = {.lex_state = 40},
  [1219] = {.lex_state = 41},
  [1220] = {.lex_state = 40},
  [1221] = {.lex_state = 41},
  [1222] = {.lex_state = 4},
  [1223] = {.lex_state = 40},
  [1224] = {.lex_state = 3},
  [1225] = {.lex_state = 40},
  [1226] = {.lex_state = 40},
  [1227] = {.lex_state = 41},
  [1228] = {.lex_state = 41},
  [1229] = {.lex_state = 40},
  [1230] = {.lex_state = 40},
  [1231] = {.lex_state = 41},
  [1232] = {.lex_state = 40},
  [1233] = {.lex_state = 40},
  [1234] = {.lex_state = 40},
  [1235] = {.lex_state = 40},
  [1236] = {.lex_state = 41},
  [1237] = {.lex_state = 41},
  [1238] = {.lex_state = 4},
  [1239] = {.lex_state = 41},
  [1240] = {.lex_state = 40},
  [1241] = {.lex_state = 40},
  [1242] = {.lex_state = 3},
  [1243] = {.lex_state = 40},
  [1244] = {.lex_state = 40},
  [1245] = {.lex_state = 4},
  [1246] = {.lex_state = 4},
  [1247] = {.lex_state = 3},
  [1248] = {.lex_state = 3},
  [1249] = {.lex_state = 40},
  [1250] = {.lex_state = 4},
  [1251] = {.lex_state = 41},
  [1252] = {.lex_state = 41},
  [1253] = {.lex_state = 41},
  [1254] = {.lex_state = 3},
  [1255] = {.lex_state = 41},
  [1256] = {.lex_state = 4},
  [1257] = {.lex_state = 41},
  [1258] = {.lex_state = 40},
  [1259] = {.lex_state = 40},
  [1260] = {.lex_state = 4},
  [1261] = {.lex_state = 3},
  [1262] = {.lex_state = 4},
  [1263] = {.lex_state = 40},
  [1264] = {.lex_state = 3},
  [1265] = {.lex_state = 40},
  [1266] = {.lex_state = 3},
  [1267] = {.lex_state = 3},
  [1268] = {.lex_state = 3},
  [1269] = {.lex_state = 4},
  [1270] = {.lex_state = 3},
  [1271] = {.lex_state = 4},
  [1272] = {.lex_state = 11},
  [1273] = {.lex_state = 3},
  [1274] = {.lex_state = 4},
  [1275] = {.lex_state = 3},
  [1276] = {.lex_state = 4},
  [1277] = {.lex_state = 11},
  [1278] = {.lex_state = 11},
  [1279] = {.lex_state = 3},
  [1280] = {.lex_state = 41},
  [1281] = {.lex_state = 41},
  [1282] = {.lex_state = 3},
  [1283] = {.lex_state = 11},
  [1284] = {.lex_state = 4},
  [1285] = {.lex_state = 3},
  [1286] = {.lex_state = 41},
  [1287] = {.lex_state = 3},
  [1288] = {.lex_state = 3},
  [1289] = {.lex_state = 3},
  [1290] = {.lex_state = 41},
  [1291] = {.lex_state = 3},
  [1292] = {.lex_state = 4},
  [1293] = {.lex_state = 4},
  [1294] = {.lex_state = 4},
  [1295] = {.lex_state = 3},
  [1296] = {.lex_state = 11},
  [1297] = {.lex_state = 3},
  [1298] = {.lex_state = 3},
  [1299] = {.lex_state = 4},
  [1300] = {.lex_state = 4},
  [1301] = {.lex_state = 3},
  [1302] = {.lex_state = 41},
  [1303] = {.lex_state = 3},
  [1304] = {.lex_state = 4},
  [1305] = {.lex_state = 41},
  [1306] = {.lex_state = 3},
  [1307] = {.lex_state = 40},
  [1308] = {.lex_state = 41},
  [1309] = {.lex_state = 4},
  [1310] = {.lex_state = 4},
  [1311] = {.lex_state = 4},
  [1312] = {.lex_state = 4},
  [1313] = {.lex_state = 4},
  [1314] = {.lex_state = 4},
  [1315] = {.lex_state = 11},
  [1316] = {.lex_state = 3},
  [1317] = {.lex_state = 4},
  [1318] = {.lex_state = 4},
  [1319] = {.lex_state = 4},
  [1320] = {.lex_state = 4},
  [1321] = {.lex_state = 3},
  [1322] = {.lex_state = 4},
  [1323] = {.lex_state = 3},
  [1324] = {.lex_state = 3},
  [1325] = {.lex_state = 41},
  [1326] = {.lex_state = 4},
  [1327] = {.lex_state = 3},
  [1328] = {.lex_state = 4},
  [1329] = {.lex_state = 41},
  [1330] = {.lex_state = 41},
  [1331] = {.lex_state = 11},
  [1332] = {.lex_state = 11},
  [1333] = {.lex_state = 11},
  [1334] = {.lex_state = 11},
  [1335] = {.lex_state = 11},
  [1336] = {.lex_state = 11},
  [1337] = {.lex_state = 11},
  [1338] = {.lex_state = 11},
  [1339] = {.lex_state = 41},
  [1340] = {.lex_state = 11},
  [1341] = {.lex_state = 11},
  [1342] = {.lex_state = 11},
  [1343] = {.lex_state = 11},
  [1344] = {.lex_state = 11},
  [1345] = {.lex_state = 11},
  [1346] = {.lex_state = 11},
  [1347] = {.lex_state = 11},
  [1348] = {.lex_state = 11},
  [1349] = {.lex_state = 11},
  [1350] = {.lex_state = 11},
  [1351] = {.lex_state = 41},
  [1352] = {.lex_state = 41},
  [1353] = {.lex_state = 11},
  [1354] = {.lex_state = 11},
  [1355] = {.lex_state = 11},
  [1356] = {.lex_state = 41},
  [1357] = {.lex_state = 11},
  [1358] = {.lex_state = 41},
  [1359] = {.lex_state = 11},
  [1360] = {.lex_state = 41},
  [1361] = {.lex_state = 41},
  [1362] = {.lex_state = 41},
  [1363] = {.lex_state = 11},
  [1364] = {.lex_state = 41},
  [1365] = {.lex_state = 11},
  [1366] = {.lex_state = 41},
  [1367] = {.lex_state = 11},
  [1368] = {.lex_state = 11},
  [1369] = {.lex_state = 11},
  [1370] = {.lex_state = 11},
  [1371] = {.lex_state = 11},
  [1372] = {.lex_state = 11},
  [1373] = {.lex_state = 41},
  [1374] = {.lex_state = 41},
  [1375] = {.lex_state = 41},
  [1376] = {.lex_state = 41},
  [1377] = {.lex_state = 41},
  [1378] = {.lex_state = 11},
  [1379] = {.lex_state = 11},
  [1380] = {.lex_state = 11},
  [1381] = {.lex_state = 11},
  [1382] = {.lex_state = 11},
  [1383] = {.lex_state = 41},
  [1384] = {.lex_state = 11},
  [1385] = {.lex_state = 41},
  [1386] = {.lex_state = 41},
  [1387] = {.lex_state = 41},
  [1388] = {.lex_state = 41},
  [1389] = {.lex_state = 41},
  [1390] = {.lex_state = 41},
  [1391] = {.lex_state = 41},
  [1392] = {.lex_state = 41},
  [1393] = {.lex_state = 41},
  [1394] = {.lex_state = 41},
  [1395] = {.lex_state = 41},
  [1396] = {.lex_state = 41},
  [1397] = {.lex_state = 41},
  [1398] = {.lex_state = 41},
  [1399] = {.lex_state = 41},
  [1400] = {.lex_state = 41},
  [1401] = {.lex_state = 41},
  [1402] = {.lex_state = 41},
  [1403] = {.lex_state = 41},
  [1404] = {.lex_state = 41},
  [1405] = {.lex_state = 41},
  [1406] = {.lex_state = 41},
  [1407] = {.lex_state = 11},
  [1408] = {.lex_state = 11},
  [1409] = {.lex_state = 11},
  [1410] = {.lex_state = 41},
  [1411] = {.lex_state = 41},
  [1412] = {.lex_state = 11},
  [1413] = {.lex_state = 11},
  [1414] = {.lex_state = 11},
  [1415] = {.lex_state = 41},
  [1416] = {.lex_state = 11},
  [1417] = {.lex_state = 11},
  [1418] = {.lex_state = 11},
  [1419] = {.lex_state = 11},
  [1420] = {.lex_state = 11},
  [1421] = {.lex_state = 11},
  [1422] = {.lex_state = 11},
  [1423] = {.lex_state = 11},
  [1424] = {.lex_state = 11},
  [1425] = {.lex_state = 41},
  [1426] = {.lex_state = 41},
  [1427] = {.lex_state = 11},
  [1428] = {.lex_state = 11},
  [1429] = {.lex_state = 11},
  [1430] = {.lex_state = 11},
  [1431] = {.lex_state = 11},
  [1432] = {.lex_state = 11},
  [1433] = {.lex_state = 11},
  [1434] = {.lex_state = 11},
  [1435] = {.lex_state = 11},
  [1436] = {.lex_state = 11},
  [1437] = {.lex_state = 11},
  [1438] = {.lex_state = 11},
  [1439] = {.lex_state = 11},
  [1440] = {.lex_state = 11},
  [1441] = {.lex_state = 11},
  [1442] = {.lex_state = 11},
  [1443] = {.lex_state = 11},
  [1444] = {.lex_state = 11},
  [1445] = {.lex_state = 11},
  [1446] = {.lex_state = 11},
  [1447] = {.lex_state = 11},
  [1448] = {.lex_state = 11},
  [1449] = {.lex_state = 11},
  [1450] = {.lex_state = 11},
  [1451] = {.lex_state = 11},
  [1452] = {.lex_state = 11},
  [1453] = {.lex_state = 11},
  [1454] = {.lex_state = 11},
  [1455] = {.lex_state = 11},
  [1456] = {.lex_state = 41},
  [1457] = {.lex_state = 41},
  [1458] = {.lex_state = 41},
  [1459] = {.lex_state = 41},
  [1460] = {.lex_state = 41},
  [1461] = {.lex_state = 41},
  [1462] = {.lex_state = 41},
  [1463] = {.lex_state = 41},
  [1464] = {.lex_state = 41},
  [1465] = {.lex_state = 41},
  [1466] = {.lex_state = 41},
  [1467] = {.lex_state = 41},
  [1468] = {.lex_state = 41},
  [1469] = {.lex_state = 41},
  [1470] = {.lex_state = 40},
  [1471] = {.lex_state = 40},
  [1472] = {.lex_state = 40},
  [1473] = {.lex_state = 40},
  [1474] = {.lex_state = 41},
  [1475] = {.lex_state = 41},
  [1476] = {.lex_state = 40},
  [1477] = {.lex_state = 40},
  [1478] = {.lex_state = 40},
  [1479] = {.lex_state = 40},
  [1480] = {.lex_state = 40},
  [1481] = {.lex_state = 40},
  [1482] = {.lex_state = 41},
  [1483] = {.lex_state = 41},
  [1484] = {.lex_state = 40},
  [1485] = {.lex_state = 40},
  [1486] = {.lex_state = 41},
  [1487] = {.lex_state = 40},
  [1488] = {.lex_state = 3},
  [1489] = {.lex_state = 41},
  [1490] = {.lex_state = 3},
  [1491] = {.lex_state = 40},
  [1492] = {.lex_state = 40},
  [1493] = {.lex_state = 40},
  [1494] = {.lex_state = 3},
  [1495] = {.lex_state = 40},
  [1496] = {.lex_state = 40},
  [1497] = {.lex_state = 3},
  [1498] = {.lex_state = 4},
  [1499] = {.lex_state = 3},
  [1500] = {.lex_state = 3},
  [1501] = {.lex_state = 41},
  [1502] = {.lex_state = 3},
  [1503] = {.lex_state = 3},
  [1504] = {.lex_state = 3},
  [1505] = {.lex_state = 40},
  [1506] = {.lex_state = 41},
  [1507] = {.lex_state = 40},
  [1508] = {.lex_state = 40},
  [1509] = {.lex_state = 3},
  [1510] = {.lex_state = 3},
  [1511] = {.lex_state = 3},
  [1512] = {.lex_state = 3},
  [1513] = {.lex_state = 41},
  [1514] = {.lex_state = 40},
  [1515] = {.lex_state = 40},
  [1516] = {.lex_state = 3},
  [1517] = {.lex_state = 40},
  [1518] = {.lex_state = 3},
  [1519] = {.lex_state = 4},
  [1520] = {.lex_state = 3},
  [1521] = {.lex_state = 40},
  [1522] = {.lex_state = 40},
  [1523] = {.lex_state = 3},
  [1524] = {.lex_state = 3},
  [1525] = {.lex_state = 3},
  [1526] = {.lex_state = 3},
  [1527] = {.lex_state = 40},
  [1528] = {.lex_state = 40},
  [1529] = {.lex_state = 40},
  [1530] = {.lex_state = 3},
  [1531] = {.lex_state = 40},
  [1532] = {.lex_state = 40},
  [1533] = {.lex_state = 40},
  [1534] = {.lex_state = 3},
  [1535] = {.lex_state = 3},
  [1536] = {.lex_state = 3},
  [1537] = {.lex_state = 3},
  [1538] = {.lex_state = 41},
  [1539] = {.lex_state = 40},
  [1540] = {.lex_state = 41},
  [1541] = {.lex_state = 41},
  [1542] = {.lex_state = 41},
  [1543] = {.lex_state = 3},
  [1544] = {.lex_state = 41},
  [1545] = {.lex_state = 40},
  [1546] = {.lex_state = 41},
  [1547] = {.lex_state = 6},
  [1548] = {.lex_state = 3},
  [1549] = {.lex_state = 41},
  [1550] = {.lex_state = 41},
  [1551] = {.lex_state = 41},
  [1552] = {.lex_state = 41},
  [1553] = {.lex_state = 41},
  [1554] = {.lex_state = 6},
  [1555] = {.lex_state = 41},
  [1556] = {.lex_state = 40},
  [1557] = {.lex_state = 41},
  [1558] = {.lex_state = 41},
  [1559] = {.lex_state = 41},
  [1560] = {.lex_state = 41},
  [1561] = {.lex_state = 41},
  [1562] = {.lex_state = 41},
  [1563] = {.lex_state = 40},
  [1564] = {.lex_state = 41},
  [1565] = {.lex_state = 41},
  [1566] = {.lex_state = 41},
  [1567] = {.lex_state = 41},
  [1568] = {.lex_state = 41},
  [1569] = {.lex_state = 41},
  [1570] = {.lex_state = 41},
  [1571] = {.lex_state = 41},
  [1572] = {.lex_state = 41},
  [1573] = {.lex_state = 41},
  [1574] = {.lex_state = 41},
  [1575] = {.lex_state = 41},
  [1576] = {.lex_state = 41},
  [1577] = {.lex_state = 41},
  [1578] = {.lex_state = 41},
  [1579] = {.lex_state = 41},
  [1580] = {.lex_state = 41},
  [1581] = {.lex_state = 41},
  [1582] = {.lex_state = 41},
  [1583] = {.lex_state = 41},
  [1584] = {.lex_state = 41},
  [1585] = {.lex_state = 41},
  [1586] = {.lex_state = 41},
  [1587] = {.lex_state = 40},
  [1588] = {.lex_state = 41},
  [1589] = {.lex_state = 41},
  [1590] = {.lex_state = 41},
  [1591] = {.lex_state = 41},
  [1592] = {.lex_state = 41},
  [1593] = {.lex_state = 41},
  [1594] = {.lex_state = 41},
  [1595] = {.lex_state = 41},
  [1596] = {.lex_state = 11},
  [1597] = {.lex_state = 41},
  [1598] = {.lex_state = 41},
  [1599] = {.lex_state = 41},
  [1600] = {.lex_state = 41},
  [1601] = {.lex_state = 40},
  [1602] = {.lex_state = 41},
  [1603] = {.lex_state = 41},
  [1604] = {.lex_state = 41},
  [1605] = {.lex_state = 41},
  [1606] = {.lex_state = 41},
  [1607] = {.lex_state = 41},
  [1608] = {.lex_state = 40},
  [1609] = {.lex_state = 41},
  [1610] = {.lex_state = 41},
  [1611] = {.lex_state = 41},
  [1612] = {.lex_state = 41},
  [1613] = {.lex_state = 41},
  [1614] = {.lex_state = 40},
  [1615] = {.lex_state = 41},
  [1616] = {.lex_state = 41},
  [1617] = {.lex_state = 41},
  [1618] = {.lex_state = 40},
  [1619] = {.lex_state = 40},
  [1620] = {.lex_state = 40},
  [1621] = {.lex_state = 40},
  [1622] = {.lex_state = 40},
  [1623] = {.lex_state = 41},
  [1624] = {.lex_state = 11},
  [1625] = {.lex_state = 40},
  [1626] = {.lex_state = 40},
  [1627] = {.lex_state = 40},
  [1628] = {.lex_state = 40},
  [1629] = {.lex_state = 40},
  [1630] = {.lex_state = 11},
  [1631] = {.lex_state = 40},
  [1632] = {.lex_state = 11},
  [1633] = {.lex_state = 40},
  [1634] = {.lex_state = 40},
  [1635] = {.lex_state = 40},
  [1636] = {.lex_state = 40},
  [1637] = {.lex_state = 40},
  [1638] = {.lex_state = 40},
  [1639] = {.lex_state = 41},
  [1640] = {.lex_state = 41},
  [1641] = {.lex_state = 41},
  [1642] = {.lex_state = 40},
  [1643] = {.lex_state = 41},
  [1644] = {.lex_state = 40},
  [1645] = {.lex_state = 40},
  [1646] = {.lex_state = 40},
  [1647] = {.lex_state = 41},
  [1648] = {.lex_state = 40},
  [1649] = {.lex_state = 40},
  [1650] = {.lex_state = 40},
  [1651] = {.lex_state = 40},
  [1652] = {.lex_state = 40},
  [1653] = {.lex_state = 40},
  [1654] = {.lex_state = 40},
  [1655] = {.lex_state = 40},
  [1656] = {.lex_state = 40},
  [1657] = {.lex_state = 40},
  [1658] = {.lex_state = 40},
  [1659] = {.lex_state = 40},
  [1660] = {.lex_state = 40},
  [1661] = {.lex_state = 40},
  [1662] = {.lex_state = 40},
  [1663] = {.lex_state = 40},
  [1664] = {.lex_state = 40},
  [1665] = {.lex_state = 40},
  [1666] = {.lex_state = 40},
  [1667] = {.lex_state = 40},
  [1668] = {.lex_state = 40},
  [1669] = {.lex_state = 40},
  [1670] = {.lex_state = 40},
  [1671] = {.lex_state = 40},
  [1672] = {.lex_state = 40},
  [1673] = {.lex_state = 40},
  [1674] = {.lex_state = 40},
  [1675] = {.lex_state = 40},
  [1676] = {.lex_state = 40},
  [1677] = {.lex_state = 40},
  [1678] = {.lex_state = 40},
  [1679] = {.lex_state = 40},
  [1680] = {.lex_state = 40},
  [1681] = {.lex_state = 40},
  [1682] = {.lex_state = 41},
  [1683] = {.lex_state = 40},
  [1684] = {.lex_state = 40},
  [1685] = {.lex_state = 40},
  [1686] = {.lex_state = 40},
  [1687] = {.lex_state = 40},
  [1688] = {.lex_state = 40},
  [1689] = {.lex_state = 40},
  [1690] = {.lex_state = 40},
  [1691] = {.lex_state = 40},
  [1692] = {.lex_state = 40},
  [1693] = {.lex_state = 40},
  [1694] = {.lex_state = 40},
  [1695] = {.lex_state = 40},
  [1696] = {.lex_state = 40},
  [1697] = {.lex_state = 40},
  [1698] = {.lex_state = 40},
  [1699] = {.lex_state = 40},
  [1700] = {.lex_state = 40},
  [1701] = {.lex_state = 40},
  [1702] = {.lex_state = 40},
  [1703] = {.lex_state = 40},
  [1704] = {.lex_state = 40},
  [1705] = {.lex_state = 40},
  [1706] = {.lex_state = 40},
  [1707] = {.lex_state = 40},
  [1708] = {.lex_state = 40},
  [1709] = {.lex_state = 40},
  [1710] = {.lex_state = 41},
  [1711] = {.lex_state = 40},
  [1712] = {.lex_state = 40},
  [1713] = {.lex_state = 40},
  [1714] = {.lex_state = 40},
  [1715] = {.lex_state = 40},
  [1716] = {.lex_state = 40},
  [1717] = {.lex_state = 40},
  [1718] = {.lex_state = 40},
  [1719] = {.lex_state = 40},
  [1720] = {.lex_state = 40},
  [1721] = {.lex_state = 40},
  [1722] = {.lex_state = 40},
  [1723] = {.lex_state = 40},
  [1724] = {.lex_state = 40},
  [1725] = {.lex_state = 40},
  [1726] = {.lex_state = 40},
  [1727] = {.lex_state = 40},
  [1728] = {.lex_state = 40},
  [1729] = {.lex_state = 40},
  [1730] = {.lex_state = 40},
  [1731] = {.lex_state = 40},
  [1732] = {.lex_state = 40},
  [1733] = {.lex_state = 40},
  [1734] = {.lex_state = 40},
  [1735] = {.lex_state = 40},
  [1736] = {.lex_state = 40},
  [1737] = {.lex_state = 40},
  [1738] = {.lex_state = 40},
  [1739] = {.lex_state = 40},
  [1740] = {.lex_state = 40},
  [1741] = {.lex_state = 40},
  [1742] = {.lex_state = 40},
  [1743] = {.lex_state = 40},
  [1744] = {.lex_state = 40},
  [1745] = {.lex_state = 40},
  [1746] = {.lex_state = 40},
  [1747] = {.lex_state = 40},
  [1748] = {.lex_state = 40},
  [1749] = {.lex_state = 40},
  [1750] = {.lex_state = 40},
  [1751] = {.lex_state = 40},
  [1752] = {.lex_state = 41},
  [1753] = {.lex_state = 40},
  [1754] = {.lex_state = 41},
  [1755] = {.lex_state = 40},
  [1756] = {.lex_state = 41},
  [1757] = {.lex_state = 40},
  [1758] = {.lex_state = 40},
  [1759] = {.lex_state = 40},
  [1760] = {.lex_state = 40},
  [1761] = {.lex_state = 40},
  [1762] = {.lex_state = 40},
  [1763] = {.lex_state = 41},
  [1764] = {.lex_state = 41},
  [1765] = {.lex_state = 41},
  [1766] = {.lex_state = 40},
  [1767] = {.lex_state = 40},
  [1768] = {.lex_state = 40},
  [1769] = {.lex_state = 40},
  [1770] = {.lex_state = 40},
  [1771] = {.lex_state = 40},
  [1772] = {.lex_state = 41},
  [1773] = {.lex_state = 40},
  [1774] = {.lex_state = 40},
  [1775] = {.lex_state = 41},
  [1776] = {.lex_state = 40},
  [1777] = {.lex_state = 40},
  [1778] = {.lex_state = 40},
  [1779] = {.lex_state = 41},
  [1780] = {.lex_state = 40},
  [1781] = {.lex_state = 40},
  [1782] = {.lex_state = 40},
  [1783] = {.lex_state = 40},
  [1784] = {.lex_state = 40},
  [1785] = {.lex_state = 40},
  [1786] = {.lex_state = 40},
  [1787] = {.lex_state = 40},
  [1788] = {.lex_state = 40},
  [1789] = {.lex_state = 40},
  [1790] = {.lex_state = 40},
  [1791] = {.lex_state = 40},
  [1792] = {.lex_state = 40},
  [1793] = {.lex_state = 40},
  [1794] = {.lex_state = 40},
  [1795] = {.lex_state = 40},
  [1796] = {.lex_state = 40},
  [1797] = {.lex_state = 40},
  [1798] = {.lex_state = 40},
  [1799] = {.lex_state = 40},
  [1800] = {.lex_state = 41},
  [1801] = {.lex_state = 40},
  [1802] = {.lex_state = 40},
  [1803] = {.lex_state = 40},
  [1804] = {.lex_state = 40},
  [1805] = {.lex_state = 40},
  [1806] = {.lex_state = 40},
  [1807] = {.lex_state = 40},
  [1808] = {.lex_state = 40},
  [1809] = {.lex_state = 40},
  [1810] = {.lex_state = 40},
  [1811] = {.lex_state = 40},
  [1812] = {.lex_state = 40},
  [1813] = {.lex_state = 40},
  [1814] = {.lex_state = 40},
  [1815] = {.lex_state = 40},
  [1816] = {.lex_state = 40},
  [1817] = {.lex_state = 40},
  [1818] = {.lex_state = 40},
  [1819] = {.lex_state = 40},
  [1820] = {.lex_state = 40},
  [1821] = {.lex_state = 40},
  [1822] = {.lex_state = 40},
  [1823] = {.lex_state = 40},
  [1824] = {.lex_state = 40},
  [1825] = {.lex_state = 40},
  [1826] = {.lex_state = 40},
  [1827] = {.lex_state = 40},
  [1828] = {.lex_state = 40},
  [1829] = {.lex_state = 40},
  [1830] = {.lex_state = 40},
  [1831] = {.lex_state = 40},
  [1832] = {.lex_state = 40},
  [1833] = {.lex_state = 40},
  [1834] = {.lex_state = 40},
  [1835] = {.lex_state = 40},
  [1836] = {.lex_state = 40},
  [1837] = {.lex_state = 40},
  [1838] = {.lex_state = 40},
  [1839] = {.lex_state = 40},
  [1840] = {.lex_state = 40},
  [1841] = {.lex_state = 40},
  [1842] = {.lex_state = 40},
  [1843] = {.lex_state = 40},
  [1844] = {.lex_state = 40},
  [1845] = {.lex_state = 40},
  [1846] = {.lex_state = 40},
  [1847] = {.lex_state = 40},
  [1848] = {.lex_state = 40},
  [1849] = {.lex_state = 40},
  [1850] = {.lex_state = 40},
  [1851] = {.lex_state = 40},
  [1852] = {.lex_state = 40},
  [1853] = {.lex_state = 40},
  [1854] = {.lex_state = 40},
  [1855] = {.lex_state = 40},
  [1856] = {.lex_state = 40},
  [1857] = {.lex_state = 40},
  [1858] = {.lex_state = 40},
  [1859] = {.lex_state = 40},
  [1860] = {.lex_state = 40},
  [1861] = {.lex_state = 40},
  [1862] = {.lex_state = 40},
  [1863] = {.lex_state = 40},
  [1864] = {.lex_state = 4},
  [1865] = {.lex_state = 10},
  [1866] = {.lex_state = 4},
  [1867] = {.lex_state = 10},
  [1868] = {.lex_state = 10},
  [1869] = {.lex_state = 10},
  [1870] = {.lex_state = 40},
  [1871] = {.lex_state = 10},
  [1872] = {.lex_state = 40},
  [1873] = {.lex_state = 40},
  [1874] = {.lex_state = 10},
  [1875] = {.lex_state = 10},
  [1876] = {.lex_state = 40},
  [1877] = {.lex_state = 10},
  [1878] = {.lex_state = 4},
  [1879] = {.lex_state = 40},
  [1880] = {.lex_state = 4},
  [1881] = {.lex_state = 10},
  [1882] = {.lex_state = 10},
  [1883] = {.lex_state = 40},
  [1884] = {.lex_state = 40},
  [1885] = {.lex_state = 40},
  [1886] = {.lex_state = 40},
  [1887] = {.lex_state = 6},
  [1888] = {.lex_state = 10},
  [1889] = {.lex_state = 40},
  [1890] = {.lex_state = 40},
  [1891] = {.lex_state = 40},
  [1892] = {.lex_state = 40},
  [1893] = {.lex_state = 41},
  [1894] = {.lex_state = 40},
  [1895] = {.lex_state = 40},
  [1896] = {.lex_state = 40},
  [1897] = {.lex_state = 40},
  [1898] = {.lex_state = 40},
  [1899] = {.lex_state = 40},
  [1900] = {.lex_state = 40},
  [1901] = {.lex_state = 1},
  [1902] = {.lex_state = 1},
  [1903] = {.lex_state = 6},
  [1904] = {.lex_state = 40},
  [1905] = {.lex_state = 40},
  [1906] = {.lex_state = 40},
  [1907] = {.lex_state = 40},
  [1908] = {.lex_state = 4},
  [1909] = {.lex_state = 6},
  [1910] = {.lex_state = 40},
  [1911] = {.lex_state = 6},
  [1912] = {.lex_state = 40},
  [1913] = {.lex_state = 6},
  [1914] = {.lex_state = 40},
  [1915] = {.lex_state = 40},
  [1916] = {.lex_state = 40},
  [1917] = {.lex_state = 40},
  [1918] = {.lex_state = 41},
  [1919] = {.lex_state = 40},
  [1920] = {.lex_state = 6},
  [1921] = {.lex_state = 40},
  [1922] = {.lex_state = 40},
  [1923] = {.lex_state = 40},
  [1924] = {.lex_state = 40},
  [1925] = {.lex_state = 40},
  [1926] = {.lex_state = 40},
  [1927] = {.lex_state = 40},
  [1928] = {.lex_state = 40},
  [1929] = {.lex_state = 40},
  [1930] = {.lex_state = 40},
  [1931] = {.lex_state = 6},
  [1932] = {.lex_state = 40},
  [1933] = {.lex_state = 41},
  [1934] = {.lex_state = 41},
  [1935] = {.lex_state = 40},
  [1936] = {.lex_state = 40},
  [1937] = {.lex_state = 40},
  [1938] = {.lex_state = 6},
  [1939] = {.lex_state = 40},
  [1940] = {.lex_state = 6},
  [1941] = {.lex_state = 40},
  [1942] = {.lex_state = 40},
  [1943] = {.lex_state = 40},
  [1944] = {.lex_state = 40},
  [1945] = {.lex_state = 40},
  [1946] = {.lex_state = 40},
  [1947] = {.lex_state = 40},
  [1948] = {.lex_state = 41},
  [1949] = {.lex_state = 6},
  [1950] = {.lex_state = 1},
  [1951] = {.lex_state = 40},
  [1952] = {.lex_state = 40},
  [1953] = {.lex_state = 40},
  [1954] = {.lex_state = 1},
  [1955] = {.lex_state = 40},
  [1956] = {.lex_state = 1},
  [1957] = {.lex_state = 40},
  [1958] = {.lex_state = 41},
  [1959] = {.lex_state = 40},
  [1960] = {.lex_state = 40},
  [1961] = {.lex_state = 41},
  [1962] = {.lex_state = 40},
  [1963] = {.lex_state = 40},
  [1964] = {.lex_state = 40},
  [1965] = {.lex_state = 1},
  [1966] = {.lex_state = 40},
  [1967] = {.lex_state = 40},
  [1968] = {.lex_state = 40},
  [1969] = {.lex_state = 40},
  [1970] = {.lex_state = 1},
  [1971] = {.lex_state = 40},
  [1972] = {.lex_state = 40},
  [1973] = {.lex_state = 6},
  [1974] = {.lex_state = 40},
  [1975] = {.lex_state = 40},
  [1976] = {.lex_state = 41},
  [1977] = {.lex_state = 40},
  [1978] = {.lex_state = 40},
  [1979] = {.lex_state = 40},
  [1980] = {.lex_state = 40},
  [1981] = {.lex_state = 41},
  [1982] = {.lex_state = 40},
  [1983] = {.lex_state = 40},
  [1984] = {.lex_state = 41},
  [1985] = {.lex_state = 40},
  [1986] = {.lex_state = 40},
  [1987] = {.lex_state = 40},
  [1988] = {.lex_state = 40},
  [1989] = {.lex_state = 40},
  [1990] = {.lex_state = 41},
  [1991] = {.lex_state = 40},
  [1992] = {.lex_state = 40},
  [1993] = {.lex_state = 40},
  [1994] = {.lex_state = 40},
  [1995] = {.lex_state = 41},
  [1996] = {.lex_state = 40},
  [1997] = {.lex_state = 40},
  [1998] = {.lex_state = 40},
  [1999] = {.lex_state = 40},
  [2000] = {.lex_state = 40},
  [2001] = {.lex_state = 40},
  [2002] = {.lex_state = 40},
  [2003] = {.lex_state = 40},
  [2004] = {.lex_state = 40},
  [2005] = {.lex_state = 40},
  [2006] = {.lex_state = 40},
  [2007] = {.lex_state = 40},
  [2008] = {.lex_state = 40},
  [2009] = {.lex_state = 40},
  [2010] = {.lex_state = 40},
  [2011] = {.lex_state = 41},
  [2012] = {.lex_state = 40},
  [2013] = {.lex_state = 40},
  [2014] = {.lex_state = 40},
  [2015] = {.lex_state = 40},
  [2016] = {.lex_state = 40},
  [2017] = {.lex_state = 40},
  [2018] = {.lex_state = 40},
  [2019] = {.lex_state = 40},
  [2020] = {.lex_state = 1},
  [2021] = {.lex_state = 40},
  [2022] = {.lex_state = 1},
  [2023] = {.lex_state = 1},
  [2024] = {.lex_state = 40},
  [2025] = {.lex_state = 40},
  [2026] = {.lex_state = 40},
  [2027] = {.lex_state = 40},
  [2028] = {.lex_state = 1},
  [2029] = {.lex_state = 6},
  [2030] = {.lex_state = 40},
  [2031] = {.lex_state = 40},
  [2032] = {.lex_state = 40},
  [2033] = {.lex_state = 40},
  [2034] = {.lex_state = 40},
  [2035] = {.lex_state = 40},
  [2036] = {.lex_state = 40},
  [2037] = {.lex_state = 40},
  [2038] = {.lex_state = 40},
  [2039] = {.lex_state = 40},
  [2040] = {.lex_state = 1},
  [2041] = {.lex_state = 40},
  [2042] = {.lex_state = 40},
  [2043] = {.lex_state = 40},
  [2044] = {.lex_state = 40},
  [2045] = {.lex_state = 40},
  [2046] = {.lex_state = 1},
  [2047] = {.lex_state = 40},
  [2048] = {.lex_state = 40},
  [2049] = {.lex_state = 40},
  [2050] = {.lex_state = 40},
  [2051] = {.lex_state = 40},
  [2052] = {.lex_state = 40},
  [2053] = {.lex_state = 40},
  [2054] = {.lex_state = 40},
  [2055] = {.lex_state = 40},
  [2056] = {.lex_state = 40},
  [2057] = {.lex_state = 40},
  [2058] = {.lex_state = 1},
  [2059] = {.lex_state = 1},
  [2060] = {.lex_state = 1},
  [2061] = {.lex_state = 1},
  [2062] = {.lex_state = 40},
  [2063] = {.lex_state = 40},
  [2064] = {.lex_state = 1},
  [2065] = {.lex_state = 40},
  [2066] = {.lex_state = 6},
  [2067] = {.lex_state = 40},
  [2068] = {.lex_state = 40},
  [2069] = {.lex_state = 40},
  [2070] = {.lex_state = 40},
  [2071] = {.lex_state = 1},
  [2072] = {.lex_state = 40},
  [2073] = {.lex_state = 40},
  [2074] = {.lex_state = 40},
  [2075] = {.lex_state = 40},
  [2076] = {.lex_state = 40},
  [2077] = {.lex_state = 40},
  [2078] = {.lex_state = 40},
  [2079] = {.lex_state = 40},
  [2080] = {.lex_state = 40},
  [2081] = {.lex_state = 40},
  [2082] = {.lex_state = 40},
  [2083] = {.lex_state = 1},
  [2084] = {.lex_state = 40},
  [2085] = {.lex_state = 40},
  [2086] = {.lex_state = 40},
  [2087] = {.lex_state = 6},
  [2088] = {.lex_state = 40},
  [2089] = {.lex_state = 6},
  [2090] = {.lex_state = 40},
  [2091] = {.lex_state = 40},
  [2092] = {.lex_state = 40},
  [2093] = {.lex_state = 40},
  [2094] = {.lex_state = 6},
  [2095] = {.lex_state = 1},
  [2096] = {.lex_state = 1},
  [2097] = {.lex_state = 6},
  [2098] = {.lex_state = 40},
  [2099] = {.lex_state = 40},
  [2100] = {.lex_state = 40},
  [2101] = {.lex_state = 40},
  [2102] = {.lex_state = 40},
  [2103] = {.lex_state = 40},
  [2104] = {.lex_state = 1},
  [2105] = {.lex_state = 40},
  [2106] = {.lex_state = 40},
  [2107] = {.lex_state = 40},
  [2108] = {.lex_state = 40},
  [2109] = {.lex_state = 40},
  [2110] = {.lex_state = 40},
  [2111] = {.lex_state = 40},
  [2112] = {.lex_state = 40},
  [2113] = {.lex_state = 40},
  [2114] = {.lex_state = 40},
  [2115] = {.lex_state = 40},
  [2116] = {.lex_state = 1},
  [2117] = {.lex_state = 40},
  [2118] = {.lex_state = 40},
  [2119] = {.lex_state = 40},
  [2120] = {.lex_state = 40},
  [2121] = {.lex_state = 40},
  [2122] = {.lex_state = 40},
  [2123] = {.lex_state = 40},
  [2124] = {.lex_state = 1},
  [2125] = {.lex_state = 1},
  [2126] = {.lex_state = 1},
  [2127] = {.lex_state = 40},
  [2128] = {.lex_state = 40},
  [2129] = {.lex_state = 40},
  [2130] = {.lex_state = 40},
  [2131] = {.lex_state = 40},
  [2132] = {.lex_state = 40},
  [2133] = {.lex_state = 40},
  [2134] = {.lex_state = 40},
  [2135] = {.lex_state = 40},
  [2136] = {.lex_state = 40},
  [2137] = {.lex_state = 40},
  [2138] = {.lex_state = 40},
  [2139] = {.lex_state = 40},
  [2140] = {.lex_state = 6},
  [2141] = {.lex_state = 40},
  [2142] = {.lex_state = 40},
  [2143] = {.lex_state = 40},
  [2144] = {.lex_state = 6},
  [2145] = {.lex_state = 40},
  [2146] = {.lex_state = 40},
  [2147] = {.lex_state = 40},
  [2148] = {.lex_state = 40},
  [2149] = {.lex_state = 40},
  [2150] = {.lex_state = 40},
  [2151] = {.lex_state = 40},
  [2152] = {.lex_state = 40},
  [2153] = {.lex_state = 40},
  [2154] = {.lex_state = 40},
  [2155] = {.lex_state = 40},
  [2156] = {.lex_state = 6},
  [2157] = {.lex_state = 1},
  [2158] = {.lex_state = 1},
  [2159] = {.lex_state = 40},
  [2160] = {.lex_state = 1},
  [2161] = {.lex_state = 40},
  [2162] = {.lex_state = 1},
  [2163] = {.lex_state = 1},
  [2164] = {.lex_state = 40},
  [2165] = {.lex_state = 1},
  [2166] = {.lex_state = 1},
  [2167] = {.lex_state = 1},
  [2168] = {.lex_state = 40},
  [2169] = {.lex_state = 40},
  [2170] = {.lex_state = 1},
  [2171] = {.lex_state = 1},
  [2172] = {.lex_state = 40},
  [2173] = {.lex_state = 40},
  [2174] = {.lex_state = 1},
  [2175] = {.lex_state = 1},
  [2176] = {.lex_state = 1},
  [2177] = {.lex_state = 1},
  [2178] = {.lex_state = 1},
  [2179] = {.lex_state = 40},
  [2180] = {.lex_state = 40},
  [2181] = {.lex_state = 40},
  [2182] = {.lex_state = 40},
  [2183] = {.lex_state = 40},
  [2184] = {.lex_state = 40},
  [2185] = {.lex_state = 40},
  [2186] = {.lex_state = 40},
  [2187] = {.lex_state = 40},
  [2188] = {.lex_state = 40},
  [2189] = {.lex_state = 1},
  [2190] = {.lex_state = 40},
  [2191] = {.lex_state = 40},
  [2192] = {.lex_state = 40},
  [2193] = {.lex_state = 40},
  [2194] = {.lex_state = 40},
  [2195] = {.lex_state = 40},
  [2196] = {.lex_state = 6},
  [2197] = {.lex_state = 40},
  [2198] = {.lex_state = 40},
  [2199] = {.lex_state = 40},
  [2200] = {.lex_state = 40},
  [2201] = {.lex_state = 40},
  [2202] = {.lex_state = 1},
  [2203] = {.lex_state = 41},
  [2204] = {.lex_state = 40},
  [2205] = {.lex_state = 40},
  [2206] = {.lex_state = 40},
  [2207] = {.lex_state = 40},
  [2208] = {.lex_state = 40},
  [2209] = {.lex_state = 40},
  [2210] = {.lex_state = 40},
  [2211] = {.lex_state = 40},
  [2212] = {.lex_state = 40},
  [2213] = {.lex_state = 40},
  [2214] = {.lex_state = 40},
  [2215] = {.lex_state = 40},
  [2216] = {.lex_state = 40},
  [2217] = {.lex_state = 40},
  [2218] = {.lex_state = 40},
  [2219] = {.lex_state = 1},
  [2220] = {.lex_state = 40},
  [2221] = {.lex_state = 40},
  [2222] = {.lex_state = 40},
  [2223] = {.lex_state = 40},
  [2224] = {.lex_state = 40},
  [2225] = {.lex_state = 41},
  [2226] = {.lex_state = 40},
  [2227] = {.lex_state = 40},
  [2228] = {.lex_state = 40},
  [2229] = {.lex_state = 40},
  [2230] = {.lex_state = 40},
  [2231] = {.lex_state = 40},
  [2232] = {.lex_state = 40},
  [2233] = {.lex_state = 40},
  [2234] = {.lex_state = 40},
  [2235] = {.lex_state = 6},
  [2236] = {.lex_state = 40},
  [2237] = {.lex_state = 1},
  [2238] = {.lex_state = 40},
  [2239] = {.lex_state = 40},
  [2240] = {.lex_state = 1},
  [2241] = {.lex_state = 6},
  [2242] = {.lex_state = 40},
  [2243] = {.lex_state = 6},
  [2244] = {.lex_state = 40},
  [2245] = {.lex_state = 40},
  [2246] = {.lex_state = 40},
  [2247] = {.lex_state = 40},
  [2248] = {.lex_state = 40},
  [2249] = {.lex_state = 40},
  [2250] = {.lex_state = 40},
  [2251] = {.lex_state = 40},
  [2252] = {.lex_state = 40},
  [2253] = {.lex_state = 40},
  [2254] = {.lex_state = 40},
  [2255] = {.lex_state = 40},
  [2256] = {.lex_state = 40},
  [2257] = {.lex_state = 40},
  [2258] = {.lex_state = 40},
  [2259] = {.lex_state = 40},
  [2260] = {.lex_state = 40},
  [2261] = {.lex_state = 40},
  [2262] = {.lex_state = 40},
  [2263] = {.lex_state = 40},
  [2264] = {.lex_state = 40},
  [2265] = {.lex_state = 40},
  [2266] = {.lex_state = 40},
  [2267] = {.lex_state = 40},
  [2268] = {.lex_state = 40},
  [2269] = {.lex_state = 40},
  [2270] = {.lex_state = 40},
  [2271] = {.lex_state = 40},
  [2272] = {.lex_state = 40},
  [2273] = {.lex_state = 40},
  [2274] = {.lex_state = 40},
  [2275] = {.lex_state = 40},
  [2276] = {.lex_state = 40},
  [2277] = {.lex_state = 40},
  [2278] = {.lex_state = 40},
  [2279] = {.lex_state = 40},
  [2280] = {.lex_state = 40},
  [2281] = {.lex_state = 40},
  [2282] = {.lex_state = 1},
  [2283] = {.lex_state = 40},
  [2284] = {.lex_state = 40},
  [2285] = {.lex_state = 1},
  [2286] = {.lex_state = 1},
  [2287] = {.lex_state = 40},
  [2288] = {.lex_state = 40},
  [2289] = {.lex_state = 1},
  [2290] = {.lex_state = 1},
  [2291] = {.lex_state = 41},
  [2292] = {.lex_state = 40},
  [2293] = {.lex_state = 40},
  [2294] = {.lex_state = 40},
  [2295] = {.lex_state = 40},
  [2296] = {.lex_state = 40},
  [2297] = {.lex_state = 41},
  [2298] = {.lex_state = 40},
  [2299] = {.lex_state = 40},
  [2300] = {.lex_state = 40},
  [2301] = {.lex_state = 40},
  [2302] = {.lex_state = 40},
  [2303] = {.lex_state = 40},
  [2304] = {.lex_state = 40},
  [2305] = {.lex_state = 40},
  [2306] = {.lex_state = 40},
  [2307] = {.lex_state = 40},
  [2308] = {.lex_state = 40},
  [2309] = {.lex_state = 40},
  [2310] = {.lex_state = 40},
  [2311] = {.lex_state = 40},
  [2312] = {.lex_state = 40},
  [2313] = {.lex_state = 40},
  [2314] = {.lex_state = 40},
  [2315] = {.lex_state = 40},
  [2316] = {.lex_state = 40},
  [2317] = {.lex_state = 40},
  [2318] = {.lex_state = 40},
  [2319] = {.lex_state = 40},
  [2320] = {.lex_state = 40},
  [2321] = {.lex_state = 40},
  [2322] = {.lex_state = 1},
  [2323] = {.lex_state = 40},
  [2324] = {.lex_state = 40},
  [2325] = {.lex_state = 40},
  [2326] = {.lex_state = 1},
  [2327] = {.lex_state = 40},
  [2328] = {.lex_state = 40},
  [2329] = {.lex_state = 40},
  [2330] = {.lex_state = 41},
  [2331] = {.lex_state = 1},
  [2332] = {.lex_state = 6},
  [2333] = {.lex_state = 6},
  [2334] = {.lex_state = 40},
  [2335] = {.lex_state = 40},
  [2336] = {.lex_state = 40},
  [2337] = {.lex_state = 40},
  [2338] = {.lex_state = 40},
  [2339] = {.lex_state = 40},
  [2340] = {.lex_state = 40},
  [2341] = {.lex_state = 40},
  [2342] = {.lex_state = 40},
  [2343] = {.lex_state = 40},
  [2344] = {.lex_state = 40},
  [2345] = {.lex_state = 40},
  [2346] = {.lex_state = 40},
  [2347] = {.lex_state = 40},
  [2348] = {.lex_state = 40},
  [2349] = {.lex_state = 40},
  [2350] = {.lex_state = 40},
  [2351] = {.lex_state = 40},
  [2352] = {.lex_state = 40},
  [2353] = {.lex_state = 40},
  [2354] = {.lex_state = 40},
  [2355] = {.lex_state = 40},
  [2356] = {.lex_state = 40},
  [2357] = {.lex_state = 40},
  [2358] = {.lex_state = 40},
  [2359] = {.lex_state = 40},
  [2360] = {.lex_state = 40},
  [2361] = {.lex_state = 40},
  [2362] = {.lex_state = 40},
  [2363] = {.lex_state = 40},
  [2364] = {.lex_state = 40},
  [2365] = {.lex_state = 40},
  [2366] = {.lex_state = 40},
  [2367] = {.lex_state = 40},
  [2368] = {.lex_state = 40},
  [2369] = {.lex_state = 40},
  [2370] = {.lex_state = 40},
  [2371] = {.lex_state = 40},
  [2372] = {.lex_state = 40},
  [2373] = {.lex_state = 40},
  [2374] = {.lex_state = 40},
  [2375] = {.lex_state = 40},
  [2376] = {.lex_state = 40},
  [2377] = {.lex_state = 40},
  [2378] = {.lex_state = 40},
  [2379] = {.lex_state = 40},
  [2380] = {.lex_state = 40},
  [2381] = {.lex_state = 40},
  [2382] = {.lex_state = 40},
  [2383] = {.lex_state = 40},
  [2384] = {.lex_state = 40},
  [2385] = {.lex_state = 40},
  [2386] = {.lex_state = 40},
  [2387] = {.lex_state = 40},
  [2388] = {.lex_state = 40},
  [2389] = {.lex_state = 40},
  [2390] = {.lex_state = 40},
  [2391] = {.lex_state = 40},
  [2392] = {.lex_state = 40},
  [2393] = {.lex_state = 40},
  [2394] = {.lex_state = 40},
  [2395] = {.lex_state = 40},
  [2396] = {.lex_state = 40},
  [2397] = {.lex_state = 40},
  [2398] = {.lex_state = 40},
  [2399] = {.lex_state = 40},
  [2400] = {.lex_state = 40},
  [2401] = {.lex_state = 40},
  [2402] = {.lex_state = 40},
  [2403] = {.lex_state = 40},
  [2404] = {.lex_state = 40},
  [2405] = {.lex_state = 40},
  [2406] = {.lex_state = 40},
  [2407] = {.lex_state = 40},
  [2408] = {.lex_state = 40},
  [2409] = {.lex_state = 40},
  [2410] = {.lex_state = 40},
  [2411] = {.lex_state = 40},
  [2412] = {.lex_state = 40},
  [2413] = {.lex_state = 40},
  [2414] = {.lex_state = 40},
  [2415] = {.lex_state = 40},
  [2416] = {.lex_state = 40},
  [2417] = {.lex_state = 40},
  [2418] = {.lex_state = 40},
  [2419] = {.lex_state = 40},
  [2420] = {.lex_state = 40},
  [2421] = {.lex_state = 40},
  [2422] = {.lex_state = 40},
  [2423] = {.lex_state = 40},
  [2424] = {.lex_state = 40},
  [2425] = {.lex_state = 40},
  [2426] = {.lex_state = 40},
  [2427] = {.lex_state = 40},
  [2428] = {.lex_state = 40},
  [2429] = {.lex_state = 40},
  [2430] = {.lex_state = 40},
  [2431] = {.lex_state = 40},
  [2432] = {.lex_state = 40},
  [2433] = {.lex_state = 40},
  [2434] = {.lex_state = 40},
  [2435] = {.lex_state = 40},
  [2436] = {.lex_state = 40},
  [2437] = {.lex_state = 40},
  [2438] = {.lex_state = 40},
  [2439] = {.lex_state = 40},
  [2440] = {.lex_state = 40},
  [2441] = {.lex_state = 40},
  [2442] = {.lex_state = 40},
  [2443] = {.lex_state = 40},
  [2444] = {.lex_state = 40},
  [2445] = {.lex_state = 40},
  [2446] = {.lex_state = 40},
  [2447] = {.lex_state = 40},
  [2448] = {.lex_state = 40},
  [2449] = {.lex_state = 40},
  [2450] = {.lex_state = 40},
  [2451] = {.lex_state = 40},
  [2452] = {.lex_state = 40},
  [2453] = {.lex_state = 40},
  [2454] = {.lex_state = 40},
  [2455] = {.lex_state = 40},
  [2456] = {.lex_state = 40},
  [2457] = {.lex_state = 40},
  [2458] = {.lex_state = 40},
  [2459] = {.lex_state = 40},
  [2460] = {.lex_state = 40},
  [2461] = {.lex_state = 40},
  [2462] = {.lex_state = 40},
  [2463] = {.lex_state = 40},
  [2464] = {.lex_state = 40},
  [2465] = {.lex_state = 40},
  [2466] = {.lex_state = 40},
  [2467] = {.lex_state = 40},
  [2468] = {.lex_state = 40},
  [2469] = {.lex_state = 40},
  [2470] = {.lex_state = 40},
  [2471] = {.lex_state = 40},
  [2472] = {.lex_state = 40},
  [2473] = {.lex_state = 40},
  [2474] = {.lex_state = 40},
  [2475] = {.lex_state = 40},
  [2476] = {.lex_state = 40},
  [2477] = {.lex_state = 40},
  [2478] = {.lex_state = 40},
  [2479] = {.lex_state = 40},
  [2480] = {.lex_state = 40},
  [2481] = {.lex_state = 40},
  [2482] = {.lex_state = 40},
  [2483] = {.lex_state = 40},
  [2484] = {.lex_state = 40},
  [2485] = {.lex_state = 40},
  [2486] = {.lex_state = 40},
  [2487] = {.lex_state = 40},
  [2488] = {.lex_state = 40},
  [2489] = {.lex_state = 40},
  [2490] = {.lex_state = 40},
  [2491] = {.lex_state = 40},
  [2492] = {.lex_state = 40},
  [2493] = {.lex_state = 40},
  [2494] = {.lex_state = 40},
  [2495] = {.lex_state = 40},
  [2496] = {.lex_state = 40},
  [2497] = {.lex_state = 40},
  [2498] = {.lex_state = 40},
  [2499] = {.lex_state = 40},
  [2500] = {.lex_state = 40},
  [2501] = {.lex_state = 40},
  [2502] = {.lex_state = 40},
  [2503] = {.lex_state = 40},
  [2504] = {.lex_state = 40},
  [2505] = {.lex_state = 40},
  [2506] = {.lex_state = 40},
  [2507] = {.lex_state = 40},
  [2508] = {.lex_state = 40},
  [2509] = {.lex_state = 40},
  [2510] = {.lex_state = 40},
  [2511] = {.lex_state = 40},
  [2512] = {.lex_state = 40},
  [2513] = {.lex_state = 40},
  [2514] = {.lex_state = 40},
  [2515] = {.lex_state = 40},
  [2516] = {.lex_state = 40},
  [2517] = {.lex_state = 40},
  [2518] = {.lex_state = 40},
  [2519] = {.lex_state = 40},
  [2520] = {.lex_state = 40},
  [2521] = {.lex_state = 40},
  [2522] = {.lex_state = 40},
  [2523] = {.lex_state = 40},
  [2524] = {.lex_state = 40},
  [2525] = {.lex_state = 40},
  [2526] = {.lex_state = 40},
  [2527] = {.lex_state = 40},
  [2528] = {.lex_state = 40},
  [2529] = {.lex_state = 40},
  [2530] = {.lex_state = 40},
  [2531] = {.lex_state = 40},
  [2532] = {.lex_state = 40},
  [2533] = {.lex_state = 40},
  [2534] = {.lex_state = 40},
  [2535] = {.lex_state = 40},
  [2536] = {.lex_state = 40},
  [2537] = {.lex_state = 40},
  [2538] = {.lex_state = 40},
  [2539] = {.lex_state = 6},
  [2540] = {.lex_state = 40},
  [2541] = {.lex_state = 40},
  [2542] = {.lex_state = 40},
  [2543] = {.lex_state = 40},
  [2544] = {.lex_state = 40},
  [2545] = {.lex_state = 40},
  [2546] = {.lex_state = 40},
  [2547] = {.lex_state = 40},
  [2548] = {.lex_state = 40},
  [2549] = {.lex_state = 40},
  [2550] = {.lex_state = 40},
  [2551] = {.lex_state = 40},
  [2552] = {.lex_state = 40},
  [2553] = {.lex_state = 40},
  [2554] = {.lex_state = 40},
  [2555] = {.lex_state = 40},
  [2556] = {.lex_state = 40},
  [2557] = {.lex_state = 40},
  [2558] = {.lex_state = 40},
  [2559] = {.lex_state = 40},
  [2560] = {.lex_state = 40},
  [2561] = {.lex_state = 40},
  [2562] = {.lex_state = 40},
  [2563] = {.lex_state = 40},
  [2564] = {.lex_state = 40},
  [2565] = {.lex_state = 40},
  [2566] = {.lex_state = 40},
  [2567] = {.lex_state = 40},
  [2568] = {.lex_state = 40},
  [2569] = {.lex_state = 40},
  [2570] = {.lex_state = 40},
  [2571] = {.lex_state = 40},
  [2572] = {.lex_state = 40},
  [2573] = {.lex_state = 40},
  [2574] = {.lex_state = 40},
  [2575] = {.lex_state = 40},
  [2576] = {.lex_state = 40},
  [2577] = {.lex_state = 40},
  [2578] = {.lex_state = 40},
  [2579] = {.lex_state = 40},
  [2580] = {.lex_state = 40},
  [2581] = {.lex_state = 40},
  [2582] = {.lex_state = 40},
  [2583] = {.lex_state = 40},
  [2584] = {.lex_state = 40},
  [2585] = {.lex_state = 40},
  [2586] = {.lex_state = 40},
  [2587] = {.lex_state = 40},
  [2588] = {.lex_state = 40},
  [2589] = {.lex_state = 40},
  [2590] = {.lex_state = 40},
  [2591] = {.lex_state = 40},
  [2592] = {.lex_state = 40},
  [2593] = {.lex_state = 40},
  [2594] = {.lex_state = 40},
  [2595] = {.lex_state = 40},
  [2596] = {.lex_state = 40},
  [2597] = {.lex_state = 40},
  [2598] = {.lex_state = 40},
  [2599] = {.lex_state = 40},
  [2600] = {.lex_state = 40},
  [2601] = {.lex_state = 40},
  [2602] = {.lex_state = 40},
  [2603] = {.lex_state = 40},
  [2604] = {.lex_state = 40},
  [2605] = {.lex_state = 40},
  [2606] = {.lex_state = 40},
  [2607] = {.lex_state = 40},
  [2608] = {.lex_state = 40},
  [2609] = {.lex_state = 40},
  [2610] = {.lex_state = 40},
  [2611] = {.lex_state = 40},
  [2612] = {.lex_state = 40},
  [2613] = {.lex_state = 40},
  [2614] = {.lex_state = 40},
  [2615] = {.lex_state = 40},
  [2616] = {.lex_state = 40},
  [2617] = {.lex_state = 40},
  [2618] = {.lex_state = 40},
  [2619] = {.lex_state = 40},
  [2620] = {.lex_state = 40},
  [2621] = {.lex_state = 40},
  [2622] = {.lex_state = 40},
  [2623] = {.lex_state = 40},
  [2624] = {.lex_state = 40},
  [2625] = {.lex_state = 40},
  [2626] = {.lex_state = 40},
  [2627] = {.lex_state = 40},
  [2628] = {.lex_state = 40},
  [2629] = {.lex_state = 40},
  [2630] = {.lex_state = 40},
  [2631] = {.lex_state = 40},
  [2632] = {.lex_state = 40},
  [2633] = {.lex_state = 40},
  [2634] = {.lex_state = 40},
  [2635] = {.lex_state = 40},
  [2636] = {.lex_state = 40},
  [2637] = {.lex_state = 40},
  [2638] = {.lex_state = 40},
  [2639] = {.lex_state = 40},
  [2640] = {.lex_state = 40},
  [2641] = {.lex_state = 40},
  [2642] = {.lex_state = 40},
  [2643] = {.lex_state = 40},
  [2644] = {.lex_state = 40},
  [2645] = {.lex_state = 40},
  [2646] = {.lex_state = 40},
  [2647] = {.lex_state = 40},
  [2648] = {.lex_state = 40},
  [2649] = {.lex_state = 40},
  [2650] = {.lex_state = 40},
  [2651] = {.lex_state = 40},
  [2652] = {.lex_state = 40},
  [2653] = {.lex_state = 40},
  [2654] = {.lex_state = 40},
  [2655] = {.lex_state = 40},
  [2656] = {.lex_state = 40},
  [2657] = {.lex_state = 40},
  [2658] = {.lex_state = 40},
  [2659] = {.lex_state = 40},
  [2660] = {.lex_state = 40},
  [2661] = {.lex_state = 40},
  [2662] = {.lex_state = 40},
  [2663] = {.lex_state = 40},
  [2664] = {.lex_state = 40},
  [2665] = {.lex_state = 40},
  [2666] = {.lex_state = 40},
  [2667] = {.lex_state = 40},
  [2668] = {.lex_state = 40},
  [2669] = {.lex_state = 40},
  [2670] = {.lex_state = 40},
  [2671] = {.lex_state = 40},
  [2672] = {.lex_state = 40},
  [2673] = {.lex_state = 40},
  [2674] = {.lex_state = 40},
  [2675] = {.lex_state = 40},
  [2676] = {.lex_state = 40},
  [2677] = {.lex_state = 40},
  [2678] = {.lex_state = 40},
  [2679] = {.lex_state = 40},
  [2680] = {.lex_state = 40},
  [2681] = {.lex_state = 40},
  [2682] = {.lex_state = 40},
  [2683] = {.lex_state = 40},
  [2684] = {.lex_state = 40},
  [2685] = {.lex_state = 40},
  [2686] = {.lex_state = 40},
  [2687] = {.lex_state = 40},
  [2688] = {.lex_state = 40},
  [2689] = {.lex_state = 40},
  [2690] = {.lex_state = 40},
  [2691] = {.lex_state = 40},
  [2692] = {.lex_state = 40},
  [2693] = {.lex_state = 40},
  [2694] = {.lex_state = 40},
  [2695] = {.lex_state = 40},
  [2696] = {.lex_state = 40},
  [2697] = {.lex_state = 40},
  [2698] = {.lex_state = 40},
  [2699] = {.lex_state = 40},
  [2700] = {.lex_state = 40},
  [2701] = {.lex_state = 40},
  [2702] = {.lex_state = 40},
  [2703] = {.lex_state = 40},
  [2704] = {.lex_state = 40},
  [2705] = {.lex_state = 40},
  [2706] = {.lex_state = 40},
  [2707] = {.lex_state = 40},
  [2708] = {.lex_state = 40},
  [2709] = {.lex_state = 40},
  [2710] = {.lex_state = 40},
  [2711] = {.lex_state = 40},
  [2712] = {.lex_state = 40},
  [2713] = {.lex_state = 40},
  [2714] = {.lex_state = 40},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [aux_sym_asmBody_token1] = ACTIONS(1),
    [aux_sym_asmBody_token2] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_type_token1] = ACTIONS(1),
    [aux_sym_type_token2] = ACTIONS(1),
    [aux_sym_type_token3] = ACTIONS(1),
    [aux_sym__literalString_token1] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [sym_kProgram] = ACTIONS(1),
    [sym_kLibrary] = ACTIONS(1),
    [sym_kUnit] = ACTIONS(1),
    [sym_kUses] = ACTIONS(1),
    [sym_kInterface] = ACTIONS(1),
    [sym_kDispInterface] = ACTIONS(1),
    [sym_kImplementation] = ACTIONS(1),
    [sym_kInitialization] = ACTIONS(1),
    [sym_kFinalization] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [sym_kBegin] = ACTIONS(1),
    [sym_kEnd] = ACTIONS(1),
    [sym_kAsm] = ACTIONS(1),
    [sym_kVar] = ACTIONS(1),
    [sym_kThreadvar] = ACTIONS(1),
    [sym_kConst] = ACTIONS(1),
    [sym_kConstref] = ACTIONS(1),
    [sym_kResourcestring] = ACTIONS(1),
    [sym_kOut] = ACTIONS(1),
    [sym_kType] = ACTIONS(1),
    [sym_kLabel] = ACTIONS(1),
    [sym_kExports] = ACTIONS(1),
    [sym_kAbsolute] = ACTIONS(1),
    [sym_kProperty] = ACTIONS(1),
    [sym_kRead] = ACTIONS(1),
    [sym_kWrite] = ACTIONS(1),
    [sym_kImplements] = ACTIONS(1),
    [sym_kDefault] = ACTIONS(1),
    [sym_kNodefault] = ACTIONS(1),
    [sym_kStored] = ACTIONS(1),
    [sym_kIndex] = ACTIONS(1),
    [sym_kDispId] = ACTIONS(1),
    [sym_kClass] = ACTIONS(1),
    [sym_kObject] = ACTIONS(1),
    [sym_kRecord] = ACTIONS(1),
    [sym_kObjcclass] = ACTIONS(1),
    [sym_kObjccategory] = ACTIONS(1),
    [sym_kObjcprotocol] = ACTIONS(1),
    [sym_kArray] = ACTIONS(1),
    [sym_kFile] = ACTIONS(1),
    [sym_kString] = ACTIONS(1),
    [sym_kSet] = ACTIONS(1),
    [sym_kOf] = ACTIONS(1),
    [sym_kHelper] = ACTIONS(1),
    [sym_kPacked] = ACTIONS(1),
    [sym_kGeneric] = ACTIONS(1),
    [sym_kSpecialize] = ACTIONS(1),
    [sym_kLt] = ACTIONS(1),
    [sym_kEq] = ACTIONS(1),
    [sym_kGt] = ACTIONS(1),
    [sym_kLte] = ACTIONS(1),
    [sym_kGte] = ACTIONS(1),
    [sym_kAdd] = ACTIONS(1),
    [sym_kSub] = ACTIONS(1),
    [sym_kMul] = ACTIONS(1),
    [sym_kFdiv] = ACTIONS(1),
    [sym_kAt] = ACTIONS(1),
    [sym_kHat] = ACTIONS(1),
    [sym_kAssign] = ACTIONS(1),
    [sym_kAssignAdd] = ACTIONS(1),
    [sym_kAssignSub] = ACTIONS(1),
    [sym_kAssignMul] = ACTIONS(1),
    [sym_kAssignDiv] = ACTIONS(1),
    [sym_kOr] = ACTIONS(1),
    [sym_kXor] = ACTIONS(1),
    [sym_kDiv] = ACTIONS(1),
    [sym_kMod] = ACTIONS(1),
    [sym_kAnd] = ACTIONS(1),
    [sym_kShl] = ACTIONS(1),
    [sym_kShr] = ACTIONS(1),
    [sym_kNot] = ACTIONS(1),
    [sym_kIs] = ACTIONS(1),
    [sym_kAs] = ACTIONS(1),
    [sym_kIn] = ACTIONS(1),
    [sym_kFor] = ACTIONS(1),
    [sym_kTo] = ACTIONS(1),
    [sym_kDownto] = ACTIONS(1),
    [sym_kIf] = ACTIONS(1),
    [sym_kThen] = ACTIONS(1),
    [sym_kElse] = ACTIONS(1),
    [sym_kDo] = ACTIONS(1),
    [sym_kWhile] = ACTIONS(1),
    [sym_kRepeat] = ACTIONS(1),
    [sym_kUntil] = ACTIONS(1),
    [sym_kTry] = ACTIONS(1),
    [sym_kExcept] = ACTIONS(1),
    [sym_kFinally] = ACTIONS(1),
    [sym_kRaise] = ACTIONS(1),
    [sym_kOn] = ACTIONS(1),
    [sym_kCase] = ACTIONS(1),
    [sym_kWith] = ACTIONS(1),
    [sym_kGoto] = ACTIONS(1),
    [sym_kFunction] = ACTIONS(1),
    [sym_kProcedure] = ACTIONS(1),
    [sym_kConstructor] = ACTIONS(1),
    [sym_kDestructor] = ACTIONS(1),
    [sym_kOperator] = ACTIONS(1),
    [sym_kReference] = ACTIONS(1),
    [sym_kPublished] = ACTIONS(1),
    [sym_kPublic] = ACTIONS(1),
    [sym_kProtected] = ACTIONS(1),
    [sym_kPrivate] = ACTIONS(1),
    [sym_kStrict] = ACTIONS(1),
    [sym_kRequired] = ACTIONS(1),
    [sym_kOptional] = ACTIONS(1),
    [sym_kForward] = ACTIONS(1),
    [sym_kStatic] = ACTIONS(1),
    [sym_kVirtual] = ACTIONS(1),
    [sym_kAbstract] = ACTIONS(1),
    [sym_kSealed] = ACTIONS(1),
    [sym_kDynamic] = ACTIONS(1),
    [sym_kOverride] = ACTIONS(1),
    [sym_kOverload] = ACTIONS(1),
    [sym_kReintroduce] = ACTIONS(1),
    [sym_kInherited] = ACTIONS(1),
    [sym_kInline] = ACTIONS(1),
    [sym_kStdcall] = ACTIONS(1),
    [sym_kCdecl] = ACTIONS(1),
    [sym_kCppdecl] = ACTIONS(1),
    [sym_kPascal] = ACTIONS(1),
    [sym_kRegister] = ACTIONS(1),
    [sym_kMwpascal] = ACTIONS(1),
    [sym_kExternal] = ACTIONS(1),
    [sym_kName] = ACTIONS(1),
    [sym_kMessage] = ACTIONS(1),
    [sym_kDeprecated] = ACTIONS(1),
    [sym_kExperimental] = ACTIONS(1),
    [sym_kPlatform] = ACTIONS(1),
    [sym_kUnimplemented] = ACTIONS(1),
    [sym_kCvar] = ACTIONS(1),
    [sym_kExport] = ACTIONS(1),
    [sym_kFar] = ACTIONS(1),
    [sym_kNear] = ACTIONS(1),
    [sym_kSafecall] = ACTIONS(1),
    [sym_kAssembler] = ACTIONS(1),
    [sym_kNostackframe] = ACTIONS(1),
    [sym_kInterrupt] = ACTIONS(1),
    [sym_kNoreturn] = ACTIONS(1),
    [sym_kIocheck] = ACTIONS(1),
    [sym_kLocal] = ACTIONS(1),
    [sym_kHardfloat] = ACTIONS(1),
    [sym_kSoftfloat] = ACTIONS(1),
    [sym_kMs_abi_default] = ACTIONS(1),
    [sym_kMs_abi_cdecl] = ACTIONS(1),
    [sym_kSaveregisters] = ACTIONS(1),
    [sym_kSysv_abi_default] = ACTIONS(1),
    [sym_kSysv_abi_cdecl] = ACTIONS(1),
    [sym_kVectorcall] = ACTIONS(1),
    [sym_kVarargs] = ACTIONS(1),
    [sym_kWinapi] = ACTIONS(1),
    [sym_kAlias] = ACTIONS(1),
    [sym_kDelayed] = ACTIONS(1),
    [sym_kNil] = ACTIONS(1),
    [sym_kTrue] = ACTIONS(1),
    [sym_kFalse] = ACTIONS(1),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_root] = STATE(2437),
    [sym_program] = STATE(2460),
    [sym_library] = STATE(2460),
    [sym_unit] = STATE(2460),
    [sym_blockTr] = STATE(1186),
    [aux_sym__definitions] = STATE(1186),
    [sym__definition] = STATE(1186),
    [sym_defProc] = STATE(1186),
    [sym_declProcFwd] = STATE(1186),
    [sym_declUses] = STATE(1186),
    [sym_declExports] = STATE(1186),
    [sym_declTypes] = STATE(1186),
    [sym_declVars] = STATE(1186),
    [sym_declConsts] = STATE(1186),
    [sym_declProc] = STATE(1118),
    [sym_declLabels] = STATE(1186),
    [sym__declProc] = STATE(1596),
    [sym__declOperator] = STATE(1624),
    [sym_rttiAttributes] = STATE(1782),
    [aux_sym_rttiAttributes_repeat2] = STATE(1680),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_LBRACK] = ACTIONS(9),
    [sym_kProgram] = ACTIONS(11),
    [sym_kLibrary] = ACTIONS(13),
    [sym_kUnit] = ACTIONS(15),
    [sym_kUses] = ACTIONS(17),
    [sym_kBegin] = ACTIONS(19),
    [sym_kVar] = ACTIONS(21),
    [sym_kThreadvar] = ACTIONS(21),
    [sym_kConst] = ACTIONS(23),
    [sym_kResourcestring] = ACTIONS(25),
    [sym_kType] = ACTIONS(27),
    [sym_kLabel] = ACTIONS(29),
    [sym_kExports] = ACTIONS(31),
    [sym_kClass] = ACTIONS(33),
    [sym_kGeneric] = ACTIONS(35),
    [sym_kFunction] = ACTIONS(37),
    [sym_kProcedure] = ACTIONS(37),
    [sym_kConstructor] = ACTIONS(37),
    [sym_kDestructor] = ACTIONS(37),
    [sym_kOperator] = ACTIONS(39),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_exceptionHandler] = STATE(1989),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_exceptionHandlerTr] = STATE(2030),
    [sym__exceptionHandlersTr] = STATE(2574),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2574),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__exceptionHandlersTr_repeat1] = STATE(1996),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(59),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kOn] = ACTIONS(83),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_exceptionHandler] = STATE(1989),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_exceptionHandlerTr] = STATE(2030),
    [sym__exceptionHandlersTr] = STATE(2616),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2616),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__exceptionHandlersTr_repeat1] = STATE(1996),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(97),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kOn] = ACTIONS(83),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_exceptionHandler] = STATE(1989),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_exceptionHandlerTr] = STATE(2030),
    [sym__exceptionHandlersTr] = STATE(2526),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2526),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__exceptionHandlersTr_repeat1] = STATE(1996),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(99),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kOn] = ACTIONS(83),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_exceptionHandler] = STATE(1989),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_exceptionHandlerTr] = STATE(2030),
    [sym__exceptionHandlersTr] = STATE(2399),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2399),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__exceptionHandlersTr_repeat1] = STATE(1996),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(101),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kOn] = ACTIONS(83),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1919),
    [sym_ifElseTr] = STATE(1919),
    [sym_whileTr] = STATE(1919),
    [sym_repeatTr] = STATE(1919),
    [sym_forTr] = STATE(1919),
    [sym_foreachTr] = STATE(1919),
    [sym_tryTr] = STATE(1919),
    [sym_caseTr] = STATE(1919),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1919),
    [sym_withTr] = STATE(1919),
    [sym_raiseTr] = STATE(1919),
    [sym_statementTr] = STATE(1919),
    [sym_gotoTr] = STATE(1919),
    [sym__statementTr] = STATE(1919),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(53),
    [sym__statementsTr] = STATE(1919),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym__statementsTr_repeat1] = STATE(53),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(103),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(117),
    [sym_kImplementation] = ACTIONS(117),
    [sym_kInitialization] = ACTIONS(117),
    [sym_kFinalization] = ACTIONS(117),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(117),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1914),
    [sym_ifElseTr] = STATE(1914),
    [sym_whileTr] = STATE(1914),
    [sym_repeatTr] = STATE(1914),
    [sym_forTr] = STATE(1914),
    [sym_foreachTr] = STATE(1914),
    [sym_tryTr] = STATE(1914),
    [sym_caseTr] = STATE(1914),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1914),
    [sym_withTr] = STATE(1914),
    [sym_raiseTr] = STATE(1914),
    [sym_statementTr] = STATE(1914),
    [sym_gotoTr] = STATE(1914),
    [sym__statementTr] = STATE(1914),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(53),
    [sym__statementsTr] = STATE(1914),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym__statementsTr_repeat1] = STATE(53),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(103),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(145),
    [sym_kImplementation] = ACTIONS(145),
    [sym_kInitialization] = ACTIONS(145),
    [sym_kFinalization] = ACTIONS(145),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(145),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2306),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(147),
    [sym_kFinally] = ACTIONS(149),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [9] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2195),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(151),
    [sym_kFinally] = ACTIONS(153),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [10] = {
    [sym_if] = STATE(1037),
    [sym_ifElse] = STATE(792),
    [sym_while] = STATE(792),
    [sym_repeat] = STATE(792),
    [sym_for] = STATE(792),
    [sym_foreach] = STATE(792),
    [sym_try] = STATE(792),
    [sym_case] = STATE(792),
    [sym_block] = STATE(792),
    [sym_asm] = STATE(792),
    [sym_with] = STATE(792),
    [sym_raise] = STATE(792),
    [sym_statement] = STATE(792),
    [sym_goto] = STATE(792),
    [sym__statement] = STATE(792),
    [sym_ifTr] = STATE(1883),
    [sym_ifElseTr] = STATE(1883),
    [sym_whileTr] = STATE(1883),
    [sym_repeatTr] = STATE(1883),
    [sym_forTr] = STATE(1883),
    [sym_foreachTr] = STATE(1883),
    [sym_tryTr] = STATE(1883),
    [sym_caseTr] = STATE(1883),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1883),
    [sym_withTr] = STATE(1883),
    [sym_raiseTr] = STATE(1883),
    [sym_statementTr] = STATE(1883),
    [sym_gotoTr] = STATE(1883),
    [sym__statementTr] = STATE(1883),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(157),
    [sym_kImplementation] = ACTIONS(157),
    [sym_kInitialization] = ACTIONS(157),
    [sym_kFinalization] = ACTIONS(157),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(157),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(159),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [11] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(793),
    [sym_while] = STATE(793),
    [sym_repeat] = STATE(793),
    [sym_for] = STATE(793),
    [sym_foreach] = STATE(793),
    [sym_try] = STATE(793),
    [sym_case] = STATE(793),
    [sym_block] = STATE(793),
    [sym_asm] = STATE(793),
    [sym_with] = STATE(793),
    [sym_raise] = STATE(793),
    [sym_statement] = STATE(793),
    [sym_goto] = STATE(793),
    [sym__statement] = STATE(793),
    [sym_ifTr] = STATE(1771),
    [sym_ifElseTr] = STATE(1771),
    [sym_whileTr] = STATE(1771),
    [sym_repeatTr] = STATE(1771),
    [sym_forTr] = STATE(1771),
    [sym_foreachTr] = STATE(1771),
    [sym_tryTr] = STATE(1771),
    [sym_caseTr] = STATE(1771),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1771),
    [sym_withTr] = STATE(1771),
    [sym_raiseTr] = STATE(1771),
    [sym_statementTr] = STATE(1771),
    [sym_gotoTr] = STATE(1771),
    [sym__statementTr] = STATE(1771),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(163),
    [sym_kImplementation] = ACTIONS(163),
    [sym_kInitialization] = ACTIONS(163),
    [sym_kFinalization] = ACTIONS(163),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(163),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(163),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [12] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(811),
    [sym_while] = STATE(811),
    [sym_repeat] = STATE(811),
    [sym_for] = STATE(811),
    [sym_foreach] = STATE(811),
    [sym_try] = STATE(811),
    [sym_case] = STATE(811),
    [sym_block] = STATE(811),
    [sym_asm] = STATE(811),
    [sym_with] = STATE(811),
    [sym_raise] = STATE(811),
    [sym_statement] = STATE(811),
    [sym_goto] = STATE(811),
    [sym__statement] = STATE(811),
    [sym_ifTr] = STATE(1783),
    [sym_ifElseTr] = STATE(1783),
    [sym_whileTr] = STATE(1783),
    [sym_repeatTr] = STATE(1783),
    [sym_forTr] = STATE(1783),
    [sym_foreachTr] = STATE(1783),
    [sym_tryTr] = STATE(1783),
    [sym_caseTr] = STATE(1783),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1783),
    [sym_withTr] = STATE(1783),
    [sym_raiseTr] = STATE(1783),
    [sym_statementTr] = STATE(1783),
    [sym_gotoTr] = STATE(1783),
    [sym__statementTr] = STATE(1783),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(167),
    [sym_kImplementation] = ACTIONS(167),
    [sym_kInitialization] = ACTIONS(167),
    [sym_kFinalization] = ACTIONS(167),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(167),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(167),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [13] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(826),
    [sym_while] = STATE(826),
    [sym_repeat] = STATE(826),
    [sym_for] = STATE(826),
    [sym_foreach] = STATE(826),
    [sym_try] = STATE(826),
    [sym_case] = STATE(826),
    [sym_block] = STATE(826),
    [sym_asm] = STATE(826),
    [sym_with] = STATE(826),
    [sym_raise] = STATE(826),
    [sym_statement] = STATE(826),
    [sym_goto] = STATE(826),
    [sym__statement] = STATE(826),
    [sym_ifTr] = STATE(1769),
    [sym_ifElseTr] = STATE(1769),
    [sym_whileTr] = STATE(1769),
    [sym_repeatTr] = STATE(1769),
    [sym_forTr] = STATE(1769),
    [sym_foreachTr] = STATE(1769),
    [sym_tryTr] = STATE(1769),
    [sym_caseTr] = STATE(1769),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1769),
    [sym_withTr] = STATE(1769),
    [sym_raiseTr] = STATE(1769),
    [sym_statementTr] = STATE(1769),
    [sym_gotoTr] = STATE(1769),
    [sym__statementTr] = STATE(1769),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(169),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(171),
    [sym_kImplementation] = ACTIONS(171),
    [sym_kInitialization] = ACTIONS(171),
    [sym_kFinalization] = ACTIONS(171),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(171),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(171),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [14] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(844),
    [sym_while] = STATE(844),
    [sym_repeat] = STATE(844),
    [sym_for] = STATE(844),
    [sym_foreach] = STATE(844),
    [sym_try] = STATE(844),
    [sym_case] = STATE(844),
    [sym_block] = STATE(844),
    [sym_asm] = STATE(844),
    [sym_with] = STATE(844),
    [sym_raise] = STATE(844),
    [sym_statement] = STATE(844),
    [sym_goto] = STATE(844),
    [sym__statement] = STATE(844),
    [sym_ifTr] = STATE(1786),
    [sym_ifElseTr] = STATE(1786),
    [sym_whileTr] = STATE(1786),
    [sym_repeatTr] = STATE(1786),
    [sym_forTr] = STATE(1786),
    [sym_foreachTr] = STATE(1786),
    [sym_tryTr] = STATE(1786),
    [sym_caseTr] = STATE(1786),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1786),
    [sym_withTr] = STATE(1786),
    [sym_raiseTr] = STATE(1786),
    [sym_statementTr] = STATE(1786),
    [sym_gotoTr] = STATE(1786),
    [sym__statementTr] = STATE(1786),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(175),
    [sym_kImplementation] = ACTIONS(175),
    [sym_kInitialization] = ACTIONS(175),
    [sym_kFinalization] = ACTIONS(175),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(175),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(175),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [15] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(808),
    [sym_while] = STATE(808),
    [sym_repeat] = STATE(808),
    [sym_for] = STATE(808),
    [sym_foreach] = STATE(808),
    [sym_try] = STATE(808),
    [sym_case] = STATE(808),
    [sym_block] = STATE(808),
    [sym_asm] = STATE(808),
    [sym_with] = STATE(808),
    [sym_raise] = STATE(808),
    [sym_statement] = STATE(808),
    [sym_goto] = STATE(808),
    [sym__statement] = STATE(808),
    [sym_ifTr] = STATE(1777),
    [sym_ifElseTr] = STATE(1777),
    [sym_whileTr] = STATE(1777),
    [sym_repeatTr] = STATE(1777),
    [sym_forTr] = STATE(1777),
    [sym_foreachTr] = STATE(1777),
    [sym_tryTr] = STATE(1777),
    [sym_caseTr] = STATE(1777),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1777),
    [sym_withTr] = STATE(1777),
    [sym_raiseTr] = STATE(1777),
    [sym_statementTr] = STATE(1777),
    [sym_gotoTr] = STATE(1777),
    [sym__statementTr] = STATE(1777),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(179),
    [sym_kImplementation] = ACTIONS(179),
    [sym_kInitialization] = ACTIONS(179),
    [sym_kFinalization] = ACTIONS(179),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(179),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(179),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [16] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(812),
    [sym_while] = STATE(812),
    [sym_repeat] = STATE(812),
    [sym_for] = STATE(812),
    [sym_foreach] = STATE(812),
    [sym_try] = STATE(812),
    [sym_case] = STATE(812),
    [sym_block] = STATE(812),
    [sym_asm] = STATE(812),
    [sym_with] = STATE(812),
    [sym_raise] = STATE(812),
    [sym_statement] = STATE(812),
    [sym_goto] = STATE(812),
    [sym__statement] = STATE(812),
    [sym_ifTr] = STATE(1780),
    [sym_ifElseTr] = STATE(1780),
    [sym_whileTr] = STATE(1780),
    [sym_repeatTr] = STATE(1780),
    [sym_forTr] = STATE(1780),
    [sym_foreachTr] = STATE(1780),
    [sym_tryTr] = STATE(1780),
    [sym_caseTr] = STATE(1780),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1780),
    [sym_withTr] = STATE(1780),
    [sym_raiseTr] = STATE(1780),
    [sym_statementTr] = STATE(1780),
    [sym_gotoTr] = STATE(1780),
    [sym__statementTr] = STATE(1780),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(181),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(183),
    [sym_kImplementation] = ACTIONS(183),
    [sym_kInitialization] = ACTIONS(183),
    [sym_kFinalization] = ACTIONS(183),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(183),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(183),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [17] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(815),
    [sym_while] = STATE(815),
    [sym_repeat] = STATE(815),
    [sym_for] = STATE(815),
    [sym_foreach] = STATE(815),
    [sym_try] = STATE(815),
    [sym_case] = STATE(815),
    [sym_block] = STATE(815),
    [sym_asm] = STATE(815),
    [sym_with] = STATE(815),
    [sym_raise] = STATE(815),
    [sym_statement] = STATE(815),
    [sym_goto] = STATE(815),
    [sym__statement] = STATE(815),
    [sym_ifTr] = STATE(1781),
    [sym_ifElseTr] = STATE(1781),
    [sym_whileTr] = STATE(1781),
    [sym_repeatTr] = STATE(1781),
    [sym_forTr] = STATE(1781),
    [sym_foreachTr] = STATE(1781),
    [sym_tryTr] = STATE(1781),
    [sym_caseTr] = STATE(1781),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1781),
    [sym_withTr] = STATE(1781),
    [sym_raiseTr] = STATE(1781),
    [sym_statementTr] = STATE(1781),
    [sym_gotoTr] = STATE(1781),
    [sym__statementTr] = STATE(1781),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(185),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(187),
    [sym_kImplementation] = ACTIONS(187),
    [sym_kInitialization] = ACTIONS(187),
    [sym_kFinalization] = ACTIONS(187),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(187),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kElse] = ACTIONS(187),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [18] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2455),
    [sym_ifElseTr] = STATE(2455),
    [sym_whileTr] = STATE(2455),
    [sym_repeatTr] = STATE(2455),
    [sym_forTr] = STATE(2455),
    [sym_foreachTr] = STATE(2455),
    [sym_tryTr] = STATE(2455),
    [sym_caseTr] = STATE(2455),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2455),
    [sym_withTr] = STATE(2455),
    [sym_raiseTr] = STATE(2455),
    [sym_statementTr] = STATE(2455),
    [sym_gotoTr] = STATE(2455),
    [sym__statementTr] = STATE(2455),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2455),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(189),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(191),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [19] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2584),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(193),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [20] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(808),
    [sym_while] = STATE(808),
    [sym_repeat] = STATE(808),
    [sym_for] = STATE(808),
    [sym_foreach] = STATE(808),
    [sym_try] = STATE(808),
    [sym_case] = STATE(808),
    [sym_block] = STATE(808),
    [sym_asm] = STATE(808),
    [sym_with] = STATE(808),
    [sym_raise] = STATE(808),
    [sym_statement] = STATE(808),
    [sym_goto] = STATE(808),
    [sym__statement] = STATE(808),
    [sym_ifTr] = STATE(1777),
    [sym_ifElseTr] = STATE(1777),
    [sym_whileTr] = STATE(1777),
    [sym_repeatTr] = STATE(1777),
    [sym_forTr] = STATE(1777),
    [sym_foreachTr] = STATE(1777),
    [sym_tryTr] = STATE(1777),
    [sym_caseTr] = STATE(1777),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1777),
    [sym_withTr] = STATE(1777),
    [sym_raiseTr] = STATE(1777),
    [sym_statementTr] = STATE(1777),
    [sym_gotoTr] = STATE(1777),
    [sym__statementTr] = STATE(1777),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(179),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(179),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(179),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(179),
    [sym_kFinally] = ACTIONS(179),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(812),
    [sym_while] = STATE(812),
    [sym_repeat] = STATE(812),
    [sym_for] = STATE(812),
    [sym_foreach] = STATE(812),
    [sym_try] = STATE(812),
    [sym_case] = STATE(812),
    [sym_block] = STATE(812),
    [sym_asm] = STATE(812),
    [sym_with] = STATE(812),
    [sym_raise] = STATE(812),
    [sym_statement] = STATE(812),
    [sym_goto] = STATE(812),
    [sym__statement] = STATE(812),
    [sym_ifTr] = STATE(1780),
    [sym_ifElseTr] = STATE(1780),
    [sym_whileTr] = STATE(1780),
    [sym_repeatTr] = STATE(1780),
    [sym_forTr] = STATE(1780),
    [sym_foreachTr] = STATE(1780),
    [sym_tryTr] = STATE(1780),
    [sym_caseTr] = STATE(1780),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1780),
    [sym_withTr] = STATE(1780),
    [sym_raiseTr] = STATE(1780),
    [sym_statementTr] = STATE(1780),
    [sym_gotoTr] = STATE(1780),
    [sym__statementTr] = STATE(1780),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(181),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(183),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(183),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(183),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(183),
    [sym_kFinally] = ACTIONS(183),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(815),
    [sym_while] = STATE(815),
    [sym_repeat] = STATE(815),
    [sym_for] = STATE(815),
    [sym_foreach] = STATE(815),
    [sym_try] = STATE(815),
    [sym_case] = STATE(815),
    [sym_block] = STATE(815),
    [sym_asm] = STATE(815),
    [sym_with] = STATE(815),
    [sym_raise] = STATE(815),
    [sym_statement] = STATE(815),
    [sym_goto] = STATE(815),
    [sym__statement] = STATE(815),
    [sym_ifTr] = STATE(1781),
    [sym_ifElseTr] = STATE(1781),
    [sym_whileTr] = STATE(1781),
    [sym_repeatTr] = STATE(1781),
    [sym_forTr] = STATE(1781),
    [sym_foreachTr] = STATE(1781),
    [sym_tryTr] = STATE(1781),
    [sym_caseTr] = STATE(1781),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1781),
    [sym_withTr] = STATE(1781),
    [sym_raiseTr] = STATE(1781),
    [sym_statementTr] = STATE(1781),
    [sym_gotoTr] = STATE(1781),
    [sym__statementTr] = STATE(1781),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(185),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(187),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(187),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(187),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(187),
    [sym_kFinally] = ACTIONS(187),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [23] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2368),
    [sym_ifElseTr] = STATE(2368),
    [sym_whileTr] = STATE(2368),
    [sym_repeatTr] = STATE(2368),
    [sym_forTr] = STATE(2368),
    [sym_foreachTr] = STATE(2368),
    [sym_tryTr] = STATE(2368),
    [sym_caseTr] = STATE(2368),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2368),
    [sym_withTr] = STATE(2368),
    [sym_raiseTr] = STATE(2368),
    [sym_statementTr] = STATE(2368),
    [sym_gotoTr] = STATE(2368),
    [sym__statementTr] = STATE(2368),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2368),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(195),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(197),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2618),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(199),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2405),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(201),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [26] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2647),
    [sym_ifElseTr] = STATE(2647),
    [sym_whileTr] = STATE(2647),
    [sym_repeatTr] = STATE(2647),
    [sym_forTr] = STATE(2647),
    [sym_foreachTr] = STATE(2647),
    [sym_tryTr] = STATE(2647),
    [sym_caseTr] = STATE(2647),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2647),
    [sym_withTr] = STATE(2647),
    [sym_raiseTr] = STATE(2647),
    [sym_statementTr] = STATE(2647),
    [sym_gotoTr] = STATE(2647),
    [sym__statementTr] = STATE(2647),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2647),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(205),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [27] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2668),
    [sym_ifElseTr] = STATE(2668),
    [sym_whileTr] = STATE(2668),
    [sym_repeatTr] = STATE(2668),
    [sym_forTr] = STATE(2668),
    [sym_foreachTr] = STATE(2668),
    [sym_tryTr] = STATE(2668),
    [sym_caseTr] = STATE(2668),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2668),
    [sym_withTr] = STATE(2668),
    [sym_raiseTr] = STATE(2668),
    [sym_statementTr] = STATE(2668),
    [sym_gotoTr] = STATE(2668),
    [sym__statementTr] = STATE(2668),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2668),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(207),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(209),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [28] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2677),
    [sym_ifElseTr] = STATE(2677),
    [sym_whileTr] = STATE(2677),
    [sym_repeatTr] = STATE(2677),
    [sym_forTr] = STATE(2677),
    [sym_foreachTr] = STATE(2677),
    [sym_tryTr] = STATE(2677),
    [sym_caseTr] = STATE(2677),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2677),
    [sym_withTr] = STATE(2677),
    [sym_raiseTr] = STATE(2677),
    [sym_statementTr] = STATE(2677),
    [sym_gotoTr] = STATE(2677),
    [sym__statementTr] = STATE(2677),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2677),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(211),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(213),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [29] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2529),
    [sym_ifElseTr] = STATE(2529),
    [sym_whileTr] = STATE(2529),
    [sym_repeatTr] = STATE(2529),
    [sym_forTr] = STATE(2529),
    [sym_foreachTr] = STATE(2529),
    [sym_tryTr] = STATE(2529),
    [sym_caseTr] = STATE(2529),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2529),
    [sym_withTr] = STATE(2529),
    [sym_raiseTr] = STATE(2529),
    [sym_statementTr] = STATE(2529),
    [sym_gotoTr] = STATE(2529),
    [sym__statementTr] = STATE(2529),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2529),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(215),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(217),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [30] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2629),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(219),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [31] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(811),
    [sym_while] = STATE(811),
    [sym_repeat] = STATE(811),
    [sym_for] = STATE(811),
    [sym_foreach] = STATE(811),
    [sym_try] = STATE(811),
    [sym_case] = STATE(811),
    [sym_block] = STATE(811),
    [sym_asm] = STATE(811),
    [sym_with] = STATE(811),
    [sym_raise] = STATE(811),
    [sym_statement] = STATE(811),
    [sym_goto] = STATE(811),
    [sym__statement] = STATE(811),
    [sym_ifTr] = STATE(1783),
    [sym_ifElseTr] = STATE(1783),
    [sym_whileTr] = STATE(1783),
    [sym_repeatTr] = STATE(1783),
    [sym_forTr] = STATE(1783),
    [sym_foreachTr] = STATE(1783),
    [sym_tryTr] = STATE(1783),
    [sym_caseTr] = STATE(1783),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1783),
    [sym_withTr] = STATE(1783),
    [sym_raiseTr] = STATE(1783),
    [sym_statementTr] = STATE(1783),
    [sym_gotoTr] = STATE(1783),
    [sym__statementTr] = STATE(1783),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(167),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(167),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(167),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(167),
    [sym_kFinally] = ACTIONS(167),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [32] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2442),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(221),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [33] = {
    [sym_if] = STATE(1031),
    [sym_ifElse] = STATE(792),
    [sym_while] = STATE(792),
    [sym_repeat] = STATE(792),
    [sym_for] = STATE(792),
    [sym_foreach] = STATE(792),
    [sym_try] = STATE(792),
    [sym_case] = STATE(792),
    [sym_block] = STATE(792),
    [sym_asm] = STATE(792),
    [sym_with] = STATE(792),
    [sym_raise] = STATE(792),
    [sym_statement] = STATE(792),
    [sym_goto] = STATE(792),
    [sym__statement] = STATE(792),
    [sym_ifTr] = STATE(1929),
    [sym_ifElseTr] = STATE(1929),
    [sym_whileTr] = STATE(1929),
    [sym_repeatTr] = STATE(1929),
    [sym_forTr] = STATE(1929),
    [sym_foreachTr] = STATE(1929),
    [sym_tryTr] = STATE(1929),
    [sym_caseTr] = STATE(1929),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1929),
    [sym_withTr] = STATE(1929),
    [sym_raiseTr] = STATE(1929),
    [sym_statementTr] = STATE(1929),
    [sym_gotoTr] = STATE(1929),
    [sym__statementTr] = STATE(1929),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(157),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(223),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(157),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(157),
    [sym_kFinally] = ACTIONS(157),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [34] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(826),
    [sym_while] = STATE(826),
    [sym_repeat] = STATE(826),
    [sym_for] = STATE(826),
    [sym_foreach] = STATE(826),
    [sym_try] = STATE(826),
    [sym_case] = STATE(826),
    [sym_block] = STATE(826),
    [sym_asm] = STATE(826),
    [sym_with] = STATE(826),
    [sym_raise] = STATE(826),
    [sym_statement] = STATE(826),
    [sym_goto] = STATE(826),
    [sym__statement] = STATE(826),
    [sym_ifTr] = STATE(1769),
    [sym_ifElseTr] = STATE(1769),
    [sym_whileTr] = STATE(1769),
    [sym_repeatTr] = STATE(1769),
    [sym_forTr] = STATE(1769),
    [sym_foreachTr] = STATE(1769),
    [sym_tryTr] = STATE(1769),
    [sym_caseTr] = STATE(1769),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1769),
    [sym_withTr] = STATE(1769),
    [sym_raiseTr] = STATE(1769),
    [sym_statementTr] = STATE(1769),
    [sym_gotoTr] = STATE(1769),
    [sym__statementTr] = STATE(1769),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(169),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(171),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(171),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(171),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(171),
    [sym_kFinally] = ACTIONS(171),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [35] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2477),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(225),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [36] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(844),
    [sym_while] = STATE(844),
    [sym_repeat] = STATE(844),
    [sym_for] = STATE(844),
    [sym_foreach] = STATE(844),
    [sym_try] = STATE(844),
    [sym_case] = STATE(844),
    [sym_block] = STATE(844),
    [sym_asm] = STATE(844),
    [sym_with] = STATE(844),
    [sym_raise] = STATE(844),
    [sym_statement] = STATE(844),
    [sym_goto] = STATE(844),
    [sym__statement] = STATE(844),
    [sym_ifTr] = STATE(1786),
    [sym_ifElseTr] = STATE(1786),
    [sym_whileTr] = STATE(1786),
    [sym_repeatTr] = STATE(1786),
    [sym_forTr] = STATE(1786),
    [sym_foreachTr] = STATE(1786),
    [sym_tryTr] = STATE(1786),
    [sym_caseTr] = STATE(1786),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1786),
    [sym_withTr] = STATE(1786),
    [sym_raiseTr] = STATE(1786),
    [sym_statementTr] = STATE(1786),
    [sym_gotoTr] = STATE(1786),
    [sym__statementTr] = STATE(1786),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(175),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(175),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(175),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(175),
    [sym_kFinally] = ACTIONS(175),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [37] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(793),
    [sym_while] = STATE(793),
    [sym_repeat] = STATE(793),
    [sym_for] = STATE(793),
    [sym_foreach] = STATE(793),
    [sym_try] = STATE(793),
    [sym_case] = STATE(793),
    [sym_block] = STATE(793),
    [sym_asm] = STATE(793),
    [sym_with] = STATE(793),
    [sym_raise] = STATE(793),
    [sym_statement] = STATE(793),
    [sym_goto] = STATE(793),
    [sym__statement] = STATE(793),
    [sym_ifTr] = STATE(1771),
    [sym_ifElseTr] = STATE(1771),
    [sym_whileTr] = STATE(1771),
    [sym_repeatTr] = STATE(1771),
    [sym_forTr] = STATE(1771),
    [sym_foreachTr] = STATE(1771),
    [sym_tryTr] = STATE(1771),
    [sym_caseTr] = STATE(1771),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1771),
    [sym_withTr] = STATE(1771),
    [sym_raiseTr] = STATE(1771),
    [sym_statementTr] = STATE(1771),
    [sym_gotoTr] = STATE(1771),
    [sym__statementTr] = STATE(1771),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(163),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(163),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kUntil] = ACTIONS(163),
    [sym_kTry] = ACTIONS(79),
    [sym_kExcept] = ACTIONS(163),
    [sym_kFinally] = ACTIONS(163),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [38] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(1998),
    [sym_ifElseTr] = STATE(1998),
    [sym_whileTr] = STATE(1998),
    [sym_repeatTr] = STATE(1998),
    [sym_forTr] = STATE(1998),
    [sym_foreachTr] = STATE(1998),
    [sym_tryTr] = STATE(1998),
    [sym_caseTr] = STATE(1998),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1998),
    [sym_withTr] = STATE(1998),
    [sym_raiseTr] = STATE(1998),
    [sym_statementTr] = STATE(1998),
    [sym_gotoTr] = STATE(1998),
    [sym__statementTr] = STATE(1998),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(1998),
    [sym_statementsTr] = STATE(2533),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(227),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [39] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2486),
    [sym_ifElseTr] = STATE(2486),
    [sym_whileTr] = STATE(2486),
    [sym_repeatTr] = STATE(2486),
    [sym_forTr] = STATE(2486),
    [sym_foreachTr] = STATE(2486),
    [sym_tryTr] = STATE(2486),
    [sym_caseTr] = STATE(2486),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2486),
    [sym_withTr] = STATE(2486),
    [sym_raiseTr] = STATE(2486),
    [sym_statementTr] = STATE(2486),
    [sym_gotoTr] = STATE(2486),
    [sym__statementTr] = STATE(2486),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2486),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(229),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [40] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2363),
    [sym_ifElseTr] = STATE(2363),
    [sym_whileTr] = STATE(2363),
    [sym_repeatTr] = STATE(2363),
    [sym_forTr] = STATE(2363),
    [sym_foreachTr] = STATE(2363),
    [sym_tryTr] = STATE(2363),
    [sym_caseTr] = STATE(2363),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2363),
    [sym_withTr] = STATE(2363),
    [sym_raiseTr] = STATE(2363),
    [sym_statementTr] = STATE(2363),
    [sym_gotoTr] = STATE(2363),
    [sym__statementTr] = STATE(2363),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2363),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(231),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [41] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2712),
    [sym_ifElseTr] = STATE(2712),
    [sym_whileTr] = STATE(2712),
    [sym_repeatTr] = STATE(2712),
    [sym_forTr] = STATE(2712),
    [sym_foreachTr] = STATE(2712),
    [sym_tryTr] = STATE(2712),
    [sym_caseTr] = STATE(2712),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2712),
    [sym_withTr] = STATE(2712),
    [sym_raiseTr] = STATE(2712),
    [sym_statementTr] = STATE(2712),
    [sym_gotoTr] = STATE(2712),
    [sym__statementTr] = STATE(2712),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2712),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(233),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [42] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2368),
    [sym_ifElseTr] = STATE(2368),
    [sym_whileTr] = STATE(2368),
    [sym_repeatTr] = STATE(2368),
    [sym_forTr] = STATE(2368),
    [sym_foreachTr] = STATE(2368),
    [sym_tryTr] = STATE(2368),
    [sym_caseTr] = STATE(2368),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2368),
    [sym_withTr] = STATE(2368),
    [sym_raiseTr] = STATE(2368),
    [sym_statementTr] = STATE(2368),
    [sym_gotoTr] = STATE(2368),
    [sym__statementTr] = STATE(2368),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2368),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(197),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [43] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2647),
    [sym_ifElseTr] = STATE(2647),
    [sym_whileTr] = STATE(2647),
    [sym_repeatTr] = STATE(2647),
    [sym_forTr] = STATE(2647),
    [sym_foreachTr] = STATE(2647),
    [sym_tryTr] = STATE(2647),
    [sym_caseTr] = STATE(2647),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2647),
    [sym_withTr] = STATE(2647),
    [sym_raiseTr] = STATE(2647),
    [sym_statementTr] = STATE(2647),
    [sym_gotoTr] = STATE(2647),
    [sym__statementTr] = STATE(2647),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2647),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(205),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [44] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2648),
    [sym_ifElseTr] = STATE(2648),
    [sym_whileTr] = STATE(2648),
    [sym_repeatTr] = STATE(2648),
    [sym_forTr] = STATE(2648),
    [sym_foreachTr] = STATE(2648),
    [sym_tryTr] = STATE(2648),
    [sym_caseTr] = STATE(2648),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2648),
    [sym_withTr] = STATE(2648),
    [sym_raiseTr] = STATE(2648),
    [sym_statementTr] = STATE(2648),
    [sym_gotoTr] = STATE(2648),
    [sym__statementTr] = STATE(2648),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2648),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(235),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [45] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2677),
    [sym_ifElseTr] = STATE(2677),
    [sym_whileTr] = STATE(2677),
    [sym_repeatTr] = STATE(2677),
    [sym_forTr] = STATE(2677),
    [sym_foreachTr] = STATE(2677),
    [sym_tryTr] = STATE(2677),
    [sym_caseTr] = STATE(2677),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2677),
    [sym_withTr] = STATE(2677),
    [sym_raiseTr] = STATE(2677),
    [sym_statementTr] = STATE(2677),
    [sym_gotoTr] = STATE(2677),
    [sym__statementTr] = STATE(2677),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2677),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(213),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [46] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2529),
    [sym_ifElseTr] = STATE(2529),
    [sym_whileTr] = STATE(2529),
    [sym_repeatTr] = STATE(2529),
    [sym_forTr] = STATE(2529),
    [sym_foreachTr] = STATE(2529),
    [sym_tryTr] = STATE(2529),
    [sym_caseTr] = STATE(2529),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2529),
    [sym_withTr] = STATE(2529),
    [sym_raiseTr] = STATE(2529),
    [sym_statementTr] = STATE(2529),
    [sym_gotoTr] = STATE(2529),
    [sym__statementTr] = STATE(2529),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2529),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(217),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [47] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2493),
    [sym_ifElseTr] = STATE(2493),
    [sym_whileTr] = STATE(2493),
    [sym_repeatTr] = STATE(2493),
    [sym_forTr] = STATE(2493),
    [sym_foreachTr] = STATE(2493),
    [sym_tryTr] = STATE(2493),
    [sym_caseTr] = STATE(2493),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2493),
    [sym_withTr] = STATE(2493),
    [sym_raiseTr] = STATE(2493),
    [sym_statementTr] = STATE(2493),
    [sym_gotoTr] = STATE(2493),
    [sym__statementTr] = STATE(2493),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2493),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(237),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [48] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2415),
    [sym_ifElseTr] = STATE(2415),
    [sym_whileTr] = STATE(2415),
    [sym_repeatTr] = STATE(2415),
    [sym_forTr] = STATE(2415),
    [sym_foreachTr] = STATE(2415),
    [sym_tryTr] = STATE(2415),
    [sym_caseTr] = STATE(2415),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2415),
    [sym_withTr] = STATE(2415),
    [sym_raiseTr] = STATE(2415),
    [sym_statementTr] = STATE(2415),
    [sym_gotoTr] = STATE(2415),
    [sym__statementTr] = STATE(2415),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2415),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(239),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [49] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2439),
    [sym_ifElseTr] = STATE(2439),
    [sym_whileTr] = STATE(2439),
    [sym_repeatTr] = STATE(2439),
    [sym_forTr] = STATE(2439),
    [sym_foreachTr] = STATE(2439),
    [sym_tryTr] = STATE(2439),
    [sym_caseTr] = STATE(2439),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2439),
    [sym_withTr] = STATE(2439),
    [sym_raiseTr] = STATE(2439),
    [sym_statementTr] = STATE(2439),
    [sym_gotoTr] = STATE(2439),
    [sym__statementTr] = STATE(2439),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2439),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(241),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [50] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2353),
    [sym_ifElseTr] = STATE(2353),
    [sym_whileTr] = STATE(2353),
    [sym_repeatTr] = STATE(2353),
    [sym_forTr] = STATE(2353),
    [sym_foreachTr] = STATE(2353),
    [sym_tryTr] = STATE(2353),
    [sym_caseTr] = STATE(2353),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2353),
    [sym_withTr] = STATE(2353),
    [sym_raiseTr] = STATE(2353),
    [sym_statementTr] = STATE(2353),
    [sym_gotoTr] = STATE(2353),
    [sym__statementTr] = STATE(2353),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2353),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(243),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [51] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2603),
    [sym_ifElseTr] = STATE(2603),
    [sym_whileTr] = STATE(2603),
    [sym_repeatTr] = STATE(2603),
    [sym_forTr] = STATE(2603),
    [sym_foreachTr] = STATE(2603),
    [sym_tryTr] = STATE(2603),
    [sym_caseTr] = STATE(2603),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2603),
    [sym_withTr] = STATE(2603),
    [sym_raiseTr] = STATE(2603),
    [sym_statementTr] = STATE(2603),
    [sym_gotoTr] = STATE(2603),
    [sym__statementTr] = STATE(2603),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2603),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(245),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [52] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1016),
    [sym_while] = STATE(1016),
    [sym_repeat] = STATE(1016),
    [sym_for] = STATE(1016),
    [sym_foreach] = STATE(1016),
    [sym_try] = STATE(1016),
    [sym_case] = STATE(1016),
    [sym_block] = STATE(1016),
    [sym_asm] = STATE(1016),
    [sym_with] = STATE(1016),
    [sym_raise] = STATE(1016),
    [sym_statement] = STATE(1016),
    [sym_goto] = STATE(1016),
    [sym__statement] = STATE(1016),
    [sym_ifTr] = STATE(2390),
    [sym_ifElseTr] = STATE(2390),
    [sym_whileTr] = STATE(2390),
    [sym_repeatTr] = STATE(2390),
    [sym_forTr] = STATE(2390),
    [sym_foreachTr] = STATE(2390),
    [sym_tryTr] = STATE(2390),
    [sym_caseTr] = STATE(2390),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2390),
    [sym_withTr] = STATE(2390),
    [sym_raiseTr] = STATE(2390),
    [sym_statementTr] = STATE(2390),
    [sym_gotoTr] = STATE(2390),
    [sym__statementTr] = STATE(2390),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(57),
    [sym__statementsTr] = STATE(2390),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(57),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(247),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [53] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1015),
    [sym_while] = STATE(1015),
    [sym_repeat] = STATE(1015),
    [sym_for] = STATE(1015),
    [sym_foreach] = STATE(1015),
    [sym_try] = STATE(1015),
    [sym_case] = STATE(1015),
    [sym_block] = STATE(1015),
    [sym_asm] = STATE(1015),
    [sym_with] = STATE(1015),
    [sym_raise] = STATE(1015),
    [sym_statement] = STATE(1015),
    [sym_goto] = STATE(1015),
    [sym__statement] = STATE(1015),
    [sym_ifTr] = STATE(1794),
    [sym_ifElseTr] = STATE(1794),
    [sym_whileTr] = STATE(1794),
    [sym_repeatTr] = STATE(1794),
    [sym_forTr] = STATE(1794),
    [sym_foreachTr] = STATE(1794),
    [sym_tryTr] = STATE(1794),
    [sym_caseTr] = STATE(1794),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1794),
    [sym_withTr] = STATE(1794),
    [sym_raiseTr] = STATE(1794),
    [sym_statementTr] = STATE(1794),
    [sym_gotoTr] = STATE(1794),
    [sym__statementTr] = STATE(1794),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1946),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(110),
    [sym__expr] = STATE(1188),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1188),
    [sym_exprUnary] = STATE(1188),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym__statementsTr_repeat1] = STATE(110),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(103),
    [anon_sym_SEMI] = ACTIONS(249),
    [anon_sym_LBRACK] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(107),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(119),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kAdd] = ACTIONS(123),
    [sym_kSub] = ACTIONS(123),
    [sym_kAt] = ACTIONS(125),
    [sym_kNot] = ACTIONS(123),
    [sym_kFor] = ACTIONS(127),
    [sym_kIf] = ACTIONS(129),
    [sym_kWhile] = ACTIONS(131),
    [sym_kRepeat] = ACTIONS(133),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(135),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(137),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [54] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(2069),
    [sym_while] = STATE(2069),
    [sym_repeat] = STATE(2069),
    [sym_for] = STATE(2069),
    [sym_foreach] = STATE(2069),
    [sym_try] = STATE(2069),
    [sym_case] = STATE(2069),
    [sym_block] = STATE(2069),
    [sym_asm] = STATE(2069),
    [sym_with] = STATE(2069),
    [sym_raise] = STATE(2069),
    [sym_statement] = STATE(2069),
    [sym_goto] = STATE(2069),
    [sym__statement] = STATE(2069),
    [sym_ifTr] = STATE(2184),
    [sym_ifElseTr] = STATE(2184),
    [sym_whileTr] = STATE(2184),
    [sym_repeatTr] = STATE(2184),
    [sym_forTr] = STATE(2184),
    [sym_foreachTr] = STATE(2184),
    [sym_tryTr] = STATE(2184),
    [sym_caseTr] = STATE(2184),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2184),
    [sym_withTr] = STATE(2184),
    [sym_raiseTr] = STATE(2184),
    [sym_statementTr] = STATE(2184),
    [sym_gotoTr] = STATE(2184),
    [sym__statementTr] = STATE(2184),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(251),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(253),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(253),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [55] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1608),
    [sym_while] = STATE(1608),
    [sym_repeat] = STATE(1608),
    [sym_for] = STATE(1608),
    [sym_foreach] = STATE(1608),
    [sym_try] = STATE(1608),
    [sym_case] = STATE(1608),
    [sym_block] = STATE(1608),
    [sym_asm] = STATE(1608),
    [sym_with] = STATE(1608),
    [sym_raise] = STATE(1608),
    [sym_statement] = STATE(1608),
    [sym_goto] = STATE(1608),
    [sym__statement] = STATE(1608),
    [sym_ifTr] = STATE(2233),
    [sym_ifElseTr] = STATE(2233),
    [sym_whileTr] = STATE(2233),
    [sym_repeatTr] = STATE(2233),
    [sym_forTr] = STATE(2233),
    [sym_foreachTr] = STATE(2233),
    [sym_tryTr] = STATE(2233),
    [sym_caseTr] = STATE(2233),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2233),
    [sym_withTr] = STATE(2233),
    [sym_raiseTr] = STATE(2233),
    [sym_statementTr] = STATE(2233),
    [sym_gotoTr] = STATE(2233),
    [sym__statementTr] = STATE(2233),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(255),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(257),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(257),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [56] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(2074),
    [sym_while] = STATE(2074),
    [sym_repeat] = STATE(2074),
    [sym_for] = STATE(2074),
    [sym_foreach] = STATE(2074),
    [sym_try] = STATE(2074),
    [sym_case] = STATE(2074),
    [sym_block] = STATE(2074),
    [sym_asm] = STATE(2074),
    [sym_with] = STATE(2074),
    [sym_raise] = STATE(2074),
    [sym_statement] = STATE(2074),
    [sym_goto] = STATE(2074),
    [sym__statement] = STATE(2074),
    [sym_ifTr] = STATE(2190),
    [sym_ifElseTr] = STATE(2190),
    [sym_whileTr] = STATE(2190),
    [sym_repeatTr] = STATE(2190),
    [sym_forTr] = STATE(2190),
    [sym_foreachTr] = STATE(2190),
    [sym_tryTr] = STATE(2190),
    [sym_caseTr] = STATE(2190),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2190),
    [sym_withTr] = STATE(2190),
    [sym_raiseTr] = STATE(2190),
    [sym_statementTr] = STATE(2190),
    [sym_gotoTr] = STATE(2190),
    [sym__statementTr] = STATE(2190),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(259),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kEnd] = ACTIONS(261),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(261),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [57] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1015),
    [sym_while] = STATE(1015),
    [sym_repeat] = STATE(1015),
    [sym_for] = STATE(1015),
    [sym_foreach] = STATE(1015),
    [sym_try] = STATE(1015),
    [sym_case] = STATE(1015),
    [sym_block] = STATE(1015),
    [sym_asm] = STATE(1015),
    [sym_with] = STATE(1015),
    [sym_raise] = STATE(1015),
    [sym_statement] = STATE(1015),
    [sym_goto] = STATE(1015),
    [sym__statement] = STATE(1015),
    [sym_ifTr] = STATE(1794),
    [sym_ifElseTr] = STATE(1794),
    [sym_whileTr] = STATE(1794),
    [sym_repeatTr] = STATE(1794),
    [sym_forTr] = STATE(1794),
    [sym_foreachTr] = STATE(1794),
    [sym_tryTr] = STATE(1794),
    [sym_caseTr] = STATE(1794),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(1794),
    [sym_withTr] = STATE(1794),
    [sym_raiseTr] = STATE(1794),
    [sym_statementTr] = STATE(1794),
    [sym_gotoTr] = STATE(1794),
    [sym__statementTr] = STATE(1794),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym_label] = STATE(110),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(110),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(249),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [58] = {
    [sym_if] = STATE(1133),
    [sym_ifElse] = STATE(792),
    [sym_while] = STATE(792),
    [sym_repeat] = STATE(792),
    [sym_for] = STATE(792),
    [sym_foreach] = STATE(792),
    [sym_try] = STATE(792),
    [sym_case] = STATE(792),
    [sym_block] = STATE(792),
    [sym_asm] = STATE(792),
    [sym_with] = STATE(792),
    [sym_raise] = STATE(792),
    [sym_statement] = STATE(792),
    [sym_goto] = STATE(792),
    [sym__statement] = STATE(792),
    [sym_ifTr] = STATE(2389),
    [sym_ifElseTr] = STATE(2389),
    [sym_whileTr] = STATE(2389),
    [sym_repeatTr] = STATE(2389),
    [sym_forTr] = STATE(2389),
    [sym_foreachTr] = STATE(2389),
    [sym_tryTr] = STATE(2389),
    [sym_caseTr] = STATE(2389),
    [sym_blockTr] = STATE(1758),
    [sym_asmTr] = STATE(2389),
    [sym_withTr] = STATE(2389),
    [sym_raiseTr] = STATE(2389),
    [sym_statementTr] = STATE(2389),
    [sym_gotoTr] = STATE(2389),
    [sym__statementTr] = STATE(2389),
    [sym_assignment] = STATE(1692),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(1692),
    [sym__expr] = STATE(1207),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1207),
    [sym_exprUnary] = STATE(1207),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(57),
    [sym_kAsm] = ACTIONS(61),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(71),
    [sym_kIf] = ACTIONS(73),
    [sym_kElse] = ACTIONS(263),
    [sym_kWhile] = ACTIONS(75),
    [sym_kRepeat] = ACTIONS(77),
    [sym_kTry] = ACTIONS(79),
    [sym_kRaise] = ACTIONS(81),
    [sym_kCase] = ACTIONS(85),
    [sym_kWith] = ACTIONS(87),
    [sym_kGoto] = ACTIONS(89),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [59] = {
    [sym__expr] = STATE(607),
    [sym__ref] = STATE(601),
    [sym_lambda] = STATE(601),
    [sym_inherited] = STATE(601),
    [sym_exprDot] = STATE(601),
    [sym_exprDeref] = STATE(601),
    [sym_exprAs] = STATE(601),
    [sym_exprTpl] = STATE(601),
    [sym_exprSubscript] = STATE(601),
    [sym_exprCall] = STATE(601),
    [sym_exprBinary] = STATE(607),
    [sym_exprUnary] = STATE(607),
    [sym_exprParens] = STATE(601),
    [sym_exprBrackets] = STATE(601),
    [sym__literal] = STATE(601),
    [sym_literalString] = STATE(601),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(601),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(265),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kVar] = ACTIONS(265),
    [sym_kThreadvar] = ACTIONS(265),
    [sym_kConst] = ACTIONS(265),
    [sym_kResourcestring] = ACTIONS(265),
    [sym_kType] = ACTIONS(265),
    [sym_kProperty] = ACTIONS(265),
    [sym_kClass] = ACTIONS(265),
    [sym_kGeneric] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(269),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(271),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(273),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kCase] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(265),
    [sym_kProcedure] = ACTIONS(265),
    [sym_kConstructor] = ACTIONS(265),
    [sym_kDestructor] = ACTIONS(265),
    [sym_kOperator] = ACTIONS(265),
    [sym_kPublished] = ACTIONS(265),
    [sym_kPublic] = ACTIONS(265),
    [sym_kProtected] = ACTIONS(265),
    [sym_kPrivate] = ACTIONS(265),
    [sym_kStrict] = ACTIONS(265),
    [sym_kRequired] = ACTIONS(265),
    [sym_kOptional] = ACTIONS(265),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(275),
    [sym_kTrue] = ACTIONS(275),
    [sym_kFalse] = ACTIONS(275),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [60] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(277),
    [anon_sym_SEMI] = ACTIONS(279),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kEnd] = ACTIONS(277),
    [sym_kVar] = ACTIONS(277),
    [sym_kThreadvar] = ACTIONS(277),
    [sym_kConst] = ACTIONS(277),
    [sym_kResourcestring] = ACTIONS(277),
    [sym_kType] = ACTIONS(277),
    [sym_kProperty] = ACTIONS(277),
    [sym_kClass] = ACTIONS(277),
    [sym_kGeneric] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kCase] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(277),
    [sym_kProcedure] = ACTIONS(277),
    [sym_kConstructor] = ACTIONS(277),
    [sym_kDestructor] = ACTIONS(277),
    [sym_kOperator] = ACTIONS(277),
    [sym_kPublished] = ACTIONS(277),
    [sym_kPublic] = ACTIONS(277),
    [sym_kProtected] = ACTIONS(277),
    [sym_kPrivate] = ACTIONS(277),
    [sym_kStrict] = ACTIONS(277),
    [sym_kRequired] = ACTIONS(277),
    [sym_kOptional] = ACTIONS(277),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [61] = {
    [sym__expr] = STATE(617),
    [sym__ref] = STATE(599),
    [sym_lambda] = STATE(599),
    [sym_inherited] = STATE(599),
    [sym_exprDot] = STATE(599),
    [sym_exprDeref] = STATE(599),
    [sym_exprAs] = STATE(599),
    [sym_exprTpl] = STATE(599),
    [sym_exprSubscript] = STATE(599),
    [sym_exprCall] = STATE(599),
    [sym_exprBinary] = STATE(617),
    [sym_exprUnary] = STATE(617),
    [sym_exprParens] = STATE(599),
    [sym_exprBrackets] = STATE(599),
    [sym__literal] = STATE(599),
    [sym_literalString] = STATE(599),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(599),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(265),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kVar] = ACTIONS(265),
    [sym_kThreadvar] = ACTIONS(265),
    [sym_kConst] = ACTIONS(265),
    [sym_kResourcestring] = ACTIONS(265),
    [sym_kType] = ACTIONS(265),
    [sym_kProperty] = ACTIONS(265),
    [sym_kClass] = ACTIONS(265),
    [sym_kGeneric] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(269),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(281),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(283),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kCase] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(265),
    [sym_kProcedure] = ACTIONS(265),
    [sym_kConstructor] = ACTIONS(265),
    [sym_kDestructor] = ACTIONS(265),
    [sym_kOperator] = ACTIONS(265),
    [sym_kPublished] = ACTIONS(265),
    [sym_kPublic] = ACTIONS(265),
    [sym_kProtected] = ACTIONS(265),
    [sym_kPrivate] = ACTIONS(265),
    [sym_kStrict] = ACTIONS(265),
    [sym_kRequired] = ACTIONS(265),
    [sym_kOptional] = ACTIONS(265),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(285),
    [sym_kTrue] = ACTIONS(285),
    [sym_kFalse] = ACTIONS(285),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [62] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(265),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kVar] = ACTIONS(265),
    [sym_kThreadvar] = ACTIONS(265),
    [sym_kConst] = ACTIONS(265),
    [sym_kResourcestring] = ACTIONS(265),
    [sym_kType] = ACTIONS(265),
    [sym_kProperty] = ACTIONS(265),
    [sym_kClass] = ACTIONS(265),
    [sym_kGeneric] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kCase] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(265),
    [sym_kProcedure] = ACTIONS(265),
    [sym_kConstructor] = ACTIONS(265),
    [sym_kDestructor] = ACTIONS(265),
    [sym_kOperator] = ACTIONS(265),
    [sym_kPublished] = ACTIONS(265),
    [sym_kPublic] = ACTIONS(265),
    [sym_kProtected] = ACTIONS(265),
    [sym_kPrivate] = ACTIONS(265),
    [sym_kStrict] = ACTIONS(265),
    [sym_kRequired] = ACTIONS(265),
    [sym_kOptional] = ACTIONS(265),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [63] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_RBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [anon_sym_RPAREN] = ACTIONS(279),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kEnd] = ACTIONS(277),
    [sym_kAbsolute] = ACTIONS(277),
    [sym_kOf] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(277),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kAssign] = ACTIONS(279),
    [sym_kAssignAdd] = ACTIONS(279),
    [sym_kAssignSub] = ACTIONS(279),
    [sym_kAssignMul] = ACTIONS(279),
    [sym_kAssignDiv] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kThen] = ACTIONS(277),
    [sym_kElse] = ACTIONS(277),
    [sym_kDo] = ACTIONS(277),
    [sym_kUntil] = ACTIONS(277),
    [sym_kExcept] = ACTIONS(277),
    [sym_kFinally] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kDelayed] = ACTIONS(277),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [64] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COLON] = ACTIONS(265),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [anon_sym_RPAREN] = ACTIONS(267),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kAbsolute] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(265),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kAssign] = ACTIONS(267),
    [sym_kAssignAdd] = ACTIONS(267),
    [sym_kAssignSub] = ACTIONS(267),
    [sym_kAssignMul] = ACTIONS(267),
    [sym_kAssignDiv] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kThen] = ACTIONS(265),
    [sym_kElse] = ACTIONS(265),
    [sym_kDo] = ACTIONS(265),
    [sym_kUntil] = ACTIONS(265),
    [sym_kExcept] = ACTIONS(265),
    [sym_kFinally] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kDelayed] = ACTIONS(265),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [65] = {
    [sym__expr] = STATE(700),
    [sym__ref] = STATE(639),
    [sym_lambda] = STATE(639),
    [sym_inherited] = STATE(639),
    [sym_exprDot] = STATE(639),
    [sym_exprDeref] = STATE(639),
    [sym_exprAs] = STATE(639),
    [sym_exprTpl] = STATE(639),
    [sym_exprSubscript] = STATE(639),
    [sym_exprCall] = STATE(639),
    [sym_exprBinary] = STATE(700),
    [sym_exprUnary] = STATE(700),
    [sym_exprParens] = STATE(639),
    [sym_exprBrackets] = STATE(639),
    [sym__literal] = STATE(639),
    [sym_literalString] = STATE(639),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(639),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(287),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COLON] = ACTIONS(265),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [anon_sym_RPAREN] = ACTIONS(267),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kAbsolute] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(265),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(289),
    [sym_kHat] = ACTIONS(267),
    [sym_kAssign] = ACTIONS(267),
    [sym_kAssignAdd] = ACTIONS(267),
    [sym_kAssignSub] = ACTIONS(267),
    [sym_kAssignMul] = ACTIONS(267),
    [sym_kAssignDiv] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(291),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kThen] = ACTIONS(265),
    [sym_kElse] = ACTIONS(265),
    [sym_kDo] = ACTIONS(265),
    [sym_kUntil] = ACTIONS(265),
    [sym_kExcept] = ACTIONS(265),
    [sym_kFinally] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kDelayed] = ACTIONS(265),
    [sym_kNil] = ACTIONS(287),
    [sym_kTrue] = ACTIONS(287),
    [sym_kFalse] = ACTIONS(287),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [66] = {
    [sym__expr] = STATE(794),
    [sym__ref] = STATE(762),
    [sym_lambda] = STATE(762),
    [sym_inherited] = STATE(762),
    [sym_exprDot] = STATE(762),
    [sym_exprDeref] = STATE(762),
    [sym_exprAs] = STATE(762),
    [sym_exprTpl] = STATE(762),
    [sym_exprSubscript] = STATE(762),
    [sym_exprCall] = STATE(762),
    [sym_exprBinary] = STATE(794),
    [sym_exprUnary] = STATE(794),
    [sym_exprParens] = STATE(762),
    [sym_exprBrackets] = STATE(762),
    [sym__literal] = STATE(762),
    [sym_literalString] = STATE(762),
    [sym__literalString] = STATE(625),
    [sym_literalChar] = STATE(625),
    [sym_literalNumber] = STATE(762),
    [sym__literalInt] = STATE(856),
    [sym__literalFloat] = STATE(856),
    [aux_sym_literalString_repeat1] = STATE(625),
    [sym_identifier] = ACTIONS(293),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(295),
    [anon_sym_POUND] = ACTIONS(297),
    [aux_sym__literalInt_token1] = ACTIONS(299),
    [aux_sym__literalInt_token2] = ACTIONS(301),
    [aux_sym__literalFloat_token1] = ACTIONS(299),
    [sym_kUses] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kBegin] = ACTIONS(265),
    [sym_kAsm] = ACTIONS(265),
    [sym_kVar] = ACTIONS(265),
    [sym_kThreadvar] = ACTIONS(265),
    [sym_kConst] = ACTIONS(265),
    [sym_kResourcestring] = ACTIONS(265),
    [sym_kType] = ACTIONS(265),
    [sym_kLabel] = ACTIONS(265),
    [sym_kExports] = ACTIONS(265),
    [sym_kClass] = ACTIONS(265),
    [sym_kGeneric] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(303),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(305),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(307),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(265),
    [sym_kProcedure] = ACTIONS(265),
    [sym_kConstructor] = ACTIONS(265),
    [sym_kDestructor] = ACTIONS(265),
    [sym_kOperator] = ACTIONS(265),
    [sym_kInherited] = ACTIONS(309),
    [sym_kNil] = ACTIONS(293),
    [sym_kTrue] = ACTIONS(293),
    [sym_kFalse] = ACTIONS(293),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [67] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kUses] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kBegin] = ACTIONS(277),
    [sym_kAsm] = ACTIONS(277),
    [sym_kVar] = ACTIONS(277),
    [sym_kThreadvar] = ACTIONS(277),
    [sym_kConst] = ACTIONS(277),
    [sym_kResourcestring] = ACTIONS(277),
    [sym_kType] = ACTIONS(277),
    [sym_kLabel] = ACTIONS(277),
    [sym_kExports] = ACTIONS(277),
    [sym_kClass] = ACTIONS(277),
    [sym_kGeneric] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(277),
    [sym_kProcedure] = ACTIONS(277),
    [sym_kConstructor] = ACTIONS(277),
    [sym_kDestructor] = ACTIONS(277),
    [sym_kOperator] = ACTIONS(277),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [68] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kUses] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kBegin] = ACTIONS(265),
    [sym_kAsm] = ACTIONS(265),
    [sym_kVar] = ACTIONS(265),
    [sym_kThreadvar] = ACTIONS(265),
    [sym_kConst] = ACTIONS(265),
    [sym_kResourcestring] = ACTIONS(265),
    [sym_kType] = ACTIONS(265),
    [sym_kLabel] = ACTIONS(265),
    [sym_kExports] = ACTIONS(265),
    [sym_kClass] = ACTIONS(265),
    [sym_kGeneric] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(265),
    [sym_kProcedure] = ACTIONS(265),
    [sym_kConstructor] = ACTIONS(265),
    [sym_kDestructor] = ACTIONS(265),
    [sym_kOperator] = ACTIONS(265),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [69] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(311),
    [sym_identifier] = ACTIONS(313),
    [anon_sym_LBRACK] = ACTIONS(315),
    [sym_kUses] = ACTIONS(313),
    [sym_kInterface] = ACTIONS(313),
    [sym_kImplementation] = ACTIONS(313),
    [sym_kInitialization] = ACTIONS(313),
    [sym_kFinalization] = ACTIONS(313),
    [sym_kBegin] = ACTIONS(313),
    [sym_kEnd] = ACTIONS(313),
    [sym_kAsm] = ACTIONS(313),
    [sym_kVar] = ACTIONS(313),
    [sym_kThreadvar] = ACTIONS(313),
    [sym_kConst] = ACTIONS(313),
    [sym_kResourcestring] = ACTIONS(313),
    [sym_kType] = ACTIONS(313),
    [sym_kLabel] = ACTIONS(313),
    [sym_kExports] = ACTIONS(313),
    [sym_kProperty] = ACTIONS(313),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(313),
    [sym_kGeneric] = ACTIONS(313),
    [sym_kFunction] = ACTIONS(313),
    [sym_kProcedure] = ACTIONS(313),
    [sym_kConstructor] = ACTIONS(313),
    [sym_kDestructor] = ACTIONS(313),
    [sym_kOperator] = ACTIONS(313),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [70] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(77),
    [aux_sym_declVar_repeat1] = STATE(77),
    [ts_builtin_sym_end] = ACTIONS(334),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_LBRACK] = ACTIONS(338),
    [sym_kUses] = ACTIONS(336),
    [sym_kInterface] = ACTIONS(336),
    [sym_kImplementation] = ACTIONS(336),
    [sym_kInitialization] = ACTIONS(336),
    [sym_kFinalization] = ACTIONS(336),
    [sym_kBegin] = ACTIONS(336),
    [sym_kEnd] = ACTIONS(336),
    [sym_kAsm] = ACTIONS(336),
    [sym_kVar] = ACTIONS(336),
    [sym_kThreadvar] = ACTIONS(336),
    [sym_kConst] = ACTIONS(336),
    [sym_kResourcestring] = ACTIONS(336),
    [sym_kType] = ACTIONS(336),
    [sym_kLabel] = ACTIONS(336),
    [sym_kExports] = ACTIONS(336),
    [sym_kProperty] = ACTIONS(336),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(336),
    [sym_kGeneric] = ACTIONS(336),
    [sym_kFunction] = ACTIONS(336),
    [sym_kProcedure] = ACTIONS(336),
    [sym_kConstructor] = ACTIONS(336),
    [sym_kDestructor] = ACTIONS(336),
    [sym_kOperator] = ACTIONS(336),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [71] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(78),
    [aux_sym_declVar_repeat1] = STATE(78),
    [ts_builtin_sym_end] = ACTIONS(341),
    [sym_identifier] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [sym_kUses] = ACTIONS(343),
    [sym_kInterface] = ACTIONS(343),
    [sym_kImplementation] = ACTIONS(343),
    [sym_kInitialization] = ACTIONS(343),
    [sym_kFinalization] = ACTIONS(343),
    [sym_kBegin] = ACTIONS(343),
    [sym_kEnd] = ACTIONS(343),
    [sym_kAsm] = ACTIONS(343),
    [sym_kVar] = ACTIONS(343),
    [sym_kThreadvar] = ACTIONS(343),
    [sym_kConst] = ACTIONS(343),
    [sym_kResourcestring] = ACTIONS(343),
    [sym_kType] = ACTIONS(343),
    [sym_kLabel] = ACTIONS(343),
    [sym_kExports] = ACTIONS(343),
    [sym_kProperty] = ACTIONS(343),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(343),
    [sym_kGeneric] = ACTIONS(343),
    [sym_kFunction] = ACTIONS(343),
    [sym_kProcedure] = ACTIONS(343),
    [sym_kConstructor] = ACTIONS(343),
    [sym_kDestructor] = ACTIONS(343),
    [sym_kOperator] = ACTIONS(343),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [72] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(348),
    [sym_identifier] = ACTIONS(350),
    [anon_sym_LBRACK] = ACTIONS(352),
    [sym_kUses] = ACTIONS(350),
    [sym_kInterface] = ACTIONS(350),
    [sym_kImplementation] = ACTIONS(350),
    [sym_kInitialization] = ACTIONS(350),
    [sym_kFinalization] = ACTIONS(350),
    [sym_kBegin] = ACTIONS(350),
    [sym_kEnd] = ACTIONS(350),
    [sym_kAsm] = ACTIONS(350),
    [sym_kVar] = ACTIONS(350),
    [sym_kThreadvar] = ACTIONS(350),
    [sym_kConst] = ACTIONS(350),
    [sym_kResourcestring] = ACTIONS(350),
    [sym_kType] = ACTIONS(350),
    [sym_kLabel] = ACTIONS(350),
    [sym_kExports] = ACTIONS(350),
    [sym_kProperty] = ACTIONS(350),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(350),
    [sym_kGeneric] = ACTIONS(350),
    [sym_kFunction] = ACTIONS(350),
    [sym_kProcedure] = ACTIONS(350),
    [sym_kConstructor] = ACTIONS(350),
    [sym_kDestructor] = ACTIONS(350),
    [sym_kOperator] = ACTIONS(350),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [73] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(93),
    [aux_sym_declVar_repeat1] = STATE(93),
    [ts_builtin_sym_end] = ACTIONS(355),
    [sym_identifier] = ACTIONS(357),
    [anon_sym_LBRACK] = ACTIONS(359),
    [sym_kUses] = ACTIONS(357),
    [sym_kInterface] = ACTIONS(357),
    [sym_kImplementation] = ACTIONS(357),
    [sym_kInitialization] = ACTIONS(357),
    [sym_kFinalization] = ACTIONS(357),
    [sym_kBegin] = ACTIONS(357),
    [sym_kEnd] = ACTIONS(357),
    [sym_kAsm] = ACTIONS(357),
    [sym_kVar] = ACTIONS(357),
    [sym_kThreadvar] = ACTIONS(357),
    [sym_kConst] = ACTIONS(357),
    [sym_kResourcestring] = ACTIONS(357),
    [sym_kType] = ACTIONS(357),
    [sym_kLabel] = ACTIONS(357),
    [sym_kExports] = ACTIONS(357),
    [sym_kProperty] = ACTIONS(357),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(357),
    [sym_kGeneric] = ACTIONS(357),
    [sym_kFunction] = ACTIONS(357),
    [sym_kProcedure] = ACTIONS(357),
    [sym_kConstructor] = ACTIONS(357),
    [sym_kDestructor] = ACTIONS(357),
    [sym_kOperator] = ACTIONS(357),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [74] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(362),
    [sym_identifier] = ACTIONS(364),
    [anon_sym_LBRACK] = ACTIONS(366),
    [sym_kUses] = ACTIONS(364),
    [sym_kInterface] = ACTIONS(364),
    [sym_kImplementation] = ACTIONS(364),
    [sym_kInitialization] = ACTIONS(364),
    [sym_kFinalization] = ACTIONS(364),
    [sym_kBegin] = ACTIONS(364),
    [sym_kEnd] = ACTIONS(364),
    [sym_kAsm] = ACTIONS(364),
    [sym_kVar] = ACTIONS(364),
    [sym_kThreadvar] = ACTIONS(364),
    [sym_kConst] = ACTIONS(364),
    [sym_kResourcestring] = ACTIONS(364),
    [sym_kType] = ACTIONS(364),
    [sym_kLabel] = ACTIONS(364),
    [sym_kExports] = ACTIONS(364),
    [sym_kProperty] = ACTIONS(364),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(364),
    [sym_kGeneric] = ACTIONS(364),
    [sym_kFunction] = ACTIONS(364),
    [sym_kProcedure] = ACTIONS(364),
    [sym_kConstructor] = ACTIONS(364),
    [sym_kDestructor] = ACTIONS(364),
    [sym_kOperator] = ACTIONS(364),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [75] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(369),
    [sym_identifier] = ACTIONS(371),
    [anon_sym_LBRACK] = ACTIONS(373),
    [sym_kUses] = ACTIONS(371),
    [sym_kInterface] = ACTIONS(371),
    [sym_kImplementation] = ACTIONS(371),
    [sym_kInitialization] = ACTIONS(371),
    [sym_kFinalization] = ACTIONS(371),
    [sym_kBegin] = ACTIONS(371),
    [sym_kEnd] = ACTIONS(371),
    [sym_kAsm] = ACTIONS(371),
    [sym_kVar] = ACTIONS(371),
    [sym_kThreadvar] = ACTIONS(371),
    [sym_kConst] = ACTIONS(371),
    [sym_kResourcestring] = ACTIONS(371),
    [sym_kType] = ACTIONS(371),
    [sym_kLabel] = ACTIONS(371),
    [sym_kExports] = ACTIONS(371),
    [sym_kProperty] = ACTIONS(371),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(371),
    [sym_kGeneric] = ACTIONS(371),
    [sym_kFunction] = ACTIONS(371),
    [sym_kProcedure] = ACTIONS(371),
    [sym_kConstructor] = ACTIONS(371),
    [sym_kDestructor] = ACTIONS(371),
    [sym_kOperator] = ACTIONS(371),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [76] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(80),
    [aux_sym_declVar_repeat1] = STATE(80),
    [ts_builtin_sym_end] = ACTIONS(376),
    [sym_identifier] = ACTIONS(378),
    [anon_sym_LBRACK] = ACTIONS(380),
    [sym_kUses] = ACTIONS(378),
    [sym_kInterface] = ACTIONS(378),
    [sym_kImplementation] = ACTIONS(378),
    [sym_kInitialization] = ACTIONS(378),
    [sym_kFinalization] = ACTIONS(378),
    [sym_kBegin] = ACTIONS(378),
    [sym_kEnd] = ACTIONS(378),
    [sym_kAsm] = ACTIONS(378),
    [sym_kVar] = ACTIONS(378),
    [sym_kThreadvar] = ACTIONS(378),
    [sym_kConst] = ACTIONS(378),
    [sym_kResourcestring] = ACTIONS(378),
    [sym_kType] = ACTIONS(378),
    [sym_kLabel] = ACTIONS(378),
    [sym_kExports] = ACTIONS(378),
    [sym_kProperty] = ACTIONS(378),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(378),
    [sym_kGeneric] = ACTIONS(378),
    [sym_kFunction] = ACTIONS(378),
    [sym_kProcedure] = ACTIONS(378),
    [sym_kConstructor] = ACTIONS(378),
    [sym_kDestructor] = ACTIONS(378),
    [sym_kOperator] = ACTIONS(378),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [77] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(383),
    [sym_identifier] = ACTIONS(385),
    [anon_sym_LBRACK] = ACTIONS(387),
    [sym_kUses] = ACTIONS(385),
    [sym_kInterface] = ACTIONS(385),
    [sym_kImplementation] = ACTIONS(385),
    [sym_kInitialization] = ACTIONS(385),
    [sym_kFinalization] = ACTIONS(385),
    [sym_kBegin] = ACTIONS(385),
    [sym_kEnd] = ACTIONS(385),
    [sym_kAsm] = ACTIONS(385),
    [sym_kVar] = ACTIONS(385),
    [sym_kThreadvar] = ACTIONS(385),
    [sym_kConst] = ACTIONS(385),
    [sym_kResourcestring] = ACTIONS(385),
    [sym_kType] = ACTIONS(385),
    [sym_kLabel] = ACTIONS(385),
    [sym_kExports] = ACTIONS(385),
    [sym_kProperty] = ACTIONS(385),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(385),
    [sym_kGeneric] = ACTIONS(385),
    [sym_kFunction] = ACTIONS(385),
    [sym_kProcedure] = ACTIONS(385),
    [sym_kConstructor] = ACTIONS(385),
    [sym_kDestructor] = ACTIONS(385),
    [sym_kOperator] = ACTIONS(385),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [78] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(390),
    [sym_identifier] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(394),
    [sym_kUses] = ACTIONS(392),
    [sym_kInterface] = ACTIONS(392),
    [sym_kImplementation] = ACTIONS(392),
    [sym_kInitialization] = ACTIONS(392),
    [sym_kFinalization] = ACTIONS(392),
    [sym_kBegin] = ACTIONS(392),
    [sym_kEnd] = ACTIONS(392),
    [sym_kAsm] = ACTIONS(392),
    [sym_kVar] = ACTIONS(392),
    [sym_kThreadvar] = ACTIONS(392),
    [sym_kConst] = ACTIONS(392),
    [sym_kResourcestring] = ACTIONS(392),
    [sym_kType] = ACTIONS(392),
    [sym_kLabel] = ACTIONS(392),
    [sym_kExports] = ACTIONS(392),
    [sym_kProperty] = ACTIONS(392),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(392),
    [sym_kGeneric] = ACTIONS(392),
    [sym_kFunction] = ACTIONS(392),
    [sym_kProcedure] = ACTIONS(392),
    [sym_kConstructor] = ACTIONS(392),
    [sym_kDestructor] = ACTIONS(392),
    [sym_kOperator] = ACTIONS(392),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [79] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(69),
    [aux_sym_declVar_repeat1] = STATE(69),
    [ts_builtin_sym_end] = ACTIONS(397),
    [sym_identifier] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [sym_kUses] = ACTIONS(399),
    [sym_kInterface] = ACTIONS(399),
    [sym_kImplementation] = ACTIONS(399),
    [sym_kInitialization] = ACTIONS(399),
    [sym_kFinalization] = ACTIONS(399),
    [sym_kBegin] = ACTIONS(399),
    [sym_kEnd] = ACTIONS(399),
    [sym_kAsm] = ACTIONS(399),
    [sym_kVar] = ACTIONS(399),
    [sym_kThreadvar] = ACTIONS(399),
    [sym_kConst] = ACTIONS(399),
    [sym_kResourcestring] = ACTIONS(399),
    [sym_kType] = ACTIONS(399),
    [sym_kLabel] = ACTIONS(399),
    [sym_kExports] = ACTIONS(399),
    [sym_kProperty] = ACTIONS(399),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(399),
    [sym_kGeneric] = ACTIONS(399),
    [sym_kFunction] = ACTIONS(399),
    [sym_kProcedure] = ACTIONS(399),
    [sym_kConstructor] = ACTIONS(399),
    [sym_kDestructor] = ACTIONS(399),
    [sym_kOperator] = ACTIONS(399),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [80] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(404),
    [sym_identifier] = ACTIONS(406),
    [anon_sym_LBRACK] = ACTIONS(408),
    [sym_kUses] = ACTIONS(406),
    [sym_kInterface] = ACTIONS(406),
    [sym_kImplementation] = ACTIONS(406),
    [sym_kInitialization] = ACTIONS(406),
    [sym_kFinalization] = ACTIONS(406),
    [sym_kBegin] = ACTIONS(406),
    [sym_kEnd] = ACTIONS(406),
    [sym_kAsm] = ACTIONS(406),
    [sym_kVar] = ACTIONS(406),
    [sym_kThreadvar] = ACTIONS(406),
    [sym_kConst] = ACTIONS(406),
    [sym_kResourcestring] = ACTIONS(406),
    [sym_kType] = ACTIONS(406),
    [sym_kLabel] = ACTIONS(406),
    [sym_kExports] = ACTIONS(406),
    [sym_kProperty] = ACTIONS(406),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(406),
    [sym_kGeneric] = ACTIONS(406),
    [sym_kFunction] = ACTIONS(406),
    [sym_kProcedure] = ACTIONS(406),
    [sym_kConstructor] = ACTIONS(406),
    [sym_kDestructor] = ACTIONS(406),
    [sym_kOperator] = ACTIONS(406),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [81] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(411),
    [sym_identifier] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(415),
    [sym_kUses] = ACTIONS(413),
    [sym_kInterface] = ACTIONS(413),
    [sym_kImplementation] = ACTIONS(413),
    [sym_kInitialization] = ACTIONS(413),
    [sym_kFinalization] = ACTIONS(413),
    [sym_kBegin] = ACTIONS(413),
    [sym_kEnd] = ACTIONS(413),
    [sym_kAsm] = ACTIONS(413),
    [sym_kVar] = ACTIONS(413),
    [sym_kThreadvar] = ACTIONS(413),
    [sym_kConst] = ACTIONS(413),
    [sym_kResourcestring] = ACTIONS(413),
    [sym_kType] = ACTIONS(413),
    [sym_kLabel] = ACTIONS(413),
    [sym_kExports] = ACTIONS(413),
    [sym_kProperty] = ACTIONS(413),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(413),
    [sym_kGeneric] = ACTIONS(413),
    [sym_kFunction] = ACTIONS(413),
    [sym_kProcedure] = ACTIONS(413),
    [sym_kConstructor] = ACTIONS(413),
    [sym_kDestructor] = ACTIONS(413),
    [sym_kOperator] = ACTIONS(413),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [82] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(72),
    [aux_sym_declVar_repeat1] = STATE(72),
    [ts_builtin_sym_end] = ACTIONS(418),
    [sym_identifier] = ACTIONS(420),
    [anon_sym_LBRACK] = ACTIONS(422),
    [sym_kUses] = ACTIONS(420),
    [sym_kInterface] = ACTIONS(420),
    [sym_kImplementation] = ACTIONS(420),
    [sym_kInitialization] = ACTIONS(420),
    [sym_kFinalization] = ACTIONS(420),
    [sym_kBegin] = ACTIONS(420),
    [sym_kEnd] = ACTIONS(420),
    [sym_kAsm] = ACTIONS(420),
    [sym_kVar] = ACTIONS(420),
    [sym_kThreadvar] = ACTIONS(420),
    [sym_kConst] = ACTIONS(420),
    [sym_kResourcestring] = ACTIONS(420),
    [sym_kType] = ACTIONS(420),
    [sym_kLabel] = ACTIONS(420),
    [sym_kExports] = ACTIONS(420),
    [sym_kProperty] = ACTIONS(420),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(420),
    [sym_kGeneric] = ACTIONS(420),
    [sym_kFunction] = ACTIONS(420),
    [sym_kProcedure] = ACTIONS(420),
    [sym_kConstructor] = ACTIONS(420),
    [sym_kDestructor] = ACTIONS(420),
    [sym_kOperator] = ACTIONS(420),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [83] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(74),
    [aux_sym_declVar_repeat1] = STATE(74),
    [ts_builtin_sym_end] = ACTIONS(425),
    [sym_identifier] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(429),
    [sym_kUses] = ACTIONS(427),
    [sym_kInterface] = ACTIONS(427),
    [sym_kImplementation] = ACTIONS(427),
    [sym_kInitialization] = ACTIONS(427),
    [sym_kFinalization] = ACTIONS(427),
    [sym_kBegin] = ACTIONS(427),
    [sym_kEnd] = ACTIONS(427),
    [sym_kAsm] = ACTIONS(427),
    [sym_kVar] = ACTIONS(427),
    [sym_kThreadvar] = ACTIONS(427),
    [sym_kConst] = ACTIONS(427),
    [sym_kResourcestring] = ACTIONS(427),
    [sym_kType] = ACTIONS(427),
    [sym_kLabel] = ACTIONS(427),
    [sym_kExports] = ACTIONS(427),
    [sym_kProperty] = ACTIONS(427),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(427),
    [sym_kGeneric] = ACTIONS(427),
    [sym_kFunction] = ACTIONS(427),
    [sym_kProcedure] = ACTIONS(427),
    [sym_kConstructor] = ACTIONS(427),
    [sym_kDestructor] = ACTIONS(427),
    [sym_kOperator] = ACTIONS(427),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [84] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(90),
    [aux_sym_declVar_repeat1] = STATE(90),
    [ts_builtin_sym_end] = ACTIONS(432),
    [sym_identifier] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(436),
    [sym_kUses] = ACTIONS(434),
    [sym_kInterface] = ACTIONS(434),
    [sym_kImplementation] = ACTIONS(434),
    [sym_kInitialization] = ACTIONS(434),
    [sym_kFinalization] = ACTIONS(434),
    [sym_kBegin] = ACTIONS(434),
    [sym_kEnd] = ACTIONS(434),
    [sym_kAsm] = ACTIONS(434),
    [sym_kVar] = ACTIONS(434),
    [sym_kThreadvar] = ACTIONS(434),
    [sym_kConst] = ACTIONS(434),
    [sym_kResourcestring] = ACTIONS(434),
    [sym_kType] = ACTIONS(434),
    [sym_kLabel] = ACTIONS(434),
    [sym_kExports] = ACTIONS(434),
    [sym_kProperty] = ACTIONS(434),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(434),
    [sym_kGeneric] = ACTIONS(434),
    [sym_kFunction] = ACTIONS(434),
    [sym_kProcedure] = ACTIONS(434),
    [sym_kConstructor] = ACTIONS(434),
    [sym_kDestructor] = ACTIONS(434),
    [sym_kOperator] = ACTIONS(434),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [85] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(81),
    [aux_sym_declVar_repeat1] = STATE(81),
    [ts_builtin_sym_end] = ACTIONS(439),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(443),
    [sym_kUses] = ACTIONS(441),
    [sym_kInterface] = ACTIONS(441),
    [sym_kImplementation] = ACTIONS(441),
    [sym_kInitialization] = ACTIONS(441),
    [sym_kFinalization] = ACTIONS(441),
    [sym_kBegin] = ACTIONS(441),
    [sym_kEnd] = ACTIONS(441),
    [sym_kAsm] = ACTIONS(441),
    [sym_kVar] = ACTIONS(441),
    [sym_kThreadvar] = ACTIONS(441),
    [sym_kConst] = ACTIONS(441),
    [sym_kResourcestring] = ACTIONS(441),
    [sym_kType] = ACTIONS(441),
    [sym_kLabel] = ACTIONS(441),
    [sym_kExports] = ACTIONS(441),
    [sym_kProperty] = ACTIONS(441),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(441),
    [sym_kGeneric] = ACTIONS(441),
    [sym_kFunction] = ACTIONS(441),
    [sym_kProcedure] = ACTIONS(441),
    [sym_kConstructor] = ACTIONS(441),
    [sym_kDestructor] = ACTIONS(441),
    [sym_kOperator] = ACTIONS(441),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [86] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(91),
    [aux_sym_declVar_repeat1] = STATE(91),
    [ts_builtin_sym_end] = ACTIONS(446),
    [sym_identifier] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(450),
    [sym_kUses] = ACTIONS(448),
    [sym_kInterface] = ACTIONS(448),
    [sym_kImplementation] = ACTIONS(448),
    [sym_kInitialization] = ACTIONS(448),
    [sym_kFinalization] = ACTIONS(448),
    [sym_kBegin] = ACTIONS(448),
    [sym_kEnd] = ACTIONS(448),
    [sym_kAsm] = ACTIONS(448),
    [sym_kVar] = ACTIONS(448),
    [sym_kThreadvar] = ACTIONS(448),
    [sym_kConst] = ACTIONS(448),
    [sym_kResourcestring] = ACTIONS(448),
    [sym_kType] = ACTIONS(448),
    [sym_kLabel] = ACTIONS(448),
    [sym_kExports] = ACTIONS(448),
    [sym_kProperty] = ACTIONS(448),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(448),
    [sym_kGeneric] = ACTIONS(448),
    [sym_kFunction] = ACTIONS(448),
    [sym_kProcedure] = ACTIONS(448),
    [sym_kConstructor] = ACTIONS(448),
    [sym_kDestructor] = ACTIONS(448),
    [sym_kOperator] = ACTIONS(448),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [87] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(453),
    [sym_identifier] = ACTIONS(455),
    [anon_sym_LBRACK] = ACTIONS(457),
    [sym_kUses] = ACTIONS(455),
    [sym_kInterface] = ACTIONS(455),
    [sym_kImplementation] = ACTIONS(455),
    [sym_kInitialization] = ACTIONS(455),
    [sym_kFinalization] = ACTIONS(455),
    [sym_kBegin] = ACTIONS(455),
    [sym_kEnd] = ACTIONS(455),
    [sym_kAsm] = ACTIONS(455),
    [sym_kVar] = ACTIONS(455),
    [sym_kThreadvar] = ACTIONS(455),
    [sym_kConst] = ACTIONS(455),
    [sym_kResourcestring] = ACTIONS(455),
    [sym_kType] = ACTIONS(455),
    [sym_kLabel] = ACTIONS(455),
    [sym_kExports] = ACTIONS(455),
    [sym_kProperty] = ACTIONS(455),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(455),
    [sym_kGeneric] = ACTIONS(455),
    [sym_kFunction] = ACTIONS(455),
    [sym_kProcedure] = ACTIONS(455),
    [sym_kConstructor] = ACTIONS(455),
    [sym_kDestructor] = ACTIONS(455),
    [sym_kOperator] = ACTIONS(455),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [88] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(75),
    [aux_sym_declVar_repeat1] = STATE(75),
    [ts_builtin_sym_end] = ACTIONS(460),
    [sym_identifier] = ACTIONS(462),
    [anon_sym_LBRACK] = ACTIONS(464),
    [sym_kUses] = ACTIONS(462),
    [sym_kInterface] = ACTIONS(462),
    [sym_kImplementation] = ACTIONS(462),
    [sym_kInitialization] = ACTIONS(462),
    [sym_kFinalization] = ACTIONS(462),
    [sym_kBegin] = ACTIONS(462),
    [sym_kEnd] = ACTIONS(462),
    [sym_kAsm] = ACTIONS(462),
    [sym_kVar] = ACTIONS(462),
    [sym_kThreadvar] = ACTIONS(462),
    [sym_kConst] = ACTIONS(462),
    [sym_kResourcestring] = ACTIONS(462),
    [sym_kType] = ACTIONS(462),
    [sym_kLabel] = ACTIONS(462),
    [sym_kExports] = ACTIONS(462),
    [sym_kProperty] = ACTIONS(462),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(462),
    [sym_kGeneric] = ACTIONS(462),
    [sym_kFunction] = ACTIONS(462),
    [sym_kProcedure] = ACTIONS(462),
    [sym_kConstructor] = ACTIONS(462),
    [sym_kDestructor] = ACTIONS(462),
    [sym_kOperator] = ACTIONS(462),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [89] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(467),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_LBRACK] = ACTIONS(471),
    [sym_kUses] = ACTIONS(469),
    [sym_kInterface] = ACTIONS(469),
    [sym_kImplementation] = ACTIONS(469),
    [sym_kInitialization] = ACTIONS(469),
    [sym_kFinalization] = ACTIONS(469),
    [sym_kBegin] = ACTIONS(469),
    [sym_kEnd] = ACTIONS(469),
    [sym_kAsm] = ACTIONS(469),
    [sym_kVar] = ACTIONS(469),
    [sym_kThreadvar] = ACTIONS(469),
    [sym_kConst] = ACTIONS(469),
    [sym_kResourcestring] = ACTIONS(469),
    [sym_kType] = ACTIONS(469),
    [sym_kLabel] = ACTIONS(469),
    [sym_kExports] = ACTIONS(469),
    [sym_kProperty] = ACTIONS(469),
    [sym_kDefault] = ACTIONS(474),
    [sym_kNodefault] = ACTIONS(474),
    [sym_kDispId] = ACTIONS(477),
    [sym_kClass] = ACTIONS(469),
    [sym_kGeneric] = ACTIONS(469),
    [sym_kFunction] = ACTIONS(469),
    [sym_kProcedure] = ACTIONS(469),
    [sym_kConstructor] = ACTIONS(469),
    [sym_kDestructor] = ACTIONS(469),
    [sym_kOperator] = ACTIONS(469),
    [sym_kPublic] = ACTIONS(480),
    [sym_kStatic] = ACTIONS(474),
    [sym_kVirtual] = ACTIONS(474),
    [sym_kAbstract] = ACTIONS(474),
    [sym_kDynamic] = ACTIONS(474),
    [sym_kOverride] = ACTIONS(474),
    [sym_kOverload] = ACTIONS(474),
    [sym_kReintroduce] = ACTIONS(474),
    [sym_kInline] = ACTIONS(474),
    [sym_kStdcall] = ACTIONS(474),
    [sym_kCdecl] = ACTIONS(474),
    [sym_kCppdecl] = ACTIONS(474),
    [sym_kPascal] = ACTIONS(474),
    [sym_kRegister] = ACTIONS(474),
    [sym_kMwpascal] = ACTIONS(474),
    [sym_kExternal] = ACTIONS(483),
    [sym_kMessage] = ACTIONS(486),
    [sym_kDeprecated] = ACTIONS(489),
    [sym_kExperimental] = ACTIONS(474),
    [sym_kPlatform] = ACTIONS(474),
    [sym_kUnimplemented] = ACTIONS(474),
    [sym_kCvar] = ACTIONS(474),
    [sym_kExport] = ACTIONS(492),
    [sym_kFar] = ACTIONS(474),
    [sym_kNear] = ACTIONS(474),
    [sym_kSafecall] = ACTIONS(474),
    [sym_kAssembler] = ACTIONS(474),
    [sym_kNostackframe] = ACTIONS(474),
    [sym_kInterrupt] = ACTIONS(474),
    [sym_kNoreturn] = ACTIONS(474),
    [sym_kIocheck] = ACTIONS(474),
    [sym_kLocal] = ACTIONS(474),
    [sym_kHardfloat] = ACTIONS(474),
    [sym_kSoftfloat] = ACTIONS(474),
    [sym_kMs_abi_default] = ACTIONS(474),
    [sym_kMs_abi_cdecl] = ACTIONS(474),
    [sym_kSaveregisters] = ACTIONS(474),
    [sym_kSysv_abi_default] = ACTIONS(474),
    [sym_kSysv_abi_cdecl] = ACTIONS(474),
    [sym_kVectorcall] = ACTIONS(474),
    [sym_kVarargs] = ACTIONS(474),
    [sym_kWinapi] = ACTIONS(474),
    [sym_kAlias] = ACTIONS(495),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [90] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(498),
    [sym_identifier] = ACTIONS(500),
    [anon_sym_LBRACK] = ACTIONS(502),
    [sym_kUses] = ACTIONS(500),
    [sym_kInterface] = ACTIONS(500),
    [sym_kImplementation] = ACTIONS(500),
    [sym_kInitialization] = ACTIONS(500),
    [sym_kFinalization] = ACTIONS(500),
    [sym_kBegin] = ACTIONS(500),
    [sym_kEnd] = ACTIONS(500),
    [sym_kAsm] = ACTIONS(500),
    [sym_kVar] = ACTIONS(500),
    [sym_kThreadvar] = ACTIONS(500),
    [sym_kConst] = ACTIONS(500),
    [sym_kResourcestring] = ACTIONS(500),
    [sym_kType] = ACTIONS(500),
    [sym_kLabel] = ACTIONS(500),
    [sym_kExports] = ACTIONS(500),
    [sym_kProperty] = ACTIONS(500),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(500),
    [sym_kGeneric] = ACTIONS(500),
    [sym_kFunction] = ACTIONS(500),
    [sym_kProcedure] = ACTIONS(500),
    [sym_kConstructor] = ACTIONS(500),
    [sym_kDestructor] = ACTIONS(500),
    [sym_kOperator] = ACTIONS(500),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [91] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(505),
    [sym_identifier] = ACTIONS(507),
    [anon_sym_LBRACK] = ACTIONS(509),
    [sym_kUses] = ACTIONS(507),
    [sym_kInterface] = ACTIONS(507),
    [sym_kImplementation] = ACTIONS(507),
    [sym_kInitialization] = ACTIONS(507),
    [sym_kFinalization] = ACTIONS(507),
    [sym_kBegin] = ACTIONS(507),
    [sym_kEnd] = ACTIONS(507),
    [sym_kAsm] = ACTIONS(507),
    [sym_kVar] = ACTIONS(507),
    [sym_kThreadvar] = ACTIONS(507),
    [sym_kConst] = ACTIONS(507),
    [sym_kResourcestring] = ACTIONS(507),
    [sym_kType] = ACTIONS(507),
    [sym_kLabel] = ACTIONS(507),
    [sym_kExports] = ACTIONS(507),
    [sym_kProperty] = ACTIONS(507),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(507),
    [sym_kGeneric] = ACTIONS(507),
    [sym_kFunction] = ACTIONS(507),
    [sym_kProcedure] = ACTIONS(507),
    [sym_kConstructor] = ACTIONS(507),
    [sym_kDestructor] = ACTIONS(507),
    [sym_kOperator] = ACTIONS(507),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [92] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(87),
    [aux_sym_declVar_repeat1] = STATE(87),
    [ts_builtin_sym_end] = ACTIONS(512),
    [sym_identifier] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(516),
    [sym_kUses] = ACTIONS(514),
    [sym_kInterface] = ACTIONS(514),
    [sym_kImplementation] = ACTIONS(514),
    [sym_kInitialization] = ACTIONS(514),
    [sym_kFinalization] = ACTIONS(514),
    [sym_kBegin] = ACTIONS(514),
    [sym_kEnd] = ACTIONS(514),
    [sym_kAsm] = ACTIONS(514),
    [sym_kVar] = ACTIONS(514),
    [sym_kThreadvar] = ACTIONS(514),
    [sym_kConst] = ACTIONS(514),
    [sym_kResourcestring] = ACTIONS(514),
    [sym_kType] = ACTIONS(514),
    [sym_kLabel] = ACTIONS(514),
    [sym_kExports] = ACTIONS(514),
    [sym_kProperty] = ACTIONS(514),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(514),
    [sym_kGeneric] = ACTIONS(514),
    [sym_kFunction] = ACTIONS(514),
    [sym_kProcedure] = ACTIONS(514),
    [sym_kConstructor] = ACTIONS(514),
    [sym_kDestructor] = ACTIONS(514),
    [sym_kOperator] = ACTIONS(514),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [93] = {
    [sym__procAttribute] = STATE(183),
    [sym_procAttribute] = STATE(2702),
    [sym_procExternal] = STATE(89),
    [aux_sym_declVar_repeat1] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(519),
    [sym_identifier] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [sym_kUses] = ACTIONS(521),
    [sym_kInterface] = ACTIONS(521),
    [sym_kImplementation] = ACTIONS(521),
    [sym_kInitialization] = ACTIONS(521),
    [sym_kFinalization] = ACTIONS(521),
    [sym_kBegin] = ACTIONS(521),
    [sym_kEnd] = ACTIONS(521),
    [sym_kAsm] = ACTIONS(521),
    [sym_kVar] = ACTIONS(521),
    [sym_kThreadvar] = ACTIONS(521),
    [sym_kConst] = ACTIONS(521),
    [sym_kResourcestring] = ACTIONS(521),
    [sym_kType] = ACTIONS(521),
    [sym_kLabel] = ACTIONS(521),
    [sym_kExports] = ACTIONS(521),
    [sym_kProperty] = ACTIONS(521),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(521),
    [sym_kGeneric] = ACTIONS(521),
    [sym_kFunction] = ACTIONS(521),
    [sym_kProcedure] = ACTIONS(521),
    [sym_kConstructor] = ACTIONS(521),
    [sym_kDestructor] = ACTIONS(521),
    [sym_kOperator] = ACTIONS(521),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(324),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [94] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(279),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kInterface] = ACTIONS(277),
    [sym_kImplementation] = ACTIONS(277),
    [sym_kInitialization] = ACTIONS(277),
    [sym_kFinalization] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kEnd] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(277),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kAssign] = ACTIONS(279),
    [sym_kAssignAdd] = ACTIONS(279),
    [sym_kAssignSub] = ACTIONS(279),
    [sym_kAssignMul] = ACTIONS(279),
    [sym_kAssignDiv] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kElse] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [95] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(98),
    [ts_builtin_sym_end] = ACTIONS(526),
    [sym_identifier] = ACTIONS(528),
    [anon_sym_LBRACK] = ACTIONS(530),
    [sym_kUses] = ACTIONS(528),
    [sym_kInterface] = ACTIONS(528),
    [sym_kImplementation] = ACTIONS(528),
    [sym_kInitialization] = ACTIONS(528),
    [sym_kFinalization] = ACTIONS(528),
    [sym_kBegin] = ACTIONS(528),
    [sym_kEnd] = ACTIONS(528),
    [sym_kAsm] = ACTIONS(528),
    [sym_kVar] = ACTIONS(528),
    [sym_kThreadvar] = ACTIONS(528),
    [sym_kConst] = ACTIONS(528),
    [sym_kResourcestring] = ACTIONS(528),
    [sym_kType] = ACTIONS(528),
    [sym_kLabel] = ACTIONS(528),
    [sym_kExports] = ACTIONS(528),
    [sym_kProperty] = ACTIONS(528),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(528),
    [sym_kGeneric] = ACTIONS(528),
    [sym_kFunction] = ACTIONS(528),
    [sym_kProcedure] = ACTIONS(528),
    [sym_kConstructor] = ACTIONS(528),
    [sym_kDestructor] = ACTIONS(528),
    [sym_kOperator] = ACTIONS(528),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [96] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(117),
    [ts_builtin_sym_end] = ACTIONS(533),
    [sym_identifier] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(537),
    [sym_kUses] = ACTIONS(535),
    [sym_kInterface] = ACTIONS(535),
    [sym_kImplementation] = ACTIONS(535),
    [sym_kInitialization] = ACTIONS(535),
    [sym_kFinalization] = ACTIONS(535),
    [sym_kBegin] = ACTIONS(535),
    [sym_kEnd] = ACTIONS(535),
    [sym_kAsm] = ACTIONS(535),
    [sym_kVar] = ACTIONS(535),
    [sym_kThreadvar] = ACTIONS(535),
    [sym_kConst] = ACTIONS(535),
    [sym_kResourcestring] = ACTIONS(535),
    [sym_kType] = ACTIONS(535),
    [sym_kLabel] = ACTIONS(535),
    [sym_kExports] = ACTIONS(535),
    [sym_kProperty] = ACTIONS(535),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(535),
    [sym_kGeneric] = ACTIONS(535),
    [sym_kFunction] = ACTIONS(535),
    [sym_kProcedure] = ACTIONS(535),
    [sym_kConstructor] = ACTIONS(535),
    [sym_kDestructor] = ACTIONS(535),
    [sym_kOperator] = ACTIONS(535),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [97] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(540),
    [sym_identifier] = ACTIONS(542),
    [anon_sym_LBRACK] = ACTIONS(544),
    [sym_kUses] = ACTIONS(542),
    [sym_kInterface] = ACTIONS(542),
    [sym_kImplementation] = ACTIONS(542),
    [sym_kInitialization] = ACTIONS(542),
    [sym_kFinalization] = ACTIONS(542),
    [sym_kBegin] = ACTIONS(542),
    [sym_kEnd] = ACTIONS(542),
    [sym_kAsm] = ACTIONS(542),
    [sym_kVar] = ACTIONS(542),
    [sym_kThreadvar] = ACTIONS(542),
    [sym_kConst] = ACTIONS(542),
    [sym_kResourcestring] = ACTIONS(542),
    [sym_kType] = ACTIONS(542),
    [sym_kLabel] = ACTIONS(542),
    [sym_kExports] = ACTIONS(542),
    [sym_kProperty] = ACTIONS(542),
    [sym_kDefault] = ACTIONS(547),
    [sym_kNodefault] = ACTIONS(547),
    [sym_kDispId] = ACTIONS(550),
    [sym_kClass] = ACTIONS(542),
    [sym_kGeneric] = ACTIONS(542),
    [sym_kFunction] = ACTIONS(542),
    [sym_kProcedure] = ACTIONS(542),
    [sym_kConstructor] = ACTIONS(542),
    [sym_kDestructor] = ACTIONS(542),
    [sym_kOperator] = ACTIONS(542),
    [sym_kPublic] = ACTIONS(553),
    [sym_kStatic] = ACTIONS(547),
    [sym_kVirtual] = ACTIONS(547),
    [sym_kAbstract] = ACTIONS(547),
    [sym_kDynamic] = ACTIONS(547),
    [sym_kOverride] = ACTIONS(547),
    [sym_kOverload] = ACTIONS(547),
    [sym_kReintroduce] = ACTIONS(547),
    [sym_kInline] = ACTIONS(547),
    [sym_kStdcall] = ACTIONS(547),
    [sym_kCdecl] = ACTIONS(547),
    [sym_kCppdecl] = ACTIONS(547),
    [sym_kPascal] = ACTIONS(547),
    [sym_kRegister] = ACTIONS(547),
    [sym_kMwpascal] = ACTIONS(547),
    [sym_kMessage] = ACTIONS(556),
    [sym_kDeprecated] = ACTIONS(559),
    [sym_kExperimental] = ACTIONS(547),
    [sym_kPlatform] = ACTIONS(547),
    [sym_kUnimplemented] = ACTIONS(547),
    [sym_kCvar] = ACTIONS(547),
    [sym_kExport] = ACTIONS(562),
    [sym_kFar] = ACTIONS(547),
    [sym_kNear] = ACTIONS(547),
    [sym_kSafecall] = ACTIONS(547),
    [sym_kAssembler] = ACTIONS(547),
    [sym_kNostackframe] = ACTIONS(547),
    [sym_kInterrupt] = ACTIONS(547),
    [sym_kNoreturn] = ACTIONS(547),
    [sym_kIocheck] = ACTIONS(547),
    [sym_kLocal] = ACTIONS(547),
    [sym_kHardfloat] = ACTIONS(547),
    [sym_kSoftfloat] = ACTIONS(547),
    [sym_kMs_abi_default] = ACTIONS(547),
    [sym_kMs_abi_cdecl] = ACTIONS(547),
    [sym_kSaveregisters] = ACTIONS(547),
    [sym_kSysv_abi_default] = ACTIONS(547),
    [sym_kSysv_abi_cdecl] = ACTIONS(547),
    [sym_kVectorcall] = ACTIONS(547),
    [sym_kVarargs] = ACTIONS(547),
    [sym_kWinapi] = ACTIONS(547),
    [sym_kAlias] = ACTIONS(565),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [98] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(568),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LBRACK] = ACTIONS(572),
    [sym_kUses] = ACTIONS(570),
    [sym_kInterface] = ACTIONS(570),
    [sym_kImplementation] = ACTIONS(570),
    [sym_kInitialization] = ACTIONS(570),
    [sym_kFinalization] = ACTIONS(570),
    [sym_kBegin] = ACTIONS(570),
    [sym_kEnd] = ACTIONS(570),
    [sym_kAsm] = ACTIONS(570),
    [sym_kVar] = ACTIONS(570),
    [sym_kThreadvar] = ACTIONS(570),
    [sym_kConst] = ACTIONS(570),
    [sym_kResourcestring] = ACTIONS(570),
    [sym_kType] = ACTIONS(570),
    [sym_kLabel] = ACTIONS(570),
    [sym_kExports] = ACTIONS(570),
    [sym_kProperty] = ACTIONS(570),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(570),
    [sym_kGeneric] = ACTIONS(570),
    [sym_kFunction] = ACTIONS(570),
    [sym_kProcedure] = ACTIONS(570),
    [sym_kConstructor] = ACTIONS(570),
    [sym_kDestructor] = ACTIONS(570),
    [sym_kOperator] = ACTIONS(570),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [99] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(122),
    [ts_builtin_sym_end] = ACTIONS(575),
    [sym_identifier] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(579),
    [sym_kUses] = ACTIONS(577),
    [sym_kInterface] = ACTIONS(577),
    [sym_kImplementation] = ACTIONS(577),
    [sym_kInitialization] = ACTIONS(577),
    [sym_kFinalization] = ACTIONS(577),
    [sym_kBegin] = ACTIONS(577),
    [sym_kEnd] = ACTIONS(577),
    [sym_kAsm] = ACTIONS(577),
    [sym_kVar] = ACTIONS(577),
    [sym_kThreadvar] = ACTIONS(577),
    [sym_kConst] = ACTIONS(577),
    [sym_kResourcestring] = ACTIONS(577),
    [sym_kType] = ACTIONS(577),
    [sym_kLabel] = ACTIONS(577),
    [sym_kExports] = ACTIONS(577),
    [sym_kProperty] = ACTIONS(577),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(577),
    [sym_kGeneric] = ACTIONS(577),
    [sym_kFunction] = ACTIONS(577),
    [sym_kProcedure] = ACTIONS(577),
    [sym_kConstructor] = ACTIONS(577),
    [sym_kDestructor] = ACTIONS(577),
    [sym_kOperator] = ACTIONS(577),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [100] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(101),
    [ts_builtin_sym_end] = ACTIONS(582),
    [sym_identifier] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(586),
    [sym_kUses] = ACTIONS(584),
    [sym_kInterface] = ACTIONS(584),
    [sym_kImplementation] = ACTIONS(584),
    [sym_kInitialization] = ACTIONS(584),
    [sym_kFinalization] = ACTIONS(584),
    [sym_kBegin] = ACTIONS(584),
    [sym_kEnd] = ACTIONS(584),
    [sym_kAsm] = ACTIONS(584),
    [sym_kVar] = ACTIONS(584),
    [sym_kThreadvar] = ACTIONS(584),
    [sym_kConst] = ACTIONS(584),
    [sym_kResourcestring] = ACTIONS(584),
    [sym_kType] = ACTIONS(584),
    [sym_kLabel] = ACTIONS(584),
    [sym_kExports] = ACTIONS(584),
    [sym_kProperty] = ACTIONS(584),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(584),
    [sym_kGeneric] = ACTIONS(584),
    [sym_kFunction] = ACTIONS(584),
    [sym_kProcedure] = ACTIONS(584),
    [sym_kConstructor] = ACTIONS(584),
    [sym_kDestructor] = ACTIONS(584),
    [sym_kOperator] = ACTIONS(584),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [101] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(589),
    [sym_identifier] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [sym_kUses] = ACTIONS(591),
    [sym_kInterface] = ACTIONS(591),
    [sym_kImplementation] = ACTIONS(591),
    [sym_kInitialization] = ACTIONS(591),
    [sym_kFinalization] = ACTIONS(591),
    [sym_kBegin] = ACTIONS(591),
    [sym_kEnd] = ACTIONS(591),
    [sym_kAsm] = ACTIONS(591),
    [sym_kVar] = ACTIONS(591),
    [sym_kThreadvar] = ACTIONS(591),
    [sym_kConst] = ACTIONS(591),
    [sym_kResourcestring] = ACTIONS(591),
    [sym_kType] = ACTIONS(591),
    [sym_kLabel] = ACTIONS(591),
    [sym_kExports] = ACTIONS(591),
    [sym_kProperty] = ACTIONS(591),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(591),
    [sym_kGeneric] = ACTIONS(591),
    [sym_kFunction] = ACTIONS(591),
    [sym_kProcedure] = ACTIONS(591),
    [sym_kConstructor] = ACTIONS(591),
    [sym_kDestructor] = ACTIONS(591),
    [sym_kOperator] = ACTIONS(591),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [102] = {
    [ts_builtin_sym_end] = ACTIONS(596),
    [sym_identifier] = ACTIONS(598),
    [anon_sym_COMMA] = ACTIONS(596),
    [anon_sym_LBRACK] = ACTIONS(596),
    [anon_sym_RBRACK] = ACTIONS(596),
    [sym_kUses] = ACTIONS(598),
    [sym_kInterface] = ACTIONS(598),
    [sym_kImplementation] = ACTIONS(598),
    [sym_kInitialization] = ACTIONS(598),
    [sym_kFinalization] = ACTIONS(598),
    [sym_kBegin] = ACTIONS(598),
    [sym_kEnd] = ACTIONS(598),
    [sym_kAsm] = ACTIONS(598),
    [sym_kVar] = ACTIONS(598),
    [sym_kThreadvar] = ACTIONS(598),
    [sym_kConst] = ACTIONS(598),
    [sym_kResourcestring] = ACTIONS(598),
    [sym_kType] = ACTIONS(598),
    [sym_kLabel] = ACTIONS(598),
    [sym_kExports] = ACTIONS(598),
    [sym_kProperty] = ACTIONS(598),
    [sym_kDefault] = ACTIONS(598),
    [sym_kNodefault] = ACTIONS(598),
    [sym_kDispId] = ACTIONS(598),
    [sym_kClass] = ACTIONS(598),
    [sym_kGeneric] = ACTIONS(598),
    [sym_kFunction] = ACTIONS(598),
    [sym_kProcedure] = ACTIONS(598),
    [sym_kConstructor] = ACTIONS(598),
    [sym_kDestructor] = ACTIONS(598),
    [sym_kOperator] = ACTIONS(598),
    [sym_kPublic] = ACTIONS(598),
    [sym_kStatic] = ACTIONS(598),
    [sym_kVirtual] = ACTIONS(598),
    [sym_kAbstract] = ACTIONS(598),
    [sym_kDynamic] = ACTIONS(598),
    [sym_kOverride] = ACTIONS(598),
    [sym_kOverload] = ACTIONS(598),
    [sym_kReintroduce] = ACTIONS(598),
    [sym_kInline] = ACTIONS(598),
    [sym_kStdcall] = ACTIONS(598),
    [sym_kCdecl] = ACTIONS(598),
    [sym_kCppdecl] = ACTIONS(598),
    [sym_kPascal] = ACTIONS(598),
    [sym_kRegister] = ACTIONS(598),
    [sym_kMwpascal] = ACTIONS(598),
    [sym_kExternal] = ACTIONS(598),
    [sym_kMessage] = ACTIONS(598),
    [sym_kDeprecated] = ACTIONS(598),
    [sym_kExperimental] = ACTIONS(598),
    [sym_kPlatform] = ACTIONS(598),
    [sym_kUnimplemented] = ACTIONS(598),
    [sym_kCvar] = ACTIONS(598),
    [sym_kExport] = ACTIONS(598),
    [sym_kFar] = ACTIONS(598),
    [sym_kNear] = ACTIONS(598),
    [sym_kSafecall] = ACTIONS(598),
    [sym_kAssembler] = ACTIONS(598),
    [sym_kNostackframe] = ACTIONS(598),
    [sym_kInterrupt] = ACTIONS(598),
    [sym_kNoreturn] = ACTIONS(598),
    [sym_kIocheck] = ACTIONS(598),
    [sym_kLocal] = ACTIONS(598),
    [sym_kHardfloat] = ACTIONS(598),
    [sym_kSoftfloat] = ACTIONS(598),
    [sym_kMs_abi_default] = ACTIONS(598),
    [sym_kMs_abi_cdecl] = ACTIONS(598),
    [sym_kSaveregisters] = ACTIONS(598),
    [sym_kSysv_abi_default] = ACTIONS(598),
    [sym_kSysv_abi_cdecl] = ACTIONS(598),
    [sym_kVectorcall] = ACTIONS(598),
    [sym_kVarargs] = ACTIONS(598),
    [sym_kWinapi] = ACTIONS(598),
    [sym_kAlias] = ACTIONS(598),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [103] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(600),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(604),
    [sym_kUses] = ACTIONS(602),
    [sym_kInterface] = ACTIONS(602),
    [sym_kImplementation] = ACTIONS(602),
    [sym_kInitialization] = ACTIONS(602),
    [sym_kFinalization] = ACTIONS(602),
    [sym_kBegin] = ACTIONS(602),
    [sym_kEnd] = ACTIONS(602),
    [sym_kAsm] = ACTIONS(602),
    [sym_kVar] = ACTIONS(602),
    [sym_kThreadvar] = ACTIONS(602),
    [sym_kConst] = ACTIONS(602),
    [sym_kResourcestring] = ACTIONS(602),
    [sym_kType] = ACTIONS(602),
    [sym_kLabel] = ACTIONS(602),
    [sym_kExports] = ACTIONS(602),
    [sym_kProperty] = ACTIONS(602),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(602),
    [sym_kGeneric] = ACTIONS(602),
    [sym_kFunction] = ACTIONS(602),
    [sym_kProcedure] = ACTIONS(602),
    [sym_kConstructor] = ACTIONS(602),
    [sym_kDestructor] = ACTIONS(602),
    [sym_kOperator] = ACTIONS(602),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [104] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_LBRACK] = ACTIONS(611),
    [sym_kUses] = ACTIONS(609),
    [sym_kInterface] = ACTIONS(609),
    [sym_kImplementation] = ACTIONS(609),
    [sym_kInitialization] = ACTIONS(609),
    [sym_kFinalization] = ACTIONS(609),
    [sym_kBegin] = ACTIONS(609),
    [sym_kEnd] = ACTIONS(609),
    [sym_kAsm] = ACTIONS(609),
    [sym_kVar] = ACTIONS(609),
    [sym_kThreadvar] = ACTIONS(609),
    [sym_kConst] = ACTIONS(609),
    [sym_kResourcestring] = ACTIONS(609),
    [sym_kType] = ACTIONS(609),
    [sym_kLabel] = ACTIONS(609),
    [sym_kExports] = ACTIONS(609),
    [sym_kProperty] = ACTIONS(609),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(609),
    [sym_kGeneric] = ACTIONS(609),
    [sym_kFunction] = ACTIONS(609),
    [sym_kProcedure] = ACTIONS(609),
    [sym_kConstructor] = ACTIONS(609),
    [sym_kDestructor] = ACTIONS(609),
    [sym_kOperator] = ACTIONS(609),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [105] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(108),
    [ts_builtin_sym_end] = ACTIONS(614),
    [sym_identifier] = ACTIONS(616),
    [anon_sym_LBRACK] = ACTIONS(618),
    [sym_kUses] = ACTIONS(616),
    [sym_kInterface] = ACTIONS(616),
    [sym_kImplementation] = ACTIONS(616),
    [sym_kInitialization] = ACTIONS(616),
    [sym_kFinalization] = ACTIONS(616),
    [sym_kBegin] = ACTIONS(616),
    [sym_kEnd] = ACTIONS(616),
    [sym_kAsm] = ACTIONS(616),
    [sym_kVar] = ACTIONS(616),
    [sym_kThreadvar] = ACTIONS(616),
    [sym_kConst] = ACTIONS(616),
    [sym_kResourcestring] = ACTIONS(616),
    [sym_kType] = ACTIONS(616),
    [sym_kLabel] = ACTIONS(616),
    [sym_kExports] = ACTIONS(616),
    [sym_kProperty] = ACTIONS(616),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(616),
    [sym_kGeneric] = ACTIONS(616),
    [sym_kFunction] = ACTIONS(616),
    [sym_kProcedure] = ACTIONS(616),
    [sym_kConstructor] = ACTIONS(616),
    [sym_kDestructor] = ACTIONS(616),
    [sym_kOperator] = ACTIONS(616),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [106] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(621),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(625),
    [sym_kUses] = ACTIONS(623),
    [sym_kInterface] = ACTIONS(623),
    [sym_kImplementation] = ACTIONS(623),
    [sym_kInitialization] = ACTIONS(623),
    [sym_kFinalization] = ACTIONS(623),
    [sym_kBegin] = ACTIONS(623),
    [sym_kEnd] = ACTIONS(623),
    [sym_kAsm] = ACTIONS(623),
    [sym_kVar] = ACTIONS(623),
    [sym_kThreadvar] = ACTIONS(623),
    [sym_kConst] = ACTIONS(623),
    [sym_kResourcestring] = ACTIONS(623),
    [sym_kType] = ACTIONS(623),
    [sym_kLabel] = ACTIONS(623),
    [sym_kExports] = ACTIONS(623),
    [sym_kProperty] = ACTIONS(623),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(623),
    [sym_kGeneric] = ACTIONS(623),
    [sym_kFunction] = ACTIONS(623),
    [sym_kProcedure] = ACTIONS(623),
    [sym_kConstructor] = ACTIONS(623),
    [sym_kDestructor] = ACTIONS(623),
    [sym_kOperator] = ACTIONS(623),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [107] = {
    [ts_builtin_sym_end] = ACTIONS(628),
    [sym_identifier] = ACTIONS(630),
    [anon_sym_COMMA] = ACTIONS(628),
    [anon_sym_LBRACK] = ACTIONS(628),
    [anon_sym_RBRACK] = ACTIONS(628),
    [sym_kUses] = ACTIONS(630),
    [sym_kInterface] = ACTIONS(630),
    [sym_kImplementation] = ACTIONS(630),
    [sym_kInitialization] = ACTIONS(630),
    [sym_kFinalization] = ACTIONS(630),
    [sym_kBegin] = ACTIONS(630),
    [sym_kEnd] = ACTIONS(630),
    [sym_kAsm] = ACTIONS(630),
    [sym_kVar] = ACTIONS(630),
    [sym_kThreadvar] = ACTIONS(630),
    [sym_kConst] = ACTIONS(630),
    [sym_kResourcestring] = ACTIONS(630),
    [sym_kType] = ACTIONS(630),
    [sym_kLabel] = ACTIONS(630),
    [sym_kExports] = ACTIONS(630),
    [sym_kProperty] = ACTIONS(630),
    [sym_kDefault] = ACTIONS(630),
    [sym_kNodefault] = ACTIONS(630),
    [sym_kDispId] = ACTIONS(630),
    [sym_kClass] = ACTIONS(630),
    [sym_kGeneric] = ACTIONS(630),
    [sym_kFunction] = ACTIONS(630),
    [sym_kProcedure] = ACTIONS(630),
    [sym_kConstructor] = ACTIONS(630),
    [sym_kDestructor] = ACTIONS(630),
    [sym_kOperator] = ACTIONS(630),
    [sym_kPublic] = ACTIONS(630),
    [sym_kStatic] = ACTIONS(630),
    [sym_kVirtual] = ACTIONS(630),
    [sym_kAbstract] = ACTIONS(630),
    [sym_kDynamic] = ACTIONS(630),
    [sym_kOverride] = ACTIONS(630),
    [sym_kOverload] = ACTIONS(630),
    [sym_kReintroduce] = ACTIONS(630),
    [sym_kInline] = ACTIONS(630),
    [sym_kStdcall] = ACTIONS(630),
    [sym_kCdecl] = ACTIONS(630),
    [sym_kCppdecl] = ACTIONS(630),
    [sym_kPascal] = ACTIONS(630),
    [sym_kRegister] = ACTIONS(630),
    [sym_kMwpascal] = ACTIONS(630),
    [sym_kExternal] = ACTIONS(630),
    [sym_kMessage] = ACTIONS(630),
    [sym_kDeprecated] = ACTIONS(630),
    [sym_kExperimental] = ACTIONS(630),
    [sym_kPlatform] = ACTIONS(630),
    [sym_kUnimplemented] = ACTIONS(630),
    [sym_kCvar] = ACTIONS(630),
    [sym_kExport] = ACTIONS(630),
    [sym_kFar] = ACTIONS(630),
    [sym_kNear] = ACTIONS(630),
    [sym_kSafecall] = ACTIONS(630),
    [sym_kAssembler] = ACTIONS(630),
    [sym_kNostackframe] = ACTIONS(630),
    [sym_kInterrupt] = ACTIONS(630),
    [sym_kNoreturn] = ACTIONS(630),
    [sym_kIocheck] = ACTIONS(630),
    [sym_kLocal] = ACTIONS(630),
    [sym_kHardfloat] = ACTIONS(630),
    [sym_kSoftfloat] = ACTIONS(630),
    [sym_kMs_abi_default] = ACTIONS(630),
    [sym_kMs_abi_cdecl] = ACTIONS(630),
    [sym_kSaveregisters] = ACTIONS(630),
    [sym_kSysv_abi_default] = ACTIONS(630),
    [sym_kSysv_abi_cdecl] = ACTIONS(630),
    [sym_kVectorcall] = ACTIONS(630),
    [sym_kVarargs] = ACTIONS(630),
    [sym_kWinapi] = ACTIONS(630),
    [sym_kAlias] = ACTIONS(630),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [108] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(632),
    [sym_identifier] = ACTIONS(634),
    [anon_sym_LBRACK] = ACTIONS(636),
    [sym_kUses] = ACTIONS(634),
    [sym_kInterface] = ACTIONS(634),
    [sym_kImplementation] = ACTIONS(634),
    [sym_kInitialization] = ACTIONS(634),
    [sym_kFinalization] = ACTIONS(634),
    [sym_kBegin] = ACTIONS(634),
    [sym_kEnd] = ACTIONS(634),
    [sym_kAsm] = ACTIONS(634),
    [sym_kVar] = ACTIONS(634),
    [sym_kThreadvar] = ACTIONS(634),
    [sym_kConst] = ACTIONS(634),
    [sym_kResourcestring] = ACTIONS(634),
    [sym_kType] = ACTIONS(634),
    [sym_kLabel] = ACTIONS(634),
    [sym_kExports] = ACTIONS(634),
    [sym_kProperty] = ACTIONS(634),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(634),
    [sym_kGeneric] = ACTIONS(634),
    [sym_kFunction] = ACTIONS(634),
    [sym_kProcedure] = ACTIONS(634),
    [sym_kConstructor] = ACTIONS(634),
    [sym_kDestructor] = ACTIONS(634),
    [sym_kOperator] = ACTIONS(634),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [109] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(112),
    [ts_builtin_sym_end] = ACTIONS(639),
    [sym_identifier] = ACTIONS(641),
    [anon_sym_LBRACK] = ACTIONS(643),
    [sym_kUses] = ACTIONS(641),
    [sym_kInterface] = ACTIONS(641),
    [sym_kImplementation] = ACTIONS(641),
    [sym_kInitialization] = ACTIONS(641),
    [sym_kFinalization] = ACTIONS(641),
    [sym_kBegin] = ACTIONS(641),
    [sym_kEnd] = ACTIONS(641),
    [sym_kAsm] = ACTIONS(641),
    [sym_kVar] = ACTIONS(641),
    [sym_kThreadvar] = ACTIONS(641),
    [sym_kConst] = ACTIONS(641),
    [sym_kResourcestring] = ACTIONS(641),
    [sym_kType] = ACTIONS(641),
    [sym_kLabel] = ACTIONS(641),
    [sym_kExports] = ACTIONS(641),
    [sym_kProperty] = ACTIONS(641),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(641),
    [sym_kGeneric] = ACTIONS(641),
    [sym_kFunction] = ACTIONS(641),
    [sym_kProcedure] = ACTIONS(641),
    [sym_kConstructor] = ACTIONS(641),
    [sym_kDestructor] = ACTIONS(641),
    [sym_kOperator] = ACTIONS(641),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [110] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(110),
    [sym_while] = STATE(110),
    [sym_repeat] = STATE(110),
    [sym_for] = STATE(110),
    [sym_foreach] = STATE(110),
    [sym_try] = STATE(110),
    [sym_case] = STATE(110),
    [sym_block] = STATE(110),
    [sym_asm] = STATE(110),
    [sym_with] = STATE(110),
    [sym_raise] = STATE(110),
    [sym_statement] = STATE(110),
    [sym_goto] = STATE(110),
    [sym__statement] = STATE(110),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym_label] = STATE(110),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym__statementsTr_repeat1] = STATE(110),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(646),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(652),
    [anon_sym_LPAREN] = ACTIONS(655),
    [aux_sym__literalString_token1] = ACTIONS(658),
    [anon_sym_POUND] = ACTIONS(661),
    [aux_sym__literalInt_token1] = ACTIONS(664),
    [aux_sym__literalInt_token2] = ACTIONS(667),
    [aux_sym__literalFloat_token1] = ACTIONS(664),
    [sym_kBegin] = ACTIONS(670),
    [sym_kAsm] = ACTIONS(673),
    [sym_kVar] = ACTIONS(676),
    [sym_kSpecialize] = ACTIONS(679),
    [sym_kAdd] = ACTIONS(682),
    [sym_kSub] = ACTIONS(682),
    [sym_kAt] = ACTIONS(685),
    [sym_kNot] = ACTIONS(682),
    [sym_kFor] = ACTIONS(688),
    [sym_kIf] = ACTIONS(691),
    [sym_kWhile] = ACTIONS(694),
    [sym_kRepeat] = ACTIONS(697),
    [sym_kTry] = ACTIONS(700),
    [sym_kRaise] = ACTIONS(703),
    [sym_kCase] = ACTIONS(706),
    [sym_kWith] = ACTIONS(709),
    [sym_kGoto] = ACTIONS(712),
    [sym_kFunction] = ACTIONS(715),
    [sym_kProcedure] = ACTIONS(715),
    [sym_kInherited] = ACTIONS(718),
    [sym_kNil] = ACTIONS(721),
    [sym_kTrue] = ACTIONS(721),
    [sym_kFalse] = ACTIONS(721),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [111] = {
    [ts_builtin_sym_end] = ACTIONS(724),
    [sym_identifier] = ACTIONS(726),
    [anon_sym_COMMA] = ACTIONS(724),
    [anon_sym_LBRACK] = ACTIONS(724),
    [anon_sym_RBRACK] = ACTIONS(724),
    [sym_kUses] = ACTIONS(726),
    [sym_kInterface] = ACTIONS(726),
    [sym_kImplementation] = ACTIONS(726),
    [sym_kInitialization] = ACTIONS(726),
    [sym_kFinalization] = ACTIONS(726),
    [sym_kBegin] = ACTIONS(726),
    [sym_kEnd] = ACTIONS(726),
    [sym_kAsm] = ACTIONS(726),
    [sym_kVar] = ACTIONS(726),
    [sym_kThreadvar] = ACTIONS(726),
    [sym_kConst] = ACTIONS(726),
    [sym_kResourcestring] = ACTIONS(726),
    [sym_kType] = ACTIONS(726),
    [sym_kLabel] = ACTIONS(726),
    [sym_kExports] = ACTIONS(726),
    [sym_kProperty] = ACTIONS(726),
    [sym_kDefault] = ACTIONS(726),
    [sym_kNodefault] = ACTIONS(726),
    [sym_kDispId] = ACTIONS(726),
    [sym_kClass] = ACTIONS(726),
    [sym_kGeneric] = ACTIONS(726),
    [sym_kFunction] = ACTIONS(726),
    [sym_kProcedure] = ACTIONS(726),
    [sym_kConstructor] = ACTIONS(726),
    [sym_kDestructor] = ACTIONS(726),
    [sym_kOperator] = ACTIONS(726),
    [sym_kPublic] = ACTIONS(726),
    [sym_kStatic] = ACTIONS(726),
    [sym_kVirtual] = ACTIONS(726),
    [sym_kAbstract] = ACTIONS(726),
    [sym_kDynamic] = ACTIONS(726),
    [sym_kOverride] = ACTIONS(726),
    [sym_kOverload] = ACTIONS(726),
    [sym_kReintroduce] = ACTIONS(726),
    [sym_kInline] = ACTIONS(726),
    [sym_kStdcall] = ACTIONS(726),
    [sym_kCdecl] = ACTIONS(726),
    [sym_kCppdecl] = ACTIONS(726),
    [sym_kPascal] = ACTIONS(726),
    [sym_kRegister] = ACTIONS(726),
    [sym_kMwpascal] = ACTIONS(726),
    [sym_kExternal] = ACTIONS(726),
    [sym_kMessage] = ACTIONS(726),
    [sym_kDeprecated] = ACTIONS(726),
    [sym_kExperimental] = ACTIONS(726),
    [sym_kPlatform] = ACTIONS(726),
    [sym_kUnimplemented] = ACTIONS(726),
    [sym_kCvar] = ACTIONS(726),
    [sym_kExport] = ACTIONS(726),
    [sym_kFar] = ACTIONS(726),
    [sym_kNear] = ACTIONS(726),
    [sym_kSafecall] = ACTIONS(726),
    [sym_kAssembler] = ACTIONS(726),
    [sym_kNostackframe] = ACTIONS(726),
    [sym_kInterrupt] = ACTIONS(726),
    [sym_kNoreturn] = ACTIONS(726),
    [sym_kIocheck] = ACTIONS(726),
    [sym_kLocal] = ACTIONS(726),
    [sym_kHardfloat] = ACTIONS(726),
    [sym_kSoftfloat] = ACTIONS(726),
    [sym_kMs_abi_default] = ACTIONS(726),
    [sym_kMs_abi_cdecl] = ACTIONS(726),
    [sym_kSaveregisters] = ACTIONS(726),
    [sym_kSysv_abi_default] = ACTIONS(726),
    [sym_kSysv_abi_cdecl] = ACTIONS(726),
    [sym_kVectorcall] = ACTIONS(726),
    [sym_kVarargs] = ACTIONS(726),
    [sym_kWinapi] = ACTIONS(726),
    [sym_kAlias] = ACTIONS(726),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [112] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(728),
    [sym_identifier] = ACTIONS(730),
    [anon_sym_LBRACK] = ACTIONS(732),
    [sym_kUses] = ACTIONS(730),
    [sym_kInterface] = ACTIONS(730),
    [sym_kImplementation] = ACTIONS(730),
    [sym_kInitialization] = ACTIONS(730),
    [sym_kFinalization] = ACTIONS(730),
    [sym_kBegin] = ACTIONS(730),
    [sym_kEnd] = ACTIONS(730),
    [sym_kAsm] = ACTIONS(730),
    [sym_kVar] = ACTIONS(730),
    [sym_kThreadvar] = ACTIONS(730),
    [sym_kConst] = ACTIONS(730),
    [sym_kResourcestring] = ACTIONS(730),
    [sym_kType] = ACTIONS(730),
    [sym_kLabel] = ACTIONS(730),
    [sym_kExports] = ACTIONS(730),
    [sym_kProperty] = ACTIONS(730),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(730),
    [sym_kGeneric] = ACTIONS(730),
    [sym_kFunction] = ACTIONS(730),
    [sym_kProcedure] = ACTIONS(730),
    [sym_kConstructor] = ACTIONS(730),
    [sym_kDestructor] = ACTIONS(730),
    [sym_kOperator] = ACTIONS(730),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [113] = {
    [sym__expr] = STATE(1071),
    [sym__ref] = STATE(1029),
    [sym_lambda] = STATE(1029),
    [sym_inherited] = STATE(1029),
    [sym_exprDot] = STATE(1029),
    [sym_exprDeref] = STATE(1029),
    [sym_exprAs] = STATE(1029),
    [sym_exprTpl] = STATE(1029),
    [sym_exprSubscript] = STATE(1029),
    [sym_exprCall] = STATE(1029),
    [sym_exprBinary] = STATE(1071),
    [sym_exprUnary] = STATE(1071),
    [sym_exprParens] = STATE(1029),
    [sym_exprBrackets] = STATE(1029),
    [sym__literal] = STATE(1029),
    [sym_literalString] = STATE(1029),
    [sym__literalString] = STATE(851),
    [sym_literalChar] = STATE(851),
    [sym_literalNumber] = STATE(1029),
    [sym__literalInt] = STATE(1052),
    [sym__literalFloat] = STATE(1052),
    [aux_sym_literalString_repeat1] = STATE(851),
    [sym_identifier] = ACTIONS(735),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(737),
    [anon_sym_POUND] = ACTIONS(739),
    [aux_sym__literalInt_token1] = ACTIONS(741),
    [aux_sym__literalInt_token2] = ACTIONS(743),
    [aux_sym__literalFloat_token1] = ACTIONS(741),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kRead] = ACTIONS(265),
    [sym_kWrite] = ACTIONS(265),
    [sym_kImplements] = ACTIONS(265),
    [sym_kDefault] = ACTIONS(265),
    [sym_kNodefault] = ACTIONS(265),
    [sym_kStored] = ACTIONS(265),
    [sym_kIndex] = ACTIONS(265),
    [sym_kDispId] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(745),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(747),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(749),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(751),
    [sym_kProcedure] = ACTIONS(751),
    [sym_kInherited] = ACTIONS(753),
    [sym_kName] = ACTIONS(265),
    [sym_kDelayed] = ACTIONS(265),
    [sym_kNil] = ACTIONS(735),
    [sym_kTrue] = ACTIONS(735),
    [sym_kFalse] = ACTIONS(735),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [114] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(279),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kRead] = ACTIONS(277),
    [sym_kWrite] = ACTIONS(277),
    [sym_kImplements] = ACTIONS(277),
    [sym_kDefault] = ACTIONS(277),
    [sym_kNodefault] = ACTIONS(277),
    [sym_kStored] = ACTIONS(277),
    [sym_kIndex] = ACTIONS(277),
    [sym_kDispId] = ACTIONS(277),
    [sym_kOf] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kName] = ACTIONS(277),
    [sym_kDelayed] = ACTIONS(277),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [115] = {
    [ts_builtin_sym_end] = ACTIONS(755),
    [sym_identifier] = ACTIONS(757),
    [anon_sym_COMMA] = ACTIONS(755),
    [anon_sym_LBRACK] = ACTIONS(755),
    [anon_sym_RBRACK] = ACTIONS(755),
    [sym_kUses] = ACTIONS(757),
    [sym_kInterface] = ACTIONS(757),
    [sym_kImplementation] = ACTIONS(757),
    [sym_kInitialization] = ACTIONS(757),
    [sym_kFinalization] = ACTIONS(757),
    [sym_kBegin] = ACTIONS(757),
    [sym_kEnd] = ACTIONS(757),
    [sym_kAsm] = ACTIONS(757),
    [sym_kVar] = ACTIONS(757),
    [sym_kThreadvar] = ACTIONS(757),
    [sym_kConst] = ACTIONS(757),
    [sym_kResourcestring] = ACTIONS(757),
    [sym_kType] = ACTIONS(757),
    [sym_kLabel] = ACTIONS(757),
    [sym_kExports] = ACTIONS(757),
    [sym_kProperty] = ACTIONS(757),
    [sym_kDefault] = ACTIONS(757),
    [sym_kNodefault] = ACTIONS(757),
    [sym_kDispId] = ACTIONS(757),
    [sym_kClass] = ACTIONS(757),
    [sym_kGeneric] = ACTIONS(757),
    [sym_kFunction] = ACTIONS(757),
    [sym_kProcedure] = ACTIONS(757),
    [sym_kConstructor] = ACTIONS(757),
    [sym_kDestructor] = ACTIONS(757),
    [sym_kOperator] = ACTIONS(757),
    [sym_kPublic] = ACTIONS(757),
    [sym_kStatic] = ACTIONS(757),
    [sym_kVirtual] = ACTIONS(757),
    [sym_kAbstract] = ACTIONS(757),
    [sym_kDynamic] = ACTIONS(757),
    [sym_kOverride] = ACTIONS(757),
    [sym_kOverload] = ACTIONS(757),
    [sym_kReintroduce] = ACTIONS(757),
    [sym_kInline] = ACTIONS(757),
    [sym_kStdcall] = ACTIONS(757),
    [sym_kCdecl] = ACTIONS(757),
    [sym_kCppdecl] = ACTIONS(757),
    [sym_kPascal] = ACTIONS(757),
    [sym_kRegister] = ACTIONS(757),
    [sym_kMwpascal] = ACTIONS(757),
    [sym_kExternal] = ACTIONS(757),
    [sym_kMessage] = ACTIONS(757),
    [sym_kDeprecated] = ACTIONS(757),
    [sym_kExperimental] = ACTIONS(757),
    [sym_kPlatform] = ACTIONS(757),
    [sym_kUnimplemented] = ACTIONS(757),
    [sym_kCvar] = ACTIONS(757),
    [sym_kExport] = ACTIONS(757),
    [sym_kFar] = ACTIONS(757),
    [sym_kNear] = ACTIONS(757),
    [sym_kSafecall] = ACTIONS(757),
    [sym_kAssembler] = ACTIONS(757),
    [sym_kNostackframe] = ACTIONS(757),
    [sym_kInterrupt] = ACTIONS(757),
    [sym_kNoreturn] = ACTIONS(757),
    [sym_kIocheck] = ACTIONS(757),
    [sym_kLocal] = ACTIONS(757),
    [sym_kHardfloat] = ACTIONS(757),
    [sym_kSoftfloat] = ACTIONS(757),
    [sym_kMs_abi_default] = ACTIONS(757),
    [sym_kMs_abi_cdecl] = ACTIONS(757),
    [sym_kSaveregisters] = ACTIONS(757),
    [sym_kSysv_abi_default] = ACTIONS(757),
    [sym_kSysv_abi_cdecl] = ACTIONS(757),
    [sym_kVectorcall] = ACTIONS(757),
    [sym_kVarargs] = ACTIONS(757),
    [sym_kWinapi] = ACTIONS(757),
    [sym_kAlias] = ACTIONS(757),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [116] = {
    [sym__expr] = STATE(1075),
    [sym__ref] = STATE(1025),
    [sym_lambda] = STATE(1025),
    [sym_inherited] = STATE(1025),
    [sym_exprDot] = STATE(1025),
    [sym_exprDeref] = STATE(1025),
    [sym_exprAs] = STATE(1025),
    [sym_exprTpl] = STATE(1025),
    [sym_exprSubscript] = STATE(1025),
    [sym_exprCall] = STATE(1025),
    [sym_exprBinary] = STATE(1075),
    [sym_exprUnary] = STATE(1075),
    [sym_exprParens] = STATE(1025),
    [sym_exprBrackets] = STATE(1025),
    [sym__literal] = STATE(1025),
    [sym_literalString] = STATE(1025),
    [sym__literalString] = STATE(843),
    [sym_literalChar] = STATE(843),
    [sym_literalNumber] = STATE(1025),
    [sym__literalInt] = STATE(1085),
    [sym__literalFloat] = STATE(1085),
    [aux_sym_literalString_repeat1] = STATE(843),
    [sym_identifier] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(109),
    [anon_sym_POUND] = ACTIONS(111),
    [aux_sym__literalInt_token1] = ACTIONS(113),
    [aux_sym__literalInt_token2] = ACTIONS(115),
    [aux_sym__literalFloat_token1] = ACTIONS(113),
    [sym_kInterface] = ACTIONS(265),
    [sym_kImplementation] = ACTIONS(265),
    [sym_kInitialization] = ACTIONS(265),
    [sym_kFinalization] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(121),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(265),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(125),
    [sym_kHat] = ACTIONS(267),
    [sym_kAssign] = ACTIONS(267),
    [sym_kAssignAdd] = ACTIONS(267),
    [sym_kAssignSub] = ACTIONS(267),
    [sym_kAssignMul] = ACTIONS(267),
    [sym_kAssignDiv] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(123),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kElse] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(139),
    [sym_kProcedure] = ACTIONS(139),
    [sym_kInherited] = ACTIONS(141),
    [sym_kNil] = ACTIONS(143),
    [sym_kTrue] = ACTIONS(143),
    [sym_kFalse] = ACTIONS(143),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [117] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_identifier] = ACTIONS(761),
    [anon_sym_LBRACK] = ACTIONS(763),
    [sym_kUses] = ACTIONS(761),
    [sym_kInterface] = ACTIONS(761),
    [sym_kImplementation] = ACTIONS(761),
    [sym_kInitialization] = ACTIONS(761),
    [sym_kFinalization] = ACTIONS(761),
    [sym_kBegin] = ACTIONS(761),
    [sym_kEnd] = ACTIONS(761),
    [sym_kAsm] = ACTIONS(761),
    [sym_kVar] = ACTIONS(761),
    [sym_kThreadvar] = ACTIONS(761),
    [sym_kConst] = ACTIONS(761),
    [sym_kResourcestring] = ACTIONS(761),
    [sym_kType] = ACTIONS(761),
    [sym_kLabel] = ACTIONS(761),
    [sym_kExports] = ACTIONS(761),
    [sym_kProperty] = ACTIONS(761),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(761),
    [sym_kGeneric] = ACTIONS(761),
    [sym_kFunction] = ACTIONS(761),
    [sym_kProcedure] = ACTIONS(761),
    [sym_kConstructor] = ACTIONS(761),
    [sym_kDestructor] = ACTIONS(761),
    [sym_kOperator] = ACTIONS(761),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [118] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kRead] = ACTIONS(265),
    [sym_kWrite] = ACTIONS(265),
    [sym_kImplements] = ACTIONS(265),
    [sym_kDefault] = ACTIONS(265),
    [sym_kNodefault] = ACTIONS(265),
    [sym_kStored] = ACTIONS(265),
    [sym_kIndex] = ACTIONS(265),
    [sym_kDispId] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kName] = ACTIONS(265),
    [sym_kDelayed] = ACTIONS(265),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [119] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(103),
    [ts_builtin_sym_end] = ACTIONS(766),
    [sym_identifier] = ACTIONS(768),
    [anon_sym_LBRACK] = ACTIONS(770),
    [sym_kUses] = ACTIONS(768),
    [sym_kInterface] = ACTIONS(768),
    [sym_kImplementation] = ACTIONS(768),
    [sym_kInitialization] = ACTIONS(768),
    [sym_kFinalization] = ACTIONS(768),
    [sym_kBegin] = ACTIONS(768),
    [sym_kEnd] = ACTIONS(768),
    [sym_kAsm] = ACTIONS(768),
    [sym_kVar] = ACTIONS(768),
    [sym_kThreadvar] = ACTIONS(768),
    [sym_kConst] = ACTIONS(768),
    [sym_kResourcestring] = ACTIONS(768),
    [sym_kType] = ACTIONS(768),
    [sym_kLabel] = ACTIONS(768),
    [sym_kExports] = ACTIONS(768),
    [sym_kProperty] = ACTIONS(768),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(768),
    [sym_kGeneric] = ACTIONS(768),
    [sym_kFunction] = ACTIONS(768),
    [sym_kProcedure] = ACTIONS(768),
    [sym_kConstructor] = ACTIONS(768),
    [sym_kDestructor] = ACTIONS(768),
    [sym_kOperator] = ACTIONS(768),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [120] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(104),
    [ts_builtin_sym_end] = ACTIONS(773),
    [sym_identifier] = ACTIONS(775),
    [anon_sym_LBRACK] = ACTIONS(777),
    [sym_kUses] = ACTIONS(775),
    [sym_kInterface] = ACTIONS(775),
    [sym_kImplementation] = ACTIONS(775),
    [sym_kInitialization] = ACTIONS(775),
    [sym_kFinalization] = ACTIONS(775),
    [sym_kBegin] = ACTIONS(775),
    [sym_kEnd] = ACTIONS(775),
    [sym_kAsm] = ACTIONS(775),
    [sym_kVar] = ACTIONS(775),
    [sym_kThreadvar] = ACTIONS(775),
    [sym_kConst] = ACTIONS(775),
    [sym_kResourcestring] = ACTIONS(775),
    [sym_kType] = ACTIONS(775),
    [sym_kLabel] = ACTIONS(775),
    [sym_kExports] = ACTIONS(775),
    [sym_kProperty] = ACTIONS(775),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(775),
    [sym_kGeneric] = ACTIONS(775),
    [sym_kFunction] = ACTIONS(775),
    [sym_kProcedure] = ACTIONS(775),
    [sym_kConstructor] = ACTIONS(775),
    [sym_kDestructor] = ACTIONS(775),
    [sym_kOperator] = ACTIONS(775),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [121] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kInterface] = ACTIONS(265),
    [sym_kImplementation] = ACTIONS(265),
    [sym_kInitialization] = ACTIONS(265),
    [sym_kFinalization] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kEnd] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(265),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kAssign] = ACTIONS(267),
    [sym_kAssignAdd] = ACTIONS(267),
    [sym_kAssignSub] = ACTIONS(267),
    [sym_kAssignMul] = ACTIONS(267),
    [sym_kAssignDiv] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kElse] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [122] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(780),
    [sym_identifier] = ACTIONS(782),
    [anon_sym_LBRACK] = ACTIONS(784),
    [sym_kUses] = ACTIONS(782),
    [sym_kInterface] = ACTIONS(782),
    [sym_kImplementation] = ACTIONS(782),
    [sym_kInitialization] = ACTIONS(782),
    [sym_kFinalization] = ACTIONS(782),
    [sym_kBegin] = ACTIONS(782),
    [sym_kEnd] = ACTIONS(782),
    [sym_kAsm] = ACTIONS(782),
    [sym_kVar] = ACTIONS(782),
    [sym_kThreadvar] = ACTIONS(782),
    [sym_kConst] = ACTIONS(782),
    [sym_kResourcestring] = ACTIONS(782),
    [sym_kType] = ACTIONS(782),
    [sym_kLabel] = ACTIONS(782),
    [sym_kExports] = ACTIONS(782),
    [sym_kProperty] = ACTIONS(782),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(782),
    [sym_kGeneric] = ACTIONS(782),
    [sym_kFunction] = ACTIONS(782),
    [sym_kProcedure] = ACTIONS(782),
    [sym_kConstructor] = ACTIONS(782),
    [sym_kDestructor] = ACTIONS(782),
    [sym_kOperator] = ACTIONS(782),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [123] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(787),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [sym_kUses] = ACTIONS(789),
    [sym_kInterface] = ACTIONS(789),
    [sym_kImplementation] = ACTIONS(789),
    [sym_kInitialization] = ACTIONS(789),
    [sym_kFinalization] = ACTIONS(789),
    [sym_kBegin] = ACTIONS(789),
    [sym_kEnd] = ACTIONS(789),
    [sym_kAsm] = ACTIONS(789),
    [sym_kVar] = ACTIONS(789),
    [sym_kThreadvar] = ACTIONS(789),
    [sym_kConst] = ACTIONS(789),
    [sym_kResourcestring] = ACTIONS(789),
    [sym_kType] = ACTIONS(789),
    [sym_kLabel] = ACTIONS(789),
    [sym_kExports] = ACTIONS(789),
    [sym_kProperty] = ACTIONS(789),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(789),
    [sym_kGeneric] = ACTIONS(789),
    [sym_kFunction] = ACTIONS(789),
    [sym_kProcedure] = ACTIONS(789),
    [sym_kConstructor] = ACTIONS(789),
    [sym_kDestructor] = ACTIONS(789),
    [sym_kOperator] = ACTIONS(789),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [124] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(106),
    [ts_builtin_sym_end] = ACTIONS(794),
    [sym_identifier] = ACTIONS(796),
    [anon_sym_LBRACK] = ACTIONS(798),
    [sym_kUses] = ACTIONS(796),
    [sym_kInterface] = ACTIONS(796),
    [sym_kImplementation] = ACTIONS(796),
    [sym_kInitialization] = ACTIONS(796),
    [sym_kFinalization] = ACTIONS(796),
    [sym_kBegin] = ACTIONS(796),
    [sym_kEnd] = ACTIONS(796),
    [sym_kAsm] = ACTIONS(796),
    [sym_kVar] = ACTIONS(796),
    [sym_kThreadvar] = ACTIONS(796),
    [sym_kConst] = ACTIONS(796),
    [sym_kResourcestring] = ACTIONS(796),
    [sym_kType] = ACTIONS(796),
    [sym_kLabel] = ACTIONS(796),
    [sym_kExports] = ACTIONS(796),
    [sym_kProperty] = ACTIONS(796),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(796),
    [sym_kGeneric] = ACTIONS(796),
    [sym_kFunction] = ACTIONS(796),
    [sym_kProcedure] = ACTIONS(796),
    [sym_kConstructor] = ACTIONS(796),
    [sym_kDestructor] = ACTIONS(796),
    [sym_kOperator] = ACTIONS(796),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [125] = {
    [ts_builtin_sym_end] = ACTIONS(801),
    [sym_identifier] = ACTIONS(803),
    [anon_sym_COMMA] = ACTIONS(801),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_RBRACK] = ACTIONS(801),
    [sym_kUses] = ACTIONS(803),
    [sym_kInterface] = ACTIONS(803),
    [sym_kImplementation] = ACTIONS(803),
    [sym_kInitialization] = ACTIONS(803),
    [sym_kFinalization] = ACTIONS(803),
    [sym_kBegin] = ACTIONS(803),
    [sym_kEnd] = ACTIONS(803),
    [sym_kAsm] = ACTIONS(803),
    [sym_kVar] = ACTIONS(803),
    [sym_kThreadvar] = ACTIONS(803),
    [sym_kConst] = ACTIONS(803),
    [sym_kResourcestring] = ACTIONS(803),
    [sym_kType] = ACTIONS(803),
    [sym_kLabel] = ACTIONS(803),
    [sym_kExports] = ACTIONS(803),
    [sym_kProperty] = ACTIONS(803),
    [sym_kDefault] = ACTIONS(803),
    [sym_kNodefault] = ACTIONS(803),
    [sym_kDispId] = ACTIONS(803),
    [sym_kClass] = ACTIONS(803),
    [sym_kGeneric] = ACTIONS(803),
    [sym_kFunction] = ACTIONS(803),
    [sym_kProcedure] = ACTIONS(803),
    [sym_kConstructor] = ACTIONS(803),
    [sym_kDestructor] = ACTIONS(803),
    [sym_kOperator] = ACTIONS(803),
    [sym_kPublic] = ACTIONS(803),
    [sym_kStatic] = ACTIONS(803),
    [sym_kVirtual] = ACTIONS(803),
    [sym_kAbstract] = ACTIONS(803),
    [sym_kDynamic] = ACTIONS(803),
    [sym_kOverride] = ACTIONS(803),
    [sym_kOverload] = ACTIONS(803),
    [sym_kReintroduce] = ACTIONS(803),
    [sym_kInline] = ACTIONS(803),
    [sym_kStdcall] = ACTIONS(803),
    [sym_kCdecl] = ACTIONS(803),
    [sym_kCppdecl] = ACTIONS(803),
    [sym_kPascal] = ACTIONS(803),
    [sym_kRegister] = ACTIONS(803),
    [sym_kMwpascal] = ACTIONS(803),
    [sym_kExternal] = ACTIONS(803),
    [sym_kMessage] = ACTIONS(803),
    [sym_kDeprecated] = ACTIONS(803),
    [sym_kExperimental] = ACTIONS(803),
    [sym_kPlatform] = ACTIONS(803),
    [sym_kUnimplemented] = ACTIONS(803),
    [sym_kCvar] = ACTIONS(803),
    [sym_kExport] = ACTIONS(803),
    [sym_kFar] = ACTIONS(803),
    [sym_kNear] = ACTIONS(803),
    [sym_kSafecall] = ACTIONS(803),
    [sym_kAssembler] = ACTIONS(803),
    [sym_kNostackframe] = ACTIONS(803),
    [sym_kInterrupt] = ACTIONS(803),
    [sym_kNoreturn] = ACTIONS(803),
    [sym_kIocheck] = ACTIONS(803),
    [sym_kLocal] = ACTIONS(803),
    [sym_kHardfloat] = ACTIONS(803),
    [sym_kSoftfloat] = ACTIONS(803),
    [sym_kMs_abi_default] = ACTIONS(803),
    [sym_kMs_abi_cdecl] = ACTIONS(803),
    [sym_kSaveregisters] = ACTIONS(803),
    [sym_kSysv_abi_default] = ACTIONS(803),
    [sym_kSysv_abi_cdecl] = ACTIONS(803),
    [sym_kVectorcall] = ACTIONS(803),
    [sym_kVarargs] = ACTIONS(803),
    [sym_kWinapi] = ACTIONS(803),
    [sym_kAlias] = ACTIONS(803),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [126] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(123),
    [ts_builtin_sym_end] = ACTIONS(805),
    [sym_identifier] = ACTIONS(807),
    [anon_sym_LBRACK] = ACTIONS(809),
    [sym_kUses] = ACTIONS(807),
    [sym_kInterface] = ACTIONS(807),
    [sym_kImplementation] = ACTIONS(807),
    [sym_kInitialization] = ACTIONS(807),
    [sym_kFinalization] = ACTIONS(807),
    [sym_kBegin] = ACTIONS(807),
    [sym_kEnd] = ACTIONS(807),
    [sym_kAsm] = ACTIONS(807),
    [sym_kVar] = ACTIONS(807),
    [sym_kThreadvar] = ACTIONS(807),
    [sym_kConst] = ACTIONS(807),
    [sym_kResourcestring] = ACTIONS(807),
    [sym_kType] = ACTIONS(807),
    [sym_kLabel] = ACTIONS(807),
    [sym_kExports] = ACTIONS(807),
    [sym_kProperty] = ACTIONS(807),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(807),
    [sym_kGeneric] = ACTIONS(807),
    [sym_kFunction] = ACTIONS(807),
    [sym_kProcedure] = ACTIONS(807),
    [sym_kConstructor] = ACTIONS(807),
    [sym_kDestructor] = ACTIONS(807),
    [sym_kOperator] = ACTIONS(807),
    [sym_kPublic] = ACTIONS(322),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [127] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(131),
    [ts_builtin_sym_end] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(814),
    [sym_kUses] = ACTIONS(812),
    [sym_kInterface] = ACTIONS(812),
    [sym_kImplementation] = ACTIONS(812),
    [sym_kInitialization] = ACTIONS(812),
    [sym_kFinalization] = ACTIONS(812),
    [sym_kBegin] = ACTIONS(812),
    [sym_kEnd] = ACTIONS(812),
    [sym_kAsm] = ACTIONS(812),
    [sym_kVar] = ACTIONS(817),
    [sym_kThreadvar] = ACTIONS(812),
    [sym_kConst] = ACTIONS(817),
    [sym_kResourcestring] = ACTIONS(812),
    [sym_kType] = ACTIONS(812),
    [sym_kLabel] = ACTIONS(812),
    [sym_kExports] = ACTIONS(812),
    [sym_kProperty] = ACTIONS(812),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(812),
    [sym_kGeneric] = ACTIONS(812),
    [sym_kFunction] = ACTIONS(812),
    [sym_kProcedure] = ACTIONS(812),
    [sym_kConstructor] = ACTIONS(812),
    [sym_kDestructor] = ACTIONS(812),
    [sym_kOperator] = ACTIONS(812),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [128] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(128),
    [sym_while] = STATE(128),
    [sym_repeat] = STATE(128),
    [sym_for] = STATE(128),
    [sym_foreach] = STATE(128),
    [sym_try] = STATE(128),
    [sym_case] = STATE(128),
    [sym_block] = STATE(128),
    [sym_asm] = STATE(128),
    [sym_with] = STATE(128),
    [sym_raise] = STATE(128),
    [sym_statement] = STATE(128),
    [sym_goto] = STATE(128),
    [sym__statement] = STATE(128),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_exceptionElse_repeat1] = STATE(128),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(831),
    [anon_sym_SEMI] = ACTIONS(834),
    [anon_sym_LBRACK] = ACTIONS(837),
    [anon_sym_LPAREN] = ACTIONS(840),
    [aux_sym__literalString_token1] = ACTIONS(843),
    [anon_sym_POUND] = ACTIONS(846),
    [aux_sym__literalInt_token1] = ACTIONS(849),
    [aux_sym__literalInt_token2] = ACTIONS(852),
    [aux_sym__literalFloat_token1] = ACTIONS(849),
    [sym_kBegin] = ACTIONS(855),
    [sym_kAsm] = ACTIONS(858),
    [sym_kVar] = ACTIONS(861),
    [sym_kSpecialize] = ACTIONS(864),
    [sym_kAdd] = ACTIONS(867),
    [sym_kSub] = ACTIONS(867),
    [sym_kAt] = ACTIONS(870),
    [sym_kNot] = ACTIONS(867),
    [sym_kFor] = ACTIONS(873),
    [sym_kIf] = ACTIONS(876),
    [sym_kWhile] = ACTIONS(879),
    [sym_kRepeat] = ACTIONS(882),
    [sym_kTry] = ACTIONS(885),
    [sym_kRaise] = ACTIONS(888),
    [sym_kCase] = ACTIONS(891),
    [sym_kWith] = ACTIONS(894),
    [sym_kGoto] = ACTIONS(897),
    [sym_kFunction] = ACTIONS(900),
    [sym_kProcedure] = ACTIONS(900),
    [sym_kInherited] = ACTIONS(903),
    [sym_kNil] = ACTIONS(831),
    [sym_kTrue] = ACTIONS(831),
    [sym_kFalse] = ACTIONS(831),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [129] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(132),
    [aux_sym_declVar_repeat1] = STATE(132),
    [sym_identifier] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(906),
    [sym_kEnd] = ACTIONS(434),
    [sym_kVar] = ACTIONS(434),
    [sym_kThreadvar] = ACTIONS(434),
    [sym_kConst] = ACTIONS(434),
    [sym_kResourcestring] = ACTIONS(434),
    [sym_kType] = ACTIONS(434),
    [sym_kProperty] = ACTIONS(434),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(434),
    [sym_kGeneric] = ACTIONS(434),
    [sym_kCase] = ACTIONS(434),
    [sym_kFunction] = ACTIONS(434),
    [sym_kProcedure] = ACTIONS(434),
    [sym_kConstructor] = ACTIONS(434),
    [sym_kDestructor] = ACTIONS(434),
    [sym_kOperator] = ACTIONS(434),
    [sym_kPublished] = ACTIONS(434),
    [sym_kPublic] = ACTIONS(909),
    [sym_kProtected] = ACTIONS(434),
    [sym_kPrivate] = ACTIONS(434),
    [sym_kStrict] = ACTIONS(434),
    [sym_kRequired] = ACTIONS(434),
    [sym_kOptional] = ACTIONS(434),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [130] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(156),
    [ts_builtin_sym_end] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(916),
    [sym_kUses] = ACTIONS(914),
    [sym_kInterface] = ACTIONS(914),
    [sym_kImplementation] = ACTIONS(914),
    [sym_kInitialization] = ACTIONS(914),
    [sym_kFinalization] = ACTIONS(914),
    [sym_kBegin] = ACTIONS(914),
    [sym_kEnd] = ACTIONS(914),
    [sym_kAsm] = ACTIONS(914),
    [sym_kVar] = ACTIONS(919),
    [sym_kThreadvar] = ACTIONS(914),
    [sym_kConst] = ACTIONS(919),
    [sym_kResourcestring] = ACTIONS(914),
    [sym_kType] = ACTIONS(914),
    [sym_kLabel] = ACTIONS(914),
    [sym_kExports] = ACTIONS(914),
    [sym_kProperty] = ACTIONS(914),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(914),
    [sym_kGeneric] = ACTIONS(914),
    [sym_kFunction] = ACTIONS(914),
    [sym_kProcedure] = ACTIONS(914),
    [sym_kConstructor] = ACTIONS(914),
    [sym_kDestructor] = ACTIONS(914),
    [sym_kOperator] = ACTIONS(914),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [131] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(921),
    [anon_sym_LBRACK] = ACTIONS(923),
    [sym_kUses] = ACTIONS(921),
    [sym_kInterface] = ACTIONS(921),
    [sym_kImplementation] = ACTIONS(921),
    [sym_kInitialization] = ACTIONS(921),
    [sym_kFinalization] = ACTIONS(921),
    [sym_kBegin] = ACTIONS(921),
    [sym_kEnd] = ACTIONS(921),
    [sym_kAsm] = ACTIONS(921),
    [sym_kVar] = ACTIONS(926),
    [sym_kThreadvar] = ACTIONS(921),
    [sym_kConst] = ACTIONS(926),
    [sym_kResourcestring] = ACTIONS(921),
    [sym_kType] = ACTIONS(921),
    [sym_kLabel] = ACTIONS(921),
    [sym_kExports] = ACTIONS(921),
    [sym_kProperty] = ACTIONS(921),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(921),
    [sym_kGeneric] = ACTIONS(921),
    [sym_kFunction] = ACTIONS(921),
    [sym_kProcedure] = ACTIONS(921),
    [sym_kConstructor] = ACTIONS(921),
    [sym_kDestructor] = ACTIONS(921),
    [sym_kOperator] = ACTIONS(921),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [132] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(500),
    [anon_sym_LBRACK] = ACTIONS(928),
    [sym_kEnd] = ACTIONS(500),
    [sym_kVar] = ACTIONS(500),
    [sym_kThreadvar] = ACTIONS(500),
    [sym_kConst] = ACTIONS(500),
    [sym_kResourcestring] = ACTIONS(500),
    [sym_kType] = ACTIONS(500),
    [sym_kProperty] = ACTIONS(500),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(500),
    [sym_kGeneric] = ACTIONS(500),
    [sym_kCase] = ACTIONS(500),
    [sym_kFunction] = ACTIONS(500),
    [sym_kProcedure] = ACTIONS(500),
    [sym_kConstructor] = ACTIONS(500),
    [sym_kDestructor] = ACTIONS(500),
    [sym_kOperator] = ACTIONS(500),
    [sym_kPublished] = ACTIONS(500),
    [sym_kPublic] = ACTIONS(931),
    [sym_kProtected] = ACTIONS(500),
    [sym_kPrivate] = ACTIONS(500),
    [sym_kStrict] = ACTIONS(500),
    [sym_kRequired] = ACTIONS(500),
    [sym_kOptional] = ACTIONS(500),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [133] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(138),
    [aux_sym_declVar_repeat1] = STATE(138),
    [sym_identifier] = ACTIONS(357),
    [anon_sym_LBRACK] = ACTIONS(934),
    [sym_kEnd] = ACTIONS(357),
    [sym_kVar] = ACTIONS(357),
    [sym_kThreadvar] = ACTIONS(357),
    [sym_kConst] = ACTIONS(357),
    [sym_kResourcestring] = ACTIONS(357),
    [sym_kType] = ACTIONS(357),
    [sym_kProperty] = ACTIONS(357),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(357),
    [sym_kGeneric] = ACTIONS(357),
    [sym_kCase] = ACTIONS(357),
    [sym_kFunction] = ACTIONS(357),
    [sym_kProcedure] = ACTIONS(357),
    [sym_kConstructor] = ACTIONS(357),
    [sym_kDestructor] = ACTIONS(357),
    [sym_kOperator] = ACTIONS(357),
    [sym_kPublished] = ACTIONS(357),
    [sym_kPublic] = ACTIONS(937),
    [sym_kProtected] = ACTIONS(357),
    [sym_kPrivate] = ACTIONS(357),
    [sym_kStrict] = ACTIONS(357),
    [sym_kRequired] = ACTIONS(357),
    [sym_kOptional] = ACTIONS(357),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [134] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(139),
    [aux_sym_declVar_repeat1] = STATE(139),
    [sym_identifier] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(940),
    [sym_kEnd] = ACTIONS(399),
    [sym_kVar] = ACTIONS(399),
    [sym_kThreadvar] = ACTIONS(399),
    [sym_kConst] = ACTIONS(399),
    [sym_kResourcestring] = ACTIONS(399),
    [sym_kType] = ACTIONS(399),
    [sym_kProperty] = ACTIONS(399),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(399),
    [sym_kGeneric] = ACTIONS(399),
    [sym_kCase] = ACTIONS(399),
    [sym_kFunction] = ACTIONS(399),
    [sym_kProcedure] = ACTIONS(399),
    [sym_kConstructor] = ACTIONS(399),
    [sym_kDestructor] = ACTIONS(399),
    [sym_kOperator] = ACTIONS(399),
    [sym_kPublished] = ACTIONS(399),
    [sym_kPublic] = ACTIONS(943),
    [sym_kProtected] = ACTIONS(399),
    [sym_kPrivate] = ACTIONS(399),
    [sym_kStrict] = ACTIONS(399),
    [sym_kRequired] = ACTIONS(399),
    [sym_kOptional] = ACTIONS(399),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [135] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(142),
    [aux_sym_declVar_repeat1] = STATE(142),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(946),
    [sym_kEnd] = ACTIONS(441),
    [sym_kVar] = ACTIONS(441),
    [sym_kThreadvar] = ACTIONS(441),
    [sym_kConst] = ACTIONS(441),
    [sym_kResourcestring] = ACTIONS(441),
    [sym_kType] = ACTIONS(441),
    [sym_kProperty] = ACTIONS(441),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(441),
    [sym_kGeneric] = ACTIONS(441),
    [sym_kCase] = ACTIONS(441),
    [sym_kFunction] = ACTIONS(441),
    [sym_kProcedure] = ACTIONS(441),
    [sym_kConstructor] = ACTIONS(441),
    [sym_kDestructor] = ACTIONS(441),
    [sym_kOperator] = ACTIONS(441),
    [sym_kPublished] = ACTIONS(441),
    [sym_kPublic] = ACTIONS(949),
    [sym_kProtected] = ACTIONS(441),
    [sym_kPrivate] = ACTIONS(441),
    [sym_kStrict] = ACTIONS(441),
    [sym_kRequired] = ACTIONS(441),
    [sym_kOptional] = ACTIONS(441),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [136] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_LBRACK] = ACTIONS(952),
    [sym_kEnd] = ACTIONS(469),
    [sym_kVar] = ACTIONS(469),
    [sym_kThreadvar] = ACTIONS(469),
    [sym_kConst] = ACTIONS(469),
    [sym_kResourcestring] = ACTIONS(469),
    [sym_kType] = ACTIONS(469),
    [sym_kProperty] = ACTIONS(469),
    [sym_kDefault] = ACTIONS(474),
    [sym_kNodefault] = ACTIONS(474),
    [sym_kDispId] = ACTIONS(477),
    [sym_kClass] = ACTIONS(469),
    [sym_kGeneric] = ACTIONS(469),
    [sym_kCase] = ACTIONS(469),
    [sym_kFunction] = ACTIONS(469),
    [sym_kProcedure] = ACTIONS(469),
    [sym_kConstructor] = ACTIONS(469),
    [sym_kDestructor] = ACTIONS(469),
    [sym_kOperator] = ACTIONS(469),
    [sym_kPublished] = ACTIONS(469),
    [sym_kPublic] = ACTIONS(480),
    [sym_kProtected] = ACTIONS(469),
    [sym_kPrivate] = ACTIONS(469),
    [sym_kStrict] = ACTIONS(469),
    [sym_kRequired] = ACTIONS(469),
    [sym_kOptional] = ACTIONS(469),
    [sym_kStatic] = ACTIONS(474),
    [sym_kVirtual] = ACTIONS(474),
    [sym_kAbstract] = ACTIONS(474),
    [sym_kDynamic] = ACTIONS(474),
    [sym_kOverride] = ACTIONS(474),
    [sym_kOverload] = ACTIONS(474),
    [sym_kReintroduce] = ACTIONS(474),
    [sym_kInline] = ACTIONS(474),
    [sym_kStdcall] = ACTIONS(474),
    [sym_kCdecl] = ACTIONS(474),
    [sym_kCppdecl] = ACTIONS(474),
    [sym_kPascal] = ACTIONS(474),
    [sym_kRegister] = ACTIONS(474),
    [sym_kMwpascal] = ACTIONS(474),
    [sym_kExternal] = ACTIONS(955),
    [sym_kMessage] = ACTIONS(486),
    [sym_kDeprecated] = ACTIONS(489),
    [sym_kExperimental] = ACTIONS(474),
    [sym_kPlatform] = ACTIONS(474),
    [sym_kUnimplemented] = ACTIONS(474),
    [sym_kCvar] = ACTIONS(474),
    [sym_kExport] = ACTIONS(492),
    [sym_kFar] = ACTIONS(474),
    [sym_kNear] = ACTIONS(474),
    [sym_kSafecall] = ACTIONS(474),
    [sym_kAssembler] = ACTIONS(474),
    [sym_kNostackframe] = ACTIONS(474),
    [sym_kInterrupt] = ACTIONS(474),
    [sym_kNoreturn] = ACTIONS(474),
    [sym_kIocheck] = ACTIONS(474),
    [sym_kLocal] = ACTIONS(474),
    [sym_kHardfloat] = ACTIONS(474),
    [sym_kSoftfloat] = ACTIONS(474),
    [sym_kMs_abi_default] = ACTIONS(474),
    [sym_kMs_abi_cdecl] = ACTIONS(474),
    [sym_kSaveregisters] = ACTIONS(474),
    [sym_kSysv_abi_default] = ACTIONS(474),
    [sym_kSysv_abi_cdecl] = ACTIONS(474),
    [sym_kVectorcall] = ACTIONS(474),
    [sym_kVarargs] = ACTIONS(474),
    [sym_kWinapi] = ACTIONS(474),
    [sym_kAlias] = ACTIONS(495),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [137] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(144),
    [aux_sym_declVar_repeat1] = STATE(144),
    [sym_identifier] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(958),
    [sym_kEnd] = ACTIONS(514),
    [sym_kVar] = ACTIONS(514),
    [sym_kThreadvar] = ACTIONS(514),
    [sym_kConst] = ACTIONS(514),
    [sym_kResourcestring] = ACTIONS(514),
    [sym_kType] = ACTIONS(514),
    [sym_kProperty] = ACTIONS(514),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(514),
    [sym_kGeneric] = ACTIONS(514),
    [sym_kCase] = ACTIONS(514),
    [sym_kFunction] = ACTIONS(514),
    [sym_kProcedure] = ACTIONS(514),
    [sym_kConstructor] = ACTIONS(514),
    [sym_kDestructor] = ACTIONS(514),
    [sym_kOperator] = ACTIONS(514),
    [sym_kPublished] = ACTIONS(514),
    [sym_kPublic] = ACTIONS(961),
    [sym_kProtected] = ACTIONS(514),
    [sym_kPrivate] = ACTIONS(514),
    [sym_kStrict] = ACTIONS(514),
    [sym_kRequired] = ACTIONS(514),
    [sym_kOptional] = ACTIONS(514),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [138] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(964),
    [sym_kEnd] = ACTIONS(521),
    [sym_kVar] = ACTIONS(521),
    [sym_kThreadvar] = ACTIONS(521),
    [sym_kConst] = ACTIONS(521),
    [sym_kResourcestring] = ACTIONS(521),
    [sym_kType] = ACTIONS(521),
    [sym_kProperty] = ACTIONS(521),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(521),
    [sym_kGeneric] = ACTIONS(521),
    [sym_kCase] = ACTIONS(521),
    [sym_kFunction] = ACTIONS(521),
    [sym_kProcedure] = ACTIONS(521),
    [sym_kConstructor] = ACTIONS(521),
    [sym_kDestructor] = ACTIONS(521),
    [sym_kOperator] = ACTIONS(521),
    [sym_kPublished] = ACTIONS(521),
    [sym_kPublic] = ACTIONS(967),
    [sym_kProtected] = ACTIONS(521),
    [sym_kPrivate] = ACTIONS(521),
    [sym_kStrict] = ACTIONS(521),
    [sym_kRequired] = ACTIONS(521),
    [sym_kOptional] = ACTIONS(521),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [139] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(313),
    [anon_sym_LBRACK] = ACTIONS(970),
    [sym_kEnd] = ACTIONS(313),
    [sym_kVar] = ACTIONS(313),
    [sym_kThreadvar] = ACTIONS(313),
    [sym_kConst] = ACTIONS(313),
    [sym_kResourcestring] = ACTIONS(313),
    [sym_kType] = ACTIONS(313),
    [sym_kProperty] = ACTIONS(313),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(313),
    [sym_kGeneric] = ACTIONS(313),
    [sym_kCase] = ACTIONS(313),
    [sym_kFunction] = ACTIONS(313),
    [sym_kProcedure] = ACTIONS(313),
    [sym_kConstructor] = ACTIONS(313),
    [sym_kDestructor] = ACTIONS(313),
    [sym_kOperator] = ACTIONS(313),
    [sym_kPublished] = ACTIONS(313),
    [sym_kPublic] = ACTIONS(973),
    [sym_kProtected] = ACTIONS(313),
    [sym_kPrivate] = ACTIONS(313),
    [sym_kStrict] = ACTIONS(313),
    [sym_kRequired] = ACTIONS(313),
    [sym_kOptional] = ACTIONS(313),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [140] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(146),
    [aux_sym_declVar_repeat1] = STATE(146),
    [sym_identifier] = ACTIONS(448),
    [anon_sym_LBRACK] = ACTIONS(976),
    [sym_kEnd] = ACTIONS(448),
    [sym_kVar] = ACTIONS(448),
    [sym_kThreadvar] = ACTIONS(448),
    [sym_kConst] = ACTIONS(448),
    [sym_kResourcestring] = ACTIONS(448),
    [sym_kType] = ACTIONS(448),
    [sym_kProperty] = ACTIONS(448),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(448),
    [sym_kGeneric] = ACTIONS(448),
    [sym_kCase] = ACTIONS(448),
    [sym_kFunction] = ACTIONS(448),
    [sym_kProcedure] = ACTIONS(448),
    [sym_kConstructor] = ACTIONS(448),
    [sym_kDestructor] = ACTIONS(448),
    [sym_kOperator] = ACTIONS(448),
    [sym_kPublished] = ACTIONS(448),
    [sym_kPublic] = ACTIONS(979),
    [sym_kProtected] = ACTIONS(448),
    [sym_kPrivate] = ACTIONS(448),
    [sym_kStrict] = ACTIONS(448),
    [sym_kRequired] = ACTIONS(448),
    [sym_kOptional] = ACTIONS(448),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [141] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(147),
    [aux_sym_declVar_repeat1] = STATE(147),
    [sym_identifier] = ACTIONS(427),
    [anon_sym_LBRACK] = ACTIONS(982),
    [sym_kEnd] = ACTIONS(427),
    [sym_kVar] = ACTIONS(427),
    [sym_kThreadvar] = ACTIONS(427),
    [sym_kConst] = ACTIONS(427),
    [sym_kResourcestring] = ACTIONS(427),
    [sym_kType] = ACTIONS(427),
    [sym_kProperty] = ACTIONS(427),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(427),
    [sym_kGeneric] = ACTIONS(427),
    [sym_kCase] = ACTIONS(427),
    [sym_kFunction] = ACTIONS(427),
    [sym_kProcedure] = ACTIONS(427),
    [sym_kConstructor] = ACTIONS(427),
    [sym_kDestructor] = ACTIONS(427),
    [sym_kOperator] = ACTIONS(427),
    [sym_kPublished] = ACTIONS(427),
    [sym_kPublic] = ACTIONS(985),
    [sym_kProtected] = ACTIONS(427),
    [sym_kPrivate] = ACTIONS(427),
    [sym_kStrict] = ACTIONS(427),
    [sym_kRequired] = ACTIONS(427),
    [sym_kOptional] = ACTIONS(427),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [142] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(988),
    [sym_kEnd] = ACTIONS(413),
    [sym_kVar] = ACTIONS(413),
    [sym_kThreadvar] = ACTIONS(413),
    [sym_kConst] = ACTIONS(413),
    [sym_kResourcestring] = ACTIONS(413),
    [sym_kType] = ACTIONS(413),
    [sym_kProperty] = ACTIONS(413),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(413),
    [sym_kGeneric] = ACTIONS(413),
    [sym_kCase] = ACTIONS(413),
    [sym_kFunction] = ACTIONS(413),
    [sym_kProcedure] = ACTIONS(413),
    [sym_kConstructor] = ACTIONS(413),
    [sym_kDestructor] = ACTIONS(413),
    [sym_kOperator] = ACTIONS(413),
    [sym_kPublished] = ACTIONS(413),
    [sym_kPublic] = ACTIONS(991),
    [sym_kProtected] = ACTIONS(413),
    [sym_kPrivate] = ACTIONS(413),
    [sym_kStrict] = ACTIONS(413),
    [sym_kRequired] = ACTIONS(413),
    [sym_kOptional] = ACTIONS(413),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [143] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(150),
    [aux_sym_declVar_repeat1] = STATE(150),
    [sym_identifier] = ACTIONS(420),
    [anon_sym_LBRACK] = ACTIONS(994),
    [sym_kEnd] = ACTIONS(420),
    [sym_kVar] = ACTIONS(420),
    [sym_kThreadvar] = ACTIONS(420),
    [sym_kConst] = ACTIONS(420),
    [sym_kResourcestring] = ACTIONS(420),
    [sym_kType] = ACTIONS(420),
    [sym_kProperty] = ACTIONS(420),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(420),
    [sym_kGeneric] = ACTIONS(420),
    [sym_kCase] = ACTIONS(420),
    [sym_kFunction] = ACTIONS(420),
    [sym_kProcedure] = ACTIONS(420),
    [sym_kConstructor] = ACTIONS(420),
    [sym_kDestructor] = ACTIONS(420),
    [sym_kOperator] = ACTIONS(420),
    [sym_kPublished] = ACTIONS(420),
    [sym_kPublic] = ACTIONS(997),
    [sym_kProtected] = ACTIONS(420),
    [sym_kPrivate] = ACTIONS(420),
    [sym_kStrict] = ACTIONS(420),
    [sym_kRequired] = ACTIONS(420),
    [sym_kOptional] = ACTIONS(420),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [144] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(455),
    [anon_sym_LBRACK] = ACTIONS(1000),
    [sym_kEnd] = ACTIONS(455),
    [sym_kVar] = ACTIONS(455),
    [sym_kThreadvar] = ACTIONS(455),
    [sym_kConst] = ACTIONS(455),
    [sym_kResourcestring] = ACTIONS(455),
    [sym_kType] = ACTIONS(455),
    [sym_kProperty] = ACTIONS(455),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(455),
    [sym_kGeneric] = ACTIONS(455),
    [sym_kCase] = ACTIONS(455),
    [sym_kFunction] = ACTIONS(455),
    [sym_kProcedure] = ACTIONS(455),
    [sym_kConstructor] = ACTIONS(455),
    [sym_kDestructor] = ACTIONS(455),
    [sym_kOperator] = ACTIONS(455),
    [sym_kPublished] = ACTIONS(455),
    [sym_kPublic] = ACTIONS(1003),
    [sym_kProtected] = ACTIONS(455),
    [sym_kPrivate] = ACTIONS(455),
    [sym_kStrict] = ACTIONS(455),
    [sym_kRequired] = ACTIONS(455),
    [sym_kOptional] = ACTIONS(455),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [145] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(151),
    [aux_sym_declVar_repeat1] = STATE(151),
    [sym_identifier] = ACTIONS(462),
    [anon_sym_LBRACK] = ACTIONS(1006),
    [sym_kEnd] = ACTIONS(462),
    [sym_kVar] = ACTIONS(462),
    [sym_kThreadvar] = ACTIONS(462),
    [sym_kConst] = ACTIONS(462),
    [sym_kResourcestring] = ACTIONS(462),
    [sym_kType] = ACTIONS(462),
    [sym_kProperty] = ACTIONS(462),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(462),
    [sym_kGeneric] = ACTIONS(462),
    [sym_kCase] = ACTIONS(462),
    [sym_kFunction] = ACTIONS(462),
    [sym_kProcedure] = ACTIONS(462),
    [sym_kConstructor] = ACTIONS(462),
    [sym_kDestructor] = ACTIONS(462),
    [sym_kOperator] = ACTIONS(462),
    [sym_kPublished] = ACTIONS(462),
    [sym_kPublic] = ACTIONS(1009),
    [sym_kProtected] = ACTIONS(462),
    [sym_kPrivate] = ACTIONS(462),
    [sym_kStrict] = ACTIONS(462),
    [sym_kRequired] = ACTIONS(462),
    [sym_kOptional] = ACTIONS(462),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [146] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(507),
    [anon_sym_LBRACK] = ACTIONS(1012),
    [sym_kEnd] = ACTIONS(507),
    [sym_kVar] = ACTIONS(507),
    [sym_kThreadvar] = ACTIONS(507),
    [sym_kConst] = ACTIONS(507),
    [sym_kResourcestring] = ACTIONS(507),
    [sym_kType] = ACTIONS(507),
    [sym_kProperty] = ACTIONS(507),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(507),
    [sym_kGeneric] = ACTIONS(507),
    [sym_kCase] = ACTIONS(507),
    [sym_kFunction] = ACTIONS(507),
    [sym_kProcedure] = ACTIONS(507),
    [sym_kConstructor] = ACTIONS(507),
    [sym_kDestructor] = ACTIONS(507),
    [sym_kOperator] = ACTIONS(507),
    [sym_kPublished] = ACTIONS(507),
    [sym_kPublic] = ACTIONS(1015),
    [sym_kProtected] = ACTIONS(507),
    [sym_kPrivate] = ACTIONS(507),
    [sym_kStrict] = ACTIONS(507),
    [sym_kRequired] = ACTIONS(507),
    [sym_kOptional] = ACTIONS(507),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [147] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(364),
    [anon_sym_LBRACK] = ACTIONS(1018),
    [sym_kEnd] = ACTIONS(364),
    [sym_kVar] = ACTIONS(364),
    [sym_kThreadvar] = ACTIONS(364),
    [sym_kConst] = ACTIONS(364),
    [sym_kResourcestring] = ACTIONS(364),
    [sym_kType] = ACTIONS(364),
    [sym_kProperty] = ACTIONS(364),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(364),
    [sym_kGeneric] = ACTIONS(364),
    [sym_kCase] = ACTIONS(364),
    [sym_kFunction] = ACTIONS(364),
    [sym_kProcedure] = ACTIONS(364),
    [sym_kConstructor] = ACTIONS(364),
    [sym_kDestructor] = ACTIONS(364),
    [sym_kOperator] = ACTIONS(364),
    [sym_kPublished] = ACTIONS(364),
    [sym_kPublic] = ACTIONS(1021),
    [sym_kProtected] = ACTIONS(364),
    [sym_kPrivate] = ACTIONS(364),
    [sym_kStrict] = ACTIONS(364),
    [sym_kRequired] = ACTIONS(364),
    [sym_kOptional] = ACTIONS(364),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [148] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(153),
    [aux_sym_declVar_repeat1] = STATE(153),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_LBRACK] = ACTIONS(1024),
    [sym_kEnd] = ACTIONS(336),
    [sym_kVar] = ACTIONS(336),
    [sym_kThreadvar] = ACTIONS(336),
    [sym_kConst] = ACTIONS(336),
    [sym_kResourcestring] = ACTIONS(336),
    [sym_kType] = ACTIONS(336),
    [sym_kProperty] = ACTIONS(336),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(336),
    [sym_kGeneric] = ACTIONS(336),
    [sym_kCase] = ACTIONS(336),
    [sym_kFunction] = ACTIONS(336),
    [sym_kProcedure] = ACTIONS(336),
    [sym_kConstructor] = ACTIONS(336),
    [sym_kDestructor] = ACTIONS(336),
    [sym_kOperator] = ACTIONS(336),
    [sym_kPublished] = ACTIONS(336),
    [sym_kPublic] = ACTIONS(1027),
    [sym_kProtected] = ACTIONS(336),
    [sym_kPrivate] = ACTIONS(336),
    [sym_kStrict] = ACTIONS(336),
    [sym_kRequired] = ACTIONS(336),
    [sym_kOptional] = ACTIONS(336),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [149] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(154),
    [aux_sym_declVar_repeat1] = STATE(154),
    [sym_identifier] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(1030),
    [sym_kEnd] = ACTIONS(343),
    [sym_kVar] = ACTIONS(343),
    [sym_kThreadvar] = ACTIONS(343),
    [sym_kConst] = ACTIONS(343),
    [sym_kResourcestring] = ACTIONS(343),
    [sym_kType] = ACTIONS(343),
    [sym_kProperty] = ACTIONS(343),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(343),
    [sym_kGeneric] = ACTIONS(343),
    [sym_kCase] = ACTIONS(343),
    [sym_kFunction] = ACTIONS(343),
    [sym_kProcedure] = ACTIONS(343),
    [sym_kConstructor] = ACTIONS(343),
    [sym_kDestructor] = ACTIONS(343),
    [sym_kOperator] = ACTIONS(343),
    [sym_kPublished] = ACTIONS(343),
    [sym_kPublic] = ACTIONS(1033),
    [sym_kProtected] = ACTIONS(343),
    [sym_kPrivate] = ACTIONS(343),
    [sym_kStrict] = ACTIONS(343),
    [sym_kRequired] = ACTIONS(343),
    [sym_kOptional] = ACTIONS(343),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [150] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(350),
    [anon_sym_LBRACK] = ACTIONS(1036),
    [sym_kEnd] = ACTIONS(350),
    [sym_kVar] = ACTIONS(350),
    [sym_kThreadvar] = ACTIONS(350),
    [sym_kConst] = ACTIONS(350),
    [sym_kResourcestring] = ACTIONS(350),
    [sym_kType] = ACTIONS(350),
    [sym_kProperty] = ACTIONS(350),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(350),
    [sym_kGeneric] = ACTIONS(350),
    [sym_kCase] = ACTIONS(350),
    [sym_kFunction] = ACTIONS(350),
    [sym_kProcedure] = ACTIONS(350),
    [sym_kConstructor] = ACTIONS(350),
    [sym_kDestructor] = ACTIONS(350),
    [sym_kOperator] = ACTIONS(350),
    [sym_kPublished] = ACTIONS(350),
    [sym_kPublic] = ACTIONS(1039),
    [sym_kProtected] = ACTIONS(350),
    [sym_kPrivate] = ACTIONS(350),
    [sym_kStrict] = ACTIONS(350),
    [sym_kRequired] = ACTIONS(350),
    [sym_kOptional] = ACTIONS(350),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [151] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(371),
    [anon_sym_LBRACK] = ACTIONS(1042),
    [sym_kEnd] = ACTIONS(371),
    [sym_kVar] = ACTIONS(371),
    [sym_kThreadvar] = ACTIONS(371),
    [sym_kConst] = ACTIONS(371),
    [sym_kResourcestring] = ACTIONS(371),
    [sym_kType] = ACTIONS(371),
    [sym_kProperty] = ACTIONS(371),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(371),
    [sym_kGeneric] = ACTIONS(371),
    [sym_kCase] = ACTIONS(371),
    [sym_kFunction] = ACTIONS(371),
    [sym_kProcedure] = ACTIONS(371),
    [sym_kConstructor] = ACTIONS(371),
    [sym_kDestructor] = ACTIONS(371),
    [sym_kOperator] = ACTIONS(371),
    [sym_kPublished] = ACTIONS(371),
    [sym_kPublic] = ACTIONS(1045),
    [sym_kProtected] = ACTIONS(371),
    [sym_kPrivate] = ACTIONS(371),
    [sym_kStrict] = ACTIONS(371),
    [sym_kRequired] = ACTIONS(371),
    [sym_kOptional] = ACTIONS(371),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [152] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(155),
    [aux_sym_declVar_repeat1] = STATE(155),
    [sym_identifier] = ACTIONS(378),
    [anon_sym_LBRACK] = ACTIONS(1048),
    [sym_kEnd] = ACTIONS(378),
    [sym_kVar] = ACTIONS(378),
    [sym_kThreadvar] = ACTIONS(378),
    [sym_kConst] = ACTIONS(378),
    [sym_kResourcestring] = ACTIONS(378),
    [sym_kType] = ACTIONS(378),
    [sym_kProperty] = ACTIONS(378),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(378),
    [sym_kGeneric] = ACTIONS(378),
    [sym_kCase] = ACTIONS(378),
    [sym_kFunction] = ACTIONS(378),
    [sym_kProcedure] = ACTIONS(378),
    [sym_kConstructor] = ACTIONS(378),
    [sym_kDestructor] = ACTIONS(378),
    [sym_kOperator] = ACTIONS(378),
    [sym_kPublished] = ACTIONS(378),
    [sym_kPublic] = ACTIONS(1051),
    [sym_kProtected] = ACTIONS(378),
    [sym_kPrivate] = ACTIONS(378),
    [sym_kStrict] = ACTIONS(378),
    [sym_kRequired] = ACTIONS(378),
    [sym_kOptional] = ACTIONS(378),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [153] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(385),
    [anon_sym_LBRACK] = ACTIONS(1054),
    [sym_kEnd] = ACTIONS(385),
    [sym_kVar] = ACTIONS(385),
    [sym_kThreadvar] = ACTIONS(385),
    [sym_kConst] = ACTIONS(385),
    [sym_kResourcestring] = ACTIONS(385),
    [sym_kType] = ACTIONS(385),
    [sym_kProperty] = ACTIONS(385),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(385),
    [sym_kGeneric] = ACTIONS(385),
    [sym_kCase] = ACTIONS(385),
    [sym_kFunction] = ACTIONS(385),
    [sym_kProcedure] = ACTIONS(385),
    [sym_kConstructor] = ACTIONS(385),
    [sym_kDestructor] = ACTIONS(385),
    [sym_kOperator] = ACTIONS(385),
    [sym_kPublished] = ACTIONS(385),
    [sym_kPublic] = ACTIONS(1057),
    [sym_kProtected] = ACTIONS(385),
    [sym_kPrivate] = ACTIONS(385),
    [sym_kStrict] = ACTIONS(385),
    [sym_kRequired] = ACTIONS(385),
    [sym_kOptional] = ACTIONS(385),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [154] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(1060),
    [sym_kEnd] = ACTIONS(392),
    [sym_kVar] = ACTIONS(392),
    [sym_kThreadvar] = ACTIONS(392),
    [sym_kConst] = ACTIONS(392),
    [sym_kResourcestring] = ACTIONS(392),
    [sym_kType] = ACTIONS(392),
    [sym_kProperty] = ACTIONS(392),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(392),
    [sym_kGeneric] = ACTIONS(392),
    [sym_kCase] = ACTIONS(392),
    [sym_kFunction] = ACTIONS(392),
    [sym_kProcedure] = ACTIONS(392),
    [sym_kConstructor] = ACTIONS(392),
    [sym_kDestructor] = ACTIONS(392),
    [sym_kOperator] = ACTIONS(392),
    [sym_kPublished] = ACTIONS(392),
    [sym_kPublic] = ACTIONS(1063),
    [sym_kProtected] = ACTIONS(392),
    [sym_kPrivate] = ACTIONS(392),
    [sym_kStrict] = ACTIONS(392),
    [sym_kRequired] = ACTIONS(392),
    [sym_kOptional] = ACTIONS(392),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [155] = {
    [sym__procAttribute] = STATE(449),
    [sym_procAttribute] = STATE(2555),
    [sym_procExternal] = STATE(136),
    [aux_sym_declVar_repeat1] = STATE(136),
    [sym_identifier] = ACTIONS(406),
    [anon_sym_LBRACK] = ACTIONS(1066),
    [sym_kEnd] = ACTIONS(406),
    [sym_kVar] = ACTIONS(406),
    [sym_kThreadvar] = ACTIONS(406),
    [sym_kConst] = ACTIONS(406),
    [sym_kResourcestring] = ACTIONS(406),
    [sym_kType] = ACTIONS(406),
    [sym_kProperty] = ACTIONS(406),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(406),
    [sym_kGeneric] = ACTIONS(406),
    [sym_kCase] = ACTIONS(406),
    [sym_kFunction] = ACTIONS(406),
    [sym_kProcedure] = ACTIONS(406),
    [sym_kConstructor] = ACTIONS(406),
    [sym_kDestructor] = ACTIONS(406),
    [sym_kOperator] = ACTIONS(406),
    [sym_kPublished] = ACTIONS(406),
    [sym_kPublic] = ACTIONS(1069),
    [sym_kProtected] = ACTIONS(406),
    [sym_kPrivate] = ACTIONS(406),
    [sym_kStrict] = ACTIONS(406),
    [sym_kRequired] = ACTIONS(406),
    [sym_kOptional] = ACTIONS(406),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kExternal] = ACTIONS(912),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [156] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [ts_builtin_sym_end] = ACTIONS(1072),
    [anon_sym_LBRACK] = ACTIONS(1074),
    [sym_kUses] = ACTIONS(1072),
    [sym_kInterface] = ACTIONS(1072),
    [sym_kImplementation] = ACTIONS(1072),
    [sym_kInitialization] = ACTIONS(1072),
    [sym_kFinalization] = ACTIONS(1072),
    [sym_kBegin] = ACTIONS(1072),
    [sym_kEnd] = ACTIONS(1072),
    [sym_kAsm] = ACTIONS(1072),
    [sym_kVar] = ACTIONS(1077),
    [sym_kThreadvar] = ACTIONS(1072),
    [sym_kConst] = ACTIONS(1077),
    [sym_kResourcestring] = ACTIONS(1072),
    [sym_kType] = ACTIONS(1072),
    [sym_kLabel] = ACTIONS(1072),
    [sym_kExports] = ACTIONS(1072),
    [sym_kProperty] = ACTIONS(1072),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1072),
    [sym_kGeneric] = ACTIONS(1072),
    [sym_kFunction] = ACTIONS(1072),
    [sym_kProcedure] = ACTIONS(1072),
    [sym_kConstructor] = ACTIONS(1072),
    [sym_kDestructor] = ACTIONS(1072),
    [sym_kOperator] = ACTIONS(1072),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [157] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1194),
    [sym_while] = STATE(1194),
    [sym_repeat] = STATE(1194),
    [sym_for] = STATE(1194),
    [sym_foreach] = STATE(1194),
    [sym_try] = STATE(1194),
    [sym_case] = STATE(1194),
    [sym_block] = STATE(1194),
    [sym_asm] = STATE(1194),
    [sym_with] = STATE(1194),
    [sym_raise] = STATE(1194),
    [sym_statement] = STATE(1194),
    [sym_goto] = STATE(1194),
    [sym__statement] = STATE(1194),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_exceptionElse_repeat1] = STATE(158),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(1079),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [158] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1193),
    [sym_while] = STATE(1193),
    [sym_repeat] = STATE(1193),
    [sym_for] = STATE(1193),
    [sym_foreach] = STATE(1193),
    [sym_try] = STATE(1193),
    [sym_case] = STATE(1193),
    [sym_block] = STATE(1193),
    [sym_asm] = STATE(1193),
    [sym_with] = STATE(1193),
    [sym_raise] = STATE(1193),
    [sym_statement] = STATE(1193),
    [sym_goto] = STATE(1193),
    [sym__statement] = STATE(1193),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_exceptionElse_repeat1] = STATE(128),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(1103),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [159] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1105),
    [sym_kUses] = ACTIONS(1108),
    [sym_kInterface] = ACTIONS(1108),
    [sym_kImplementation] = ACTIONS(1108),
    [sym_kInitialization] = ACTIONS(1108),
    [sym_kFinalization] = ACTIONS(1108),
    [sym_kEnd] = ACTIONS(1108),
    [sym_kVar] = ACTIONS(1110),
    [sym_kThreadvar] = ACTIONS(1108),
    [sym_kConst] = ACTIONS(1110),
    [sym_kResourcestring] = ACTIONS(1108),
    [sym_kType] = ACTIONS(1108),
    [sym_kLabel] = ACTIONS(1108),
    [sym_kExports] = ACTIONS(1108),
    [sym_kProperty] = ACTIONS(1108),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1108),
    [sym_kGeneric] = ACTIONS(1108),
    [sym_kFunction] = ACTIONS(1108),
    [sym_kProcedure] = ACTIONS(1108),
    [sym_kConstructor] = ACTIONS(1108),
    [sym_kDestructor] = ACTIONS(1108),
    [sym_kOperator] = ACTIONS(1108),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1108),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1108),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [160] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1112),
    [sym_kUses] = ACTIONS(1115),
    [sym_kInterface] = ACTIONS(1115),
    [sym_kImplementation] = ACTIONS(1115),
    [sym_kInitialization] = ACTIONS(1115),
    [sym_kFinalization] = ACTIONS(1115),
    [sym_kEnd] = ACTIONS(1115),
    [sym_kVar] = ACTIONS(1117),
    [sym_kThreadvar] = ACTIONS(1115),
    [sym_kConst] = ACTIONS(1117),
    [sym_kResourcestring] = ACTIONS(1115),
    [sym_kType] = ACTIONS(1115),
    [sym_kLabel] = ACTIONS(1115),
    [sym_kExports] = ACTIONS(1115),
    [sym_kProperty] = ACTIONS(1115),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1115),
    [sym_kGeneric] = ACTIONS(1115),
    [sym_kFunction] = ACTIONS(1115),
    [sym_kProcedure] = ACTIONS(1115),
    [sym_kConstructor] = ACTIONS(1115),
    [sym_kDestructor] = ACTIONS(1115),
    [sym_kOperator] = ACTIONS(1115),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1115),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1115),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [161] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(197),
    [anon_sym_LBRACK] = ACTIONS(1119),
    [sym_kUses] = ACTIONS(1122),
    [sym_kInterface] = ACTIONS(1122),
    [sym_kImplementation] = ACTIONS(1122),
    [sym_kInitialization] = ACTIONS(1122),
    [sym_kFinalization] = ACTIONS(1122),
    [sym_kEnd] = ACTIONS(1122),
    [sym_kVar] = ACTIONS(1124),
    [sym_kThreadvar] = ACTIONS(1122),
    [sym_kConst] = ACTIONS(1124),
    [sym_kResourcestring] = ACTIONS(1122),
    [sym_kType] = ACTIONS(1122),
    [sym_kLabel] = ACTIONS(1122),
    [sym_kExports] = ACTIONS(1122),
    [sym_kProperty] = ACTIONS(1122),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1122),
    [sym_kGeneric] = ACTIONS(1122),
    [sym_kFunction] = ACTIONS(1122),
    [sym_kProcedure] = ACTIONS(1122),
    [sym_kConstructor] = ACTIONS(1122),
    [sym_kDestructor] = ACTIONS(1122),
    [sym_kOperator] = ACTIONS(1122),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1122),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1122),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [162] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(199),
    [anon_sym_LBRACK] = ACTIONS(1126),
    [sym_kUses] = ACTIONS(1129),
    [sym_kInterface] = ACTIONS(1129),
    [sym_kImplementation] = ACTIONS(1129),
    [sym_kInitialization] = ACTIONS(1129),
    [sym_kFinalization] = ACTIONS(1129),
    [sym_kEnd] = ACTIONS(1129),
    [sym_kVar] = ACTIONS(1131),
    [sym_kThreadvar] = ACTIONS(1129),
    [sym_kConst] = ACTIONS(1131),
    [sym_kResourcestring] = ACTIONS(1129),
    [sym_kType] = ACTIONS(1129),
    [sym_kLabel] = ACTIONS(1129),
    [sym_kExports] = ACTIONS(1129),
    [sym_kProperty] = ACTIONS(1129),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1129),
    [sym_kGeneric] = ACTIONS(1129),
    [sym_kFunction] = ACTIONS(1129),
    [sym_kProcedure] = ACTIONS(1129),
    [sym_kConstructor] = ACTIONS(1129),
    [sym_kDestructor] = ACTIONS(1129),
    [sym_kOperator] = ACTIONS(1129),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1129),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1129),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [163] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1133),
    [sym_kUses] = ACTIONS(1136),
    [sym_kInterface] = ACTIONS(1136),
    [sym_kImplementation] = ACTIONS(1136),
    [sym_kInitialization] = ACTIONS(1136),
    [sym_kFinalization] = ACTIONS(1136),
    [sym_kEnd] = ACTIONS(1136),
    [sym_kVar] = ACTIONS(1138),
    [sym_kThreadvar] = ACTIONS(1136),
    [sym_kConst] = ACTIONS(1138),
    [sym_kResourcestring] = ACTIONS(1136),
    [sym_kType] = ACTIONS(1136),
    [sym_kLabel] = ACTIONS(1136),
    [sym_kExports] = ACTIONS(1136),
    [sym_kProperty] = ACTIONS(1136),
    [sym_kDefault] = ACTIONS(1140),
    [sym_kNodefault] = ACTIONS(1140),
    [sym_kDispId] = ACTIONS(1143),
    [sym_kClass] = ACTIONS(1136),
    [sym_kGeneric] = ACTIONS(1136),
    [sym_kFunction] = ACTIONS(1136),
    [sym_kProcedure] = ACTIONS(1136),
    [sym_kConstructor] = ACTIONS(1136),
    [sym_kDestructor] = ACTIONS(1136),
    [sym_kOperator] = ACTIONS(1136),
    [sym_kPublic] = ACTIONS(1146),
    [sym_kForward] = ACTIONS(1136),
    [sym_kStatic] = ACTIONS(1140),
    [sym_kVirtual] = ACTIONS(1140),
    [sym_kAbstract] = ACTIONS(1140),
    [sym_kDynamic] = ACTIONS(1140),
    [sym_kOverride] = ACTIONS(1140),
    [sym_kOverload] = ACTIONS(1140),
    [sym_kReintroduce] = ACTIONS(1140),
    [sym_kInline] = ACTIONS(1140),
    [sym_kStdcall] = ACTIONS(1140),
    [sym_kCdecl] = ACTIONS(1140),
    [sym_kCppdecl] = ACTIONS(1140),
    [sym_kPascal] = ACTIONS(1140),
    [sym_kRegister] = ACTIONS(1140),
    [sym_kMwpascal] = ACTIONS(1140),
    [sym_kExternal] = ACTIONS(1136),
    [sym_kMessage] = ACTIONS(1149),
    [sym_kDeprecated] = ACTIONS(1152),
    [sym_kExperimental] = ACTIONS(1140),
    [sym_kPlatform] = ACTIONS(1140),
    [sym_kUnimplemented] = ACTIONS(1140),
    [sym_kCvar] = ACTIONS(1140),
    [sym_kExport] = ACTIONS(1155),
    [sym_kFar] = ACTIONS(1140),
    [sym_kNear] = ACTIONS(1140),
    [sym_kSafecall] = ACTIONS(1140),
    [sym_kAssembler] = ACTIONS(1140),
    [sym_kNostackframe] = ACTIONS(1140),
    [sym_kInterrupt] = ACTIONS(1140),
    [sym_kNoreturn] = ACTIONS(1140),
    [sym_kIocheck] = ACTIONS(1140),
    [sym_kLocal] = ACTIONS(1140),
    [sym_kHardfloat] = ACTIONS(1140),
    [sym_kSoftfloat] = ACTIONS(1140),
    [sym_kMs_abi_default] = ACTIONS(1140),
    [sym_kMs_abi_cdecl] = ACTIONS(1140),
    [sym_kSaveregisters] = ACTIONS(1140),
    [sym_kSysv_abi_default] = ACTIONS(1140),
    [sym_kSysv_abi_cdecl] = ACTIONS(1140),
    [sym_kVectorcall] = ACTIONS(1140),
    [sym_kVarargs] = ACTIONS(1140),
    [sym_kWinapi] = ACTIONS(1140),
    [sym_kAlias] = ACTIONS(1158),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [164] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(217),
    [anon_sym_LBRACK] = ACTIONS(1161),
    [sym_kUses] = ACTIONS(1164),
    [sym_kInterface] = ACTIONS(1164),
    [sym_kImplementation] = ACTIONS(1164),
    [sym_kInitialization] = ACTIONS(1164),
    [sym_kFinalization] = ACTIONS(1164),
    [sym_kEnd] = ACTIONS(1164),
    [sym_kVar] = ACTIONS(1166),
    [sym_kThreadvar] = ACTIONS(1164),
    [sym_kConst] = ACTIONS(1166),
    [sym_kResourcestring] = ACTIONS(1164),
    [sym_kType] = ACTIONS(1164),
    [sym_kLabel] = ACTIONS(1164),
    [sym_kExports] = ACTIONS(1164),
    [sym_kProperty] = ACTIONS(1164),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1164),
    [sym_kGeneric] = ACTIONS(1164),
    [sym_kFunction] = ACTIONS(1164),
    [sym_kProcedure] = ACTIONS(1164),
    [sym_kConstructor] = ACTIONS(1164),
    [sym_kDestructor] = ACTIONS(1164),
    [sym_kOperator] = ACTIONS(1164),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1164),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1164),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [165] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1168),
    [sym_kUses] = ACTIONS(1171),
    [sym_kInterface] = ACTIONS(1171),
    [sym_kImplementation] = ACTIONS(1171),
    [sym_kInitialization] = ACTIONS(1171),
    [sym_kFinalization] = ACTIONS(1171),
    [sym_kEnd] = ACTIONS(1171),
    [sym_kVar] = ACTIONS(1173),
    [sym_kThreadvar] = ACTIONS(1171),
    [sym_kConst] = ACTIONS(1173),
    [sym_kResourcestring] = ACTIONS(1171),
    [sym_kType] = ACTIONS(1171),
    [sym_kLabel] = ACTIONS(1171),
    [sym_kExports] = ACTIONS(1171),
    [sym_kProperty] = ACTIONS(1171),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1171),
    [sym_kGeneric] = ACTIONS(1171),
    [sym_kFunction] = ACTIONS(1171),
    [sym_kProcedure] = ACTIONS(1171),
    [sym_kConstructor] = ACTIONS(1171),
    [sym_kDestructor] = ACTIONS(1171),
    [sym_kOperator] = ACTIONS(1171),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1171),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1171),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [166] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [sym_kUses] = ACTIONS(1178),
    [sym_kInterface] = ACTIONS(1178),
    [sym_kImplementation] = ACTIONS(1178),
    [sym_kInitialization] = ACTIONS(1178),
    [sym_kFinalization] = ACTIONS(1178),
    [sym_kEnd] = ACTIONS(1178),
    [sym_kVar] = ACTIONS(1180),
    [sym_kThreadvar] = ACTIONS(1178),
    [sym_kConst] = ACTIONS(1180),
    [sym_kResourcestring] = ACTIONS(1178),
    [sym_kType] = ACTIONS(1178),
    [sym_kLabel] = ACTIONS(1178),
    [sym_kExports] = ACTIONS(1178),
    [sym_kProperty] = ACTIONS(1178),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1178),
    [sym_kGeneric] = ACTIONS(1178),
    [sym_kFunction] = ACTIONS(1178),
    [sym_kProcedure] = ACTIONS(1178),
    [sym_kConstructor] = ACTIONS(1178),
    [sym_kDestructor] = ACTIONS(1178),
    [sym_kOperator] = ACTIONS(1178),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1178),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1178),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [167] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(160),
    [anon_sym_LBRACK] = ACTIONS(1182),
    [sym_kUses] = ACTIONS(1185),
    [sym_kInterface] = ACTIONS(1185),
    [sym_kImplementation] = ACTIONS(1185),
    [sym_kInitialization] = ACTIONS(1185),
    [sym_kFinalization] = ACTIONS(1185),
    [sym_kEnd] = ACTIONS(1185),
    [sym_kVar] = ACTIONS(1187),
    [sym_kThreadvar] = ACTIONS(1185),
    [sym_kConst] = ACTIONS(1187),
    [sym_kResourcestring] = ACTIONS(1185),
    [sym_kType] = ACTIONS(1185),
    [sym_kLabel] = ACTIONS(1185),
    [sym_kExports] = ACTIONS(1185),
    [sym_kProperty] = ACTIONS(1185),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1185),
    [sym_kGeneric] = ACTIONS(1185),
    [sym_kFunction] = ACTIONS(1185),
    [sym_kProcedure] = ACTIONS(1185),
    [sym_kConstructor] = ACTIONS(1185),
    [sym_kDestructor] = ACTIONS(1185),
    [sym_kOperator] = ACTIONS(1185),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1185),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1185),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [168] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(811),
    [sym_while] = STATE(811),
    [sym_repeat] = STATE(811),
    [sym_for] = STATE(811),
    [sym_foreach] = STATE(811),
    [sym_try] = STATE(811),
    [sym_case] = STATE(811),
    [sym_block] = STATE(811),
    [sym_asm] = STATE(811),
    [sym_with] = STATE(811),
    [sym_raise] = STATE(811),
    [sym_statement] = STATE(811),
    [sym_goto] = STATE(811),
    [sym__statement] = STATE(811),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [169] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1189),
    [sym_kUses] = ACTIONS(1192),
    [sym_kInterface] = ACTIONS(1192),
    [sym_kImplementation] = ACTIONS(1192),
    [sym_kInitialization] = ACTIONS(1192),
    [sym_kFinalization] = ACTIONS(1192),
    [sym_kEnd] = ACTIONS(1192),
    [sym_kVar] = ACTIONS(1194),
    [sym_kThreadvar] = ACTIONS(1192),
    [sym_kConst] = ACTIONS(1194),
    [sym_kResourcestring] = ACTIONS(1192),
    [sym_kType] = ACTIONS(1192),
    [sym_kLabel] = ACTIONS(1192),
    [sym_kExports] = ACTIONS(1192),
    [sym_kProperty] = ACTIONS(1192),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1192),
    [sym_kGeneric] = ACTIONS(1192),
    [sym_kFunction] = ACTIONS(1192),
    [sym_kProcedure] = ACTIONS(1192),
    [sym_kConstructor] = ACTIONS(1192),
    [sym_kDestructor] = ACTIONS(1192),
    [sym_kOperator] = ACTIONS(1192),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1192),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1192),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [170] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(187),
    [anon_sym_LBRACK] = ACTIONS(1196),
    [sym_kUses] = ACTIONS(1199),
    [sym_kInterface] = ACTIONS(1199),
    [sym_kImplementation] = ACTIONS(1199),
    [sym_kInitialization] = ACTIONS(1199),
    [sym_kFinalization] = ACTIONS(1199),
    [sym_kEnd] = ACTIONS(1199),
    [sym_kVar] = ACTIONS(1201),
    [sym_kThreadvar] = ACTIONS(1199),
    [sym_kConst] = ACTIONS(1201),
    [sym_kResourcestring] = ACTIONS(1199),
    [sym_kType] = ACTIONS(1199),
    [sym_kLabel] = ACTIONS(1199),
    [sym_kExports] = ACTIONS(1199),
    [sym_kProperty] = ACTIONS(1199),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1199),
    [sym_kGeneric] = ACTIONS(1199),
    [sym_kFunction] = ACTIONS(1199),
    [sym_kProcedure] = ACTIONS(1199),
    [sym_kConstructor] = ACTIONS(1199),
    [sym_kDestructor] = ACTIONS(1199),
    [sym_kOperator] = ACTIONS(1199),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1199),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1199),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [171] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(188),
    [anon_sym_LBRACK] = ACTIONS(1203),
    [sym_kUses] = ACTIONS(1206),
    [sym_kInterface] = ACTIONS(1206),
    [sym_kImplementation] = ACTIONS(1206),
    [sym_kInitialization] = ACTIONS(1206),
    [sym_kFinalization] = ACTIONS(1206),
    [sym_kEnd] = ACTIONS(1206),
    [sym_kVar] = ACTIONS(1208),
    [sym_kThreadvar] = ACTIONS(1206),
    [sym_kConst] = ACTIONS(1208),
    [sym_kResourcestring] = ACTIONS(1206),
    [sym_kType] = ACTIONS(1206),
    [sym_kLabel] = ACTIONS(1206),
    [sym_kExports] = ACTIONS(1206),
    [sym_kProperty] = ACTIONS(1206),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1206),
    [sym_kGeneric] = ACTIONS(1206),
    [sym_kFunction] = ACTIONS(1206),
    [sym_kProcedure] = ACTIONS(1206),
    [sym_kConstructor] = ACTIONS(1206),
    [sym_kDestructor] = ACTIONS(1206),
    [sym_kOperator] = ACTIONS(1206),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1206),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1206),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [172] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1210),
    [sym_kUses] = ACTIONS(1213),
    [sym_kInterface] = ACTIONS(1213),
    [sym_kImplementation] = ACTIONS(1213),
    [sym_kInitialization] = ACTIONS(1213),
    [sym_kFinalization] = ACTIONS(1213),
    [sym_kEnd] = ACTIONS(1213),
    [sym_kVar] = ACTIONS(1215),
    [sym_kThreadvar] = ACTIONS(1213),
    [sym_kConst] = ACTIONS(1215),
    [sym_kResourcestring] = ACTIONS(1213),
    [sym_kType] = ACTIONS(1213),
    [sym_kLabel] = ACTIONS(1213),
    [sym_kExports] = ACTIONS(1213),
    [sym_kProperty] = ACTIONS(1213),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1213),
    [sym_kGeneric] = ACTIONS(1213),
    [sym_kFunction] = ACTIONS(1213),
    [sym_kProcedure] = ACTIONS(1213),
    [sym_kConstructor] = ACTIONS(1213),
    [sym_kDestructor] = ACTIONS(1213),
    [sym_kOperator] = ACTIONS(1213),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1213),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1213),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [173] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(190),
    [anon_sym_LBRACK] = ACTIONS(1217),
    [sym_kUses] = ACTIONS(1220),
    [sym_kInterface] = ACTIONS(1220),
    [sym_kImplementation] = ACTIONS(1220),
    [sym_kInitialization] = ACTIONS(1220),
    [sym_kFinalization] = ACTIONS(1220),
    [sym_kEnd] = ACTIONS(1220),
    [sym_kVar] = ACTIONS(1222),
    [sym_kThreadvar] = ACTIONS(1220),
    [sym_kConst] = ACTIONS(1222),
    [sym_kResourcestring] = ACTIONS(1220),
    [sym_kType] = ACTIONS(1220),
    [sym_kLabel] = ACTIONS(1220),
    [sym_kExports] = ACTIONS(1220),
    [sym_kProperty] = ACTIONS(1220),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1220),
    [sym_kGeneric] = ACTIONS(1220),
    [sym_kFunction] = ACTIONS(1220),
    [sym_kProcedure] = ACTIONS(1220),
    [sym_kConstructor] = ACTIONS(1220),
    [sym_kDestructor] = ACTIONS(1220),
    [sym_kOperator] = ACTIONS(1220),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1220),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1220),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [174] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1224),
    [sym_kUses] = ACTIONS(1227),
    [sym_kInterface] = ACTIONS(1227),
    [sym_kImplementation] = ACTIONS(1227),
    [sym_kInitialization] = ACTIONS(1227),
    [sym_kFinalization] = ACTIONS(1227),
    [sym_kEnd] = ACTIONS(1227),
    [sym_kVar] = ACTIONS(1229),
    [sym_kThreadvar] = ACTIONS(1227),
    [sym_kConst] = ACTIONS(1229),
    [sym_kResourcestring] = ACTIONS(1227),
    [sym_kType] = ACTIONS(1227),
    [sym_kLabel] = ACTIONS(1227),
    [sym_kExports] = ACTIONS(1227),
    [sym_kProperty] = ACTIONS(1227),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1227),
    [sym_kGeneric] = ACTIONS(1227),
    [sym_kFunction] = ACTIONS(1227),
    [sym_kProcedure] = ACTIONS(1227),
    [sym_kConstructor] = ACTIONS(1227),
    [sym_kDestructor] = ACTIONS(1227),
    [sym_kOperator] = ACTIONS(1227),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1227),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1227),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [175] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [sym_kUses] = ACTIONS(1234),
    [sym_kInterface] = ACTIONS(1234),
    [sym_kImplementation] = ACTIONS(1234),
    [sym_kInitialization] = ACTIONS(1234),
    [sym_kFinalization] = ACTIONS(1234),
    [sym_kEnd] = ACTIONS(1234),
    [sym_kVar] = ACTIONS(1236),
    [sym_kThreadvar] = ACTIONS(1234),
    [sym_kConst] = ACTIONS(1236),
    [sym_kResourcestring] = ACTIONS(1234),
    [sym_kType] = ACTIONS(1234),
    [sym_kLabel] = ACTIONS(1234),
    [sym_kExports] = ACTIONS(1234),
    [sym_kProperty] = ACTIONS(1234),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1234),
    [sym_kGeneric] = ACTIONS(1234),
    [sym_kFunction] = ACTIONS(1234),
    [sym_kProcedure] = ACTIONS(1234),
    [sym_kConstructor] = ACTIONS(1234),
    [sym_kDestructor] = ACTIONS(1234),
    [sym_kOperator] = ACTIONS(1234),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1234),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1234),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [176] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(193),
    [anon_sym_LBRACK] = ACTIONS(1238),
    [sym_kUses] = ACTIONS(1241),
    [sym_kInterface] = ACTIONS(1241),
    [sym_kImplementation] = ACTIONS(1241),
    [sym_kInitialization] = ACTIONS(1241),
    [sym_kFinalization] = ACTIONS(1241),
    [sym_kEnd] = ACTIONS(1241),
    [sym_kVar] = ACTIONS(1243),
    [sym_kThreadvar] = ACTIONS(1241),
    [sym_kConst] = ACTIONS(1243),
    [sym_kResourcestring] = ACTIONS(1241),
    [sym_kType] = ACTIONS(1241),
    [sym_kLabel] = ACTIONS(1241),
    [sym_kExports] = ACTIONS(1241),
    [sym_kProperty] = ACTIONS(1241),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1241),
    [sym_kGeneric] = ACTIONS(1241),
    [sym_kFunction] = ACTIONS(1241),
    [sym_kProcedure] = ACTIONS(1241),
    [sym_kConstructor] = ACTIONS(1241),
    [sym_kDestructor] = ACTIONS(1241),
    [sym_kOperator] = ACTIONS(1241),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1241),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1241),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [177] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1245),
    [sym_kUses] = ACTIONS(1248),
    [sym_kInterface] = ACTIONS(1248),
    [sym_kImplementation] = ACTIONS(1248),
    [sym_kInitialization] = ACTIONS(1248),
    [sym_kFinalization] = ACTIONS(1248),
    [sym_kEnd] = ACTIONS(1248),
    [sym_kVar] = ACTIONS(1250),
    [sym_kThreadvar] = ACTIONS(1248),
    [sym_kConst] = ACTIONS(1250),
    [sym_kResourcestring] = ACTIONS(1248),
    [sym_kType] = ACTIONS(1248),
    [sym_kLabel] = ACTIONS(1248),
    [sym_kExports] = ACTIONS(1248),
    [sym_kProperty] = ACTIONS(1248),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1248),
    [sym_kGeneric] = ACTIONS(1248),
    [sym_kFunction] = ACTIONS(1248),
    [sym_kProcedure] = ACTIONS(1248),
    [sym_kConstructor] = ACTIONS(1248),
    [sym_kDestructor] = ACTIONS(1248),
    [sym_kOperator] = ACTIONS(1248),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1248),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1248),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [178] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(808),
    [sym_while] = STATE(808),
    [sym_repeat] = STATE(808),
    [sym_for] = STATE(808),
    [sym_foreach] = STATE(808),
    [sym_try] = STATE(808),
    [sym_case] = STATE(808),
    [sym_block] = STATE(808),
    [sym_asm] = STATE(808),
    [sym_with] = STATE(808),
    [sym_raise] = STATE(808),
    [sym_statement] = STATE(808),
    [sym_goto] = STATE(808),
    [sym__statement] = STATE(808),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [179] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(194),
    [anon_sym_LBRACK] = ACTIONS(1252),
    [sym_kUses] = ACTIONS(1255),
    [sym_kInterface] = ACTIONS(1255),
    [sym_kImplementation] = ACTIONS(1255),
    [sym_kInitialization] = ACTIONS(1255),
    [sym_kFinalization] = ACTIONS(1255),
    [sym_kEnd] = ACTIONS(1255),
    [sym_kVar] = ACTIONS(1257),
    [sym_kThreadvar] = ACTIONS(1255),
    [sym_kConst] = ACTIONS(1257),
    [sym_kResourcestring] = ACTIONS(1255),
    [sym_kType] = ACTIONS(1255),
    [sym_kLabel] = ACTIONS(1255),
    [sym_kExports] = ACTIONS(1255),
    [sym_kProperty] = ACTIONS(1255),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1255),
    [sym_kGeneric] = ACTIONS(1255),
    [sym_kFunction] = ACTIONS(1255),
    [sym_kProcedure] = ACTIONS(1255),
    [sym_kConstructor] = ACTIONS(1255),
    [sym_kDestructor] = ACTIONS(1255),
    [sym_kOperator] = ACTIONS(1255),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1255),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1255),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [180] = {
    [ts_builtin_sym_end] = ACTIONS(1259),
    [sym_identifier] = ACTIONS(1261),
    [anon_sym_SEMI] = ACTIONS(1259),
    [anon_sym_COLON] = ACTIONS(1261),
    [anon_sym_COMMA] = ACTIONS(1259),
    [anon_sym_LBRACK] = ACTIONS(1259),
    [anon_sym_RBRACK] = ACTIONS(1259),
    [anon_sym_LPAREN] = ACTIONS(1261),
    [anon_sym_RPAREN] = ACTIONS(1259),
    [sym_kUses] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1259),
    [sym_kBegin] = ACTIONS(1261),
    [sym_kEnd] = ACTIONS(1261),
    [sym_kAsm] = ACTIONS(1261),
    [sym_kVar] = ACTIONS(1261),
    [sym_kThreadvar] = ACTIONS(1261),
    [sym_kConst] = ACTIONS(1261),
    [sym_kResourcestring] = ACTIONS(1261),
    [sym_kType] = ACTIONS(1261),
    [sym_kLabel] = ACTIONS(1261),
    [sym_kExports] = ACTIONS(1261),
    [sym_kAbsolute] = ACTIONS(1261),
    [sym_kProperty] = ACTIONS(1261),
    [sym_kClass] = ACTIONS(1261),
    [sym_kOf] = ACTIONS(1261),
    [sym_kGeneric] = ACTIONS(1261),
    [sym_kLt] = ACTIONS(1261),
    [sym_kEq] = ACTIONS(1259),
    [sym_kNeq] = ACTIONS(1259),
    [sym_kGt] = ACTIONS(1261),
    [sym_kLte] = ACTIONS(1259),
    [sym_kGte] = ACTIONS(1259),
    [sym_kAdd] = ACTIONS(1261),
    [sym_kSub] = ACTIONS(1261),
    [sym_kMul] = ACTIONS(1261),
    [sym_kFdiv] = ACTIONS(1261),
    [sym_kHat] = ACTIONS(1259),
    [sym_kAssign] = ACTIONS(1259),
    [sym_kAssignAdd] = ACTIONS(1259),
    [sym_kAssignSub] = ACTIONS(1259),
    [sym_kAssignMul] = ACTIONS(1259),
    [sym_kAssignDiv] = ACTIONS(1259),
    [sym_kOr] = ACTIONS(1261),
    [sym_kXor] = ACTIONS(1261),
    [sym_kDiv] = ACTIONS(1261),
    [sym_kMod] = ACTIONS(1261),
    [sym_kAnd] = ACTIONS(1261),
    [sym_kShl] = ACTIONS(1261),
    [sym_kShr] = ACTIONS(1261),
    [sym_kIs] = ACTIONS(1261),
    [sym_kAs] = ACTIONS(1261),
    [sym_kIn] = ACTIONS(1261),
    [sym_kThen] = ACTIONS(1261),
    [sym_kElse] = ACTIONS(1261),
    [sym_kDo] = ACTIONS(1261),
    [sym_kUntil] = ACTIONS(1261),
    [sym_kExcept] = ACTIONS(1261),
    [sym_kFinally] = ACTIONS(1261),
    [sym_kCase] = ACTIONS(1261),
    [sym_kFunction] = ACTIONS(1261),
    [sym_kProcedure] = ACTIONS(1261),
    [sym_kConstructor] = ACTIONS(1261),
    [sym_kDestructor] = ACTIONS(1261),
    [sym_kOperator] = ACTIONS(1261),
    [sym_kPublished] = ACTIONS(1261),
    [sym_kPublic] = ACTIONS(1261),
    [sym_kProtected] = ACTIONS(1261),
    [sym_kPrivate] = ACTIONS(1261),
    [sym_kStrict] = ACTIONS(1261),
    [sym_kRequired] = ACTIONS(1261),
    [sym_kOptional] = ACTIONS(1261),
    [sym_kDelayed] = ACTIONS(1261),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [181] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(165),
    [anon_sym_LBRACK] = ACTIONS(1263),
    [sym_kUses] = ACTIONS(1266),
    [sym_kInterface] = ACTIONS(1266),
    [sym_kImplementation] = ACTIONS(1266),
    [sym_kInitialization] = ACTIONS(1266),
    [sym_kFinalization] = ACTIONS(1266),
    [sym_kEnd] = ACTIONS(1266),
    [sym_kVar] = ACTIONS(1268),
    [sym_kThreadvar] = ACTIONS(1266),
    [sym_kConst] = ACTIONS(1268),
    [sym_kResourcestring] = ACTIONS(1266),
    [sym_kType] = ACTIONS(1266),
    [sym_kLabel] = ACTIONS(1266),
    [sym_kExports] = ACTIONS(1266),
    [sym_kProperty] = ACTIONS(1266),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1266),
    [sym_kGeneric] = ACTIONS(1266),
    [sym_kFunction] = ACTIONS(1266),
    [sym_kProcedure] = ACTIONS(1266),
    [sym_kConstructor] = ACTIONS(1266),
    [sym_kDestructor] = ACTIONS(1266),
    [sym_kOperator] = ACTIONS(1266),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1266),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1266),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [182] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(166),
    [anon_sym_LBRACK] = ACTIONS(1270),
    [sym_kUses] = ACTIONS(1273),
    [sym_kInterface] = ACTIONS(1273),
    [sym_kImplementation] = ACTIONS(1273),
    [sym_kInitialization] = ACTIONS(1273),
    [sym_kFinalization] = ACTIONS(1273),
    [sym_kEnd] = ACTIONS(1273),
    [sym_kVar] = ACTIONS(1275),
    [sym_kThreadvar] = ACTIONS(1273),
    [sym_kConst] = ACTIONS(1275),
    [sym_kResourcestring] = ACTIONS(1273),
    [sym_kType] = ACTIONS(1273),
    [sym_kLabel] = ACTIONS(1273),
    [sym_kExports] = ACTIONS(1273),
    [sym_kProperty] = ACTIONS(1273),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1273),
    [sym_kGeneric] = ACTIONS(1273),
    [sym_kFunction] = ACTIONS(1273),
    [sym_kProcedure] = ACTIONS(1273),
    [sym_kConstructor] = ACTIONS(1273),
    [sym_kDestructor] = ACTIONS(1273),
    [sym_kOperator] = ACTIONS(1273),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1273),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1273),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [183] = {
    [ts_builtin_sym_end] = ACTIONS(1277),
    [sym_identifier] = ACTIONS(1279),
    [anon_sym_LBRACK] = ACTIONS(1277),
    [sym_kUses] = ACTIONS(1279),
    [sym_kInterface] = ACTIONS(1279),
    [sym_kImplementation] = ACTIONS(1279),
    [sym_kInitialization] = ACTIONS(1279),
    [sym_kFinalization] = ACTIONS(1279),
    [sym_kBegin] = ACTIONS(1279),
    [sym_kEnd] = ACTIONS(1279),
    [sym_kAsm] = ACTIONS(1279),
    [sym_kVar] = ACTIONS(1279),
    [sym_kThreadvar] = ACTIONS(1279),
    [sym_kConst] = ACTIONS(1279),
    [sym_kResourcestring] = ACTIONS(1279),
    [sym_kType] = ACTIONS(1279),
    [sym_kLabel] = ACTIONS(1279),
    [sym_kExports] = ACTIONS(1279),
    [sym_kProperty] = ACTIONS(1279),
    [sym_kDefault] = ACTIONS(1279),
    [sym_kNodefault] = ACTIONS(1279),
    [sym_kDispId] = ACTIONS(1279),
    [sym_kClass] = ACTIONS(1279),
    [sym_kGeneric] = ACTIONS(1279),
    [sym_kFunction] = ACTIONS(1279),
    [sym_kProcedure] = ACTIONS(1279),
    [sym_kConstructor] = ACTIONS(1279),
    [sym_kDestructor] = ACTIONS(1279),
    [sym_kOperator] = ACTIONS(1279),
    [sym_kPublic] = ACTIONS(1279),
    [sym_kStatic] = ACTIONS(1279),
    [sym_kVirtual] = ACTIONS(1279),
    [sym_kAbstract] = ACTIONS(1279),
    [sym_kDynamic] = ACTIONS(1279),
    [sym_kOverride] = ACTIONS(1279),
    [sym_kOverload] = ACTIONS(1279),
    [sym_kReintroduce] = ACTIONS(1279),
    [sym_kInline] = ACTIONS(1279),
    [sym_kStdcall] = ACTIONS(1279),
    [sym_kCdecl] = ACTIONS(1279),
    [sym_kCppdecl] = ACTIONS(1279),
    [sym_kPascal] = ACTIONS(1279),
    [sym_kRegister] = ACTIONS(1279),
    [sym_kMwpascal] = ACTIONS(1279),
    [sym_kExternal] = ACTIONS(1279),
    [sym_kMessage] = ACTIONS(1279),
    [sym_kDeprecated] = ACTIONS(1279),
    [sym_kExperimental] = ACTIONS(1279),
    [sym_kPlatform] = ACTIONS(1279),
    [sym_kUnimplemented] = ACTIONS(1279),
    [sym_kCvar] = ACTIONS(1279),
    [sym_kExport] = ACTIONS(1279),
    [sym_kFar] = ACTIONS(1279),
    [sym_kNear] = ACTIONS(1279),
    [sym_kSafecall] = ACTIONS(1279),
    [sym_kAssembler] = ACTIONS(1279),
    [sym_kNostackframe] = ACTIONS(1279),
    [sym_kInterrupt] = ACTIONS(1279),
    [sym_kNoreturn] = ACTIONS(1279),
    [sym_kIocheck] = ACTIONS(1279),
    [sym_kLocal] = ACTIONS(1279),
    [sym_kHardfloat] = ACTIONS(1279),
    [sym_kSoftfloat] = ACTIONS(1279),
    [sym_kMs_abi_default] = ACTIONS(1279),
    [sym_kMs_abi_cdecl] = ACTIONS(1279),
    [sym_kSaveregisters] = ACTIONS(1279),
    [sym_kSysv_abi_default] = ACTIONS(1279),
    [sym_kSysv_abi_cdecl] = ACTIONS(1279),
    [sym_kVectorcall] = ACTIONS(1279),
    [sym_kVarargs] = ACTIONS(1279),
    [sym_kWinapi] = ACTIONS(1279),
    [sym_kAlias] = ACTIONS(1279),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [184] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1281),
    [sym_kUses] = ACTIONS(1284),
    [sym_kInterface] = ACTIONS(1284),
    [sym_kImplementation] = ACTIONS(1284),
    [sym_kInitialization] = ACTIONS(1284),
    [sym_kFinalization] = ACTIONS(1284),
    [sym_kEnd] = ACTIONS(1284),
    [sym_kVar] = ACTIONS(1286),
    [sym_kThreadvar] = ACTIONS(1284),
    [sym_kConst] = ACTIONS(1286),
    [sym_kResourcestring] = ACTIONS(1284),
    [sym_kType] = ACTIONS(1284),
    [sym_kLabel] = ACTIONS(1284),
    [sym_kExports] = ACTIONS(1284),
    [sym_kProperty] = ACTIONS(1284),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1284),
    [sym_kGeneric] = ACTIONS(1284),
    [sym_kFunction] = ACTIONS(1284),
    [sym_kProcedure] = ACTIONS(1284),
    [sym_kConstructor] = ACTIONS(1284),
    [sym_kDestructor] = ACTIONS(1284),
    [sym_kOperator] = ACTIONS(1284),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1284),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1284),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [185] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(196),
    [anon_sym_LBRACK] = ACTIONS(1288),
    [sym_kUses] = ACTIONS(1291),
    [sym_kInterface] = ACTIONS(1291),
    [sym_kImplementation] = ACTIONS(1291),
    [sym_kInitialization] = ACTIONS(1291),
    [sym_kFinalization] = ACTIONS(1291),
    [sym_kEnd] = ACTIONS(1291),
    [sym_kVar] = ACTIONS(1293),
    [sym_kThreadvar] = ACTIONS(1291),
    [sym_kConst] = ACTIONS(1293),
    [sym_kResourcestring] = ACTIONS(1291),
    [sym_kType] = ACTIONS(1291),
    [sym_kLabel] = ACTIONS(1291),
    [sym_kExports] = ACTIONS(1291),
    [sym_kProperty] = ACTIONS(1291),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1291),
    [sym_kGeneric] = ACTIONS(1291),
    [sym_kFunction] = ACTIONS(1291),
    [sym_kProcedure] = ACTIONS(1291),
    [sym_kConstructor] = ACTIONS(1291),
    [sym_kDestructor] = ACTIONS(1291),
    [sym_kOperator] = ACTIONS(1291),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1291),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1291),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [186] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(169),
    [anon_sym_LBRACK] = ACTIONS(1295),
    [sym_kUses] = ACTIONS(1298),
    [sym_kInterface] = ACTIONS(1298),
    [sym_kImplementation] = ACTIONS(1298),
    [sym_kInitialization] = ACTIONS(1298),
    [sym_kFinalization] = ACTIONS(1298),
    [sym_kEnd] = ACTIONS(1298),
    [sym_kVar] = ACTIONS(1300),
    [sym_kThreadvar] = ACTIONS(1298),
    [sym_kConst] = ACTIONS(1300),
    [sym_kResourcestring] = ACTIONS(1298),
    [sym_kType] = ACTIONS(1298),
    [sym_kLabel] = ACTIONS(1298),
    [sym_kExports] = ACTIONS(1298),
    [sym_kProperty] = ACTIONS(1298),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1298),
    [sym_kGeneric] = ACTIONS(1298),
    [sym_kFunction] = ACTIONS(1298),
    [sym_kProcedure] = ACTIONS(1298),
    [sym_kConstructor] = ACTIONS(1298),
    [sym_kDestructor] = ACTIONS(1298),
    [sym_kOperator] = ACTIONS(1298),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1298),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1298),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [187] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1302),
    [sym_kUses] = ACTIONS(1305),
    [sym_kInterface] = ACTIONS(1305),
    [sym_kImplementation] = ACTIONS(1305),
    [sym_kInitialization] = ACTIONS(1305),
    [sym_kFinalization] = ACTIONS(1305),
    [sym_kEnd] = ACTIONS(1305),
    [sym_kVar] = ACTIONS(1307),
    [sym_kThreadvar] = ACTIONS(1305),
    [sym_kConst] = ACTIONS(1307),
    [sym_kResourcestring] = ACTIONS(1305),
    [sym_kType] = ACTIONS(1305),
    [sym_kLabel] = ACTIONS(1305),
    [sym_kExports] = ACTIONS(1305),
    [sym_kProperty] = ACTIONS(1305),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1305),
    [sym_kGeneric] = ACTIONS(1305),
    [sym_kFunction] = ACTIONS(1305),
    [sym_kProcedure] = ACTIONS(1305),
    [sym_kConstructor] = ACTIONS(1305),
    [sym_kDestructor] = ACTIONS(1305),
    [sym_kOperator] = ACTIONS(1305),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1305),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1305),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [188] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1309),
    [sym_kUses] = ACTIONS(1312),
    [sym_kInterface] = ACTIONS(1312),
    [sym_kImplementation] = ACTIONS(1312),
    [sym_kInitialization] = ACTIONS(1312),
    [sym_kFinalization] = ACTIONS(1312),
    [sym_kEnd] = ACTIONS(1312),
    [sym_kVar] = ACTIONS(1314),
    [sym_kThreadvar] = ACTIONS(1312),
    [sym_kConst] = ACTIONS(1314),
    [sym_kResourcestring] = ACTIONS(1312),
    [sym_kType] = ACTIONS(1312),
    [sym_kLabel] = ACTIONS(1312),
    [sym_kExports] = ACTIONS(1312),
    [sym_kProperty] = ACTIONS(1312),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1312),
    [sym_kGeneric] = ACTIONS(1312),
    [sym_kFunction] = ACTIONS(1312),
    [sym_kProcedure] = ACTIONS(1312),
    [sym_kConstructor] = ACTIONS(1312),
    [sym_kDestructor] = ACTIONS(1312),
    [sym_kOperator] = ACTIONS(1312),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1312),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1312),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [189] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(200),
    [anon_sym_LBRACK] = ACTIONS(1316),
    [sym_kUses] = ACTIONS(1319),
    [sym_kInterface] = ACTIONS(1319),
    [sym_kImplementation] = ACTIONS(1319),
    [sym_kInitialization] = ACTIONS(1319),
    [sym_kFinalization] = ACTIONS(1319),
    [sym_kEnd] = ACTIONS(1319),
    [sym_kVar] = ACTIONS(1321),
    [sym_kThreadvar] = ACTIONS(1319),
    [sym_kConst] = ACTIONS(1321),
    [sym_kResourcestring] = ACTIONS(1319),
    [sym_kType] = ACTIONS(1319),
    [sym_kLabel] = ACTIONS(1319),
    [sym_kExports] = ACTIONS(1319),
    [sym_kProperty] = ACTIONS(1319),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1319),
    [sym_kGeneric] = ACTIONS(1319),
    [sym_kFunction] = ACTIONS(1319),
    [sym_kProcedure] = ACTIONS(1319),
    [sym_kConstructor] = ACTIONS(1319),
    [sym_kDestructor] = ACTIONS(1319),
    [sym_kOperator] = ACTIONS(1319),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1319),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1319),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [190] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1323),
    [sym_kUses] = ACTIONS(1326),
    [sym_kInterface] = ACTIONS(1326),
    [sym_kImplementation] = ACTIONS(1326),
    [sym_kInitialization] = ACTIONS(1326),
    [sym_kFinalization] = ACTIONS(1326),
    [sym_kEnd] = ACTIONS(1326),
    [sym_kVar] = ACTIONS(1328),
    [sym_kThreadvar] = ACTIONS(1326),
    [sym_kConst] = ACTIONS(1328),
    [sym_kResourcestring] = ACTIONS(1326),
    [sym_kType] = ACTIONS(1326),
    [sym_kLabel] = ACTIONS(1326),
    [sym_kExports] = ACTIONS(1326),
    [sym_kProperty] = ACTIONS(1326),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1326),
    [sym_kGeneric] = ACTIONS(1326),
    [sym_kFunction] = ACTIONS(1326),
    [sym_kProcedure] = ACTIONS(1326),
    [sym_kConstructor] = ACTIONS(1326),
    [sym_kDestructor] = ACTIONS(1326),
    [sym_kOperator] = ACTIONS(1326),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1326),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1326),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [191] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(201),
    [anon_sym_LBRACK] = ACTIONS(1330),
    [sym_kUses] = ACTIONS(1333),
    [sym_kInterface] = ACTIONS(1333),
    [sym_kImplementation] = ACTIONS(1333),
    [sym_kInitialization] = ACTIONS(1333),
    [sym_kFinalization] = ACTIONS(1333),
    [sym_kEnd] = ACTIONS(1333),
    [sym_kVar] = ACTIONS(1335),
    [sym_kThreadvar] = ACTIONS(1333),
    [sym_kConst] = ACTIONS(1335),
    [sym_kResourcestring] = ACTIONS(1333),
    [sym_kType] = ACTIONS(1333),
    [sym_kLabel] = ACTIONS(1333),
    [sym_kExports] = ACTIONS(1333),
    [sym_kProperty] = ACTIONS(1333),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1333),
    [sym_kGeneric] = ACTIONS(1333),
    [sym_kFunction] = ACTIONS(1333),
    [sym_kProcedure] = ACTIONS(1333),
    [sym_kConstructor] = ACTIONS(1333),
    [sym_kDestructor] = ACTIONS(1333),
    [sym_kOperator] = ACTIONS(1333),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1333),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1333),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [192] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(202),
    [anon_sym_LBRACK] = ACTIONS(1337),
    [sym_kUses] = ACTIONS(1340),
    [sym_kInterface] = ACTIONS(1340),
    [sym_kImplementation] = ACTIONS(1340),
    [sym_kInitialization] = ACTIONS(1340),
    [sym_kFinalization] = ACTIONS(1340),
    [sym_kEnd] = ACTIONS(1340),
    [sym_kVar] = ACTIONS(1342),
    [sym_kThreadvar] = ACTIONS(1340),
    [sym_kConst] = ACTIONS(1342),
    [sym_kResourcestring] = ACTIONS(1340),
    [sym_kType] = ACTIONS(1340),
    [sym_kLabel] = ACTIONS(1340),
    [sym_kExports] = ACTIONS(1340),
    [sym_kProperty] = ACTIONS(1340),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1340),
    [sym_kGeneric] = ACTIONS(1340),
    [sym_kFunction] = ACTIONS(1340),
    [sym_kProcedure] = ACTIONS(1340),
    [sym_kConstructor] = ACTIONS(1340),
    [sym_kDestructor] = ACTIONS(1340),
    [sym_kOperator] = ACTIONS(1340),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1340),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1340),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [193] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1344),
    [sym_kUses] = ACTIONS(1347),
    [sym_kInterface] = ACTIONS(1347),
    [sym_kImplementation] = ACTIONS(1347),
    [sym_kInitialization] = ACTIONS(1347),
    [sym_kFinalization] = ACTIONS(1347),
    [sym_kEnd] = ACTIONS(1347),
    [sym_kVar] = ACTIONS(1349),
    [sym_kThreadvar] = ACTIONS(1347),
    [sym_kConst] = ACTIONS(1349),
    [sym_kResourcestring] = ACTIONS(1347),
    [sym_kType] = ACTIONS(1347),
    [sym_kLabel] = ACTIONS(1347),
    [sym_kExports] = ACTIONS(1347),
    [sym_kProperty] = ACTIONS(1347),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1347),
    [sym_kGeneric] = ACTIONS(1347),
    [sym_kFunction] = ACTIONS(1347),
    [sym_kProcedure] = ACTIONS(1347),
    [sym_kConstructor] = ACTIONS(1347),
    [sym_kDestructor] = ACTIONS(1347),
    [sym_kOperator] = ACTIONS(1347),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1347),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1347),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [194] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [sym_kUses] = ACTIONS(1354),
    [sym_kInterface] = ACTIONS(1354),
    [sym_kImplementation] = ACTIONS(1354),
    [sym_kInitialization] = ACTIONS(1354),
    [sym_kFinalization] = ACTIONS(1354),
    [sym_kEnd] = ACTIONS(1354),
    [sym_kVar] = ACTIONS(1356),
    [sym_kThreadvar] = ACTIONS(1354),
    [sym_kConst] = ACTIONS(1356),
    [sym_kResourcestring] = ACTIONS(1354),
    [sym_kType] = ACTIONS(1354),
    [sym_kLabel] = ACTIONS(1354),
    [sym_kExports] = ACTIONS(1354),
    [sym_kProperty] = ACTIONS(1354),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1354),
    [sym_kGeneric] = ACTIONS(1354),
    [sym_kFunction] = ACTIONS(1354),
    [sym_kProcedure] = ACTIONS(1354),
    [sym_kConstructor] = ACTIONS(1354),
    [sym_kDestructor] = ACTIONS(1354),
    [sym_kOperator] = ACTIONS(1354),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1354),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1354),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [195] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1358),
    [sym_kUses] = ACTIONS(1361),
    [sym_kInterface] = ACTIONS(1361),
    [sym_kImplementation] = ACTIONS(1361),
    [sym_kInitialization] = ACTIONS(1361),
    [sym_kFinalization] = ACTIONS(1361),
    [sym_kEnd] = ACTIONS(1361),
    [sym_kVar] = ACTIONS(1363),
    [sym_kThreadvar] = ACTIONS(1361),
    [sym_kConst] = ACTIONS(1363),
    [sym_kResourcestring] = ACTIONS(1361),
    [sym_kType] = ACTIONS(1361),
    [sym_kLabel] = ACTIONS(1361),
    [sym_kExports] = ACTIONS(1361),
    [sym_kProperty] = ACTIONS(1361),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1361),
    [sym_kGeneric] = ACTIONS(1361),
    [sym_kFunction] = ACTIONS(1361),
    [sym_kProcedure] = ACTIONS(1361),
    [sym_kConstructor] = ACTIONS(1361),
    [sym_kDestructor] = ACTIONS(1361),
    [sym_kOperator] = ACTIONS(1361),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1361),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1361),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [196] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1365),
    [sym_kUses] = ACTIONS(1368),
    [sym_kInterface] = ACTIONS(1368),
    [sym_kImplementation] = ACTIONS(1368),
    [sym_kInitialization] = ACTIONS(1368),
    [sym_kFinalization] = ACTIONS(1368),
    [sym_kEnd] = ACTIONS(1368),
    [sym_kVar] = ACTIONS(1370),
    [sym_kThreadvar] = ACTIONS(1368),
    [sym_kConst] = ACTIONS(1370),
    [sym_kResourcestring] = ACTIONS(1368),
    [sym_kType] = ACTIONS(1368),
    [sym_kLabel] = ACTIONS(1368),
    [sym_kExports] = ACTIONS(1368),
    [sym_kProperty] = ACTIONS(1368),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1368),
    [sym_kGeneric] = ACTIONS(1368),
    [sym_kFunction] = ACTIONS(1368),
    [sym_kProcedure] = ACTIONS(1368),
    [sym_kConstructor] = ACTIONS(1368),
    [sym_kDestructor] = ACTIONS(1368),
    [sym_kOperator] = ACTIONS(1368),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1368),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1368),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [197] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1372),
    [sym_kUses] = ACTIONS(1375),
    [sym_kInterface] = ACTIONS(1375),
    [sym_kImplementation] = ACTIONS(1375),
    [sym_kInitialization] = ACTIONS(1375),
    [sym_kFinalization] = ACTIONS(1375),
    [sym_kEnd] = ACTIONS(1375),
    [sym_kVar] = ACTIONS(1377),
    [sym_kThreadvar] = ACTIONS(1375),
    [sym_kConst] = ACTIONS(1377),
    [sym_kResourcestring] = ACTIONS(1375),
    [sym_kType] = ACTIONS(1375),
    [sym_kLabel] = ACTIONS(1375),
    [sym_kExports] = ACTIONS(1375),
    [sym_kProperty] = ACTIONS(1375),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1375),
    [sym_kGeneric] = ACTIONS(1375),
    [sym_kFunction] = ACTIONS(1375),
    [sym_kProcedure] = ACTIONS(1375),
    [sym_kConstructor] = ACTIONS(1375),
    [sym_kDestructor] = ACTIONS(1375),
    [sym_kOperator] = ACTIONS(1375),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1375),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1375),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [198] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(172),
    [anon_sym_LBRACK] = ACTIONS(1379),
    [sym_kUses] = ACTIONS(1382),
    [sym_kInterface] = ACTIONS(1382),
    [sym_kImplementation] = ACTIONS(1382),
    [sym_kInitialization] = ACTIONS(1382),
    [sym_kFinalization] = ACTIONS(1382),
    [sym_kEnd] = ACTIONS(1382),
    [sym_kVar] = ACTIONS(1384),
    [sym_kThreadvar] = ACTIONS(1382),
    [sym_kConst] = ACTIONS(1384),
    [sym_kResourcestring] = ACTIONS(1382),
    [sym_kType] = ACTIONS(1382),
    [sym_kLabel] = ACTIONS(1382),
    [sym_kExports] = ACTIONS(1382),
    [sym_kProperty] = ACTIONS(1382),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1382),
    [sym_kGeneric] = ACTIONS(1382),
    [sym_kFunction] = ACTIONS(1382),
    [sym_kProcedure] = ACTIONS(1382),
    [sym_kConstructor] = ACTIONS(1382),
    [sym_kDestructor] = ACTIONS(1382),
    [sym_kOperator] = ACTIONS(1382),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1382),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1382),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [199] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1386),
    [sym_kUses] = ACTIONS(1389),
    [sym_kInterface] = ACTIONS(1389),
    [sym_kImplementation] = ACTIONS(1389),
    [sym_kInitialization] = ACTIONS(1389),
    [sym_kFinalization] = ACTIONS(1389),
    [sym_kEnd] = ACTIONS(1389),
    [sym_kVar] = ACTIONS(1391),
    [sym_kThreadvar] = ACTIONS(1389),
    [sym_kConst] = ACTIONS(1391),
    [sym_kResourcestring] = ACTIONS(1389),
    [sym_kType] = ACTIONS(1389),
    [sym_kLabel] = ACTIONS(1389),
    [sym_kExports] = ACTIONS(1389),
    [sym_kProperty] = ACTIONS(1389),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1389),
    [sym_kGeneric] = ACTIONS(1389),
    [sym_kFunction] = ACTIONS(1389),
    [sym_kProcedure] = ACTIONS(1389),
    [sym_kConstructor] = ACTIONS(1389),
    [sym_kDestructor] = ACTIONS(1389),
    [sym_kOperator] = ACTIONS(1389),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1389),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1389),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [200] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1393),
    [sym_kUses] = ACTIONS(1396),
    [sym_kInterface] = ACTIONS(1396),
    [sym_kImplementation] = ACTIONS(1396),
    [sym_kInitialization] = ACTIONS(1396),
    [sym_kFinalization] = ACTIONS(1396),
    [sym_kEnd] = ACTIONS(1396),
    [sym_kVar] = ACTIONS(1398),
    [sym_kThreadvar] = ACTIONS(1396),
    [sym_kConst] = ACTIONS(1398),
    [sym_kResourcestring] = ACTIONS(1396),
    [sym_kType] = ACTIONS(1396),
    [sym_kLabel] = ACTIONS(1396),
    [sym_kExports] = ACTIONS(1396),
    [sym_kProperty] = ACTIONS(1396),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1396),
    [sym_kGeneric] = ACTIONS(1396),
    [sym_kFunction] = ACTIONS(1396),
    [sym_kProcedure] = ACTIONS(1396),
    [sym_kConstructor] = ACTIONS(1396),
    [sym_kDestructor] = ACTIONS(1396),
    [sym_kOperator] = ACTIONS(1396),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1396),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1396),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [201] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1400),
    [sym_kUses] = ACTIONS(1403),
    [sym_kInterface] = ACTIONS(1403),
    [sym_kImplementation] = ACTIONS(1403),
    [sym_kInitialization] = ACTIONS(1403),
    [sym_kFinalization] = ACTIONS(1403),
    [sym_kEnd] = ACTIONS(1403),
    [sym_kVar] = ACTIONS(1405),
    [sym_kThreadvar] = ACTIONS(1403),
    [sym_kConst] = ACTIONS(1405),
    [sym_kResourcestring] = ACTIONS(1403),
    [sym_kType] = ACTIONS(1403),
    [sym_kLabel] = ACTIONS(1403),
    [sym_kExports] = ACTIONS(1403),
    [sym_kProperty] = ACTIONS(1403),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1403),
    [sym_kGeneric] = ACTIONS(1403),
    [sym_kFunction] = ACTIONS(1403),
    [sym_kProcedure] = ACTIONS(1403),
    [sym_kConstructor] = ACTIONS(1403),
    [sym_kDestructor] = ACTIONS(1403),
    [sym_kOperator] = ACTIONS(1403),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1403),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1403),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [202] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1407),
    [sym_kUses] = ACTIONS(1410),
    [sym_kInterface] = ACTIONS(1410),
    [sym_kImplementation] = ACTIONS(1410),
    [sym_kInitialization] = ACTIONS(1410),
    [sym_kFinalization] = ACTIONS(1410),
    [sym_kEnd] = ACTIONS(1410),
    [sym_kVar] = ACTIONS(1412),
    [sym_kThreadvar] = ACTIONS(1410),
    [sym_kConst] = ACTIONS(1412),
    [sym_kResourcestring] = ACTIONS(1410),
    [sym_kType] = ACTIONS(1410),
    [sym_kLabel] = ACTIONS(1410),
    [sym_kExports] = ACTIONS(1410),
    [sym_kProperty] = ACTIONS(1410),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1410),
    [sym_kGeneric] = ACTIONS(1410),
    [sym_kFunction] = ACTIONS(1410),
    [sym_kProcedure] = ACTIONS(1410),
    [sym_kConstructor] = ACTIONS(1410),
    [sym_kDestructor] = ACTIONS(1410),
    [sym_kOperator] = ACTIONS(1410),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1410),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1410),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [203] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(205),
    [anon_sym_LBRACK] = ACTIONS(1414),
    [sym_kUses] = ACTIONS(1417),
    [sym_kInterface] = ACTIONS(1417),
    [sym_kImplementation] = ACTIONS(1417),
    [sym_kInitialization] = ACTIONS(1417),
    [sym_kFinalization] = ACTIONS(1417),
    [sym_kEnd] = ACTIONS(1417),
    [sym_kVar] = ACTIONS(1419),
    [sym_kThreadvar] = ACTIONS(1417),
    [sym_kConst] = ACTIONS(1419),
    [sym_kResourcestring] = ACTIONS(1417),
    [sym_kType] = ACTIONS(1417),
    [sym_kLabel] = ACTIONS(1417),
    [sym_kExports] = ACTIONS(1417),
    [sym_kProperty] = ACTIONS(1417),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1417),
    [sym_kGeneric] = ACTIONS(1417),
    [sym_kFunction] = ACTIONS(1417),
    [sym_kProcedure] = ACTIONS(1417),
    [sym_kConstructor] = ACTIONS(1417),
    [sym_kDestructor] = ACTIONS(1417),
    [sym_kOperator] = ACTIONS(1417),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1417),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1417),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [204] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(174),
    [anon_sym_LBRACK] = ACTIONS(1421),
    [sym_kUses] = ACTIONS(1424),
    [sym_kInterface] = ACTIONS(1424),
    [sym_kImplementation] = ACTIONS(1424),
    [sym_kInitialization] = ACTIONS(1424),
    [sym_kFinalization] = ACTIONS(1424),
    [sym_kEnd] = ACTIONS(1424),
    [sym_kVar] = ACTIONS(1426),
    [sym_kThreadvar] = ACTIONS(1424),
    [sym_kConst] = ACTIONS(1426),
    [sym_kResourcestring] = ACTIONS(1424),
    [sym_kType] = ACTIONS(1424),
    [sym_kLabel] = ACTIONS(1424),
    [sym_kExports] = ACTIONS(1424),
    [sym_kProperty] = ACTIONS(1424),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1424),
    [sym_kGeneric] = ACTIONS(1424),
    [sym_kFunction] = ACTIONS(1424),
    [sym_kProcedure] = ACTIONS(1424),
    [sym_kConstructor] = ACTIONS(1424),
    [sym_kDestructor] = ACTIONS(1424),
    [sym_kOperator] = ACTIONS(1424),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1424),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1424),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [205] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1428),
    [sym_kUses] = ACTIONS(1431),
    [sym_kInterface] = ACTIONS(1431),
    [sym_kImplementation] = ACTIONS(1431),
    [sym_kInitialization] = ACTIONS(1431),
    [sym_kFinalization] = ACTIONS(1431),
    [sym_kEnd] = ACTIONS(1431),
    [sym_kVar] = ACTIONS(1433),
    [sym_kThreadvar] = ACTIONS(1431),
    [sym_kConst] = ACTIONS(1433),
    [sym_kResourcestring] = ACTIONS(1431),
    [sym_kType] = ACTIONS(1431),
    [sym_kLabel] = ACTIONS(1431),
    [sym_kExports] = ACTIONS(1431),
    [sym_kProperty] = ACTIONS(1431),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1431),
    [sym_kGeneric] = ACTIONS(1431),
    [sym_kFunction] = ACTIONS(1431),
    [sym_kProcedure] = ACTIONS(1431),
    [sym_kConstructor] = ACTIONS(1431),
    [sym_kDestructor] = ACTIONS(1431),
    [sym_kOperator] = ACTIONS(1431),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1431),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1431),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [206] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(1608),
    [sym_while] = STATE(1608),
    [sym_repeat] = STATE(1608),
    [sym_for] = STATE(1608),
    [sym_foreach] = STATE(1608),
    [sym_try] = STATE(1608),
    [sym_case] = STATE(1608),
    [sym_block] = STATE(1608),
    [sym_asm] = STATE(1608),
    [sym_with] = STATE(1608),
    [sym_raise] = STATE(1608),
    [sym_statement] = STATE(1608),
    [sym_goto] = STATE(1608),
    [sym__statement] = STATE(1608),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(255),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [207] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(826),
    [sym_while] = STATE(826),
    [sym_repeat] = STATE(826),
    [sym_for] = STATE(826),
    [sym_foreach] = STATE(826),
    [sym_try] = STATE(826),
    [sym_case] = STATE(826),
    [sym_block] = STATE(826),
    [sym_asm] = STATE(826),
    [sym_with] = STATE(826),
    [sym_raise] = STATE(826),
    [sym_statement] = STATE(826),
    [sym_goto] = STATE(826),
    [sym__statement] = STATE(826),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(169),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [208] = {
    [ts_builtin_sym_end] = ACTIONS(1435),
    [sym_identifier] = ACTIONS(1437),
    [anon_sym_LBRACK] = ACTIONS(1435),
    [sym_kUses] = ACTIONS(1437),
    [sym_kInterface] = ACTIONS(1437),
    [sym_kImplementation] = ACTIONS(1437),
    [sym_kInitialization] = ACTIONS(1437),
    [sym_kFinalization] = ACTIONS(1437),
    [sym_kBegin] = ACTIONS(1437),
    [sym_kEnd] = ACTIONS(1437),
    [sym_kAsm] = ACTIONS(1437),
    [sym_kVar] = ACTIONS(1437),
    [sym_kThreadvar] = ACTIONS(1437),
    [sym_kConst] = ACTIONS(1437),
    [sym_kResourcestring] = ACTIONS(1437),
    [sym_kType] = ACTIONS(1437),
    [sym_kLabel] = ACTIONS(1437),
    [sym_kExports] = ACTIONS(1437),
    [sym_kProperty] = ACTIONS(1437),
    [sym_kDefault] = ACTIONS(1437),
    [sym_kNodefault] = ACTIONS(1437),
    [sym_kDispId] = ACTIONS(1437),
    [sym_kClass] = ACTIONS(1437),
    [sym_kGeneric] = ACTIONS(1437),
    [sym_kFunction] = ACTIONS(1437),
    [sym_kProcedure] = ACTIONS(1437),
    [sym_kConstructor] = ACTIONS(1437),
    [sym_kDestructor] = ACTIONS(1437),
    [sym_kOperator] = ACTIONS(1437),
    [sym_kPublic] = ACTIONS(1437),
    [sym_kStatic] = ACTIONS(1437),
    [sym_kVirtual] = ACTIONS(1437),
    [sym_kAbstract] = ACTIONS(1437),
    [sym_kDynamic] = ACTIONS(1437),
    [sym_kOverride] = ACTIONS(1437),
    [sym_kOverload] = ACTIONS(1437),
    [sym_kReintroduce] = ACTIONS(1437),
    [sym_kInline] = ACTIONS(1437),
    [sym_kStdcall] = ACTIONS(1437),
    [sym_kCdecl] = ACTIONS(1437),
    [sym_kCppdecl] = ACTIONS(1437),
    [sym_kPascal] = ACTIONS(1437),
    [sym_kRegister] = ACTIONS(1437),
    [sym_kMwpascal] = ACTIONS(1437),
    [sym_kExternal] = ACTIONS(1437),
    [sym_kMessage] = ACTIONS(1437),
    [sym_kDeprecated] = ACTIONS(1437),
    [sym_kExperimental] = ACTIONS(1437),
    [sym_kPlatform] = ACTIONS(1437),
    [sym_kUnimplemented] = ACTIONS(1437),
    [sym_kCvar] = ACTIONS(1437),
    [sym_kExport] = ACTIONS(1437),
    [sym_kFar] = ACTIONS(1437),
    [sym_kNear] = ACTIONS(1437),
    [sym_kSafecall] = ACTIONS(1437),
    [sym_kAssembler] = ACTIONS(1437),
    [sym_kNostackframe] = ACTIONS(1437),
    [sym_kInterrupt] = ACTIONS(1437),
    [sym_kNoreturn] = ACTIONS(1437),
    [sym_kIocheck] = ACTIONS(1437),
    [sym_kLocal] = ACTIONS(1437),
    [sym_kHardfloat] = ACTIONS(1437),
    [sym_kSoftfloat] = ACTIONS(1437),
    [sym_kMs_abi_default] = ACTIONS(1437),
    [sym_kMs_abi_cdecl] = ACTIONS(1437),
    [sym_kSaveregisters] = ACTIONS(1437),
    [sym_kSysv_abi_default] = ACTIONS(1437),
    [sym_kSysv_abi_cdecl] = ACTIONS(1437),
    [sym_kVectorcall] = ACTIONS(1437),
    [sym_kVarargs] = ACTIONS(1437),
    [sym_kWinapi] = ACTIONS(1437),
    [sym_kAlias] = ACTIONS(1437),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [209] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(844),
    [sym_while] = STATE(844),
    [sym_repeat] = STATE(844),
    [sym_for] = STATE(844),
    [sym_foreach] = STATE(844),
    [sym_try] = STATE(844),
    [sym_case] = STATE(844),
    [sym_block] = STATE(844),
    [sym_asm] = STATE(844),
    [sym_with] = STATE(844),
    [sym_raise] = STATE(844),
    [sym_statement] = STATE(844),
    [sym_goto] = STATE(844),
    [sym__statement] = STATE(844),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [210] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(812),
    [sym_while] = STATE(812),
    [sym_repeat] = STATE(812),
    [sym_for] = STATE(812),
    [sym_foreach] = STATE(812),
    [sym_try] = STATE(812),
    [sym_case] = STATE(812),
    [sym_block] = STATE(812),
    [sym_asm] = STATE(812),
    [sym_with] = STATE(812),
    [sym_raise] = STATE(812),
    [sym_statement] = STATE(812),
    [sym_goto] = STATE(812),
    [sym__statement] = STATE(812),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(181),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [211] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(2069),
    [sym_while] = STATE(2069),
    [sym_repeat] = STATE(2069),
    [sym_for] = STATE(2069),
    [sym_foreach] = STATE(2069),
    [sym_try] = STATE(2069),
    [sym_case] = STATE(2069),
    [sym_block] = STATE(2069),
    [sym_asm] = STATE(2069),
    [sym_with] = STATE(2069),
    [sym_raise] = STATE(2069),
    [sym_statement] = STATE(2069),
    [sym_goto] = STATE(2069),
    [sym__statement] = STATE(2069),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(251),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [212] = {
    [ts_builtin_sym_end] = ACTIONS(1439),
    [sym_identifier] = ACTIONS(1441),
    [anon_sym_LBRACK] = ACTIONS(1439),
    [sym_kUses] = ACTIONS(1441),
    [sym_kInterface] = ACTIONS(1441),
    [sym_kImplementation] = ACTIONS(1441),
    [sym_kInitialization] = ACTIONS(1441),
    [sym_kFinalization] = ACTIONS(1441),
    [sym_kBegin] = ACTIONS(1441),
    [sym_kEnd] = ACTIONS(1441),
    [sym_kAsm] = ACTIONS(1441),
    [sym_kVar] = ACTIONS(1441),
    [sym_kThreadvar] = ACTIONS(1441),
    [sym_kConst] = ACTIONS(1441),
    [sym_kResourcestring] = ACTIONS(1441),
    [sym_kType] = ACTIONS(1441),
    [sym_kLabel] = ACTIONS(1441),
    [sym_kExports] = ACTIONS(1441),
    [sym_kProperty] = ACTIONS(1441),
    [sym_kDefault] = ACTIONS(1441),
    [sym_kNodefault] = ACTIONS(1441),
    [sym_kDispId] = ACTIONS(1441),
    [sym_kClass] = ACTIONS(1441),
    [sym_kGeneric] = ACTIONS(1441),
    [sym_kFunction] = ACTIONS(1441),
    [sym_kProcedure] = ACTIONS(1441),
    [sym_kConstructor] = ACTIONS(1441),
    [sym_kDestructor] = ACTIONS(1441),
    [sym_kOperator] = ACTIONS(1441),
    [sym_kPublic] = ACTIONS(1441),
    [sym_kStatic] = ACTIONS(1441),
    [sym_kVirtual] = ACTIONS(1441),
    [sym_kAbstract] = ACTIONS(1441),
    [sym_kDynamic] = ACTIONS(1441),
    [sym_kOverride] = ACTIONS(1441),
    [sym_kOverload] = ACTIONS(1441),
    [sym_kReintroduce] = ACTIONS(1441),
    [sym_kInline] = ACTIONS(1441),
    [sym_kStdcall] = ACTIONS(1441),
    [sym_kCdecl] = ACTIONS(1441),
    [sym_kCppdecl] = ACTIONS(1441),
    [sym_kPascal] = ACTIONS(1441),
    [sym_kRegister] = ACTIONS(1441),
    [sym_kMwpascal] = ACTIONS(1441),
    [sym_kExternal] = ACTIONS(1441),
    [sym_kMessage] = ACTIONS(1441),
    [sym_kDeprecated] = ACTIONS(1441),
    [sym_kExperimental] = ACTIONS(1441),
    [sym_kPlatform] = ACTIONS(1441),
    [sym_kUnimplemented] = ACTIONS(1441),
    [sym_kCvar] = ACTIONS(1441),
    [sym_kExport] = ACTIONS(1441),
    [sym_kFar] = ACTIONS(1441),
    [sym_kNear] = ACTIONS(1441),
    [sym_kSafecall] = ACTIONS(1441),
    [sym_kAssembler] = ACTIONS(1441),
    [sym_kNostackframe] = ACTIONS(1441),
    [sym_kInterrupt] = ACTIONS(1441),
    [sym_kNoreturn] = ACTIONS(1441),
    [sym_kIocheck] = ACTIONS(1441),
    [sym_kLocal] = ACTIONS(1441),
    [sym_kHardfloat] = ACTIONS(1441),
    [sym_kSoftfloat] = ACTIONS(1441),
    [sym_kMs_abi_default] = ACTIONS(1441),
    [sym_kMs_abi_cdecl] = ACTIONS(1441),
    [sym_kSaveregisters] = ACTIONS(1441),
    [sym_kSysv_abi_default] = ACTIONS(1441),
    [sym_kSysv_abi_cdecl] = ACTIONS(1441),
    [sym_kVectorcall] = ACTIONS(1441),
    [sym_kVarargs] = ACTIONS(1441),
    [sym_kWinapi] = ACTIONS(1441),
    [sym_kAlias] = ACTIONS(1441),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [213] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(793),
    [sym_while] = STATE(793),
    [sym_repeat] = STATE(793),
    [sym_for] = STATE(793),
    [sym_foreach] = STATE(793),
    [sym_try] = STATE(793),
    [sym_case] = STATE(793),
    [sym_block] = STATE(793),
    [sym_asm] = STATE(793),
    [sym_with] = STATE(793),
    [sym_raise] = STATE(793),
    [sym_statement] = STATE(793),
    [sym_goto] = STATE(793),
    [sym__statement] = STATE(793),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [214] = {
    [ts_builtin_sym_end] = ACTIONS(1443),
    [sym_identifier] = ACTIONS(1445),
    [anon_sym_LBRACK] = ACTIONS(1443),
    [sym_kUses] = ACTIONS(1445),
    [sym_kInterface] = ACTIONS(1445),
    [sym_kImplementation] = ACTIONS(1445),
    [sym_kInitialization] = ACTIONS(1445),
    [sym_kFinalization] = ACTIONS(1445),
    [sym_kBegin] = ACTIONS(1445),
    [sym_kEnd] = ACTIONS(1445),
    [sym_kAsm] = ACTIONS(1445),
    [sym_kVar] = ACTIONS(1445),
    [sym_kThreadvar] = ACTIONS(1445),
    [sym_kConst] = ACTIONS(1445),
    [sym_kResourcestring] = ACTIONS(1445),
    [sym_kType] = ACTIONS(1445),
    [sym_kLabel] = ACTIONS(1445),
    [sym_kExports] = ACTIONS(1445),
    [sym_kProperty] = ACTIONS(1445),
    [sym_kDefault] = ACTIONS(1445),
    [sym_kNodefault] = ACTIONS(1445),
    [sym_kDispId] = ACTIONS(1445),
    [sym_kClass] = ACTIONS(1445),
    [sym_kGeneric] = ACTIONS(1445),
    [sym_kFunction] = ACTIONS(1445),
    [sym_kProcedure] = ACTIONS(1445),
    [sym_kConstructor] = ACTIONS(1445),
    [sym_kDestructor] = ACTIONS(1445),
    [sym_kOperator] = ACTIONS(1445),
    [sym_kPublic] = ACTIONS(1445),
    [sym_kStatic] = ACTIONS(1445),
    [sym_kVirtual] = ACTIONS(1445),
    [sym_kAbstract] = ACTIONS(1445),
    [sym_kDynamic] = ACTIONS(1445),
    [sym_kOverride] = ACTIONS(1445),
    [sym_kOverload] = ACTIONS(1445),
    [sym_kReintroduce] = ACTIONS(1445),
    [sym_kInline] = ACTIONS(1445),
    [sym_kStdcall] = ACTIONS(1445),
    [sym_kCdecl] = ACTIONS(1445),
    [sym_kCppdecl] = ACTIONS(1445),
    [sym_kPascal] = ACTIONS(1445),
    [sym_kRegister] = ACTIONS(1445),
    [sym_kMwpascal] = ACTIONS(1445),
    [sym_kExternal] = ACTIONS(1445),
    [sym_kMessage] = ACTIONS(1445),
    [sym_kDeprecated] = ACTIONS(1445),
    [sym_kExperimental] = ACTIONS(1445),
    [sym_kPlatform] = ACTIONS(1445),
    [sym_kUnimplemented] = ACTIONS(1445),
    [sym_kCvar] = ACTIONS(1445),
    [sym_kExport] = ACTIONS(1445),
    [sym_kFar] = ACTIONS(1445),
    [sym_kNear] = ACTIONS(1445),
    [sym_kSafecall] = ACTIONS(1445),
    [sym_kAssembler] = ACTIONS(1445),
    [sym_kNostackframe] = ACTIONS(1445),
    [sym_kInterrupt] = ACTIONS(1445),
    [sym_kNoreturn] = ACTIONS(1445),
    [sym_kIocheck] = ACTIONS(1445),
    [sym_kLocal] = ACTIONS(1445),
    [sym_kHardfloat] = ACTIONS(1445),
    [sym_kSoftfloat] = ACTIONS(1445),
    [sym_kMs_abi_default] = ACTIONS(1445),
    [sym_kMs_abi_cdecl] = ACTIONS(1445),
    [sym_kSaveregisters] = ACTIONS(1445),
    [sym_kSysv_abi_default] = ACTIONS(1445),
    [sym_kSysv_abi_cdecl] = ACTIONS(1445),
    [sym_kVectorcall] = ACTIONS(1445),
    [sym_kVarargs] = ACTIONS(1445),
    [sym_kWinapi] = ACTIONS(1445),
    [sym_kAlias] = ACTIONS(1445),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [215] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(195),
    [anon_sym_LBRACK] = ACTIONS(1447),
    [sym_kUses] = ACTIONS(1450),
    [sym_kInterface] = ACTIONS(1450),
    [sym_kImplementation] = ACTIONS(1450),
    [sym_kInitialization] = ACTIONS(1450),
    [sym_kFinalization] = ACTIONS(1450),
    [sym_kEnd] = ACTIONS(1450),
    [sym_kVar] = ACTIONS(1452),
    [sym_kThreadvar] = ACTIONS(1450),
    [sym_kConst] = ACTIONS(1452),
    [sym_kResourcestring] = ACTIONS(1450),
    [sym_kType] = ACTIONS(1450),
    [sym_kLabel] = ACTIONS(1450),
    [sym_kExports] = ACTIONS(1450),
    [sym_kProperty] = ACTIONS(1450),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1450),
    [sym_kGeneric] = ACTIONS(1450),
    [sym_kFunction] = ACTIONS(1450),
    [sym_kProcedure] = ACTIONS(1450),
    [sym_kConstructor] = ACTIONS(1450),
    [sym_kDestructor] = ACTIONS(1450),
    [sym_kOperator] = ACTIONS(1450),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1450),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1450),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [216] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(175),
    [anon_sym_LBRACK] = ACTIONS(1454),
    [sym_kUses] = ACTIONS(1457),
    [sym_kInterface] = ACTIONS(1457),
    [sym_kImplementation] = ACTIONS(1457),
    [sym_kInitialization] = ACTIONS(1457),
    [sym_kFinalization] = ACTIONS(1457),
    [sym_kEnd] = ACTIONS(1457),
    [sym_kVar] = ACTIONS(1459),
    [sym_kThreadvar] = ACTIONS(1457),
    [sym_kConst] = ACTIONS(1459),
    [sym_kResourcestring] = ACTIONS(1457),
    [sym_kType] = ACTIONS(1457),
    [sym_kLabel] = ACTIONS(1457),
    [sym_kExports] = ACTIONS(1457),
    [sym_kProperty] = ACTIONS(1457),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1457),
    [sym_kGeneric] = ACTIONS(1457),
    [sym_kFunction] = ACTIONS(1457),
    [sym_kProcedure] = ACTIONS(1457),
    [sym_kConstructor] = ACTIONS(1457),
    [sym_kDestructor] = ACTIONS(1457),
    [sym_kOperator] = ACTIONS(1457),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1457),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1457),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [217] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1461),
    [sym_kUses] = ACTIONS(1464),
    [sym_kInterface] = ACTIONS(1464),
    [sym_kImplementation] = ACTIONS(1464),
    [sym_kInitialization] = ACTIONS(1464),
    [sym_kFinalization] = ACTIONS(1464),
    [sym_kEnd] = ACTIONS(1464),
    [sym_kVar] = ACTIONS(1466),
    [sym_kThreadvar] = ACTIONS(1464),
    [sym_kConst] = ACTIONS(1466),
    [sym_kResourcestring] = ACTIONS(1464),
    [sym_kType] = ACTIONS(1464),
    [sym_kLabel] = ACTIONS(1464),
    [sym_kExports] = ACTIONS(1464),
    [sym_kProperty] = ACTIONS(1464),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1464),
    [sym_kGeneric] = ACTIONS(1464),
    [sym_kFunction] = ACTIONS(1464),
    [sym_kProcedure] = ACTIONS(1464),
    [sym_kConstructor] = ACTIONS(1464),
    [sym_kDestructor] = ACTIONS(1464),
    [sym_kOperator] = ACTIONS(1464),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1464),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1464),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [218] = {
    [ts_builtin_sym_end] = ACTIONS(1468),
    [sym_identifier] = ACTIONS(1470),
    [anon_sym_SEMI] = ACTIONS(1468),
    [anon_sym_COLON] = ACTIONS(1470),
    [anon_sym_COMMA] = ACTIONS(1468),
    [anon_sym_LBRACK] = ACTIONS(1468),
    [anon_sym_RBRACK] = ACTIONS(1468),
    [anon_sym_LPAREN] = ACTIONS(1470),
    [anon_sym_RPAREN] = ACTIONS(1468),
    [sym_kUses] = ACTIONS(1470),
    [anon_sym_DOT] = ACTIONS(1468),
    [sym_kBegin] = ACTIONS(1470),
    [sym_kEnd] = ACTIONS(1470),
    [sym_kAsm] = ACTIONS(1470),
    [sym_kVar] = ACTIONS(1470),
    [sym_kThreadvar] = ACTIONS(1470),
    [sym_kConst] = ACTIONS(1470),
    [sym_kResourcestring] = ACTIONS(1470),
    [sym_kType] = ACTIONS(1470),
    [sym_kLabel] = ACTIONS(1470),
    [sym_kExports] = ACTIONS(1470),
    [sym_kAbsolute] = ACTIONS(1470),
    [sym_kProperty] = ACTIONS(1470),
    [sym_kClass] = ACTIONS(1470),
    [sym_kOf] = ACTIONS(1470),
    [sym_kGeneric] = ACTIONS(1470),
    [sym_kLt] = ACTIONS(1470),
    [sym_kEq] = ACTIONS(1468),
    [sym_kNeq] = ACTIONS(1468),
    [sym_kGt] = ACTIONS(1470),
    [sym_kLte] = ACTIONS(1468),
    [sym_kGte] = ACTIONS(1468),
    [sym_kAdd] = ACTIONS(1470),
    [sym_kSub] = ACTIONS(1470),
    [sym_kMul] = ACTIONS(1470),
    [sym_kFdiv] = ACTIONS(1470),
    [sym_kHat] = ACTIONS(1468),
    [sym_kAssign] = ACTIONS(1468),
    [sym_kAssignAdd] = ACTIONS(1468),
    [sym_kAssignSub] = ACTIONS(1468),
    [sym_kAssignMul] = ACTIONS(1468),
    [sym_kAssignDiv] = ACTIONS(1468),
    [sym_kOr] = ACTIONS(1470),
    [sym_kXor] = ACTIONS(1470),
    [sym_kDiv] = ACTIONS(1470),
    [sym_kMod] = ACTIONS(1470),
    [sym_kAnd] = ACTIONS(1470),
    [sym_kShl] = ACTIONS(1470),
    [sym_kShr] = ACTIONS(1470),
    [sym_kIs] = ACTIONS(1470),
    [sym_kAs] = ACTIONS(1470),
    [sym_kIn] = ACTIONS(1470),
    [sym_kThen] = ACTIONS(1470),
    [sym_kElse] = ACTIONS(1470),
    [sym_kDo] = ACTIONS(1470),
    [sym_kUntil] = ACTIONS(1470),
    [sym_kExcept] = ACTIONS(1470),
    [sym_kFinally] = ACTIONS(1470),
    [sym_kCase] = ACTIONS(1470),
    [sym_kFunction] = ACTIONS(1470),
    [sym_kProcedure] = ACTIONS(1470),
    [sym_kConstructor] = ACTIONS(1470),
    [sym_kDestructor] = ACTIONS(1470),
    [sym_kOperator] = ACTIONS(1470),
    [sym_kPublished] = ACTIONS(1470),
    [sym_kPublic] = ACTIONS(1470),
    [sym_kProtected] = ACTIONS(1470),
    [sym_kPrivate] = ACTIONS(1470),
    [sym_kStrict] = ACTIONS(1470),
    [sym_kRequired] = ACTIONS(1470),
    [sym_kOptional] = ACTIONS(1470),
    [sym_kDelayed] = ACTIONS(1470),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [219] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(184),
    [anon_sym_LBRACK] = ACTIONS(1472),
    [sym_kUses] = ACTIONS(1475),
    [sym_kInterface] = ACTIONS(1475),
    [sym_kImplementation] = ACTIONS(1475),
    [sym_kInitialization] = ACTIONS(1475),
    [sym_kFinalization] = ACTIONS(1475),
    [sym_kEnd] = ACTIONS(1475),
    [sym_kVar] = ACTIONS(1477),
    [sym_kThreadvar] = ACTIONS(1475),
    [sym_kConst] = ACTIONS(1477),
    [sym_kResourcestring] = ACTIONS(1475),
    [sym_kType] = ACTIONS(1475),
    [sym_kLabel] = ACTIONS(1475),
    [sym_kExports] = ACTIONS(1475),
    [sym_kProperty] = ACTIONS(1475),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1475),
    [sym_kGeneric] = ACTIONS(1475),
    [sym_kFunction] = ACTIONS(1475),
    [sym_kProcedure] = ACTIONS(1475),
    [sym_kConstructor] = ACTIONS(1475),
    [sym_kDestructor] = ACTIONS(1475),
    [sym_kOperator] = ACTIONS(1475),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1475),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1475),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [220] = {
    [ts_builtin_sym_end] = ACTIONS(1479),
    [sym_identifier] = ACTIONS(1481),
    [anon_sym_LBRACK] = ACTIONS(1479),
    [sym_kUses] = ACTIONS(1481),
    [sym_kInterface] = ACTIONS(1481),
    [sym_kImplementation] = ACTIONS(1481),
    [sym_kInitialization] = ACTIONS(1481),
    [sym_kFinalization] = ACTIONS(1481),
    [sym_kBegin] = ACTIONS(1481),
    [sym_kEnd] = ACTIONS(1481),
    [sym_kAsm] = ACTIONS(1481),
    [sym_kVar] = ACTIONS(1481),
    [sym_kThreadvar] = ACTIONS(1481),
    [sym_kConst] = ACTIONS(1481),
    [sym_kResourcestring] = ACTIONS(1481),
    [sym_kType] = ACTIONS(1481),
    [sym_kLabel] = ACTIONS(1481),
    [sym_kExports] = ACTIONS(1481),
    [sym_kProperty] = ACTIONS(1481),
    [sym_kDefault] = ACTIONS(1481),
    [sym_kNodefault] = ACTIONS(1481),
    [sym_kDispId] = ACTIONS(1481),
    [sym_kClass] = ACTIONS(1481),
    [sym_kGeneric] = ACTIONS(1481),
    [sym_kFunction] = ACTIONS(1481),
    [sym_kProcedure] = ACTIONS(1481),
    [sym_kConstructor] = ACTIONS(1481),
    [sym_kDestructor] = ACTIONS(1481),
    [sym_kOperator] = ACTIONS(1481),
    [sym_kPublic] = ACTIONS(1481),
    [sym_kStatic] = ACTIONS(1481),
    [sym_kVirtual] = ACTIONS(1481),
    [sym_kAbstract] = ACTIONS(1481),
    [sym_kDynamic] = ACTIONS(1481),
    [sym_kOverride] = ACTIONS(1481),
    [sym_kOverload] = ACTIONS(1481),
    [sym_kReintroduce] = ACTIONS(1481),
    [sym_kInline] = ACTIONS(1481),
    [sym_kStdcall] = ACTIONS(1481),
    [sym_kCdecl] = ACTIONS(1481),
    [sym_kCppdecl] = ACTIONS(1481),
    [sym_kPascal] = ACTIONS(1481),
    [sym_kRegister] = ACTIONS(1481),
    [sym_kMwpascal] = ACTIONS(1481),
    [sym_kExternal] = ACTIONS(1481),
    [sym_kMessage] = ACTIONS(1481),
    [sym_kDeprecated] = ACTIONS(1481),
    [sym_kExperimental] = ACTIONS(1481),
    [sym_kPlatform] = ACTIONS(1481),
    [sym_kUnimplemented] = ACTIONS(1481),
    [sym_kCvar] = ACTIONS(1481),
    [sym_kExport] = ACTIONS(1481),
    [sym_kFar] = ACTIONS(1481),
    [sym_kNear] = ACTIONS(1481),
    [sym_kSafecall] = ACTIONS(1481),
    [sym_kAssembler] = ACTIONS(1481),
    [sym_kNostackframe] = ACTIONS(1481),
    [sym_kInterrupt] = ACTIONS(1481),
    [sym_kNoreturn] = ACTIONS(1481),
    [sym_kIocheck] = ACTIONS(1481),
    [sym_kLocal] = ACTIONS(1481),
    [sym_kHardfloat] = ACTIONS(1481),
    [sym_kSoftfloat] = ACTIONS(1481),
    [sym_kMs_abi_default] = ACTIONS(1481),
    [sym_kMs_abi_cdecl] = ACTIONS(1481),
    [sym_kSaveregisters] = ACTIONS(1481),
    [sym_kSysv_abi_default] = ACTIONS(1481),
    [sym_kSysv_abi_cdecl] = ACTIONS(1481),
    [sym_kVectorcall] = ACTIONS(1481),
    [sym_kVarargs] = ACTIONS(1481),
    [sym_kWinapi] = ACTIONS(1481),
    [sym_kAlias] = ACTIONS(1481),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [221] = {
    [ts_builtin_sym_end] = ACTIONS(1479),
    [sym_identifier] = ACTIONS(1481),
    [anon_sym_LBRACK] = ACTIONS(1479),
    [sym_kUses] = ACTIONS(1481),
    [sym_kInterface] = ACTIONS(1481),
    [sym_kImplementation] = ACTIONS(1481),
    [sym_kInitialization] = ACTIONS(1481),
    [sym_kFinalization] = ACTIONS(1481),
    [sym_kBegin] = ACTIONS(1481),
    [sym_kEnd] = ACTIONS(1481),
    [sym_kAsm] = ACTIONS(1481),
    [sym_kVar] = ACTIONS(1481),
    [sym_kThreadvar] = ACTIONS(1481),
    [sym_kConst] = ACTIONS(1481),
    [sym_kResourcestring] = ACTIONS(1481),
    [sym_kType] = ACTIONS(1481),
    [sym_kLabel] = ACTIONS(1481),
    [sym_kExports] = ACTIONS(1481),
    [sym_kProperty] = ACTIONS(1481),
    [sym_kDefault] = ACTIONS(1481),
    [sym_kNodefault] = ACTIONS(1481),
    [sym_kDispId] = ACTIONS(1481),
    [sym_kClass] = ACTIONS(1481),
    [sym_kGeneric] = ACTIONS(1481),
    [sym_kFunction] = ACTIONS(1481),
    [sym_kProcedure] = ACTIONS(1481),
    [sym_kConstructor] = ACTIONS(1481),
    [sym_kDestructor] = ACTIONS(1481),
    [sym_kOperator] = ACTIONS(1481),
    [sym_kPublic] = ACTIONS(1481),
    [sym_kStatic] = ACTIONS(1481),
    [sym_kVirtual] = ACTIONS(1481),
    [sym_kAbstract] = ACTIONS(1481),
    [sym_kDynamic] = ACTIONS(1481),
    [sym_kOverride] = ACTIONS(1481),
    [sym_kOverload] = ACTIONS(1481),
    [sym_kReintroduce] = ACTIONS(1481),
    [sym_kInline] = ACTIONS(1481),
    [sym_kStdcall] = ACTIONS(1481),
    [sym_kCdecl] = ACTIONS(1481),
    [sym_kCppdecl] = ACTIONS(1481),
    [sym_kPascal] = ACTIONS(1481),
    [sym_kRegister] = ACTIONS(1481),
    [sym_kMwpascal] = ACTIONS(1481),
    [sym_kExternal] = ACTIONS(1481),
    [sym_kMessage] = ACTIONS(1481),
    [sym_kDeprecated] = ACTIONS(1481),
    [sym_kExperimental] = ACTIONS(1481),
    [sym_kPlatform] = ACTIONS(1481),
    [sym_kUnimplemented] = ACTIONS(1481),
    [sym_kCvar] = ACTIONS(1481),
    [sym_kExport] = ACTIONS(1481),
    [sym_kFar] = ACTIONS(1481),
    [sym_kNear] = ACTIONS(1481),
    [sym_kSafecall] = ACTIONS(1481),
    [sym_kAssembler] = ACTIONS(1481),
    [sym_kNostackframe] = ACTIONS(1481),
    [sym_kInterrupt] = ACTIONS(1481),
    [sym_kNoreturn] = ACTIONS(1481),
    [sym_kIocheck] = ACTIONS(1481),
    [sym_kLocal] = ACTIONS(1481),
    [sym_kHardfloat] = ACTIONS(1481),
    [sym_kSoftfloat] = ACTIONS(1481),
    [sym_kMs_abi_default] = ACTIONS(1481),
    [sym_kMs_abi_cdecl] = ACTIONS(1481),
    [sym_kSaveregisters] = ACTIONS(1481),
    [sym_kSysv_abi_default] = ACTIONS(1481),
    [sym_kSysv_abi_cdecl] = ACTIONS(1481),
    [sym_kVectorcall] = ACTIONS(1481),
    [sym_kVarargs] = ACTIONS(1481),
    [sym_kWinapi] = ACTIONS(1481),
    [sym_kAlias] = ACTIONS(1481),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [222] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(177),
    [anon_sym_LBRACK] = ACTIONS(1483),
    [sym_kUses] = ACTIONS(1486),
    [sym_kInterface] = ACTIONS(1486),
    [sym_kImplementation] = ACTIONS(1486),
    [sym_kInitialization] = ACTIONS(1486),
    [sym_kFinalization] = ACTIONS(1486),
    [sym_kEnd] = ACTIONS(1486),
    [sym_kVar] = ACTIONS(1488),
    [sym_kThreadvar] = ACTIONS(1486),
    [sym_kConst] = ACTIONS(1488),
    [sym_kResourcestring] = ACTIONS(1486),
    [sym_kType] = ACTIONS(1486),
    [sym_kLabel] = ACTIONS(1486),
    [sym_kExports] = ACTIONS(1486),
    [sym_kProperty] = ACTIONS(1486),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1486),
    [sym_kGeneric] = ACTIONS(1486),
    [sym_kFunction] = ACTIONS(1486),
    [sym_kProcedure] = ACTIONS(1486),
    [sym_kConstructor] = ACTIONS(1486),
    [sym_kDestructor] = ACTIONS(1486),
    [sym_kOperator] = ACTIONS(1486),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1486),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1486),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [223] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(2074),
    [sym_while] = STATE(2074),
    [sym_repeat] = STATE(2074),
    [sym_for] = STATE(2074),
    [sym_foreach] = STATE(2074),
    [sym_try] = STATE(2074),
    [sym_case] = STATE(2074),
    [sym_block] = STATE(2074),
    [sym_asm] = STATE(2074),
    [sym_with] = STATE(2074),
    [sym_raise] = STATE(2074),
    [sym_statement] = STATE(2074),
    [sym_goto] = STATE(2074),
    [sym__statement] = STATE(2074),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(259),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [224] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(159),
    [anon_sym_LBRACK] = ACTIONS(1490),
    [sym_kUses] = ACTIONS(1493),
    [sym_kInterface] = ACTIONS(1493),
    [sym_kImplementation] = ACTIONS(1493),
    [sym_kInitialization] = ACTIONS(1493),
    [sym_kFinalization] = ACTIONS(1493),
    [sym_kEnd] = ACTIONS(1493),
    [sym_kVar] = ACTIONS(1495),
    [sym_kThreadvar] = ACTIONS(1493),
    [sym_kConst] = ACTIONS(1495),
    [sym_kResourcestring] = ACTIONS(1493),
    [sym_kType] = ACTIONS(1493),
    [sym_kLabel] = ACTIONS(1493),
    [sym_kExports] = ACTIONS(1493),
    [sym_kProperty] = ACTIONS(1493),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1493),
    [sym_kGeneric] = ACTIONS(1493),
    [sym_kFunction] = ACTIONS(1493),
    [sym_kProcedure] = ACTIONS(1493),
    [sym_kConstructor] = ACTIONS(1493),
    [sym_kDestructor] = ACTIONS(1493),
    [sym_kOperator] = ACTIONS(1493),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1493),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1493),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [225] = {
    [sym_if] = STATE(810),
    [sym_ifElse] = STATE(815),
    [sym_while] = STATE(815),
    [sym_repeat] = STATE(815),
    [sym_for] = STATE(815),
    [sym_foreach] = STATE(815),
    [sym_try] = STATE(815),
    [sym_case] = STATE(815),
    [sym_block] = STATE(815),
    [sym_asm] = STATE(815),
    [sym_with] = STATE(815),
    [sym_raise] = STATE(815),
    [sym_statement] = STATE(815),
    [sym_goto] = STATE(815),
    [sym__statement] = STATE(815),
    [sym_assignment] = STATE(2600),
    [sym_varAssignDef] = STATE(1942),
    [sym_varDef] = STATE(2600),
    [sym__expr] = STATE(1364),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(1364),
    [sym_exprUnary] = STATE(1364),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_SEMI] = ACTIONS(185),
    [anon_sym_LBRACK] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(47),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [sym_kBegin] = ACTIONS(1081),
    [sym_kAsm] = ACTIONS(1083),
    [sym_kVar] = ACTIONS(63),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kAdd] = ACTIONS(67),
    [sym_kSub] = ACTIONS(67),
    [sym_kAt] = ACTIONS(69),
    [sym_kNot] = ACTIONS(67),
    [sym_kFor] = ACTIONS(1085),
    [sym_kIf] = ACTIONS(1087),
    [sym_kWhile] = ACTIONS(1089),
    [sym_kRepeat] = ACTIONS(1091),
    [sym_kTry] = ACTIONS(1093),
    [sym_kRaise] = ACTIONS(1095),
    [sym_kCase] = ACTIONS(1097),
    [sym_kWith] = ACTIONS(1099),
    [sym_kGoto] = ACTIONS(1101),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [226] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(730),
    [anon_sym_LBRACK] = ACTIONS(1497),
    [sym_kEnd] = ACTIONS(730),
    [sym_kVar] = ACTIONS(730),
    [sym_kThreadvar] = ACTIONS(730),
    [sym_kConst] = ACTIONS(730),
    [sym_kResourcestring] = ACTIONS(730),
    [sym_kType] = ACTIONS(730),
    [sym_kProperty] = ACTIONS(730),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(730),
    [sym_kGeneric] = ACTIONS(730),
    [sym_kCase] = ACTIONS(730),
    [sym_kFunction] = ACTIONS(730),
    [sym_kProcedure] = ACTIONS(730),
    [sym_kConstructor] = ACTIONS(730),
    [sym_kDestructor] = ACTIONS(730),
    [sym_kOperator] = ACTIONS(730),
    [sym_kPublished] = ACTIONS(730),
    [sym_kPublic] = ACTIONS(1500),
    [sym_kProtected] = ACTIONS(730),
    [sym_kPrivate] = ACTIONS(730),
    [sym_kStrict] = ACTIONS(730),
    [sym_kRequired] = ACTIONS(730),
    [sym_kOptional] = ACTIONS(730),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [227] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(634),
    [anon_sym_LBRACK] = ACTIONS(1503),
    [sym_kEnd] = ACTIONS(634),
    [sym_kVar] = ACTIONS(634),
    [sym_kThreadvar] = ACTIONS(634),
    [sym_kConst] = ACTIONS(634),
    [sym_kResourcestring] = ACTIONS(634),
    [sym_kType] = ACTIONS(634),
    [sym_kProperty] = ACTIONS(634),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(634),
    [sym_kGeneric] = ACTIONS(634),
    [sym_kCase] = ACTIONS(634),
    [sym_kFunction] = ACTIONS(634),
    [sym_kProcedure] = ACTIONS(634),
    [sym_kConstructor] = ACTIONS(634),
    [sym_kDestructor] = ACTIONS(634),
    [sym_kOperator] = ACTIONS(634),
    [sym_kPublished] = ACTIONS(634),
    [sym_kPublic] = ACTIONS(1506),
    [sym_kProtected] = ACTIONS(634),
    [sym_kPrivate] = ACTIONS(634),
    [sym_kStrict] = ACTIONS(634),
    [sym_kRequired] = ACTIONS(634),
    [sym_kOptional] = ACTIONS(634),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [228] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [sym_identifier] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1509),
    [sym_kUses] = ACTIONS(1511),
    [sym_kInterface] = ACTIONS(1511),
    [sym_kImplementation] = ACTIONS(1511),
    [sym_kInitialization] = ACTIONS(1511),
    [sym_kFinalization] = ACTIONS(1511),
    [sym_kBegin] = ACTIONS(1511),
    [sym_kEnd] = ACTIONS(1511),
    [sym_kAsm] = ACTIONS(1511),
    [sym_kVar] = ACTIONS(1511),
    [sym_kThreadvar] = ACTIONS(1511),
    [sym_kConst] = ACTIONS(1511),
    [sym_kResourcestring] = ACTIONS(1511),
    [sym_kType] = ACTIONS(1511),
    [sym_kLabel] = ACTIONS(1511),
    [sym_kExports] = ACTIONS(1511),
    [sym_kProperty] = ACTIONS(1511),
    [sym_kDefault] = ACTIONS(1511),
    [sym_kNodefault] = ACTIONS(1511),
    [sym_kDispId] = ACTIONS(1511),
    [sym_kClass] = ACTIONS(1511),
    [sym_kGeneric] = ACTIONS(1511),
    [sym_kFunction] = ACTIONS(1511),
    [sym_kProcedure] = ACTIONS(1511),
    [sym_kConstructor] = ACTIONS(1511),
    [sym_kDestructor] = ACTIONS(1511),
    [sym_kOperator] = ACTIONS(1511),
    [sym_kPublic] = ACTIONS(1511),
    [sym_kStatic] = ACTIONS(1511),
    [sym_kVirtual] = ACTIONS(1511),
    [sym_kAbstract] = ACTIONS(1511),
    [sym_kDynamic] = ACTIONS(1511),
    [sym_kOverride] = ACTIONS(1511),
    [sym_kOverload] = ACTIONS(1511),
    [sym_kReintroduce] = ACTIONS(1511),
    [sym_kInline] = ACTIONS(1511),
    [sym_kStdcall] = ACTIONS(1511),
    [sym_kCdecl] = ACTIONS(1511),
    [sym_kCppdecl] = ACTIONS(1511),
    [sym_kPascal] = ACTIONS(1511),
    [sym_kRegister] = ACTIONS(1511),
    [sym_kMwpascal] = ACTIONS(1511),
    [sym_kMessage] = ACTIONS(1511),
    [sym_kDeprecated] = ACTIONS(1511),
    [sym_kExperimental] = ACTIONS(1511),
    [sym_kPlatform] = ACTIONS(1511),
    [sym_kUnimplemented] = ACTIONS(1511),
    [sym_kCvar] = ACTIONS(1511),
    [sym_kExport] = ACTIONS(1511),
    [sym_kFar] = ACTIONS(1511),
    [sym_kNear] = ACTIONS(1511),
    [sym_kSafecall] = ACTIONS(1511),
    [sym_kAssembler] = ACTIONS(1511),
    [sym_kNostackframe] = ACTIONS(1511),
    [sym_kInterrupt] = ACTIONS(1511),
    [sym_kNoreturn] = ACTIONS(1511),
    [sym_kIocheck] = ACTIONS(1511),
    [sym_kLocal] = ACTIONS(1511),
    [sym_kHardfloat] = ACTIONS(1511),
    [sym_kSoftfloat] = ACTIONS(1511),
    [sym_kMs_abi_default] = ACTIONS(1511),
    [sym_kMs_abi_cdecl] = ACTIONS(1511),
    [sym_kSaveregisters] = ACTIONS(1511),
    [sym_kSysv_abi_default] = ACTIONS(1511),
    [sym_kSysv_abi_cdecl] = ACTIONS(1511),
    [sym_kVectorcall] = ACTIONS(1511),
    [sym_kVarargs] = ACTIONS(1511),
    [sym_kWinapi] = ACTIONS(1511),
    [sym_kAlias] = ACTIONS(1511),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [229] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(226),
    [sym_identifier] = ACTIONS(641),
    [anon_sym_LBRACK] = ACTIONS(1513),
    [sym_kEnd] = ACTIONS(641),
    [sym_kVar] = ACTIONS(641),
    [sym_kThreadvar] = ACTIONS(641),
    [sym_kConst] = ACTIONS(641),
    [sym_kResourcestring] = ACTIONS(641),
    [sym_kType] = ACTIONS(641),
    [sym_kProperty] = ACTIONS(641),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(641),
    [sym_kGeneric] = ACTIONS(641),
    [sym_kCase] = ACTIONS(641),
    [sym_kFunction] = ACTIONS(641),
    [sym_kProcedure] = ACTIONS(641),
    [sym_kConstructor] = ACTIONS(641),
    [sym_kDestructor] = ACTIONS(641),
    [sym_kOperator] = ACTIONS(641),
    [sym_kPublished] = ACTIONS(641),
    [sym_kPublic] = ACTIONS(1516),
    [sym_kProtected] = ACTIONS(641),
    [sym_kPrivate] = ACTIONS(641),
    [sym_kStrict] = ACTIONS(641),
    [sym_kRequired] = ACTIONS(641),
    [sym_kOptional] = ACTIONS(641),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [230] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(542),
    [anon_sym_LBRACK] = ACTIONS(1519),
    [sym_kEnd] = ACTIONS(542),
    [sym_kVar] = ACTIONS(542),
    [sym_kThreadvar] = ACTIONS(542),
    [sym_kConst] = ACTIONS(542),
    [sym_kResourcestring] = ACTIONS(542),
    [sym_kType] = ACTIONS(542),
    [sym_kProperty] = ACTIONS(542),
    [sym_kDefault] = ACTIONS(547),
    [sym_kNodefault] = ACTIONS(547),
    [sym_kDispId] = ACTIONS(550),
    [sym_kClass] = ACTIONS(542),
    [sym_kGeneric] = ACTIONS(542),
    [sym_kCase] = ACTIONS(542),
    [sym_kFunction] = ACTIONS(542),
    [sym_kProcedure] = ACTIONS(542),
    [sym_kConstructor] = ACTIONS(542),
    [sym_kDestructor] = ACTIONS(542),
    [sym_kOperator] = ACTIONS(542),
    [sym_kPublished] = ACTIONS(542),
    [sym_kPublic] = ACTIONS(553),
    [sym_kProtected] = ACTIONS(542),
    [sym_kPrivate] = ACTIONS(542),
    [sym_kStrict] = ACTIONS(542),
    [sym_kRequired] = ACTIONS(542),
    [sym_kOptional] = ACTIONS(542),
    [sym_kStatic] = ACTIONS(547),
    [sym_kVirtual] = ACTIONS(547),
    [sym_kAbstract] = ACTIONS(547),
    [sym_kDynamic] = ACTIONS(547),
    [sym_kOverride] = ACTIONS(547),
    [sym_kOverload] = ACTIONS(547),
    [sym_kReintroduce] = ACTIONS(547),
    [sym_kInline] = ACTIONS(547),
    [sym_kStdcall] = ACTIONS(547),
    [sym_kCdecl] = ACTIONS(547),
    [sym_kCppdecl] = ACTIONS(547),
    [sym_kPascal] = ACTIONS(547),
    [sym_kRegister] = ACTIONS(547),
    [sym_kMwpascal] = ACTIONS(547),
    [sym_kMessage] = ACTIONS(556),
    [sym_kDeprecated] = ACTIONS(559),
    [sym_kExperimental] = ACTIONS(547),
    [sym_kPlatform] = ACTIONS(547),
    [sym_kUnimplemented] = ACTIONS(547),
    [sym_kCvar] = ACTIONS(547),
    [sym_kExport] = ACTIONS(562),
    [sym_kFar] = ACTIONS(547),
    [sym_kNear] = ACTIONS(547),
    [sym_kSafecall] = ACTIONS(547),
    [sym_kAssembler] = ACTIONS(547),
    [sym_kNostackframe] = ACTIONS(547),
    [sym_kInterrupt] = ACTIONS(547),
    [sym_kNoreturn] = ACTIONS(547),
    [sym_kIocheck] = ACTIONS(547),
    [sym_kLocal] = ACTIONS(547),
    [sym_kHardfloat] = ACTIONS(547),
    [sym_kSoftfloat] = ACTIONS(547),
    [sym_kMs_abi_default] = ACTIONS(547),
    [sym_kMs_abi_cdecl] = ACTIONS(547),
    [sym_kSaveregisters] = ACTIONS(547),
    [sym_kSysv_abi_default] = ACTIONS(547),
    [sym_kSysv_abi_cdecl] = ACTIONS(547),
    [sym_kVectorcall] = ACTIONS(547),
    [sym_kVarargs] = ACTIONS(547),
    [sym_kWinapi] = ACTIONS(547),
    [sym_kAlias] = ACTIONS(565),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [231] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(234),
    [sym_identifier] = ACTIONS(528),
    [anon_sym_LBRACK] = ACTIONS(1522),
    [sym_kEnd] = ACTIONS(528),
    [sym_kVar] = ACTIONS(528),
    [sym_kThreadvar] = ACTIONS(528),
    [sym_kConst] = ACTIONS(528),
    [sym_kResourcestring] = ACTIONS(528),
    [sym_kType] = ACTIONS(528),
    [sym_kProperty] = ACTIONS(528),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(528),
    [sym_kGeneric] = ACTIONS(528),
    [sym_kCase] = ACTIONS(528),
    [sym_kFunction] = ACTIONS(528),
    [sym_kProcedure] = ACTIONS(528),
    [sym_kConstructor] = ACTIONS(528),
    [sym_kDestructor] = ACTIONS(528),
    [sym_kOperator] = ACTIONS(528),
    [sym_kPublished] = ACTIONS(528),
    [sym_kPublic] = ACTIONS(1525),
    [sym_kProtected] = ACTIONS(528),
    [sym_kPrivate] = ACTIONS(528),
    [sym_kStrict] = ACTIONS(528),
    [sym_kRequired] = ACTIONS(528),
    [sym_kOptional] = ACTIONS(528),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [232] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(237),
    [sym_identifier] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(1528),
    [sym_kEnd] = ACTIONS(584),
    [sym_kVar] = ACTIONS(584),
    [sym_kThreadvar] = ACTIONS(584),
    [sym_kConst] = ACTIONS(584),
    [sym_kResourcestring] = ACTIONS(584),
    [sym_kType] = ACTIONS(584),
    [sym_kProperty] = ACTIONS(584),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(584),
    [sym_kGeneric] = ACTIONS(584),
    [sym_kCase] = ACTIONS(584),
    [sym_kFunction] = ACTIONS(584),
    [sym_kProcedure] = ACTIONS(584),
    [sym_kConstructor] = ACTIONS(584),
    [sym_kDestructor] = ACTIONS(584),
    [sym_kOperator] = ACTIONS(584),
    [sym_kPublished] = ACTIONS(584),
    [sym_kPublic] = ACTIONS(1531),
    [sym_kProtected] = ACTIONS(584),
    [sym_kPrivate] = ACTIONS(584),
    [sym_kStrict] = ACTIONS(584),
    [sym_kRequired] = ACTIONS(584),
    [sym_kOptional] = ACTIONS(584),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [233] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(238),
    [sym_identifier] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(1534),
    [sym_kEnd] = ACTIONS(535),
    [sym_kVar] = ACTIONS(535),
    [sym_kThreadvar] = ACTIONS(535),
    [sym_kConst] = ACTIONS(535),
    [sym_kResourcestring] = ACTIONS(535),
    [sym_kType] = ACTIONS(535),
    [sym_kProperty] = ACTIONS(535),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(535),
    [sym_kGeneric] = ACTIONS(535),
    [sym_kCase] = ACTIONS(535),
    [sym_kFunction] = ACTIONS(535),
    [sym_kProcedure] = ACTIONS(535),
    [sym_kConstructor] = ACTIONS(535),
    [sym_kDestructor] = ACTIONS(535),
    [sym_kOperator] = ACTIONS(535),
    [sym_kPublished] = ACTIONS(535),
    [sym_kPublic] = ACTIONS(1537),
    [sym_kProtected] = ACTIONS(535),
    [sym_kPrivate] = ACTIONS(535),
    [sym_kStrict] = ACTIONS(535),
    [sym_kRequired] = ACTIONS(535),
    [sym_kOptional] = ACTIONS(535),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [234] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LBRACK] = ACTIONS(1540),
    [sym_kEnd] = ACTIONS(570),
    [sym_kVar] = ACTIONS(570),
    [sym_kThreadvar] = ACTIONS(570),
    [sym_kConst] = ACTIONS(570),
    [sym_kResourcestring] = ACTIONS(570),
    [sym_kType] = ACTIONS(570),
    [sym_kProperty] = ACTIONS(570),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(570),
    [sym_kGeneric] = ACTIONS(570),
    [sym_kCase] = ACTIONS(570),
    [sym_kFunction] = ACTIONS(570),
    [sym_kProcedure] = ACTIONS(570),
    [sym_kConstructor] = ACTIONS(570),
    [sym_kDestructor] = ACTIONS(570),
    [sym_kOperator] = ACTIONS(570),
    [sym_kPublished] = ACTIONS(570),
    [sym_kPublic] = ACTIONS(1543),
    [sym_kProtected] = ACTIONS(570),
    [sym_kPrivate] = ACTIONS(570),
    [sym_kStrict] = ACTIONS(570),
    [sym_kRequired] = ACTIONS(570),
    [sym_kOptional] = ACTIONS(570),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [235] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(241),
    [sym_identifier] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(1546),
    [sym_kEnd] = ACTIONS(577),
    [sym_kVar] = ACTIONS(577),
    [sym_kThreadvar] = ACTIONS(577),
    [sym_kConst] = ACTIONS(577),
    [sym_kResourcestring] = ACTIONS(577),
    [sym_kType] = ACTIONS(577),
    [sym_kProperty] = ACTIONS(577),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(577),
    [sym_kGeneric] = ACTIONS(577),
    [sym_kCase] = ACTIONS(577),
    [sym_kFunction] = ACTIONS(577),
    [sym_kProcedure] = ACTIONS(577),
    [sym_kConstructor] = ACTIONS(577),
    [sym_kDestructor] = ACTIONS(577),
    [sym_kOperator] = ACTIONS(577),
    [sym_kPublished] = ACTIONS(577),
    [sym_kPublic] = ACTIONS(1549),
    [sym_kProtected] = ACTIONS(577),
    [sym_kPrivate] = ACTIONS(577),
    [sym_kStrict] = ACTIONS(577),
    [sym_kRequired] = ACTIONS(577),
    [sym_kOptional] = ACTIONS(577),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [236] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(242),
    [sym_identifier] = ACTIONS(807),
    [anon_sym_LBRACK] = ACTIONS(1552),
    [sym_kEnd] = ACTIONS(807),
    [sym_kVar] = ACTIONS(807),
    [sym_kThreadvar] = ACTIONS(807),
    [sym_kConst] = ACTIONS(807),
    [sym_kResourcestring] = ACTIONS(807),
    [sym_kType] = ACTIONS(807),
    [sym_kProperty] = ACTIONS(807),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(807),
    [sym_kGeneric] = ACTIONS(807),
    [sym_kCase] = ACTIONS(807),
    [sym_kFunction] = ACTIONS(807),
    [sym_kProcedure] = ACTIONS(807),
    [sym_kConstructor] = ACTIONS(807),
    [sym_kDestructor] = ACTIONS(807),
    [sym_kOperator] = ACTIONS(807),
    [sym_kPublished] = ACTIONS(807),
    [sym_kPublic] = ACTIONS(1555),
    [sym_kProtected] = ACTIONS(807),
    [sym_kPrivate] = ACTIONS(807),
    [sym_kStrict] = ACTIONS(807),
    [sym_kRequired] = ACTIONS(807),
    [sym_kOptional] = ACTIONS(807),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [237] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(1558),
    [sym_kEnd] = ACTIONS(591),
    [sym_kVar] = ACTIONS(591),
    [sym_kThreadvar] = ACTIONS(591),
    [sym_kConst] = ACTIONS(591),
    [sym_kResourcestring] = ACTIONS(591),
    [sym_kType] = ACTIONS(591),
    [sym_kProperty] = ACTIONS(591),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(591),
    [sym_kGeneric] = ACTIONS(591),
    [sym_kCase] = ACTIONS(591),
    [sym_kFunction] = ACTIONS(591),
    [sym_kProcedure] = ACTIONS(591),
    [sym_kConstructor] = ACTIONS(591),
    [sym_kDestructor] = ACTIONS(591),
    [sym_kOperator] = ACTIONS(591),
    [sym_kPublished] = ACTIONS(591),
    [sym_kPublic] = ACTIONS(1561),
    [sym_kProtected] = ACTIONS(591),
    [sym_kPrivate] = ACTIONS(591),
    [sym_kStrict] = ACTIONS(591),
    [sym_kRequired] = ACTIONS(591),
    [sym_kOptional] = ACTIONS(591),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [238] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(761),
    [anon_sym_LBRACK] = ACTIONS(1564),
    [sym_kEnd] = ACTIONS(761),
    [sym_kVar] = ACTIONS(761),
    [sym_kThreadvar] = ACTIONS(761),
    [sym_kConst] = ACTIONS(761),
    [sym_kResourcestring] = ACTIONS(761),
    [sym_kType] = ACTIONS(761),
    [sym_kProperty] = ACTIONS(761),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(761),
    [sym_kGeneric] = ACTIONS(761),
    [sym_kCase] = ACTIONS(761),
    [sym_kFunction] = ACTIONS(761),
    [sym_kProcedure] = ACTIONS(761),
    [sym_kConstructor] = ACTIONS(761),
    [sym_kDestructor] = ACTIONS(761),
    [sym_kOperator] = ACTIONS(761),
    [sym_kPublished] = ACTIONS(761),
    [sym_kPublic] = ACTIONS(1567),
    [sym_kProtected] = ACTIONS(761),
    [sym_kPrivate] = ACTIONS(761),
    [sym_kStrict] = ACTIONS(761),
    [sym_kRequired] = ACTIONS(761),
    [sym_kOptional] = ACTIONS(761),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [239] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(244),
    [sym_identifier] = ACTIONS(768),
    [anon_sym_LBRACK] = ACTIONS(1570),
    [sym_kEnd] = ACTIONS(768),
    [sym_kVar] = ACTIONS(768),
    [sym_kThreadvar] = ACTIONS(768),
    [sym_kConst] = ACTIONS(768),
    [sym_kResourcestring] = ACTIONS(768),
    [sym_kType] = ACTIONS(768),
    [sym_kProperty] = ACTIONS(768),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(768),
    [sym_kGeneric] = ACTIONS(768),
    [sym_kCase] = ACTIONS(768),
    [sym_kFunction] = ACTIONS(768),
    [sym_kProcedure] = ACTIONS(768),
    [sym_kConstructor] = ACTIONS(768),
    [sym_kDestructor] = ACTIONS(768),
    [sym_kOperator] = ACTIONS(768),
    [sym_kPublished] = ACTIONS(768),
    [sym_kPublic] = ACTIONS(1573),
    [sym_kProtected] = ACTIONS(768),
    [sym_kPrivate] = ACTIONS(768),
    [sym_kStrict] = ACTIONS(768),
    [sym_kRequired] = ACTIONS(768),
    [sym_kOptional] = ACTIONS(768),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [240] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(245),
    [sym_identifier] = ACTIONS(775),
    [anon_sym_LBRACK] = ACTIONS(1576),
    [sym_kEnd] = ACTIONS(775),
    [sym_kVar] = ACTIONS(775),
    [sym_kThreadvar] = ACTIONS(775),
    [sym_kConst] = ACTIONS(775),
    [sym_kResourcestring] = ACTIONS(775),
    [sym_kType] = ACTIONS(775),
    [sym_kProperty] = ACTIONS(775),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(775),
    [sym_kGeneric] = ACTIONS(775),
    [sym_kCase] = ACTIONS(775),
    [sym_kFunction] = ACTIONS(775),
    [sym_kProcedure] = ACTIONS(775),
    [sym_kConstructor] = ACTIONS(775),
    [sym_kDestructor] = ACTIONS(775),
    [sym_kOperator] = ACTIONS(775),
    [sym_kPublished] = ACTIONS(775),
    [sym_kPublic] = ACTIONS(1579),
    [sym_kProtected] = ACTIONS(775),
    [sym_kPrivate] = ACTIONS(775),
    [sym_kStrict] = ACTIONS(775),
    [sym_kRequired] = ACTIONS(775),
    [sym_kOptional] = ACTIONS(775),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [241] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(782),
    [anon_sym_LBRACK] = ACTIONS(1582),
    [sym_kEnd] = ACTIONS(782),
    [sym_kVar] = ACTIONS(782),
    [sym_kThreadvar] = ACTIONS(782),
    [sym_kConst] = ACTIONS(782),
    [sym_kResourcestring] = ACTIONS(782),
    [sym_kType] = ACTIONS(782),
    [sym_kProperty] = ACTIONS(782),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(782),
    [sym_kGeneric] = ACTIONS(782),
    [sym_kCase] = ACTIONS(782),
    [sym_kFunction] = ACTIONS(782),
    [sym_kProcedure] = ACTIONS(782),
    [sym_kConstructor] = ACTIONS(782),
    [sym_kDestructor] = ACTIONS(782),
    [sym_kOperator] = ACTIONS(782),
    [sym_kPublished] = ACTIONS(782),
    [sym_kPublic] = ACTIONS(1585),
    [sym_kProtected] = ACTIONS(782),
    [sym_kPrivate] = ACTIONS(782),
    [sym_kStrict] = ACTIONS(782),
    [sym_kRequired] = ACTIONS(782),
    [sym_kOptional] = ACTIONS(782),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [242] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(1588),
    [sym_kEnd] = ACTIONS(789),
    [sym_kVar] = ACTIONS(789),
    [sym_kThreadvar] = ACTIONS(789),
    [sym_kConst] = ACTIONS(789),
    [sym_kResourcestring] = ACTIONS(789),
    [sym_kType] = ACTIONS(789),
    [sym_kProperty] = ACTIONS(789),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(789),
    [sym_kGeneric] = ACTIONS(789),
    [sym_kCase] = ACTIONS(789),
    [sym_kFunction] = ACTIONS(789),
    [sym_kProcedure] = ACTIONS(789),
    [sym_kConstructor] = ACTIONS(789),
    [sym_kDestructor] = ACTIONS(789),
    [sym_kOperator] = ACTIONS(789),
    [sym_kPublished] = ACTIONS(789),
    [sym_kPublic] = ACTIONS(1591),
    [sym_kProtected] = ACTIONS(789),
    [sym_kPrivate] = ACTIONS(789),
    [sym_kStrict] = ACTIONS(789),
    [sym_kRequired] = ACTIONS(789),
    [sym_kOptional] = ACTIONS(789),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [243] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(247),
    [sym_identifier] = ACTIONS(796),
    [anon_sym_LBRACK] = ACTIONS(1594),
    [sym_kEnd] = ACTIONS(796),
    [sym_kVar] = ACTIONS(796),
    [sym_kThreadvar] = ACTIONS(796),
    [sym_kConst] = ACTIONS(796),
    [sym_kResourcestring] = ACTIONS(796),
    [sym_kType] = ACTIONS(796),
    [sym_kProperty] = ACTIONS(796),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(796),
    [sym_kGeneric] = ACTIONS(796),
    [sym_kCase] = ACTIONS(796),
    [sym_kFunction] = ACTIONS(796),
    [sym_kProcedure] = ACTIONS(796),
    [sym_kConstructor] = ACTIONS(796),
    [sym_kDestructor] = ACTIONS(796),
    [sym_kOperator] = ACTIONS(796),
    [sym_kPublished] = ACTIONS(796),
    [sym_kPublic] = ACTIONS(1597),
    [sym_kProtected] = ACTIONS(796),
    [sym_kPrivate] = ACTIONS(796),
    [sym_kStrict] = ACTIONS(796),
    [sym_kRequired] = ACTIONS(796),
    [sym_kOptional] = ACTIONS(796),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [244] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(1600),
    [sym_kEnd] = ACTIONS(602),
    [sym_kVar] = ACTIONS(602),
    [sym_kThreadvar] = ACTIONS(602),
    [sym_kConst] = ACTIONS(602),
    [sym_kResourcestring] = ACTIONS(602),
    [sym_kType] = ACTIONS(602),
    [sym_kProperty] = ACTIONS(602),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(602),
    [sym_kGeneric] = ACTIONS(602),
    [sym_kCase] = ACTIONS(602),
    [sym_kFunction] = ACTIONS(602),
    [sym_kProcedure] = ACTIONS(602),
    [sym_kConstructor] = ACTIONS(602),
    [sym_kDestructor] = ACTIONS(602),
    [sym_kOperator] = ACTIONS(602),
    [sym_kPublished] = ACTIONS(602),
    [sym_kPublic] = ACTIONS(1603),
    [sym_kProtected] = ACTIONS(602),
    [sym_kPrivate] = ACTIONS(602),
    [sym_kStrict] = ACTIONS(602),
    [sym_kRequired] = ACTIONS(602),
    [sym_kOptional] = ACTIONS(602),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [245] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_LBRACK] = ACTIONS(1606),
    [sym_kEnd] = ACTIONS(609),
    [sym_kVar] = ACTIONS(609),
    [sym_kThreadvar] = ACTIONS(609),
    [sym_kConst] = ACTIONS(609),
    [sym_kResourcestring] = ACTIONS(609),
    [sym_kType] = ACTIONS(609),
    [sym_kProperty] = ACTIONS(609),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(609),
    [sym_kGeneric] = ACTIONS(609),
    [sym_kCase] = ACTIONS(609),
    [sym_kFunction] = ACTIONS(609),
    [sym_kProcedure] = ACTIONS(609),
    [sym_kConstructor] = ACTIONS(609),
    [sym_kDestructor] = ACTIONS(609),
    [sym_kOperator] = ACTIONS(609),
    [sym_kPublished] = ACTIONS(609),
    [sym_kPublic] = ACTIONS(1609),
    [sym_kProtected] = ACTIONS(609),
    [sym_kPrivate] = ACTIONS(609),
    [sym_kStrict] = ACTIONS(609),
    [sym_kRequired] = ACTIONS(609),
    [sym_kOptional] = ACTIONS(609),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [246] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(227),
    [sym_identifier] = ACTIONS(616),
    [anon_sym_LBRACK] = ACTIONS(1612),
    [sym_kEnd] = ACTIONS(616),
    [sym_kVar] = ACTIONS(616),
    [sym_kThreadvar] = ACTIONS(616),
    [sym_kConst] = ACTIONS(616),
    [sym_kResourcestring] = ACTIONS(616),
    [sym_kType] = ACTIONS(616),
    [sym_kProperty] = ACTIONS(616),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(616),
    [sym_kGeneric] = ACTIONS(616),
    [sym_kCase] = ACTIONS(616),
    [sym_kFunction] = ACTIONS(616),
    [sym_kProcedure] = ACTIONS(616),
    [sym_kConstructor] = ACTIONS(616),
    [sym_kDestructor] = ACTIONS(616),
    [sym_kOperator] = ACTIONS(616),
    [sym_kPublished] = ACTIONS(616),
    [sym_kPublic] = ACTIONS(1615),
    [sym_kProtected] = ACTIONS(616),
    [sym_kPrivate] = ACTIONS(616),
    [sym_kStrict] = ACTIONS(616),
    [sym_kRequired] = ACTIONS(616),
    [sym_kOptional] = ACTIONS(616),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [247] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(1618),
    [sym_kEnd] = ACTIONS(623),
    [sym_kVar] = ACTIONS(623),
    [sym_kThreadvar] = ACTIONS(623),
    [sym_kConst] = ACTIONS(623),
    [sym_kResourcestring] = ACTIONS(623),
    [sym_kType] = ACTIONS(623),
    [sym_kProperty] = ACTIONS(623),
    [sym_kDefault] = ACTIONS(318),
    [sym_kNodefault] = ACTIONS(318),
    [sym_kDispId] = ACTIONS(320),
    [sym_kClass] = ACTIONS(623),
    [sym_kGeneric] = ACTIONS(623),
    [sym_kCase] = ACTIONS(623),
    [sym_kFunction] = ACTIONS(623),
    [sym_kProcedure] = ACTIONS(623),
    [sym_kConstructor] = ACTIONS(623),
    [sym_kDestructor] = ACTIONS(623),
    [sym_kOperator] = ACTIONS(623),
    [sym_kPublished] = ACTIONS(623),
    [sym_kPublic] = ACTIONS(1621),
    [sym_kProtected] = ACTIONS(623),
    [sym_kPrivate] = ACTIONS(623),
    [sym_kStrict] = ACTIONS(623),
    [sym_kRequired] = ACTIONS(623),
    [sym_kOptional] = ACTIONS(623),
    [sym_kStatic] = ACTIONS(318),
    [sym_kVirtual] = ACTIONS(318),
    [sym_kAbstract] = ACTIONS(318),
    [sym_kDynamic] = ACTIONS(318),
    [sym_kOverride] = ACTIONS(318),
    [sym_kOverload] = ACTIONS(318),
    [sym_kReintroduce] = ACTIONS(318),
    [sym_kInline] = ACTIONS(318),
    [sym_kStdcall] = ACTIONS(318),
    [sym_kCdecl] = ACTIONS(318),
    [sym_kCppdecl] = ACTIONS(318),
    [sym_kPascal] = ACTIONS(318),
    [sym_kRegister] = ACTIONS(318),
    [sym_kMwpascal] = ACTIONS(318),
    [sym_kMessage] = ACTIONS(326),
    [sym_kDeprecated] = ACTIONS(328),
    [sym_kExperimental] = ACTIONS(318),
    [sym_kPlatform] = ACTIONS(318),
    [sym_kUnimplemented] = ACTIONS(318),
    [sym_kCvar] = ACTIONS(318),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(318),
    [sym_kNear] = ACTIONS(318),
    [sym_kSafecall] = ACTIONS(318),
    [sym_kAssembler] = ACTIONS(318),
    [sym_kNostackframe] = ACTIONS(318),
    [sym_kInterrupt] = ACTIONS(318),
    [sym_kNoreturn] = ACTIONS(318),
    [sym_kIocheck] = ACTIONS(318),
    [sym_kLocal] = ACTIONS(318),
    [sym_kHardfloat] = ACTIONS(318),
    [sym_kSoftfloat] = ACTIONS(318),
    [sym_kMs_abi_default] = ACTIONS(318),
    [sym_kMs_abi_cdecl] = ACTIONS(318),
    [sym_kSaveregisters] = ACTIONS(318),
    [sym_kSysv_abi_default] = ACTIONS(318),
    [sym_kSysv_abi_cdecl] = ACTIONS(318),
    [sym_kVectorcall] = ACTIONS(318),
    [sym_kVarargs] = ACTIONS(318),
    [sym_kWinapi] = ACTIONS(318),
    [sym_kAlias] = ACTIONS(332),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [248] = {
    [sym__literalString] = STATE(248),
    [sym_literalChar] = STATE(248),
    [aux_sym_literalString_repeat1] = STATE(248),
    [sym_identifier] = ACTIONS(1624),
    [anon_sym_SEMI] = ACTIONS(1626),
    [anon_sym_COLON] = ACTIONS(1624),
    [anon_sym_COMMA] = ACTIONS(1626),
    [anon_sym_LBRACK] = ACTIONS(1626),
    [anon_sym_RBRACK] = ACTIONS(1626),
    [anon_sym_LPAREN] = ACTIONS(1624),
    [anon_sym_RPAREN] = ACTIONS(1626),
    [aux_sym__literalString_token1] = ACTIONS(1628),
    [anon_sym_POUND] = ACTIONS(1631),
    [anon_sym_DOT] = ACTIONS(1626),
    [sym_kEnd] = ACTIONS(1624),
    [sym_kVar] = ACTIONS(1624),
    [sym_kThreadvar] = ACTIONS(1624),
    [sym_kConst] = ACTIONS(1624),
    [sym_kResourcestring] = ACTIONS(1624),
    [sym_kType] = ACTIONS(1624),
    [sym_kAbsolute] = ACTIONS(1624),
    [sym_kProperty] = ACTIONS(1624),
    [sym_kClass] = ACTIONS(1624),
    [sym_kOf] = ACTIONS(1624),
    [sym_kGeneric] = ACTIONS(1624),
    [sym_kLt] = ACTIONS(1624),
    [sym_kEq] = ACTIONS(1626),
    [sym_kNeq] = ACTIONS(1626),
    [sym_kGt] = ACTIONS(1624),
    [sym_kLte] = ACTIONS(1626),
    [sym_kGte] = ACTIONS(1626),
    [sym_kAdd] = ACTIONS(1624),
    [sym_kSub] = ACTIONS(1624),
    [sym_kMul] = ACTIONS(1624),
    [sym_kFdiv] = ACTIONS(1624),
    [sym_kHat] = ACTIONS(1626),
    [sym_kAssign] = ACTIONS(1626),
    [sym_kAssignAdd] = ACTIONS(1626),
    [sym_kAssignSub] = ACTIONS(1626),
    [sym_kAssignMul] = ACTIONS(1626),
    [sym_kAssignDiv] = ACTIONS(1626),
    [sym_kOr] = ACTIONS(1624),
    [sym_kXor] = ACTIONS(1624),
    [sym_kDiv] = ACTIONS(1624),
    [sym_kMod] = ACTIONS(1624),
    [sym_kAnd] = ACTIONS(1624),
    [sym_kShl] = ACTIONS(1624),
    [sym_kShr] = ACTIONS(1624),
    [sym_kIs] = ACTIONS(1624),
    [sym_kAs] = ACTIONS(1624),
    [sym_kIn] = ACTIONS(1624),
    [sym_kThen] = ACTIONS(1624),
    [sym_kElse] = ACTIONS(1624),
    [sym_kDo] = ACTIONS(1624),
    [sym_kUntil] = ACTIONS(1624),
    [sym_kExcept] = ACTIONS(1624),
    [sym_kFinally] = ACTIONS(1624),
    [sym_kCase] = ACTIONS(1624),
    [sym_kFunction] = ACTIONS(1624),
    [sym_kProcedure] = ACTIONS(1624),
    [sym_kConstructor] = ACTIONS(1624),
    [sym_kDestructor] = ACTIONS(1624),
    [sym_kOperator] = ACTIONS(1624),
    [sym_kPublished] = ACTIONS(1624),
    [sym_kPublic] = ACTIONS(1624),
    [sym_kProtected] = ACTIONS(1624),
    [sym_kPrivate] = ACTIONS(1624),
    [sym_kStrict] = ACTIONS(1624),
    [sym_kRequired] = ACTIONS(1624),
    [sym_kOptional] = ACTIONS(1624),
    [sym_kDelayed] = ACTIONS(1624),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [249] = {
    [sym__literalString] = STATE(248),
    [sym_literalChar] = STATE(248),
    [aux_sym_literalString_repeat1] = STATE(248),
    [sym_identifier] = ACTIONS(1634),
    [anon_sym_SEMI] = ACTIONS(1636),
    [anon_sym_COLON] = ACTIONS(1634),
    [anon_sym_COMMA] = ACTIONS(1636),
    [anon_sym_LBRACK] = ACTIONS(1636),
    [anon_sym_RBRACK] = ACTIONS(1636),
    [anon_sym_LPAREN] = ACTIONS(1634),
    [anon_sym_RPAREN] = ACTIONS(1636),
    [aux_sym__literalString_token1] = ACTIONS(1638),
    [anon_sym_POUND] = ACTIONS(51),
    [anon_sym_DOT] = ACTIONS(1636),
    [sym_kEnd] = ACTIONS(1634),
    [sym_kVar] = ACTIONS(1634),
    [sym_kThreadvar] = ACTIONS(1634),
    [sym_kConst] = ACTIONS(1634),
    [sym_kResourcestring] = ACTIONS(1634),
    [sym_kType] = ACTIONS(1634),
    [sym_kAbsolute] = ACTIONS(1634),
    [sym_kProperty] = ACTIONS(1634),
    [sym_kClass] = ACTIONS(1634),
    [sym_kOf] = ACTIONS(1634),
    [sym_kGeneric] = ACTIONS(1634),
    [sym_kLt] = ACTIONS(1634),
    [sym_kEq] = ACTIONS(1636),
    [sym_kNeq] = ACTIONS(1636),
    [sym_kGt] = ACTIONS(1634),
    [sym_kLte] = ACTIONS(1636),
    [sym_kGte] = ACTIONS(1636),
    [sym_kAdd] = ACTIONS(1634),
    [sym_kSub] = ACTIONS(1634),
    [sym_kMul] = ACTIONS(1634),
    [sym_kFdiv] = ACTIONS(1634),
    [sym_kHat] = ACTIONS(1636),
    [sym_kAssign] = ACTIONS(1636),
    [sym_kAssignAdd] = ACTIONS(1636),
    [sym_kAssignSub] = ACTIONS(1636),
    [sym_kAssignMul] = ACTIONS(1636),
    [sym_kAssignDiv] = ACTIONS(1636),
    [sym_kOr] = ACTIONS(1634),
    [sym_kXor] = ACTIONS(1634),
    [sym_kDiv] = ACTIONS(1634),
    [sym_kMod] = ACTIONS(1634),
    [sym_kAnd] = ACTIONS(1634),
    [sym_kShl] = ACTIONS(1634),
    [sym_kShr] = ACTIONS(1634),
    [sym_kIs] = ACTIONS(1634),
    [sym_kAs] = ACTIONS(1634),
    [sym_kIn] = ACTIONS(1634),
    [sym_kThen] = ACTIONS(1634),
    [sym_kElse] = ACTIONS(1634),
    [sym_kDo] = ACTIONS(1634),
    [sym_kUntil] = ACTIONS(1634),
    [sym_kExcept] = ACTIONS(1634),
    [sym_kFinally] = ACTIONS(1634),
    [sym_kCase] = ACTIONS(1634),
    [sym_kFunction] = ACTIONS(1634),
    [sym_kProcedure] = ACTIONS(1634),
    [sym_kConstructor] = ACTIONS(1634),
    [sym_kDestructor] = ACTIONS(1634),
    [sym_kOperator] = ACTIONS(1634),
    [sym_kPublished] = ACTIONS(1634),
    [sym_kPublic] = ACTIONS(1634),
    [sym_kProtected] = ACTIONS(1634),
    [sym_kPrivate] = ACTIONS(1634),
    [sym_kStrict] = ACTIONS(1634),
    [sym_kRequired] = ACTIONS(1634),
    [sym_kOptional] = ACTIONS(1634),
    [sym_kDelayed] = ACTIONS(1634),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [250] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(304),
    [anon_sym_LBRACK] = ACTIONS(1640),
    [sym_kUses] = ACTIONS(1643),
    [sym_kInterface] = ACTIONS(1643),
    [sym_kImplementation] = ACTIONS(1643),
    [sym_kInitialization] = ACTIONS(1643),
    [sym_kFinalization] = ACTIONS(1643),
    [sym_kEnd] = ACTIONS(1643),
    [sym_kVar] = ACTIONS(1645),
    [sym_kThreadvar] = ACTIONS(1643),
    [sym_kConst] = ACTIONS(1645),
    [sym_kResourcestring] = ACTIONS(1643),
    [sym_kType] = ACTIONS(1643),
    [sym_kLabel] = ACTIONS(1643),
    [sym_kExports] = ACTIONS(1643),
    [sym_kProperty] = ACTIONS(1643),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1643),
    [sym_kGeneric] = ACTIONS(1643),
    [sym_kFunction] = ACTIONS(1643),
    [sym_kProcedure] = ACTIONS(1643),
    [sym_kConstructor] = ACTIONS(1643),
    [sym_kDestructor] = ACTIONS(1643),
    [sym_kOperator] = ACTIONS(1643),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [251] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(254),
    [anon_sym_LBRACK] = ACTIONS(1647),
    [sym_kUses] = ACTIONS(1650),
    [sym_kInterface] = ACTIONS(1650),
    [sym_kImplementation] = ACTIONS(1650),
    [sym_kInitialization] = ACTIONS(1650),
    [sym_kFinalization] = ACTIONS(1650),
    [sym_kEnd] = ACTIONS(1650),
    [sym_kVar] = ACTIONS(1652),
    [sym_kThreadvar] = ACTIONS(1650),
    [sym_kConst] = ACTIONS(1652),
    [sym_kResourcestring] = ACTIONS(1650),
    [sym_kType] = ACTIONS(1650),
    [sym_kLabel] = ACTIONS(1650),
    [sym_kExports] = ACTIONS(1650),
    [sym_kProperty] = ACTIONS(1650),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1650),
    [sym_kGeneric] = ACTIONS(1650),
    [sym_kFunction] = ACTIONS(1650),
    [sym_kProcedure] = ACTIONS(1650),
    [sym_kConstructor] = ACTIONS(1650),
    [sym_kDestructor] = ACTIONS(1650),
    [sym_kOperator] = ACTIONS(1650),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [252] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(255),
    [anon_sym_LBRACK] = ACTIONS(1654),
    [sym_kUses] = ACTIONS(1657),
    [sym_kInterface] = ACTIONS(1657),
    [sym_kImplementation] = ACTIONS(1657),
    [sym_kInitialization] = ACTIONS(1657),
    [sym_kFinalization] = ACTIONS(1657),
    [sym_kEnd] = ACTIONS(1657),
    [sym_kVar] = ACTIONS(1659),
    [sym_kThreadvar] = ACTIONS(1657),
    [sym_kConst] = ACTIONS(1659),
    [sym_kResourcestring] = ACTIONS(1657),
    [sym_kType] = ACTIONS(1657),
    [sym_kLabel] = ACTIONS(1657),
    [sym_kExports] = ACTIONS(1657),
    [sym_kProperty] = ACTIONS(1657),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1657),
    [sym_kGeneric] = ACTIONS(1657),
    [sym_kFunction] = ACTIONS(1657),
    [sym_kProcedure] = ACTIONS(1657),
    [sym_kConstructor] = ACTIONS(1657),
    [sym_kDestructor] = ACTIONS(1657),
    [sym_kOperator] = ACTIONS(1657),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [253] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1661),
    [sym_kUses] = ACTIONS(1664),
    [sym_kInterface] = ACTIONS(1664),
    [sym_kImplementation] = ACTIONS(1664),
    [sym_kInitialization] = ACTIONS(1664),
    [sym_kFinalization] = ACTIONS(1664),
    [sym_kEnd] = ACTIONS(1664),
    [sym_kVar] = ACTIONS(1666),
    [sym_kThreadvar] = ACTIONS(1664),
    [sym_kConst] = ACTIONS(1666),
    [sym_kResourcestring] = ACTIONS(1664),
    [sym_kType] = ACTIONS(1664),
    [sym_kLabel] = ACTIONS(1664),
    [sym_kExports] = ACTIONS(1664),
    [sym_kProperty] = ACTIONS(1664),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1664),
    [sym_kGeneric] = ACTIONS(1664),
    [sym_kFunction] = ACTIONS(1664),
    [sym_kProcedure] = ACTIONS(1664),
    [sym_kConstructor] = ACTIONS(1664),
    [sym_kDestructor] = ACTIONS(1664),
    [sym_kOperator] = ACTIONS(1664),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [254] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1668),
    [sym_kUses] = ACTIONS(1671),
    [sym_kInterface] = ACTIONS(1671),
    [sym_kImplementation] = ACTIONS(1671),
    [sym_kInitialization] = ACTIONS(1671),
    [sym_kFinalization] = ACTIONS(1671),
    [sym_kEnd] = ACTIONS(1671),
    [sym_kVar] = ACTIONS(1673),
    [sym_kThreadvar] = ACTIONS(1671),
    [sym_kConst] = ACTIONS(1673),
    [sym_kResourcestring] = ACTIONS(1671),
    [sym_kType] = ACTIONS(1671),
    [sym_kLabel] = ACTIONS(1671),
    [sym_kExports] = ACTIONS(1671),
    [sym_kProperty] = ACTIONS(1671),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1671),
    [sym_kGeneric] = ACTIONS(1671),
    [sym_kFunction] = ACTIONS(1671),
    [sym_kProcedure] = ACTIONS(1671),
    [sym_kConstructor] = ACTIONS(1671),
    [sym_kDestructor] = ACTIONS(1671),
    [sym_kOperator] = ACTIONS(1671),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [255] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1675),
    [sym_kUses] = ACTIONS(1678),
    [sym_kInterface] = ACTIONS(1678),
    [sym_kImplementation] = ACTIONS(1678),
    [sym_kInitialization] = ACTIONS(1678),
    [sym_kFinalization] = ACTIONS(1678),
    [sym_kEnd] = ACTIONS(1678),
    [sym_kVar] = ACTIONS(1680),
    [sym_kThreadvar] = ACTIONS(1678),
    [sym_kConst] = ACTIONS(1680),
    [sym_kResourcestring] = ACTIONS(1678),
    [sym_kType] = ACTIONS(1678),
    [sym_kLabel] = ACTIONS(1678),
    [sym_kExports] = ACTIONS(1678),
    [sym_kProperty] = ACTIONS(1678),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1678),
    [sym_kGeneric] = ACTIONS(1678),
    [sym_kFunction] = ACTIONS(1678),
    [sym_kProcedure] = ACTIONS(1678),
    [sym_kConstructor] = ACTIONS(1678),
    [sym_kDestructor] = ACTIONS(1678),
    [sym_kOperator] = ACTIONS(1678),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [256] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(257),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [sym_kUses] = ACTIONS(1685),
    [sym_kInterface] = ACTIONS(1685),
    [sym_kImplementation] = ACTIONS(1685),
    [sym_kInitialization] = ACTIONS(1685),
    [sym_kFinalization] = ACTIONS(1685),
    [sym_kEnd] = ACTIONS(1685),
    [sym_kVar] = ACTIONS(1687),
    [sym_kThreadvar] = ACTIONS(1685),
    [sym_kConst] = ACTIONS(1687),
    [sym_kResourcestring] = ACTIONS(1685),
    [sym_kType] = ACTIONS(1685),
    [sym_kLabel] = ACTIONS(1685),
    [sym_kExports] = ACTIONS(1685),
    [sym_kProperty] = ACTIONS(1685),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1685),
    [sym_kGeneric] = ACTIONS(1685),
    [sym_kFunction] = ACTIONS(1685),
    [sym_kProcedure] = ACTIONS(1685),
    [sym_kConstructor] = ACTIONS(1685),
    [sym_kDestructor] = ACTIONS(1685),
    [sym_kOperator] = ACTIONS(1685),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [257] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1689),
    [sym_kUses] = ACTIONS(1692),
    [sym_kInterface] = ACTIONS(1692),
    [sym_kImplementation] = ACTIONS(1692),
    [sym_kInitialization] = ACTIONS(1692),
    [sym_kFinalization] = ACTIONS(1692),
    [sym_kEnd] = ACTIONS(1692),
    [sym_kVar] = ACTIONS(1694),
    [sym_kThreadvar] = ACTIONS(1692),
    [sym_kConst] = ACTIONS(1694),
    [sym_kResourcestring] = ACTIONS(1692),
    [sym_kType] = ACTIONS(1692),
    [sym_kLabel] = ACTIONS(1692),
    [sym_kExports] = ACTIONS(1692),
    [sym_kProperty] = ACTIONS(1692),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1692),
    [sym_kGeneric] = ACTIONS(1692),
    [sym_kFunction] = ACTIONS(1692),
    [sym_kProcedure] = ACTIONS(1692),
    [sym_kConstructor] = ACTIONS(1692),
    [sym_kDestructor] = ACTIONS(1692),
    [sym_kOperator] = ACTIONS(1692),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [258] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(264),
    [anon_sym_LBRACK] = ACTIONS(1696),
    [sym_kUses] = ACTIONS(1699),
    [sym_kInterface] = ACTIONS(1699),
    [sym_kImplementation] = ACTIONS(1699),
    [sym_kInitialization] = ACTIONS(1699),
    [sym_kFinalization] = ACTIONS(1699),
    [sym_kEnd] = ACTIONS(1699),
    [sym_kVar] = ACTIONS(1701),
    [sym_kThreadvar] = ACTIONS(1699),
    [sym_kConst] = ACTIONS(1701),
    [sym_kResourcestring] = ACTIONS(1699),
    [sym_kType] = ACTIONS(1699),
    [sym_kLabel] = ACTIONS(1699),
    [sym_kExports] = ACTIONS(1699),
    [sym_kProperty] = ACTIONS(1699),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1699),
    [sym_kGeneric] = ACTIONS(1699),
    [sym_kFunction] = ACTIONS(1699),
    [sym_kProcedure] = ACTIONS(1699),
    [sym_kConstructor] = ACTIONS(1699),
    [sym_kDestructor] = ACTIONS(1699),
    [sym_kOperator] = ACTIONS(1699),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [259] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [sym_kUses] = ACTIONS(1706),
    [sym_kInterface] = ACTIONS(1706),
    [sym_kImplementation] = ACTIONS(1706),
    [sym_kInitialization] = ACTIONS(1706),
    [sym_kFinalization] = ACTIONS(1706),
    [sym_kEnd] = ACTIONS(1706),
    [sym_kVar] = ACTIONS(1708),
    [sym_kThreadvar] = ACTIONS(1706),
    [sym_kConst] = ACTIONS(1708),
    [sym_kResourcestring] = ACTIONS(1706),
    [sym_kType] = ACTIONS(1706),
    [sym_kLabel] = ACTIONS(1706),
    [sym_kExports] = ACTIONS(1706),
    [sym_kProperty] = ACTIONS(1706),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1706),
    [sym_kGeneric] = ACTIONS(1706),
    [sym_kFunction] = ACTIONS(1706),
    [sym_kProcedure] = ACTIONS(1706),
    [sym_kConstructor] = ACTIONS(1706),
    [sym_kDestructor] = ACTIONS(1706),
    [sym_kOperator] = ACTIONS(1706),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [260] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(268),
    [anon_sym_LBRACK] = ACTIONS(1710),
    [sym_kUses] = ACTIONS(1713),
    [sym_kInterface] = ACTIONS(1713),
    [sym_kImplementation] = ACTIONS(1713),
    [sym_kInitialization] = ACTIONS(1713),
    [sym_kFinalization] = ACTIONS(1713),
    [sym_kEnd] = ACTIONS(1713),
    [sym_kVar] = ACTIONS(1715),
    [sym_kThreadvar] = ACTIONS(1713),
    [sym_kConst] = ACTIONS(1715),
    [sym_kResourcestring] = ACTIONS(1713),
    [sym_kType] = ACTIONS(1713),
    [sym_kLabel] = ACTIONS(1713),
    [sym_kExports] = ACTIONS(1713),
    [sym_kProperty] = ACTIONS(1713),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1713),
    [sym_kGeneric] = ACTIONS(1713),
    [sym_kFunction] = ACTIONS(1713),
    [sym_kProcedure] = ACTIONS(1713),
    [sym_kConstructor] = ACTIONS(1713),
    [sym_kDestructor] = ACTIONS(1713),
    [sym_kOperator] = ACTIONS(1713),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [261] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(269),
    [anon_sym_LBRACK] = ACTIONS(1717),
    [sym_kUses] = ACTIONS(1720),
    [sym_kInterface] = ACTIONS(1720),
    [sym_kImplementation] = ACTIONS(1720),
    [sym_kInitialization] = ACTIONS(1720),
    [sym_kFinalization] = ACTIONS(1720),
    [sym_kEnd] = ACTIONS(1720),
    [sym_kVar] = ACTIONS(1722),
    [sym_kThreadvar] = ACTIONS(1720),
    [sym_kConst] = ACTIONS(1722),
    [sym_kResourcestring] = ACTIONS(1720),
    [sym_kType] = ACTIONS(1720),
    [sym_kLabel] = ACTIONS(1720),
    [sym_kExports] = ACTIONS(1720),
    [sym_kProperty] = ACTIONS(1720),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1720),
    [sym_kGeneric] = ACTIONS(1720),
    [sym_kFunction] = ACTIONS(1720),
    [sym_kProcedure] = ACTIONS(1720),
    [sym_kConstructor] = ACTIONS(1720),
    [sym_kDestructor] = ACTIONS(1720),
    [sym_kOperator] = ACTIONS(1720),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [262] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(271),
    [anon_sym_LBRACK] = ACTIONS(1724),
    [sym_kUses] = ACTIONS(1727),
    [sym_kInterface] = ACTIONS(1727),
    [sym_kImplementation] = ACTIONS(1727),
    [sym_kInitialization] = ACTIONS(1727),
    [sym_kFinalization] = ACTIONS(1727),
    [sym_kEnd] = ACTIONS(1727),
    [sym_kVar] = ACTIONS(1729),
    [sym_kThreadvar] = ACTIONS(1727),
    [sym_kConst] = ACTIONS(1729),
    [sym_kResourcestring] = ACTIONS(1727),
    [sym_kType] = ACTIONS(1727),
    [sym_kLabel] = ACTIONS(1727),
    [sym_kExports] = ACTIONS(1727),
    [sym_kProperty] = ACTIONS(1727),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1727),
    [sym_kGeneric] = ACTIONS(1727),
    [sym_kFunction] = ACTIONS(1727),
    [sym_kProcedure] = ACTIONS(1727),
    [sym_kConstructor] = ACTIONS(1727),
    [sym_kDestructor] = ACTIONS(1727),
    [sym_kOperator] = ACTIONS(1727),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [263] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(273),
    [anon_sym_LBRACK] = ACTIONS(1731),
    [sym_kUses] = ACTIONS(1734),
    [sym_kInterface] = ACTIONS(1734),
    [sym_kImplementation] = ACTIONS(1734),
    [sym_kInitialization] = ACTIONS(1734),
    [sym_kFinalization] = ACTIONS(1734),
    [sym_kEnd] = ACTIONS(1734),
    [sym_kVar] = ACTIONS(1736),
    [sym_kThreadvar] = ACTIONS(1734),
    [sym_kConst] = ACTIONS(1736),
    [sym_kResourcestring] = ACTIONS(1734),
    [sym_kType] = ACTIONS(1734),
    [sym_kLabel] = ACTIONS(1734),
    [sym_kExports] = ACTIONS(1734),
    [sym_kProperty] = ACTIONS(1734),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1734),
    [sym_kGeneric] = ACTIONS(1734),
    [sym_kFunction] = ACTIONS(1734),
    [sym_kProcedure] = ACTIONS(1734),
    [sym_kConstructor] = ACTIONS(1734),
    [sym_kDestructor] = ACTIONS(1734),
    [sym_kOperator] = ACTIONS(1734),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [264] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1738),
    [sym_kUses] = ACTIONS(1741),
    [sym_kInterface] = ACTIONS(1741),
    [sym_kImplementation] = ACTIONS(1741),
    [sym_kInitialization] = ACTIONS(1741),
    [sym_kFinalization] = ACTIONS(1741),
    [sym_kEnd] = ACTIONS(1741),
    [sym_kVar] = ACTIONS(1743),
    [sym_kThreadvar] = ACTIONS(1741),
    [sym_kConst] = ACTIONS(1743),
    [sym_kResourcestring] = ACTIONS(1741),
    [sym_kType] = ACTIONS(1741),
    [sym_kLabel] = ACTIONS(1741),
    [sym_kExports] = ACTIONS(1741),
    [sym_kProperty] = ACTIONS(1741),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1741),
    [sym_kGeneric] = ACTIONS(1741),
    [sym_kFunction] = ACTIONS(1741),
    [sym_kProcedure] = ACTIONS(1741),
    [sym_kConstructor] = ACTIONS(1741),
    [sym_kDestructor] = ACTIONS(1741),
    [sym_kOperator] = ACTIONS(1741),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [265] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(277),
    [anon_sym_LBRACK] = ACTIONS(1745),
    [sym_kUses] = ACTIONS(1748),
    [sym_kInterface] = ACTIONS(1748),
    [sym_kImplementation] = ACTIONS(1748),
    [sym_kInitialization] = ACTIONS(1748),
    [sym_kFinalization] = ACTIONS(1748),
    [sym_kEnd] = ACTIONS(1748),
    [sym_kVar] = ACTIONS(1750),
    [sym_kThreadvar] = ACTIONS(1748),
    [sym_kConst] = ACTIONS(1750),
    [sym_kResourcestring] = ACTIONS(1748),
    [sym_kType] = ACTIONS(1748),
    [sym_kLabel] = ACTIONS(1748),
    [sym_kExports] = ACTIONS(1748),
    [sym_kProperty] = ACTIONS(1748),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1748),
    [sym_kGeneric] = ACTIONS(1748),
    [sym_kFunction] = ACTIONS(1748),
    [sym_kProcedure] = ACTIONS(1748),
    [sym_kConstructor] = ACTIONS(1748),
    [sym_kDestructor] = ACTIONS(1748),
    [sym_kOperator] = ACTIONS(1748),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [266] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(278),
    [anon_sym_LBRACK] = ACTIONS(1752),
    [sym_kUses] = ACTIONS(1755),
    [sym_kInterface] = ACTIONS(1755),
    [sym_kImplementation] = ACTIONS(1755),
    [sym_kInitialization] = ACTIONS(1755),
    [sym_kFinalization] = ACTIONS(1755),
    [sym_kEnd] = ACTIONS(1755),
    [sym_kVar] = ACTIONS(1757),
    [sym_kThreadvar] = ACTIONS(1755),
    [sym_kConst] = ACTIONS(1757),
    [sym_kResourcestring] = ACTIONS(1755),
    [sym_kType] = ACTIONS(1755),
    [sym_kLabel] = ACTIONS(1755),
    [sym_kExports] = ACTIONS(1755),
    [sym_kProperty] = ACTIONS(1755),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1755),
    [sym_kGeneric] = ACTIONS(1755),
    [sym_kFunction] = ACTIONS(1755),
    [sym_kProcedure] = ACTIONS(1755),
    [sym_kConstructor] = ACTIONS(1755),
    [sym_kDestructor] = ACTIONS(1755),
    [sym_kOperator] = ACTIONS(1755),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [267] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(280),
    [anon_sym_LBRACK] = ACTIONS(1759),
    [sym_kUses] = ACTIONS(1762),
    [sym_kInterface] = ACTIONS(1762),
    [sym_kImplementation] = ACTIONS(1762),
    [sym_kInitialization] = ACTIONS(1762),
    [sym_kFinalization] = ACTIONS(1762),
    [sym_kEnd] = ACTIONS(1762),
    [sym_kVar] = ACTIONS(1764),
    [sym_kThreadvar] = ACTIONS(1762),
    [sym_kConst] = ACTIONS(1764),
    [sym_kResourcestring] = ACTIONS(1762),
    [sym_kType] = ACTIONS(1762),
    [sym_kLabel] = ACTIONS(1762),
    [sym_kExports] = ACTIONS(1762),
    [sym_kProperty] = ACTIONS(1762),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1762),
    [sym_kGeneric] = ACTIONS(1762),
    [sym_kFunction] = ACTIONS(1762),
    [sym_kProcedure] = ACTIONS(1762),
    [sym_kConstructor] = ACTIONS(1762),
    [sym_kDestructor] = ACTIONS(1762),
    [sym_kOperator] = ACTIONS(1762),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [268] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1766),
    [sym_kUses] = ACTIONS(1769),
    [sym_kInterface] = ACTIONS(1769),
    [sym_kImplementation] = ACTIONS(1769),
    [sym_kInitialization] = ACTIONS(1769),
    [sym_kFinalization] = ACTIONS(1769),
    [sym_kEnd] = ACTIONS(1769),
    [sym_kVar] = ACTIONS(1771),
    [sym_kThreadvar] = ACTIONS(1769),
    [sym_kConst] = ACTIONS(1771),
    [sym_kResourcestring] = ACTIONS(1769),
    [sym_kType] = ACTIONS(1769),
    [sym_kLabel] = ACTIONS(1769),
    [sym_kExports] = ACTIONS(1769),
    [sym_kProperty] = ACTIONS(1769),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1769),
    [sym_kGeneric] = ACTIONS(1769),
    [sym_kFunction] = ACTIONS(1769),
    [sym_kProcedure] = ACTIONS(1769),
    [sym_kConstructor] = ACTIONS(1769),
    [sym_kDestructor] = ACTIONS(1769),
    [sym_kOperator] = ACTIONS(1769),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [269] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1773),
    [sym_kUses] = ACTIONS(1776),
    [sym_kInterface] = ACTIONS(1776),
    [sym_kImplementation] = ACTIONS(1776),
    [sym_kInitialization] = ACTIONS(1776),
    [sym_kFinalization] = ACTIONS(1776),
    [sym_kEnd] = ACTIONS(1776),
    [sym_kVar] = ACTIONS(1778),
    [sym_kThreadvar] = ACTIONS(1776),
    [sym_kConst] = ACTIONS(1778),
    [sym_kResourcestring] = ACTIONS(1776),
    [sym_kType] = ACTIONS(1776),
    [sym_kLabel] = ACTIONS(1776),
    [sym_kExports] = ACTIONS(1776),
    [sym_kProperty] = ACTIONS(1776),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1776),
    [sym_kGeneric] = ACTIONS(1776),
    [sym_kFunction] = ACTIONS(1776),
    [sym_kProcedure] = ACTIONS(1776),
    [sym_kConstructor] = ACTIONS(1776),
    [sym_kDestructor] = ACTIONS(1776),
    [sym_kOperator] = ACTIONS(1776),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [270] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(285),
    [anon_sym_LBRACK] = ACTIONS(1780),
    [sym_kUses] = ACTIONS(1783),
    [sym_kInterface] = ACTIONS(1783),
    [sym_kImplementation] = ACTIONS(1783),
    [sym_kInitialization] = ACTIONS(1783),
    [sym_kFinalization] = ACTIONS(1783),
    [sym_kEnd] = ACTIONS(1783),
    [sym_kVar] = ACTIONS(1785),
    [sym_kThreadvar] = ACTIONS(1783),
    [sym_kConst] = ACTIONS(1785),
    [sym_kResourcestring] = ACTIONS(1783),
    [sym_kType] = ACTIONS(1783),
    [sym_kLabel] = ACTIONS(1783),
    [sym_kExports] = ACTIONS(1783),
    [sym_kProperty] = ACTIONS(1783),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1783),
    [sym_kGeneric] = ACTIONS(1783),
    [sym_kFunction] = ACTIONS(1783),
    [sym_kProcedure] = ACTIONS(1783),
    [sym_kConstructor] = ACTIONS(1783),
    [sym_kDestructor] = ACTIONS(1783),
    [sym_kOperator] = ACTIONS(1783),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [271] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1787),
    [sym_kUses] = ACTIONS(1790),
    [sym_kInterface] = ACTIONS(1790),
    [sym_kImplementation] = ACTIONS(1790),
    [sym_kInitialization] = ACTIONS(1790),
    [sym_kFinalization] = ACTIONS(1790),
    [sym_kEnd] = ACTIONS(1790),
    [sym_kVar] = ACTIONS(1792),
    [sym_kThreadvar] = ACTIONS(1790),
    [sym_kConst] = ACTIONS(1792),
    [sym_kResourcestring] = ACTIONS(1790),
    [sym_kType] = ACTIONS(1790),
    [sym_kLabel] = ACTIONS(1790),
    [sym_kExports] = ACTIONS(1790),
    [sym_kProperty] = ACTIONS(1790),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1790),
    [sym_kGeneric] = ACTIONS(1790),
    [sym_kFunction] = ACTIONS(1790),
    [sym_kProcedure] = ACTIONS(1790),
    [sym_kConstructor] = ACTIONS(1790),
    [sym_kDestructor] = ACTIONS(1790),
    [sym_kOperator] = ACTIONS(1790),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [272] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(286),
    [anon_sym_LBRACK] = ACTIONS(1794),
    [sym_kUses] = ACTIONS(1797),
    [sym_kInterface] = ACTIONS(1797),
    [sym_kImplementation] = ACTIONS(1797),
    [sym_kInitialization] = ACTIONS(1797),
    [sym_kFinalization] = ACTIONS(1797),
    [sym_kEnd] = ACTIONS(1797),
    [sym_kVar] = ACTIONS(1799),
    [sym_kThreadvar] = ACTIONS(1797),
    [sym_kConst] = ACTIONS(1799),
    [sym_kResourcestring] = ACTIONS(1797),
    [sym_kType] = ACTIONS(1797),
    [sym_kLabel] = ACTIONS(1797),
    [sym_kExports] = ACTIONS(1797),
    [sym_kProperty] = ACTIONS(1797),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1797),
    [sym_kGeneric] = ACTIONS(1797),
    [sym_kFunction] = ACTIONS(1797),
    [sym_kProcedure] = ACTIONS(1797),
    [sym_kConstructor] = ACTIONS(1797),
    [sym_kDestructor] = ACTIONS(1797),
    [sym_kOperator] = ACTIONS(1797),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [273] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1801),
    [sym_kUses] = ACTIONS(1804),
    [sym_kInterface] = ACTIONS(1804),
    [sym_kImplementation] = ACTIONS(1804),
    [sym_kInitialization] = ACTIONS(1804),
    [sym_kFinalization] = ACTIONS(1804),
    [sym_kEnd] = ACTIONS(1804),
    [sym_kVar] = ACTIONS(1806),
    [sym_kThreadvar] = ACTIONS(1804),
    [sym_kConst] = ACTIONS(1806),
    [sym_kResourcestring] = ACTIONS(1804),
    [sym_kType] = ACTIONS(1804),
    [sym_kLabel] = ACTIONS(1804),
    [sym_kExports] = ACTIONS(1804),
    [sym_kProperty] = ACTIONS(1804),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1804),
    [sym_kGeneric] = ACTIONS(1804),
    [sym_kFunction] = ACTIONS(1804),
    [sym_kProcedure] = ACTIONS(1804),
    [sym_kConstructor] = ACTIONS(1804),
    [sym_kDestructor] = ACTIONS(1804),
    [sym_kOperator] = ACTIONS(1804),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [274] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(288),
    [anon_sym_LBRACK] = ACTIONS(1808),
    [sym_kUses] = ACTIONS(1811),
    [sym_kInterface] = ACTIONS(1811),
    [sym_kImplementation] = ACTIONS(1811),
    [sym_kInitialization] = ACTIONS(1811),
    [sym_kFinalization] = ACTIONS(1811),
    [sym_kEnd] = ACTIONS(1811),
    [sym_kVar] = ACTIONS(1813),
    [sym_kThreadvar] = ACTIONS(1811),
    [sym_kConst] = ACTIONS(1813),
    [sym_kResourcestring] = ACTIONS(1811),
    [sym_kType] = ACTIONS(1811),
    [sym_kLabel] = ACTIONS(1811),
    [sym_kExports] = ACTIONS(1811),
    [sym_kProperty] = ACTIONS(1811),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1811),
    [sym_kGeneric] = ACTIONS(1811),
    [sym_kFunction] = ACTIONS(1811),
    [sym_kProcedure] = ACTIONS(1811),
    [sym_kConstructor] = ACTIONS(1811),
    [sym_kDestructor] = ACTIONS(1811),
    [sym_kOperator] = ACTIONS(1811),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [275] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(289),
    [anon_sym_LBRACK] = ACTIONS(1815),
    [sym_kUses] = ACTIONS(1818),
    [sym_kInterface] = ACTIONS(1818),
    [sym_kImplementation] = ACTIONS(1818),
    [sym_kInitialization] = ACTIONS(1818),
    [sym_kFinalization] = ACTIONS(1818),
    [sym_kEnd] = ACTIONS(1818),
    [sym_kVar] = ACTIONS(1820),
    [sym_kThreadvar] = ACTIONS(1818),
    [sym_kConst] = ACTIONS(1820),
    [sym_kResourcestring] = ACTIONS(1818),
    [sym_kType] = ACTIONS(1818),
    [sym_kLabel] = ACTIONS(1818),
    [sym_kExports] = ACTIONS(1818),
    [sym_kProperty] = ACTIONS(1818),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1818),
    [sym_kGeneric] = ACTIONS(1818),
    [sym_kFunction] = ACTIONS(1818),
    [sym_kProcedure] = ACTIONS(1818),
    [sym_kConstructor] = ACTIONS(1818),
    [sym_kDestructor] = ACTIONS(1818),
    [sym_kOperator] = ACTIONS(1818),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [276] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(291),
    [anon_sym_LBRACK] = ACTIONS(1822),
    [sym_kUses] = ACTIONS(1825),
    [sym_kInterface] = ACTIONS(1825),
    [sym_kImplementation] = ACTIONS(1825),
    [sym_kInitialization] = ACTIONS(1825),
    [sym_kFinalization] = ACTIONS(1825),
    [sym_kEnd] = ACTIONS(1825),
    [sym_kVar] = ACTIONS(1827),
    [sym_kThreadvar] = ACTIONS(1825),
    [sym_kConst] = ACTIONS(1827),
    [sym_kResourcestring] = ACTIONS(1825),
    [sym_kType] = ACTIONS(1825),
    [sym_kLabel] = ACTIONS(1825),
    [sym_kExports] = ACTIONS(1825),
    [sym_kProperty] = ACTIONS(1825),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1825),
    [sym_kGeneric] = ACTIONS(1825),
    [sym_kFunction] = ACTIONS(1825),
    [sym_kProcedure] = ACTIONS(1825),
    [sym_kConstructor] = ACTIONS(1825),
    [sym_kDestructor] = ACTIONS(1825),
    [sym_kOperator] = ACTIONS(1825),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [277] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1829),
    [sym_kUses] = ACTIONS(1832),
    [sym_kInterface] = ACTIONS(1832),
    [sym_kImplementation] = ACTIONS(1832),
    [sym_kInitialization] = ACTIONS(1832),
    [sym_kFinalization] = ACTIONS(1832),
    [sym_kEnd] = ACTIONS(1832),
    [sym_kVar] = ACTIONS(1834),
    [sym_kThreadvar] = ACTIONS(1832),
    [sym_kConst] = ACTIONS(1834),
    [sym_kResourcestring] = ACTIONS(1832),
    [sym_kType] = ACTIONS(1832),
    [sym_kLabel] = ACTIONS(1832),
    [sym_kExports] = ACTIONS(1832),
    [sym_kProperty] = ACTIONS(1832),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1832),
    [sym_kGeneric] = ACTIONS(1832),
    [sym_kFunction] = ACTIONS(1832),
    [sym_kProcedure] = ACTIONS(1832),
    [sym_kConstructor] = ACTIONS(1832),
    [sym_kDestructor] = ACTIONS(1832),
    [sym_kOperator] = ACTIONS(1832),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [278] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1836),
    [sym_kUses] = ACTIONS(1839),
    [sym_kInterface] = ACTIONS(1839),
    [sym_kImplementation] = ACTIONS(1839),
    [sym_kInitialization] = ACTIONS(1839),
    [sym_kFinalization] = ACTIONS(1839),
    [sym_kEnd] = ACTIONS(1839),
    [sym_kVar] = ACTIONS(1841),
    [sym_kThreadvar] = ACTIONS(1839),
    [sym_kConst] = ACTIONS(1841),
    [sym_kResourcestring] = ACTIONS(1839),
    [sym_kType] = ACTIONS(1839),
    [sym_kLabel] = ACTIONS(1839),
    [sym_kExports] = ACTIONS(1839),
    [sym_kProperty] = ACTIONS(1839),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1839),
    [sym_kGeneric] = ACTIONS(1839),
    [sym_kFunction] = ACTIONS(1839),
    [sym_kProcedure] = ACTIONS(1839),
    [sym_kConstructor] = ACTIONS(1839),
    [sym_kDestructor] = ACTIONS(1839),
    [sym_kOperator] = ACTIONS(1839),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [279] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(294),
    [anon_sym_LBRACK] = ACTIONS(1843),
    [sym_kUses] = ACTIONS(1846),
    [sym_kInterface] = ACTIONS(1846),
    [sym_kImplementation] = ACTIONS(1846),
    [sym_kInitialization] = ACTIONS(1846),
    [sym_kFinalization] = ACTIONS(1846),
    [sym_kEnd] = ACTIONS(1846),
    [sym_kVar] = ACTIONS(1848),
    [sym_kThreadvar] = ACTIONS(1846),
    [sym_kConst] = ACTIONS(1848),
    [sym_kResourcestring] = ACTIONS(1846),
    [sym_kType] = ACTIONS(1846),
    [sym_kLabel] = ACTIONS(1846),
    [sym_kExports] = ACTIONS(1846),
    [sym_kProperty] = ACTIONS(1846),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1846),
    [sym_kGeneric] = ACTIONS(1846),
    [sym_kFunction] = ACTIONS(1846),
    [sym_kProcedure] = ACTIONS(1846),
    [sym_kConstructor] = ACTIONS(1846),
    [sym_kDestructor] = ACTIONS(1846),
    [sym_kOperator] = ACTIONS(1846),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [280] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1850),
    [sym_kUses] = ACTIONS(1853),
    [sym_kInterface] = ACTIONS(1853),
    [sym_kImplementation] = ACTIONS(1853),
    [sym_kInitialization] = ACTIONS(1853),
    [sym_kFinalization] = ACTIONS(1853),
    [sym_kEnd] = ACTIONS(1853),
    [sym_kVar] = ACTIONS(1855),
    [sym_kThreadvar] = ACTIONS(1853),
    [sym_kConst] = ACTIONS(1855),
    [sym_kResourcestring] = ACTIONS(1853),
    [sym_kType] = ACTIONS(1853),
    [sym_kLabel] = ACTIONS(1853),
    [sym_kExports] = ACTIONS(1853),
    [sym_kProperty] = ACTIONS(1853),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1853),
    [sym_kGeneric] = ACTIONS(1853),
    [sym_kFunction] = ACTIONS(1853),
    [sym_kProcedure] = ACTIONS(1853),
    [sym_kConstructor] = ACTIONS(1853),
    [sym_kDestructor] = ACTIONS(1853),
    [sym_kOperator] = ACTIONS(1853),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [281] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(295),
    [anon_sym_LBRACK] = ACTIONS(1857),
    [sym_kUses] = ACTIONS(1860),
    [sym_kInterface] = ACTIONS(1860),
    [sym_kImplementation] = ACTIONS(1860),
    [sym_kInitialization] = ACTIONS(1860),
    [sym_kFinalization] = ACTIONS(1860),
    [sym_kEnd] = ACTIONS(1860),
    [sym_kVar] = ACTIONS(1862),
    [sym_kThreadvar] = ACTIONS(1860),
    [sym_kConst] = ACTIONS(1862),
    [sym_kResourcestring] = ACTIONS(1860),
    [sym_kType] = ACTIONS(1860),
    [sym_kLabel] = ACTIONS(1860),
    [sym_kExports] = ACTIONS(1860),
    [sym_kProperty] = ACTIONS(1860),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1860),
    [sym_kGeneric] = ACTIONS(1860),
    [sym_kFunction] = ACTIONS(1860),
    [sym_kProcedure] = ACTIONS(1860),
    [sym_kConstructor] = ACTIONS(1860),
    [sym_kDestructor] = ACTIONS(1860),
    [sym_kOperator] = ACTIONS(1860),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [282] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(296),
    [anon_sym_LBRACK] = ACTIONS(1864),
    [sym_kUses] = ACTIONS(1867),
    [sym_kInterface] = ACTIONS(1867),
    [sym_kImplementation] = ACTIONS(1867),
    [sym_kInitialization] = ACTIONS(1867),
    [sym_kFinalization] = ACTIONS(1867),
    [sym_kEnd] = ACTIONS(1867),
    [sym_kVar] = ACTIONS(1869),
    [sym_kThreadvar] = ACTIONS(1867),
    [sym_kConst] = ACTIONS(1869),
    [sym_kResourcestring] = ACTIONS(1867),
    [sym_kType] = ACTIONS(1867),
    [sym_kLabel] = ACTIONS(1867),
    [sym_kExports] = ACTIONS(1867),
    [sym_kProperty] = ACTIONS(1867),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1867),
    [sym_kGeneric] = ACTIONS(1867),
    [sym_kFunction] = ACTIONS(1867),
    [sym_kProcedure] = ACTIONS(1867),
    [sym_kConstructor] = ACTIONS(1867),
    [sym_kDestructor] = ACTIONS(1867),
    [sym_kOperator] = ACTIONS(1867),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [283] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(287),
    [anon_sym_LBRACK] = ACTIONS(1871),
    [sym_kUses] = ACTIONS(1874),
    [sym_kInterface] = ACTIONS(1874),
    [sym_kImplementation] = ACTIONS(1874),
    [sym_kInitialization] = ACTIONS(1874),
    [sym_kFinalization] = ACTIONS(1874),
    [sym_kEnd] = ACTIONS(1874),
    [sym_kVar] = ACTIONS(1876),
    [sym_kThreadvar] = ACTIONS(1874),
    [sym_kConst] = ACTIONS(1876),
    [sym_kResourcestring] = ACTIONS(1874),
    [sym_kType] = ACTIONS(1874),
    [sym_kLabel] = ACTIONS(1874),
    [sym_kExports] = ACTIONS(1874),
    [sym_kProperty] = ACTIONS(1874),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1874),
    [sym_kGeneric] = ACTIONS(1874),
    [sym_kFunction] = ACTIONS(1874),
    [sym_kProcedure] = ACTIONS(1874),
    [sym_kConstructor] = ACTIONS(1874),
    [sym_kDestructor] = ACTIONS(1874),
    [sym_kOperator] = ACTIONS(1874),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [284] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(299),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [sym_kUses] = ACTIONS(1881),
    [sym_kInterface] = ACTIONS(1881),
    [sym_kImplementation] = ACTIONS(1881),
    [sym_kInitialization] = ACTIONS(1881),
    [sym_kFinalization] = ACTIONS(1881),
    [sym_kEnd] = ACTIONS(1881),
    [sym_kVar] = ACTIONS(1883),
    [sym_kThreadvar] = ACTIONS(1881),
    [sym_kConst] = ACTIONS(1883),
    [sym_kResourcestring] = ACTIONS(1881),
    [sym_kType] = ACTIONS(1881),
    [sym_kLabel] = ACTIONS(1881),
    [sym_kExports] = ACTIONS(1881),
    [sym_kProperty] = ACTIONS(1881),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1881),
    [sym_kGeneric] = ACTIONS(1881),
    [sym_kFunction] = ACTIONS(1881),
    [sym_kProcedure] = ACTIONS(1881),
    [sym_kConstructor] = ACTIONS(1881),
    [sym_kDestructor] = ACTIONS(1881),
    [sym_kOperator] = ACTIONS(1881),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [285] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1885),
    [sym_kUses] = ACTIONS(1888),
    [sym_kInterface] = ACTIONS(1888),
    [sym_kImplementation] = ACTIONS(1888),
    [sym_kInitialization] = ACTIONS(1888),
    [sym_kFinalization] = ACTIONS(1888),
    [sym_kEnd] = ACTIONS(1888),
    [sym_kVar] = ACTIONS(1890),
    [sym_kThreadvar] = ACTIONS(1888),
    [sym_kConst] = ACTIONS(1890),
    [sym_kResourcestring] = ACTIONS(1888),
    [sym_kType] = ACTIONS(1888),
    [sym_kLabel] = ACTIONS(1888),
    [sym_kExports] = ACTIONS(1888),
    [sym_kProperty] = ACTIONS(1888),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1888),
    [sym_kGeneric] = ACTIONS(1888),
    [sym_kFunction] = ACTIONS(1888),
    [sym_kProcedure] = ACTIONS(1888),
    [sym_kConstructor] = ACTIONS(1888),
    [sym_kDestructor] = ACTIONS(1888),
    [sym_kOperator] = ACTIONS(1888),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [286] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1892),
    [sym_kUses] = ACTIONS(1895),
    [sym_kInterface] = ACTIONS(1895),
    [sym_kImplementation] = ACTIONS(1895),
    [sym_kInitialization] = ACTIONS(1895),
    [sym_kFinalization] = ACTIONS(1895),
    [sym_kEnd] = ACTIONS(1895),
    [sym_kVar] = ACTIONS(1897),
    [sym_kThreadvar] = ACTIONS(1895),
    [sym_kConst] = ACTIONS(1897),
    [sym_kResourcestring] = ACTIONS(1895),
    [sym_kType] = ACTIONS(1895),
    [sym_kLabel] = ACTIONS(1895),
    [sym_kExports] = ACTIONS(1895),
    [sym_kProperty] = ACTIONS(1895),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1895),
    [sym_kGeneric] = ACTIONS(1895),
    [sym_kFunction] = ACTIONS(1895),
    [sym_kProcedure] = ACTIONS(1895),
    [sym_kConstructor] = ACTIONS(1895),
    [sym_kDestructor] = ACTIONS(1895),
    [sym_kOperator] = ACTIONS(1895),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [287] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [sym_kUses] = ACTIONS(1902),
    [sym_kInterface] = ACTIONS(1902),
    [sym_kImplementation] = ACTIONS(1902),
    [sym_kInitialization] = ACTIONS(1902),
    [sym_kFinalization] = ACTIONS(1902),
    [sym_kEnd] = ACTIONS(1902),
    [sym_kVar] = ACTIONS(1904),
    [sym_kThreadvar] = ACTIONS(1902),
    [sym_kConst] = ACTIONS(1904),
    [sym_kResourcestring] = ACTIONS(1902),
    [sym_kType] = ACTIONS(1902),
    [sym_kLabel] = ACTIONS(1902),
    [sym_kExports] = ACTIONS(1902),
    [sym_kProperty] = ACTIONS(1902),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1902),
    [sym_kGeneric] = ACTIONS(1902),
    [sym_kFunction] = ACTIONS(1902),
    [sym_kProcedure] = ACTIONS(1902),
    [sym_kConstructor] = ACTIONS(1902),
    [sym_kDestructor] = ACTIONS(1902),
    [sym_kOperator] = ACTIONS(1902),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [288] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1906),
    [sym_kUses] = ACTIONS(1909),
    [sym_kInterface] = ACTIONS(1909),
    [sym_kImplementation] = ACTIONS(1909),
    [sym_kInitialization] = ACTIONS(1909),
    [sym_kFinalization] = ACTIONS(1909),
    [sym_kEnd] = ACTIONS(1909),
    [sym_kVar] = ACTIONS(1911),
    [sym_kThreadvar] = ACTIONS(1909),
    [sym_kConst] = ACTIONS(1911),
    [sym_kResourcestring] = ACTIONS(1909),
    [sym_kType] = ACTIONS(1909),
    [sym_kLabel] = ACTIONS(1909),
    [sym_kExports] = ACTIONS(1909),
    [sym_kProperty] = ACTIONS(1909),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1909),
    [sym_kGeneric] = ACTIONS(1909),
    [sym_kFunction] = ACTIONS(1909),
    [sym_kProcedure] = ACTIONS(1909),
    [sym_kConstructor] = ACTIONS(1909),
    [sym_kDestructor] = ACTIONS(1909),
    [sym_kOperator] = ACTIONS(1909),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [289] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1913),
    [sym_kUses] = ACTIONS(1916),
    [sym_kInterface] = ACTIONS(1916),
    [sym_kImplementation] = ACTIONS(1916),
    [sym_kInitialization] = ACTIONS(1916),
    [sym_kFinalization] = ACTIONS(1916),
    [sym_kEnd] = ACTIONS(1916),
    [sym_kVar] = ACTIONS(1918),
    [sym_kThreadvar] = ACTIONS(1916),
    [sym_kConst] = ACTIONS(1918),
    [sym_kResourcestring] = ACTIONS(1916),
    [sym_kType] = ACTIONS(1916),
    [sym_kLabel] = ACTIONS(1916),
    [sym_kExports] = ACTIONS(1916),
    [sym_kProperty] = ACTIONS(1916),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1916),
    [sym_kGeneric] = ACTIONS(1916),
    [sym_kFunction] = ACTIONS(1916),
    [sym_kProcedure] = ACTIONS(1916),
    [sym_kConstructor] = ACTIONS(1916),
    [sym_kDestructor] = ACTIONS(1916),
    [sym_kOperator] = ACTIONS(1916),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [290] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(300),
    [anon_sym_LBRACK] = ACTIONS(1920),
    [sym_kUses] = ACTIONS(1923),
    [sym_kInterface] = ACTIONS(1923),
    [sym_kImplementation] = ACTIONS(1923),
    [sym_kInitialization] = ACTIONS(1923),
    [sym_kFinalization] = ACTIONS(1923),
    [sym_kEnd] = ACTIONS(1923),
    [sym_kVar] = ACTIONS(1925),
    [sym_kThreadvar] = ACTIONS(1923),
    [sym_kConst] = ACTIONS(1925),
    [sym_kResourcestring] = ACTIONS(1923),
    [sym_kType] = ACTIONS(1923),
    [sym_kLabel] = ACTIONS(1923),
    [sym_kExports] = ACTIONS(1923),
    [sym_kProperty] = ACTIONS(1923),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1923),
    [sym_kGeneric] = ACTIONS(1923),
    [sym_kFunction] = ACTIONS(1923),
    [sym_kProcedure] = ACTIONS(1923),
    [sym_kConstructor] = ACTIONS(1923),
    [sym_kDestructor] = ACTIONS(1923),
    [sym_kOperator] = ACTIONS(1923),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [291] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [sym_kUses] = ACTIONS(1930),
    [sym_kInterface] = ACTIONS(1930),
    [sym_kImplementation] = ACTIONS(1930),
    [sym_kInitialization] = ACTIONS(1930),
    [sym_kFinalization] = ACTIONS(1930),
    [sym_kEnd] = ACTIONS(1930),
    [sym_kVar] = ACTIONS(1932),
    [sym_kThreadvar] = ACTIONS(1930),
    [sym_kConst] = ACTIONS(1932),
    [sym_kResourcestring] = ACTIONS(1930),
    [sym_kType] = ACTIONS(1930),
    [sym_kLabel] = ACTIONS(1930),
    [sym_kExports] = ACTIONS(1930),
    [sym_kProperty] = ACTIONS(1930),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1930),
    [sym_kGeneric] = ACTIONS(1930),
    [sym_kFunction] = ACTIONS(1930),
    [sym_kProcedure] = ACTIONS(1930),
    [sym_kConstructor] = ACTIONS(1930),
    [sym_kDestructor] = ACTIONS(1930),
    [sym_kOperator] = ACTIONS(1930),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [292] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(301),
    [anon_sym_LBRACK] = ACTIONS(1934),
    [sym_kUses] = ACTIONS(1937),
    [sym_kInterface] = ACTIONS(1937),
    [sym_kImplementation] = ACTIONS(1937),
    [sym_kInitialization] = ACTIONS(1937),
    [sym_kFinalization] = ACTIONS(1937),
    [sym_kEnd] = ACTIONS(1937),
    [sym_kVar] = ACTIONS(1939),
    [sym_kThreadvar] = ACTIONS(1937),
    [sym_kConst] = ACTIONS(1939),
    [sym_kResourcestring] = ACTIONS(1937),
    [sym_kType] = ACTIONS(1937),
    [sym_kLabel] = ACTIONS(1937),
    [sym_kExports] = ACTIONS(1937),
    [sym_kProperty] = ACTIONS(1937),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1937),
    [sym_kGeneric] = ACTIONS(1937),
    [sym_kFunction] = ACTIONS(1937),
    [sym_kProcedure] = ACTIONS(1937),
    [sym_kConstructor] = ACTIONS(1937),
    [sym_kDestructor] = ACTIONS(1937),
    [sym_kOperator] = ACTIONS(1937),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [293] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(302),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [sym_kUses] = ACTIONS(1944),
    [sym_kInterface] = ACTIONS(1944),
    [sym_kImplementation] = ACTIONS(1944),
    [sym_kInitialization] = ACTIONS(1944),
    [sym_kFinalization] = ACTIONS(1944),
    [sym_kEnd] = ACTIONS(1944),
    [sym_kVar] = ACTIONS(1946),
    [sym_kThreadvar] = ACTIONS(1944),
    [sym_kConst] = ACTIONS(1946),
    [sym_kResourcestring] = ACTIONS(1944),
    [sym_kType] = ACTIONS(1944),
    [sym_kLabel] = ACTIONS(1944),
    [sym_kExports] = ACTIONS(1944),
    [sym_kProperty] = ACTIONS(1944),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1944),
    [sym_kGeneric] = ACTIONS(1944),
    [sym_kFunction] = ACTIONS(1944),
    [sym_kProcedure] = ACTIONS(1944),
    [sym_kConstructor] = ACTIONS(1944),
    [sym_kDestructor] = ACTIONS(1944),
    [sym_kOperator] = ACTIONS(1944),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [294] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1948),
    [sym_kUses] = ACTIONS(1951),
    [sym_kInterface] = ACTIONS(1951),
    [sym_kImplementation] = ACTIONS(1951),
    [sym_kInitialization] = ACTIONS(1951),
    [sym_kFinalization] = ACTIONS(1951),
    [sym_kEnd] = ACTIONS(1951),
    [sym_kVar] = ACTIONS(1953),
    [sym_kThreadvar] = ACTIONS(1951),
    [sym_kConst] = ACTIONS(1953),
    [sym_kResourcestring] = ACTIONS(1951),
    [sym_kType] = ACTIONS(1951),
    [sym_kLabel] = ACTIONS(1951),
    [sym_kExports] = ACTIONS(1951),
    [sym_kProperty] = ACTIONS(1951),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1951),
    [sym_kGeneric] = ACTIONS(1951),
    [sym_kFunction] = ACTIONS(1951),
    [sym_kProcedure] = ACTIONS(1951),
    [sym_kConstructor] = ACTIONS(1951),
    [sym_kDestructor] = ACTIONS(1951),
    [sym_kOperator] = ACTIONS(1951),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [295] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [sym_kUses] = ACTIONS(1958),
    [sym_kInterface] = ACTIONS(1958),
    [sym_kImplementation] = ACTIONS(1958),
    [sym_kInitialization] = ACTIONS(1958),
    [sym_kFinalization] = ACTIONS(1958),
    [sym_kEnd] = ACTIONS(1958),
    [sym_kVar] = ACTIONS(1960),
    [sym_kThreadvar] = ACTIONS(1958),
    [sym_kConst] = ACTIONS(1960),
    [sym_kResourcestring] = ACTIONS(1958),
    [sym_kType] = ACTIONS(1958),
    [sym_kLabel] = ACTIONS(1958),
    [sym_kExports] = ACTIONS(1958),
    [sym_kProperty] = ACTIONS(1958),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1958),
    [sym_kGeneric] = ACTIONS(1958),
    [sym_kFunction] = ACTIONS(1958),
    [sym_kProcedure] = ACTIONS(1958),
    [sym_kConstructor] = ACTIONS(1958),
    [sym_kDestructor] = ACTIONS(1958),
    [sym_kOperator] = ACTIONS(1958),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [296] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1962),
    [sym_kUses] = ACTIONS(1965),
    [sym_kInterface] = ACTIONS(1965),
    [sym_kImplementation] = ACTIONS(1965),
    [sym_kInitialization] = ACTIONS(1965),
    [sym_kFinalization] = ACTIONS(1965),
    [sym_kEnd] = ACTIONS(1965),
    [sym_kVar] = ACTIONS(1967),
    [sym_kThreadvar] = ACTIONS(1965),
    [sym_kConst] = ACTIONS(1967),
    [sym_kResourcestring] = ACTIONS(1965),
    [sym_kType] = ACTIONS(1965),
    [sym_kLabel] = ACTIONS(1965),
    [sym_kExports] = ACTIONS(1965),
    [sym_kProperty] = ACTIONS(1965),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1965),
    [sym_kGeneric] = ACTIONS(1965),
    [sym_kFunction] = ACTIONS(1965),
    [sym_kProcedure] = ACTIONS(1965),
    [sym_kConstructor] = ACTIONS(1965),
    [sym_kDestructor] = ACTIONS(1965),
    [sym_kOperator] = ACTIONS(1965),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [297] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(305),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [sym_kEnd] = ACTIONS(1972),
    [sym_kVar] = ACTIONS(1974),
    [sym_kThreadvar] = ACTIONS(1972),
    [sym_kConst] = ACTIONS(1974),
    [sym_kResourcestring] = ACTIONS(1972),
    [sym_kType] = ACTIONS(1972),
    [sym_kProperty] = ACTIONS(1972),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1972),
    [sym_kGeneric] = ACTIONS(1972),
    [sym_kCase] = ACTIONS(1972),
    [sym_kFunction] = ACTIONS(1972),
    [sym_kProcedure] = ACTIONS(1972),
    [sym_kConstructor] = ACTIONS(1972),
    [sym_kDestructor] = ACTIONS(1972),
    [sym_kOperator] = ACTIONS(1972),
    [sym_kPublished] = ACTIONS(1972),
    [sym_kPublic] = ACTIONS(1976),
    [sym_kProtected] = ACTIONS(1972),
    [sym_kPrivate] = ACTIONS(1972),
    [sym_kStrict] = ACTIONS(1972),
    [sym_kRequired] = ACTIONS(1972),
    [sym_kOptional] = ACTIONS(1972),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [298] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(253),
    [anon_sym_LBRACK] = ACTIONS(1981),
    [sym_kUses] = ACTIONS(1984),
    [sym_kInterface] = ACTIONS(1984),
    [sym_kImplementation] = ACTIONS(1984),
    [sym_kInitialization] = ACTIONS(1984),
    [sym_kFinalization] = ACTIONS(1984),
    [sym_kEnd] = ACTIONS(1984),
    [sym_kVar] = ACTIONS(1986),
    [sym_kThreadvar] = ACTIONS(1984),
    [sym_kConst] = ACTIONS(1986),
    [sym_kResourcestring] = ACTIONS(1984),
    [sym_kType] = ACTIONS(1984),
    [sym_kLabel] = ACTIONS(1984),
    [sym_kExports] = ACTIONS(1984),
    [sym_kProperty] = ACTIONS(1984),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1984),
    [sym_kGeneric] = ACTIONS(1984),
    [sym_kFunction] = ACTIONS(1984),
    [sym_kProcedure] = ACTIONS(1984),
    [sym_kConstructor] = ACTIONS(1984),
    [sym_kDestructor] = ACTIONS(1984),
    [sym_kOperator] = ACTIONS(1984),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [299] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(97),
    [anon_sym_LBRACK] = ACTIONS(1988),
    [sym_kUses] = ACTIONS(1991),
    [sym_kInterface] = ACTIONS(1991),
    [sym_kImplementation] = ACTIONS(1991),
    [sym_kInitialization] = ACTIONS(1991),
    [sym_kFinalization] = ACTIONS(1991),
    [sym_kEnd] = ACTIONS(1991),
    [sym_kVar] = ACTIONS(1993),
    [sym_kThreadvar] = ACTIONS(1991),
    [sym_kConst] = ACTIONS(1993),
    [sym_kResourcestring] = ACTIONS(1991),
    [sym_kType] = ACTIONS(1991),
    [sym_kLabel] = ACTIONS(1991),
    [sym_kExports] = ACTIONS(1991),
    [sym_kProperty] = ACTIONS(1991),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1991),
    [sym_kGeneric] = ACTIONS(1991),
    [sym_kFunction] = ACTIONS(1991),
    [sym_kProcedure] = ACTIONS(1991),
    [sym_kConstructor] = ACTIONS(1991),
    [sym_kDestructor] = ACTIONS(1991),
    [sym_kOperator] = ACTIONS(1991),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [300] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(1995),
    [sym_kUses] = ACTIONS(1998),
    [sym_kInterface] = ACTIONS(1998),
    [sym_kImplementation] = ACTIONS(1998),
    [sym_kInitialization] = ACTIONS(1998),
    [sym_kFinalization] = ACTIONS(1998),
    [sym_kEnd] = ACTIONS(1998),
    [sym_kVar] = ACTIONS(2000),
    [sym_kThreadvar] = ACTIONS(1998),
    [sym_kConst] = ACTIONS(2000),
    [sym_kResourcestring] = ACTIONS(1998),
    [sym_kType] = ACTIONS(1998),
    [sym_kLabel] = ACTIONS(1998),
    [sym_kExports] = ACTIONS(1998),
    [sym_kProperty] = ACTIONS(1998),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1998),
    [sym_kGeneric] = ACTIONS(1998),
    [sym_kFunction] = ACTIONS(1998),
    [sym_kProcedure] = ACTIONS(1998),
    [sym_kConstructor] = ACTIONS(1998),
    [sym_kDestructor] = ACTIONS(1998),
    [sym_kOperator] = ACTIONS(1998),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [301] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(2002),
    [sym_kUses] = ACTIONS(2005),
    [sym_kInterface] = ACTIONS(2005),
    [sym_kImplementation] = ACTIONS(2005),
    [sym_kInitialization] = ACTIONS(2005),
    [sym_kFinalization] = ACTIONS(2005),
    [sym_kEnd] = ACTIONS(2005),
    [sym_kVar] = ACTIONS(2007),
    [sym_kThreadvar] = ACTIONS(2005),
    [sym_kConst] = ACTIONS(2007),
    [sym_kResourcestring] = ACTIONS(2005),
    [sym_kType] = ACTIONS(2005),
    [sym_kLabel] = ACTIONS(2005),
    [sym_kExports] = ACTIONS(2005),
    [sym_kProperty] = ACTIONS(2005),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2005),
    [sym_kGeneric] = ACTIONS(2005),
    [sym_kFunction] = ACTIONS(2005),
    [sym_kProcedure] = ACTIONS(2005),
    [sym_kConstructor] = ACTIONS(2005),
    [sym_kDestructor] = ACTIONS(2005),
    [sym_kOperator] = ACTIONS(2005),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [302] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(2009),
    [sym_kUses] = ACTIONS(2012),
    [sym_kInterface] = ACTIONS(2012),
    [sym_kImplementation] = ACTIONS(2012),
    [sym_kInitialization] = ACTIONS(2012),
    [sym_kFinalization] = ACTIONS(2012),
    [sym_kEnd] = ACTIONS(2012),
    [sym_kVar] = ACTIONS(2014),
    [sym_kThreadvar] = ACTIONS(2012),
    [sym_kConst] = ACTIONS(2014),
    [sym_kResourcestring] = ACTIONS(2012),
    [sym_kType] = ACTIONS(2012),
    [sym_kLabel] = ACTIONS(2012),
    [sym_kExports] = ACTIONS(2012),
    [sym_kProperty] = ACTIONS(2012),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2012),
    [sym_kGeneric] = ACTIONS(2012),
    [sym_kFunction] = ACTIONS(2012),
    [sym_kProcedure] = ACTIONS(2012),
    [sym_kConstructor] = ACTIONS(2012),
    [sym_kDestructor] = ACTIONS(2012),
    [sym_kOperator] = ACTIONS(2012),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [303] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(309),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [sym_kUses] = ACTIONS(2019),
    [sym_kInterface] = ACTIONS(2019),
    [sym_kImplementation] = ACTIONS(2019),
    [sym_kInitialization] = ACTIONS(2019),
    [sym_kFinalization] = ACTIONS(2019),
    [sym_kEnd] = ACTIONS(2019),
    [sym_kVar] = ACTIONS(2021),
    [sym_kThreadvar] = ACTIONS(2019),
    [sym_kConst] = ACTIONS(2021),
    [sym_kResourcestring] = ACTIONS(2019),
    [sym_kType] = ACTIONS(2019),
    [sym_kLabel] = ACTIONS(2019),
    [sym_kExports] = ACTIONS(2019),
    [sym_kProperty] = ACTIONS(2019),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2019),
    [sym_kGeneric] = ACTIONS(2019),
    [sym_kFunction] = ACTIONS(2019),
    [sym_kProcedure] = ACTIONS(2019),
    [sym_kConstructor] = ACTIONS(2019),
    [sym_kDestructor] = ACTIONS(2019),
    [sym_kOperator] = ACTIONS(2019),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [304] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(2023),
    [sym_kUses] = ACTIONS(2026),
    [sym_kInterface] = ACTIONS(2026),
    [sym_kImplementation] = ACTIONS(2026),
    [sym_kInitialization] = ACTIONS(2026),
    [sym_kFinalization] = ACTIONS(2026),
    [sym_kEnd] = ACTIONS(2026),
    [sym_kVar] = ACTIONS(2028),
    [sym_kThreadvar] = ACTIONS(2026),
    [sym_kConst] = ACTIONS(2028),
    [sym_kResourcestring] = ACTIONS(2026),
    [sym_kType] = ACTIONS(2026),
    [sym_kLabel] = ACTIONS(2026),
    [sym_kExports] = ACTIONS(2026),
    [sym_kProperty] = ACTIONS(2026),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2026),
    [sym_kGeneric] = ACTIONS(2026),
    [sym_kFunction] = ACTIONS(2026),
    [sym_kProcedure] = ACTIONS(2026),
    [sym_kConstructor] = ACTIONS(2026),
    [sym_kDestructor] = ACTIONS(2026),
    [sym_kOperator] = ACTIONS(2026),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [305] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2030),
    [sym_kEnd] = ACTIONS(1706),
    [sym_kVar] = ACTIONS(1708),
    [sym_kThreadvar] = ACTIONS(1706),
    [sym_kConst] = ACTIONS(1708),
    [sym_kResourcestring] = ACTIONS(1706),
    [sym_kType] = ACTIONS(1706),
    [sym_kProperty] = ACTIONS(1706),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1706),
    [sym_kGeneric] = ACTIONS(1706),
    [sym_kCase] = ACTIONS(1706),
    [sym_kFunction] = ACTIONS(1706),
    [sym_kProcedure] = ACTIONS(1706),
    [sym_kConstructor] = ACTIONS(1706),
    [sym_kDestructor] = ACTIONS(1706),
    [sym_kOperator] = ACTIONS(1706),
    [sym_kPublished] = ACTIONS(1706),
    [sym_kPublic] = ACTIONS(2033),
    [sym_kProtected] = ACTIONS(1706),
    [sym_kPrivate] = ACTIONS(1706),
    [sym_kStrict] = ACTIONS(1706),
    [sym_kRequired] = ACTIONS(1706),
    [sym_kOptional] = ACTIONS(1706),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [306] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(310),
    [anon_sym_LBRACK] = ACTIONS(2036),
    [sym_kEnd] = ACTIONS(1713),
    [sym_kVar] = ACTIONS(1715),
    [sym_kThreadvar] = ACTIONS(1713),
    [sym_kConst] = ACTIONS(1715),
    [sym_kResourcestring] = ACTIONS(1713),
    [sym_kType] = ACTIONS(1713),
    [sym_kProperty] = ACTIONS(1713),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1713),
    [sym_kGeneric] = ACTIONS(1713),
    [sym_kCase] = ACTIONS(1713),
    [sym_kFunction] = ACTIONS(1713),
    [sym_kProcedure] = ACTIONS(1713),
    [sym_kConstructor] = ACTIONS(1713),
    [sym_kDestructor] = ACTIONS(1713),
    [sym_kOperator] = ACTIONS(1713),
    [sym_kPublished] = ACTIONS(1713),
    [sym_kPublic] = ACTIONS(2039),
    [sym_kProtected] = ACTIONS(1713),
    [sym_kPrivate] = ACTIONS(1713),
    [sym_kStrict] = ACTIONS(1713),
    [sym_kRequired] = ACTIONS(1713),
    [sym_kOptional] = ACTIONS(1713),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [307] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(311),
    [anon_sym_LBRACK] = ACTIONS(2042),
    [sym_kEnd] = ACTIONS(1720),
    [sym_kVar] = ACTIONS(1722),
    [sym_kThreadvar] = ACTIONS(1720),
    [sym_kConst] = ACTIONS(1722),
    [sym_kResourcestring] = ACTIONS(1720),
    [sym_kType] = ACTIONS(1720),
    [sym_kProperty] = ACTIONS(1720),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1720),
    [sym_kGeneric] = ACTIONS(1720),
    [sym_kCase] = ACTIONS(1720),
    [sym_kFunction] = ACTIONS(1720),
    [sym_kProcedure] = ACTIONS(1720),
    [sym_kConstructor] = ACTIONS(1720),
    [sym_kDestructor] = ACTIONS(1720),
    [sym_kOperator] = ACTIONS(1720),
    [sym_kPublished] = ACTIONS(1720),
    [sym_kPublic] = ACTIONS(2045),
    [sym_kProtected] = ACTIONS(1720),
    [sym_kPrivate] = ACTIONS(1720),
    [sym_kStrict] = ACTIONS(1720),
    [sym_kRequired] = ACTIONS(1720),
    [sym_kOptional] = ACTIONS(1720),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [308] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(313),
    [anon_sym_LBRACK] = ACTIONS(2048),
    [sym_kEnd] = ACTIONS(1727),
    [sym_kVar] = ACTIONS(1729),
    [sym_kThreadvar] = ACTIONS(1727),
    [sym_kConst] = ACTIONS(1729),
    [sym_kResourcestring] = ACTIONS(1727),
    [sym_kType] = ACTIONS(1727),
    [sym_kProperty] = ACTIONS(1727),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1727),
    [sym_kGeneric] = ACTIONS(1727),
    [sym_kCase] = ACTIONS(1727),
    [sym_kFunction] = ACTIONS(1727),
    [sym_kProcedure] = ACTIONS(1727),
    [sym_kConstructor] = ACTIONS(1727),
    [sym_kDestructor] = ACTIONS(1727),
    [sym_kOperator] = ACTIONS(1727),
    [sym_kPublished] = ACTIONS(1727),
    [sym_kPublic] = ACTIONS(2051),
    [sym_kProtected] = ACTIONS(1727),
    [sym_kPrivate] = ACTIONS(1727),
    [sym_kStrict] = ACTIONS(1727),
    [sym_kRequired] = ACTIONS(1727),
    [sym_kOptional] = ACTIONS(1727),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [309] = {
    [sym__procAttributeNoExt] = STATE(412),
    [sym_procAttribute] = STATE(2465),
    [aux_sym__declProc_repeat1] = STATE(163),
    [anon_sym_LBRACK] = ACTIONS(2054),
    [sym_kUses] = ACTIONS(2057),
    [sym_kInterface] = ACTIONS(2057),
    [sym_kImplementation] = ACTIONS(2057),
    [sym_kInitialization] = ACTIONS(2057),
    [sym_kFinalization] = ACTIONS(2057),
    [sym_kEnd] = ACTIONS(2057),
    [sym_kVar] = ACTIONS(2059),
    [sym_kThreadvar] = ACTIONS(2057),
    [sym_kConst] = ACTIONS(2059),
    [sym_kResourcestring] = ACTIONS(2057),
    [sym_kType] = ACTIONS(2057),
    [sym_kLabel] = ACTIONS(2057),
    [sym_kExports] = ACTIONS(2057),
    [sym_kProperty] = ACTIONS(2057),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2057),
    [sym_kGeneric] = ACTIONS(2057),
    [sym_kFunction] = ACTIONS(2057),
    [sym_kProcedure] = ACTIONS(2057),
    [sym_kConstructor] = ACTIONS(2057),
    [sym_kDestructor] = ACTIONS(2057),
    [sym_kOperator] = ACTIONS(2057),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [310] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2061),
    [sym_kEnd] = ACTIONS(1769),
    [sym_kVar] = ACTIONS(1771),
    [sym_kThreadvar] = ACTIONS(1769),
    [sym_kConst] = ACTIONS(1771),
    [sym_kResourcestring] = ACTIONS(1769),
    [sym_kType] = ACTIONS(1769),
    [sym_kProperty] = ACTIONS(1769),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1769),
    [sym_kGeneric] = ACTIONS(1769),
    [sym_kCase] = ACTIONS(1769),
    [sym_kFunction] = ACTIONS(1769),
    [sym_kProcedure] = ACTIONS(1769),
    [sym_kConstructor] = ACTIONS(1769),
    [sym_kDestructor] = ACTIONS(1769),
    [sym_kOperator] = ACTIONS(1769),
    [sym_kPublished] = ACTIONS(1769),
    [sym_kPublic] = ACTIONS(2064),
    [sym_kProtected] = ACTIONS(1769),
    [sym_kPrivate] = ACTIONS(1769),
    [sym_kStrict] = ACTIONS(1769),
    [sym_kRequired] = ACTIONS(1769),
    [sym_kOptional] = ACTIONS(1769),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [311] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2067),
    [sym_kEnd] = ACTIONS(1776),
    [sym_kVar] = ACTIONS(1778),
    [sym_kThreadvar] = ACTIONS(1776),
    [sym_kConst] = ACTIONS(1778),
    [sym_kResourcestring] = ACTIONS(1776),
    [sym_kType] = ACTIONS(1776),
    [sym_kProperty] = ACTIONS(1776),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1776),
    [sym_kGeneric] = ACTIONS(1776),
    [sym_kCase] = ACTIONS(1776),
    [sym_kFunction] = ACTIONS(1776),
    [sym_kProcedure] = ACTIONS(1776),
    [sym_kConstructor] = ACTIONS(1776),
    [sym_kDestructor] = ACTIONS(1776),
    [sym_kOperator] = ACTIONS(1776),
    [sym_kPublished] = ACTIONS(1776),
    [sym_kPublic] = ACTIONS(2070),
    [sym_kProtected] = ACTIONS(1776),
    [sym_kPrivate] = ACTIONS(1776),
    [sym_kStrict] = ACTIONS(1776),
    [sym_kRequired] = ACTIONS(1776),
    [sym_kOptional] = ACTIONS(1776),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [312] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(317),
    [anon_sym_LBRACK] = ACTIONS(2073),
    [sym_kEnd] = ACTIONS(1783),
    [sym_kVar] = ACTIONS(1785),
    [sym_kThreadvar] = ACTIONS(1783),
    [sym_kConst] = ACTIONS(1785),
    [sym_kResourcestring] = ACTIONS(1783),
    [sym_kType] = ACTIONS(1783),
    [sym_kProperty] = ACTIONS(1783),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1783),
    [sym_kGeneric] = ACTIONS(1783),
    [sym_kCase] = ACTIONS(1783),
    [sym_kFunction] = ACTIONS(1783),
    [sym_kProcedure] = ACTIONS(1783),
    [sym_kConstructor] = ACTIONS(1783),
    [sym_kDestructor] = ACTIONS(1783),
    [sym_kOperator] = ACTIONS(1783),
    [sym_kPublished] = ACTIONS(1783),
    [sym_kPublic] = ACTIONS(2076),
    [sym_kProtected] = ACTIONS(1783),
    [sym_kPrivate] = ACTIONS(1783),
    [sym_kStrict] = ACTIONS(1783),
    [sym_kRequired] = ACTIONS(1783),
    [sym_kOptional] = ACTIONS(1783),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [313] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2079),
    [sym_kEnd] = ACTIONS(1790),
    [sym_kVar] = ACTIONS(1792),
    [sym_kThreadvar] = ACTIONS(1790),
    [sym_kConst] = ACTIONS(1792),
    [sym_kResourcestring] = ACTIONS(1790),
    [sym_kType] = ACTIONS(1790),
    [sym_kProperty] = ACTIONS(1790),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1790),
    [sym_kGeneric] = ACTIONS(1790),
    [sym_kCase] = ACTIONS(1790),
    [sym_kFunction] = ACTIONS(1790),
    [sym_kProcedure] = ACTIONS(1790),
    [sym_kConstructor] = ACTIONS(1790),
    [sym_kDestructor] = ACTIONS(1790),
    [sym_kOperator] = ACTIONS(1790),
    [sym_kPublished] = ACTIONS(1790),
    [sym_kPublic] = ACTIONS(2082),
    [sym_kProtected] = ACTIONS(1790),
    [sym_kPrivate] = ACTIONS(1790),
    [sym_kStrict] = ACTIONS(1790),
    [sym_kRequired] = ACTIONS(1790),
    [sym_kOptional] = ACTIONS(1790),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [314] = {
    [sym__procAttribute] = STATE(228),
    [sym_procAttribute] = STATE(2702),
    [aux_sym_declProcFwd_repeat1] = STATE(259),
    [anon_sym_LBRACK] = ACTIONS(2085),
    [sym_kUses] = ACTIONS(1972),
    [sym_kInterface] = ACTIONS(1972),
    [sym_kImplementation] = ACTIONS(1972),
    [sym_kInitialization] = ACTIONS(1972),
    [sym_kFinalization] = ACTIONS(1972),
    [sym_kEnd] = ACTIONS(1972),
    [sym_kVar] = ACTIONS(1974),
    [sym_kThreadvar] = ACTIONS(1972),
    [sym_kConst] = ACTIONS(1974),
    [sym_kResourcestring] = ACTIONS(1972),
    [sym_kType] = ACTIONS(1972),
    [sym_kLabel] = ACTIONS(1972),
    [sym_kExports] = ACTIONS(1972),
    [sym_kProperty] = ACTIONS(1972),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1972),
    [sym_kGeneric] = ACTIONS(1972),
    [sym_kFunction] = ACTIONS(1972),
    [sym_kProcedure] = ACTIONS(1972),
    [sym_kConstructor] = ACTIONS(1972),
    [sym_kDestructor] = ACTIONS(1972),
    [sym_kOperator] = ACTIONS(1972),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [315] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(319),
    [anon_sym_LBRACK] = ACTIONS(2088),
    [sym_kEnd] = ACTIONS(1874),
    [sym_kVar] = ACTIONS(1876),
    [sym_kThreadvar] = ACTIONS(1874),
    [sym_kConst] = ACTIONS(1876),
    [sym_kResourcestring] = ACTIONS(1874),
    [sym_kType] = ACTIONS(1874),
    [sym_kProperty] = ACTIONS(1874),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1874),
    [sym_kGeneric] = ACTIONS(1874),
    [sym_kCase] = ACTIONS(1874),
    [sym_kFunction] = ACTIONS(1874),
    [sym_kProcedure] = ACTIONS(1874),
    [sym_kConstructor] = ACTIONS(1874),
    [sym_kDestructor] = ACTIONS(1874),
    [sym_kOperator] = ACTIONS(1874),
    [sym_kPublished] = ACTIONS(1874),
    [sym_kPublic] = ACTIONS(2091),
    [sym_kProtected] = ACTIONS(1874),
    [sym_kPrivate] = ACTIONS(1874),
    [sym_kStrict] = ACTIONS(1874),
    [sym_kRequired] = ACTIONS(1874),
    [sym_kOptional] = ACTIONS(1874),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [316] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(321),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [sym_kEnd] = ACTIONS(1881),
    [sym_kVar] = ACTIONS(1883),
    [sym_kThreadvar] = ACTIONS(1881),
    [sym_kConst] = ACTIONS(1883),
    [sym_kResourcestring] = ACTIONS(1881),
    [sym_kType] = ACTIONS(1881),
    [sym_kProperty] = ACTIONS(1881),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1881),
    [sym_kGeneric] = ACTIONS(1881),
    [sym_kCase] = ACTIONS(1881),
    [sym_kFunction] = ACTIONS(1881),
    [sym_kProcedure] = ACTIONS(1881),
    [sym_kConstructor] = ACTIONS(1881),
    [sym_kDestructor] = ACTIONS(1881),
    [sym_kOperator] = ACTIONS(1881),
    [sym_kPublished] = ACTIONS(1881),
    [sym_kPublic] = ACTIONS(2097),
    [sym_kProtected] = ACTIONS(1881),
    [sym_kPrivate] = ACTIONS(1881),
    [sym_kStrict] = ACTIONS(1881),
    [sym_kRequired] = ACTIONS(1881),
    [sym_kOptional] = ACTIONS(1881),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [317] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2100),
    [sym_kEnd] = ACTIONS(1888),
    [sym_kVar] = ACTIONS(1890),
    [sym_kThreadvar] = ACTIONS(1888),
    [sym_kConst] = ACTIONS(1890),
    [sym_kResourcestring] = ACTIONS(1888),
    [sym_kType] = ACTIONS(1888),
    [sym_kProperty] = ACTIONS(1888),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1888),
    [sym_kGeneric] = ACTIONS(1888),
    [sym_kCase] = ACTIONS(1888),
    [sym_kFunction] = ACTIONS(1888),
    [sym_kProcedure] = ACTIONS(1888),
    [sym_kConstructor] = ACTIONS(1888),
    [sym_kDestructor] = ACTIONS(1888),
    [sym_kOperator] = ACTIONS(1888),
    [sym_kPublished] = ACTIONS(1888),
    [sym_kPublic] = ACTIONS(2103),
    [sym_kProtected] = ACTIONS(1888),
    [sym_kPrivate] = ACTIONS(1888),
    [sym_kStrict] = ACTIONS(1888),
    [sym_kRequired] = ACTIONS(1888),
    [sym_kOptional] = ACTIONS(1888),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [318] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [sym_kEnd] = ACTIONS(1895),
    [sym_kVar] = ACTIONS(1897),
    [sym_kThreadvar] = ACTIONS(1895),
    [sym_kConst] = ACTIONS(1897),
    [sym_kResourcestring] = ACTIONS(1895),
    [sym_kType] = ACTIONS(1895),
    [sym_kProperty] = ACTIONS(1895),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1895),
    [sym_kGeneric] = ACTIONS(1895),
    [sym_kCase] = ACTIONS(1895),
    [sym_kFunction] = ACTIONS(1895),
    [sym_kProcedure] = ACTIONS(1895),
    [sym_kConstructor] = ACTIONS(1895),
    [sym_kDestructor] = ACTIONS(1895),
    [sym_kOperator] = ACTIONS(1895),
    [sym_kPublished] = ACTIONS(1895),
    [sym_kPublic] = ACTIONS(2109),
    [sym_kProtected] = ACTIONS(1895),
    [sym_kPrivate] = ACTIONS(1895),
    [sym_kStrict] = ACTIONS(1895),
    [sym_kRequired] = ACTIONS(1895),
    [sym_kOptional] = ACTIONS(1895),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [319] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2112),
    [sym_kEnd] = ACTIONS(1902),
    [sym_kVar] = ACTIONS(1904),
    [sym_kThreadvar] = ACTIONS(1902),
    [sym_kConst] = ACTIONS(1904),
    [sym_kResourcestring] = ACTIONS(1902),
    [sym_kType] = ACTIONS(1902),
    [sym_kProperty] = ACTIONS(1902),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1902),
    [sym_kGeneric] = ACTIONS(1902),
    [sym_kCase] = ACTIONS(1902),
    [sym_kFunction] = ACTIONS(1902),
    [sym_kProcedure] = ACTIONS(1902),
    [sym_kConstructor] = ACTIONS(1902),
    [sym_kDestructor] = ACTIONS(1902),
    [sym_kOperator] = ACTIONS(1902),
    [sym_kPublished] = ACTIONS(1902),
    [sym_kPublic] = ACTIONS(2115),
    [sym_kProtected] = ACTIONS(1902),
    [sym_kPrivate] = ACTIONS(1902),
    [sym_kStrict] = ACTIONS(1902),
    [sym_kRequired] = ACTIONS(1902),
    [sym_kOptional] = ACTIONS(1902),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [320] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(324),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [sym_kEnd] = ACTIONS(1984),
    [sym_kVar] = ACTIONS(1986),
    [sym_kThreadvar] = ACTIONS(1984),
    [sym_kConst] = ACTIONS(1986),
    [sym_kResourcestring] = ACTIONS(1984),
    [sym_kType] = ACTIONS(1984),
    [sym_kProperty] = ACTIONS(1984),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1984),
    [sym_kGeneric] = ACTIONS(1984),
    [sym_kCase] = ACTIONS(1984),
    [sym_kFunction] = ACTIONS(1984),
    [sym_kProcedure] = ACTIONS(1984),
    [sym_kConstructor] = ACTIONS(1984),
    [sym_kDestructor] = ACTIONS(1984),
    [sym_kOperator] = ACTIONS(1984),
    [sym_kPublished] = ACTIONS(1984),
    [sym_kPublic] = ACTIONS(2121),
    [sym_kProtected] = ACTIONS(1984),
    [sym_kPrivate] = ACTIONS(1984),
    [sym_kStrict] = ACTIONS(1984),
    [sym_kRequired] = ACTIONS(1984),
    [sym_kOptional] = ACTIONS(1984),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [321] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2124),
    [sym_kEnd] = ACTIONS(1991),
    [sym_kVar] = ACTIONS(1993),
    [sym_kThreadvar] = ACTIONS(1991),
    [sym_kConst] = ACTIONS(1993),
    [sym_kResourcestring] = ACTIONS(1991),
    [sym_kType] = ACTIONS(1991),
    [sym_kProperty] = ACTIONS(1991),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1991),
    [sym_kGeneric] = ACTIONS(1991),
    [sym_kCase] = ACTIONS(1991),
    [sym_kFunction] = ACTIONS(1991),
    [sym_kProcedure] = ACTIONS(1991),
    [sym_kConstructor] = ACTIONS(1991),
    [sym_kDestructor] = ACTIONS(1991),
    [sym_kOperator] = ACTIONS(1991),
    [sym_kPublished] = ACTIONS(1991),
    [sym_kPublic] = ACTIONS(2127),
    [sym_kProtected] = ACTIONS(1991),
    [sym_kPrivate] = ACTIONS(1991),
    [sym_kStrict] = ACTIONS(1991),
    [sym_kRequired] = ACTIONS(1991),
    [sym_kOptional] = ACTIONS(1991),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [322] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(325),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [sym_kEnd] = ACTIONS(1650),
    [sym_kVar] = ACTIONS(1652),
    [sym_kThreadvar] = ACTIONS(1650),
    [sym_kConst] = ACTIONS(1652),
    [sym_kResourcestring] = ACTIONS(1650),
    [sym_kType] = ACTIONS(1650),
    [sym_kProperty] = ACTIONS(1650),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1650),
    [sym_kGeneric] = ACTIONS(1650),
    [sym_kCase] = ACTIONS(1650),
    [sym_kFunction] = ACTIONS(1650),
    [sym_kProcedure] = ACTIONS(1650),
    [sym_kConstructor] = ACTIONS(1650),
    [sym_kDestructor] = ACTIONS(1650),
    [sym_kOperator] = ACTIONS(1650),
    [sym_kPublished] = ACTIONS(1650),
    [sym_kPublic] = ACTIONS(2133),
    [sym_kProtected] = ACTIONS(1650),
    [sym_kPrivate] = ACTIONS(1650),
    [sym_kStrict] = ACTIONS(1650),
    [sym_kRequired] = ACTIONS(1650),
    [sym_kOptional] = ACTIONS(1650),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [323] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(326),
    [anon_sym_LBRACK] = ACTIONS(2136),
    [sym_kEnd] = ACTIONS(1657),
    [sym_kVar] = ACTIONS(1659),
    [sym_kThreadvar] = ACTIONS(1657),
    [sym_kConst] = ACTIONS(1659),
    [sym_kResourcestring] = ACTIONS(1657),
    [sym_kType] = ACTIONS(1657),
    [sym_kProperty] = ACTIONS(1657),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1657),
    [sym_kGeneric] = ACTIONS(1657),
    [sym_kCase] = ACTIONS(1657),
    [sym_kFunction] = ACTIONS(1657),
    [sym_kProcedure] = ACTIONS(1657),
    [sym_kConstructor] = ACTIONS(1657),
    [sym_kDestructor] = ACTIONS(1657),
    [sym_kOperator] = ACTIONS(1657),
    [sym_kPublished] = ACTIONS(1657),
    [sym_kPublic] = ACTIONS(2139),
    [sym_kProtected] = ACTIONS(1657),
    [sym_kPrivate] = ACTIONS(1657),
    [sym_kStrict] = ACTIONS(1657),
    [sym_kRequired] = ACTIONS(1657),
    [sym_kOptional] = ACTIONS(1657),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [324] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [sym_kEnd] = ACTIONS(1664),
    [sym_kVar] = ACTIONS(1666),
    [sym_kThreadvar] = ACTIONS(1664),
    [sym_kConst] = ACTIONS(1666),
    [sym_kResourcestring] = ACTIONS(1664),
    [sym_kType] = ACTIONS(1664),
    [sym_kProperty] = ACTIONS(1664),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1664),
    [sym_kGeneric] = ACTIONS(1664),
    [sym_kCase] = ACTIONS(1664),
    [sym_kFunction] = ACTIONS(1664),
    [sym_kProcedure] = ACTIONS(1664),
    [sym_kConstructor] = ACTIONS(1664),
    [sym_kDestructor] = ACTIONS(1664),
    [sym_kOperator] = ACTIONS(1664),
    [sym_kPublished] = ACTIONS(1664),
    [sym_kPublic] = ACTIONS(2145),
    [sym_kProtected] = ACTIONS(1664),
    [sym_kPrivate] = ACTIONS(1664),
    [sym_kStrict] = ACTIONS(1664),
    [sym_kRequired] = ACTIONS(1664),
    [sym_kOptional] = ACTIONS(1664),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [325] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2148),
    [sym_kEnd] = ACTIONS(1671),
    [sym_kVar] = ACTIONS(1673),
    [sym_kThreadvar] = ACTIONS(1671),
    [sym_kConst] = ACTIONS(1673),
    [sym_kResourcestring] = ACTIONS(1671),
    [sym_kType] = ACTIONS(1671),
    [sym_kProperty] = ACTIONS(1671),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1671),
    [sym_kGeneric] = ACTIONS(1671),
    [sym_kCase] = ACTIONS(1671),
    [sym_kFunction] = ACTIONS(1671),
    [sym_kProcedure] = ACTIONS(1671),
    [sym_kConstructor] = ACTIONS(1671),
    [sym_kDestructor] = ACTIONS(1671),
    [sym_kOperator] = ACTIONS(1671),
    [sym_kPublished] = ACTIONS(1671),
    [sym_kPublic] = ACTIONS(2151),
    [sym_kProtected] = ACTIONS(1671),
    [sym_kPrivate] = ACTIONS(1671),
    [sym_kStrict] = ACTIONS(1671),
    [sym_kRequired] = ACTIONS(1671),
    [sym_kOptional] = ACTIONS(1671),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [326] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [sym_kEnd] = ACTIONS(1678),
    [sym_kVar] = ACTIONS(1680),
    [sym_kThreadvar] = ACTIONS(1678),
    [sym_kConst] = ACTIONS(1680),
    [sym_kResourcestring] = ACTIONS(1678),
    [sym_kType] = ACTIONS(1678),
    [sym_kProperty] = ACTIONS(1678),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1678),
    [sym_kGeneric] = ACTIONS(1678),
    [sym_kCase] = ACTIONS(1678),
    [sym_kFunction] = ACTIONS(1678),
    [sym_kProcedure] = ACTIONS(1678),
    [sym_kConstructor] = ACTIONS(1678),
    [sym_kDestructor] = ACTIONS(1678),
    [sym_kOperator] = ACTIONS(1678),
    [sym_kPublished] = ACTIONS(1678),
    [sym_kPublic] = ACTIONS(2157),
    [sym_kProtected] = ACTIONS(1678),
    [sym_kPrivate] = ACTIONS(1678),
    [sym_kStrict] = ACTIONS(1678),
    [sym_kRequired] = ACTIONS(1678),
    [sym_kOptional] = ACTIONS(1678),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [327] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(328),
    [anon_sym_LBRACK] = ACTIONS(2160),
    [sym_kEnd] = ACTIONS(1685),
    [sym_kVar] = ACTIONS(1687),
    [sym_kThreadvar] = ACTIONS(1685),
    [sym_kConst] = ACTIONS(1687),
    [sym_kResourcestring] = ACTIONS(1685),
    [sym_kType] = ACTIONS(1685),
    [sym_kProperty] = ACTIONS(1685),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1685),
    [sym_kGeneric] = ACTIONS(1685),
    [sym_kCase] = ACTIONS(1685),
    [sym_kFunction] = ACTIONS(1685),
    [sym_kProcedure] = ACTIONS(1685),
    [sym_kConstructor] = ACTIONS(1685),
    [sym_kDestructor] = ACTIONS(1685),
    [sym_kOperator] = ACTIONS(1685),
    [sym_kPublished] = ACTIONS(1685),
    [sym_kPublic] = ACTIONS(2163),
    [sym_kProtected] = ACTIONS(1685),
    [sym_kPrivate] = ACTIONS(1685),
    [sym_kStrict] = ACTIONS(1685),
    [sym_kRequired] = ACTIONS(1685),
    [sym_kOptional] = ACTIONS(1685),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [328] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(230),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [sym_kEnd] = ACTIONS(1692),
    [sym_kVar] = ACTIONS(1694),
    [sym_kThreadvar] = ACTIONS(1692),
    [sym_kConst] = ACTIONS(1694),
    [sym_kResourcestring] = ACTIONS(1692),
    [sym_kType] = ACTIONS(1692),
    [sym_kProperty] = ACTIONS(1692),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1692),
    [sym_kGeneric] = ACTIONS(1692),
    [sym_kCase] = ACTIONS(1692),
    [sym_kFunction] = ACTIONS(1692),
    [sym_kProcedure] = ACTIONS(1692),
    [sym_kConstructor] = ACTIONS(1692),
    [sym_kDestructor] = ACTIONS(1692),
    [sym_kOperator] = ACTIONS(1692),
    [sym_kPublished] = ACTIONS(1692),
    [sym_kPublic] = ACTIONS(2169),
    [sym_kProtected] = ACTIONS(1692),
    [sym_kPrivate] = ACTIONS(1692),
    [sym_kStrict] = ACTIONS(1692),
    [sym_kRequired] = ACTIONS(1692),
    [sym_kOptional] = ACTIONS(1692),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [329] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(331),
    [anon_sym_LBRACK] = ACTIONS(2172),
    [sym_kEnd] = ACTIONS(1450),
    [sym_kVar] = ACTIONS(1452),
    [sym_kThreadvar] = ACTIONS(1450),
    [sym_kConst] = ACTIONS(1452),
    [sym_kResourcestring] = ACTIONS(1450),
    [sym_kType] = ACTIONS(1450),
    [sym_kProperty] = ACTIONS(1450),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1450),
    [sym_kGeneric] = ACTIONS(1450),
    [sym_kCase] = ACTIONS(1450),
    [sym_kFunction] = ACTIONS(1450),
    [sym_kProcedure] = ACTIONS(1450),
    [sym_kConstructor] = ACTIONS(1450),
    [sym_kDestructor] = ACTIONS(1450),
    [sym_kOperator] = ACTIONS(1450),
    [sym_kPublished] = ACTIONS(1450),
    [sym_kPublic] = ACTIONS(2175),
    [sym_kProtected] = ACTIONS(1450),
    [sym_kPrivate] = ACTIONS(1450),
    [sym_kStrict] = ACTIONS(1450),
    [sym_kRequired] = ACTIONS(1450),
    [sym_kOptional] = ACTIONS(1450),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [330] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(334),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [sym_kEnd] = ACTIONS(1475),
    [sym_kVar] = ACTIONS(1477),
    [sym_kThreadvar] = ACTIONS(1475),
    [sym_kConst] = ACTIONS(1477),
    [sym_kResourcestring] = ACTIONS(1475),
    [sym_kType] = ACTIONS(1475),
    [sym_kProperty] = ACTIONS(1475),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1475),
    [sym_kGeneric] = ACTIONS(1475),
    [sym_kCase] = ACTIONS(1475),
    [sym_kFunction] = ACTIONS(1475),
    [sym_kProcedure] = ACTIONS(1475),
    [sym_kConstructor] = ACTIONS(1475),
    [sym_kDestructor] = ACTIONS(1475),
    [sym_kOperator] = ACTIONS(1475),
    [sym_kPublished] = ACTIONS(1475),
    [sym_kPublic] = ACTIONS(2181),
    [sym_kProtected] = ACTIONS(1475),
    [sym_kPrivate] = ACTIONS(1475),
    [sym_kStrict] = ACTIONS(1475),
    [sym_kRequired] = ACTIONS(1475),
    [sym_kOptional] = ACTIONS(1475),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [331] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2184),
    [sym_kEnd] = ACTIONS(1361),
    [sym_kVar] = ACTIONS(1363),
    [sym_kThreadvar] = ACTIONS(1361),
    [sym_kConst] = ACTIONS(1363),
    [sym_kResourcestring] = ACTIONS(1361),
    [sym_kType] = ACTIONS(1361),
    [sym_kProperty] = ACTIONS(1361),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1361),
    [sym_kGeneric] = ACTIONS(1361),
    [sym_kCase] = ACTIONS(1361),
    [sym_kFunction] = ACTIONS(1361),
    [sym_kProcedure] = ACTIONS(1361),
    [sym_kConstructor] = ACTIONS(1361),
    [sym_kDestructor] = ACTIONS(1361),
    [sym_kOperator] = ACTIONS(1361),
    [sym_kPublished] = ACTIONS(1361),
    [sym_kPublic] = ACTIONS(2187),
    [sym_kProtected] = ACTIONS(1361),
    [sym_kPrivate] = ACTIONS(1361),
    [sym_kStrict] = ACTIONS(1361),
    [sym_kRequired] = ACTIONS(1361),
    [sym_kOptional] = ACTIONS(1361),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [332] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(340),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [sym_kEnd] = ACTIONS(1266),
    [sym_kVar] = ACTIONS(1268),
    [sym_kThreadvar] = ACTIONS(1266),
    [sym_kConst] = ACTIONS(1268),
    [sym_kResourcestring] = ACTIONS(1266),
    [sym_kType] = ACTIONS(1266),
    [sym_kProperty] = ACTIONS(1266),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1266),
    [sym_kGeneric] = ACTIONS(1266),
    [sym_kCase] = ACTIONS(1266),
    [sym_kFunction] = ACTIONS(1266),
    [sym_kProcedure] = ACTIONS(1266),
    [sym_kConstructor] = ACTIONS(1266),
    [sym_kDestructor] = ACTIONS(1266),
    [sym_kOperator] = ACTIONS(1266),
    [sym_kPublished] = ACTIONS(1266),
    [sym_kPublic] = ACTIONS(2193),
    [sym_kProtected] = ACTIONS(1266),
    [sym_kPrivate] = ACTIONS(1266),
    [sym_kStrict] = ACTIONS(1266),
    [sym_kRequired] = ACTIONS(1266),
    [sym_kOptional] = ACTIONS(1266),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [333] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(341),
    [anon_sym_LBRACK] = ACTIONS(2196),
    [sym_kEnd] = ACTIONS(1273),
    [sym_kVar] = ACTIONS(1275),
    [sym_kThreadvar] = ACTIONS(1273),
    [sym_kConst] = ACTIONS(1275),
    [sym_kResourcestring] = ACTIONS(1273),
    [sym_kType] = ACTIONS(1273),
    [sym_kProperty] = ACTIONS(1273),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1273),
    [sym_kGeneric] = ACTIONS(1273),
    [sym_kCase] = ACTIONS(1273),
    [sym_kFunction] = ACTIONS(1273),
    [sym_kProcedure] = ACTIONS(1273),
    [sym_kConstructor] = ACTIONS(1273),
    [sym_kDestructor] = ACTIONS(1273),
    [sym_kOperator] = ACTIONS(1273),
    [sym_kPublished] = ACTIONS(1273),
    [sym_kPublic] = ACTIONS(2199),
    [sym_kProtected] = ACTIONS(1273),
    [sym_kPrivate] = ACTIONS(1273),
    [sym_kStrict] = ACTIONS(1273),
    [sym_kRequired] = ACTIONS(1273),
    [sym_kOptional] = ACTIONS(1273),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [334] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2202),
    [sym_kEnd] = ACTIONS(1284),
    [sym_kVar] = ACTIONS(1286),
    [sym_kThreadvar] = ACTIONS(1284),
    [sym_kConst] = ACTIONS(1286),
    [sym_kResourcestring] = ACTIONS(1284),
    [sym_kType] = ACTIONS(1284),
    [sym_kProperty] = ACTIONS(1284),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1284),
    [sym_kGeneric] = ACTIONS(1284),
    [sym_kCase] = ACTIONS(1284),
    [sym_kFunction] = ACTIONS(1284),
    [sym_kProcedure] = ACTIONS(1284),
    [sym_kConstructor] = ACTIONS(1284),
    [sym_kDestructor] = ACTIONS(1284),
    [sym_kOperator] = ACTIONS(1284),
    [sym_kPublished] = ACTIONS(1284),
    [sym_kPublic] = ACTIONS(2205),
    [sym_kProtected] = ACTIONS(1284),
    [sym_kPrivate] = ACTIONS(1284),
    [sym_kStrict] = ACTIONS(1284),
    [sym_kRequired] = ACTIONS(1284),
    [sym_kOptional] = ACTIONS(1284),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [335] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(345),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [sym_kEnd] = ACTIONS(1291),
    [sym_kVar] = ACTIONS(1293),
    [sym_kThreadvar] = ACTIONS(1291),
    [sym_kConst] = ACTIONS(1293),
    [sym_kResourcestring] = ACTIONS(1291),
    [sym_kType] = ACTIONS(1291),
    [sym_kProperty] = ACTIONS(1291),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1291),
    [sym_kGeneric] = ACTIONS(1291),
    [sym_kCase] = ACTIONS(1291),
    [sym_kFunction] = ACTIONS(1291),
    [sym_kProcedure] = ACTIONS(1291),
    [sym_kConstructor] = ACTIONS(1291),
    [sym_kDestructor] = ACTIONS(1291),
    [sym_kOperator] = ACTIONS(1291),
    [sym_kPublished] = ACTIONS(1291),
    [sym_kPublic] = ACTIONS(2211),
    [sym_kProtected] = ACTIONS(1291),
    [sym_kPrivate] = ACTIONS(1291),
    [sym_kStrict] = ACTIONS(1291),
    [sym_kRequired] = ACTIONS(1291),
    [sym_kOptional] = ACTIONS(1291),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [336] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(346),
    [anon_sym_LBRACK] = ACTIONS(2214),
    [sym_kEnd] = ACTIONS(1122),
    [sym_kVar] = ACTIONS(1124),
    [sym_kThreadvar] = ACTIONS(1122),
    [sym_kConst] = ACTIONS(1124),
    [sym_kResourcestring] = ACTIONS(1122),
    [sym_kType] = ACTIONS(1122),
    [sym_kProperty] = ACTIONS(1122),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1122),
    [sym_kGeneric] = ACTIONS(1122),
    [sym_kCase] = ACTIONS(1122),
    [sym_kFunction] = ACTIONS(1122),
    [sym_kProcedure] = ACTIONS(1122),
    [sym_kConstructor] = ACTIONS(1122),
    [sym_kDestructor] = ACTIONS(1122),
    [sym_kOperator] = ACTIONS(1122),
    [sym_kPublished] = ACTIONS(1122),
    [sym_kPublic] = ACTIONS(2217),
    [sym_kProtected] = ACTIONS(1122),
    [sym_kPrivate] = ACTIONS(1122),
    [sym_kStrict] = ACTIONS(1122),
    [sym_kRequired] = ACTIONS(1122),
    [sym_kOptional] = ACTIONS(1122),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [337] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(349),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [sym_kEnd] = ACTIONS(1129),
    [sym_kVar] = ACTIONS(1131),
    [sym_kThreadvar] = ACTIONS(1129),
    [sym_kConst] = ACTIONS(1131),
    [sym_kResourcestring] = ACTIONS(1129),
    [sym_kType] = ACTIONS(1129),
    [sym_kProperty] = ACTIONS(1129),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1129),
    [sym_kGeneric] = ACTIONS(1129),
    [sym_kCase] = ACTIONS(1129),
    [sym_kFunction] = ACTIONS(1129),
    [sym_kProcedure] = ACTIONS(1129),
    [sym_kConstructor] = ACTIONS(1129),
    [sym_kDestructor] = ACTIONS(1129),
    [sym_kOperator] = ACTIONS(1129),
    [sym_kPublished] = ACTIONS(1129),
    [sym_kPublic] = ACTIONS(2223),
    [sym_kProtected] = ACTIONS(1129),
    [sym_kPrivate] = ACTIONS(1129),
    [sym_kStrict] = ACTIONS(1129),
    [sym_kRequired] = ACTIONS(1129),
    [sym_kOptional] = ACTIONS(1129),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [338] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2226),
    [sym_kEnd] = ACTIONS(1136),
    [sym_kVar] = ACTIONS(1138),
    [sym_kThreadvar] = ACTIONS(1136),
    [sym_kConst] = ACTIONS(1138),
    [sym_kResourcestring] = ACTIONS(1136),
    [sym_kType] = ACTIONS(1136),
    [sym_kProperty] = ACTIONS(1136),
    [sym_kDefault] = ACTIONS(1140),
    [sym_kNodefault] = ACTIONS(1140),
    [sym_kDispId] = ACTIONS(1143),
    [sym_kClass] = ACTIONS(1136),
    [sym_kGeneric] = ACTIONS(1136),
    [sym_kCase] = ACTIONS(1136),
    [sym_kFunction] = ACTIONS(1136),
    [sym_kProcedure] = ACTIONS(1136),
    [sym_kConstructor] = ACTIONS(1136),
    [sym_kDestructor] = ACTIONS(1136),
    [sym_kOperator] = ACTIONS(1136),
    [sym_kPublished] = ACTIONS(1136),
    [sym_kPublic] = ACTIONS(1146),
    [sym_kProtected] = ACTIONS(1136),
    [sym_kPrivate] = ACTIONS(1136),
    [sym_kStrict] = ACTIONS(1136),
    [sym_kRequired] = ACTIONS(1136),
    [sym_kOptional] = ACTIONS(1136),
    [sym_kStatic] = ACTIONS(1140),
    [sym_kVirtual] = ACTIONS(1140),
    [sym_kAbstract] = ACTIONS(1140),
    [sym_kDynamic] = ACTIONS(1140),
    [sym_kOverride] = ACTIONS(1140),
    [sym_kOverload] = ACTIONS(1140),
    [sym_kReintroduce] = ACTIONS(1140),
    [sym_kInline] = ACTIONS(1140),
    [sym_kStdcall] = ACTIONS(1140),
    [sym_kCdecl] = ACTIONS(1140),
    [sym_kCppdecl] = ACTIONS(1140),
    [sym_kPascal] = ACTIONS(1140),
    [sym_kRegister] = ACTIONS(1140),
    [sym_kMwpascal] = ACTIONS(1140),
    [sym_kMessage] = ACTIONS(1149),
    [sym_kDeprecated] = ACTIONS(1152),
    [sym_kExperimental] = ACTIONS(1140),
    [sym_kPlatform] = ACTIONS(1140),
    [sym_kUnimplemented] = ACTIONS(1140),
    [sym_kCvar] = ACTIONS(1140),
    [sym_kExport] = ACTIONS(2229),
    [sym_kFar] = ACTIONS(1140),
    [sym_kNear] = ACTIONS(1140),
    [sym_kSafecall] = ACTIONS(1140),
    [sym_kAssembler] = ACTIONS(1140),
    [sym_kNostackframe] = ACTIONS(1140),
    [sym_kInterrupt] = ACTIONS(1140),
    [sym_kNoreturn] = ACTIONS(1140),
    [sym_kIocheck] = ACTIONS(1140),
    [sym_kLocal] = ACTIONS(1140),
    [sym_kHardfloat] = ACTIONS(1140),
    [sym_kSoftfloat] = ACTIONS(1140),
    [sym_kMs_abi_default] = ACTIONS(1140),
    [sym_kMs_abi_cdecl] = ACTIONS(1140),
    [sym_kSaveregisters] = ACTIONS(1140),
    [sym_kSysv_abi_default] = ACTIONS(1140),
    [sym_kSysv_abi_cdecl] = ACTIONS(1140),
    [sym_kVectorcall] = ACTIONS(1140),
    [sym_kVarargs] = ACTIONS(1140),
    [sym_kWinapi] = ACTIONS(1140),
    [sym_kAlias] = ACTIONS(1158),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [339] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(352),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [sym_kEnd] = ACTIONS(1164),
    [sym_kVar] = ACTIONS(1166),
    [sym_kThreadvar] = ACTIONS(1164),
    [sym_kConst] = ACTIONS(1166),
    [sym_kResourcestring] = ACTIONS(1164),
    [sym_kType] = ACTIONS(1164),
    [sym_kProperty] = ACTIONS(1164),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1164),
    [sym_kGeneric] = ACTIONS(1164),
    [sym_kCase] = ACTIONS(1164),
    [sym_kFunction] = ACTIONS(1164),
    [sym_kProcedure] = ACTIONS(1164),
    [sym_kConstructor] = ACTIONS(1164),
    [sym_kDestructor] = ACTIONS(1164),
    [sym_kOperator] = ACTIONS(1164),
    [sym_kPublished] = ACTIONS(1164),
    [sym_kPublic] = ACTIONS(2235),
    [sym_kProtected] = ACTIONS(1164),
    [sym_kPrivate] = ACTIONS(1164),
    [sym_kStrict] = ACTIONS(1164),
    [sym_kRequired] = ACTIONS(1164),
    [sym_kOptional] = ACTIONS(1164),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [340] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2238),
    [sym_kEnd] = ACTIONS(1171),
    [sym_kVar] = ACTIONS(1173),
    [sym_kThreadvar] = ACTIONS(1171),
    [sym_kConst] = ACTIONS(1173),
    [sym_kResourcestring] = ACTIONS(1171),
    [sym_kType] = ACTIONS(1171),
    [sym_kProperty] = ACTIONS(1171),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1171),
    [sym_kGeneric] = ACTIONS(1171),
    [sym_kCase] = ACTIONS(1171),
    [sym_kFunction] = ACTIONS(1171),
    [sym_kProcedure] = ACTIONS(1171),
    [sym_kConstructor] = ACTIONS(1171),
    [sym_kDestructor] = ACTIONS(1171),
    [sym_kOperator] = ACTIONS(1171),
    [sym_kPublished] = ACTIONS(1171),
    [sym_kPublic] = ACTIONS(2241),
    [sym_kProtected] = ACTIONS(1171),
    [sym_kPrivate] = ACTIONS(1171),
    [sym_kStrict] = ACTIONS(1171),
    [sym_kRequired] = ACTIONS(1171),
    [sym_kOptional] = ACTIONS(1171),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [341] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [sym_kEnd] = ACTIONS(1178),
    [sym_kVar] = ACTIONS(1180),
    [sym_kThreadvar] = ACTIONS(1178),
    [sym_kConst] = ACTIONS(1180),
    [sym_kResourcestring] = ACTIONS(1178),
    [sym_kType] = ACTIONS(1178),
    [sym_kProperty] = ACTIONS(1178),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1178),
    [sym_kGeneric] = ACTIONS(1178),
    [sym_kCase] = ACTIONS(1178),
    [sym_kFunction] = ACTIONS(1178),
    [sym_kProcedure] = ACTIONS(1178),
    [sym_kConstructor] = ACTIONS(1178),
    [sym_kDestructor] = ACTIONS(1178),
    [sym_kOperator] = ACTIONS(1178),
    [sym_kPublished] = ACTIONS(1178),
    [sym_kPublic] = ACTIONS(2247),
    [sym_kProtected] = ACTIONS(1178),
    [sym_kPrivate] = ACTIONS(1178),
    [sym_kStrict] = ACTIONS(1178),
    [sym_kRequired] = ACTIONS(1178),
    [sym_kOptional] = ACTIONS(1178),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [342] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(355),
    [anon_sym_LBRACK] = ACTIONS(2250),
    [sym_kEnd] = ACTIONS(1185),
    [sym_kVar] = ACTIONS(1187),
    [sym_kThreadvar] = ACTIONS(1185),
    [sym_kConst] = ACTIONS(1187),
    [sym_kResourcestring] = ACTIONS(1185),
    [sym_kType] = ACTIONS(1185),
    [sym_kProperty] = ACTIONS(1185),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1185),
    [sym_kGeneric] = ACTIONS(1185),
    [sym_kCase] = ACTIONS(1185),
    [sym_kFunction] = ACTIONS(1185),
    [sym_kProcedure] = ACTIONS(1185),
    [sym_kConstructor] = ACTIONS(1185),
    [sym_kDestructor] = ACTIONS(1185),
    [sym_kOperator] = ACTIONS(1185),
    [sym_kPublished] = ACTIONS(1185),
    [sym_kPublic] = ACTIONS(2253),
    [sym_kProtected] = ACTIONS(1185),
    [sym_kPrivate] = ACTIONS(1185),
    [sym_kStrict] = ACTIONS(1185),
    [sym_kRequired] = ACTIONS(1185),
    [sym_kOptional] = ACTIONS(1185),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [343] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(356),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [sym_kEnd] = ACTIONS(1699),
    [sym_kVar] = ACTIONS(1701),
    [sym_kThreadvar] = ACTIONS(1699),
    [sym_kConst] = ACTIONS(1701),
    [sym_kResourcestring] = ACTIONS(1699),
    [sym_kType] = ACTIONS(1699),
    [sym_kProperty] = ACTIONS(1699),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1699),
    [sym_kGeneric] = ACTIONS(1699),
    [sym_kCase] = ACTIONS(1699),
    [sym_kFunction] = ACTIONS(1699),
    [sym_kProcedure] = ACTIONS(1699),
    [sym_kConstructor] = ACTIONS(1699),
    [sym_kDestructor] = ACTIONS(1699),
    [sym_kOperator] = ACTIONS(1699),
    [sym_kPublished] = ACTIONS(1699),
    [sym_kPublic] = ACTIONS(2259),
    [sym_kProtected] = ACTIONS(1699),
    [sym_kPrivate] = ACTIONS(1699),
    [sym_kStrict] = ACTIONS(1699),
    [sym_kRequired] = ACTIONS(1699),
    [sym_kOptional] = ACTIONS(1699),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [344] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(360),
    [anon_sym_LBRACK] = ACTIONS(2262),
    [sym_kEnd] = ACTIONS(1298),
    [sym_kVar] = ACTIONS(1300),
    [sym_kThreadvar] = ACTIONS(1298),
    [sym_kConst] = ACTIONS(1300),
    [sym_kResourcestring] = ACTIONS(1298),
    [sym_kType] = ACTIONS(1298),
    [sym_kProperty] = ACTIONS(1298),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1298),
    [sym_kGeneric] = ACTIONS(1298),
    [sym_kCase] = ACTIONS(1298),
    [sym_kFunction] = ACTIONS(1298),
    [sym_kProcedure] = ACTIONS(1298),
    [sym_kConstructor] = ACTIONS(1298),
    [sym_kDestructor] = ACTIONS(1298),
    [sym_kOperator] = ACTIONS(1298),
    [sym_kPublished] = ACTIONS(1298),
    [sym_kPublic] = ACTIONS(2265),
    [sym_kProtected] = ACTIONS(1298),
    [sym_kPrivate] = ACTIONS(1298),
    [sym_kStrict] = ACTIONS(1298),
    [sym_kRequired] = ACTIONS(1298),
    [sym_kOptional] = ACTIONS(1298),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [345] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [sym_kEnd] = ACTIONS(1368),
    [sym_kVar] = ACTIONS(1370),
    [sym_kThreadvar] = ACTIONS(1368),
    [sym_kConst] = ACTIONS(1370),
    [sym_kResourcestring] = ACTIONS(1368),
    [sym_kType] = ACTIONS(1368),
    [sym_kProperty] = ACTIONS(1368),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1368),
    [sym_kGeneric] = ACTIONS(1368),
    [sym_kCase] = ACTIONS(1368),
    [sym_kFunction] = ACTIONS(1368),
    [sym_kProcedure] = ACTIONS(1368),
    [sym_kConstructor] = ACTIONS(1368),
    [sym_kDestructor] = ACTIONS(1368),
    [sym_kOperator] = ACTIONS(1368),
    [sym_kPublished] = ACTIONS(1368),
    [sym_kPublic] = ACTIONS(2271),
    [sym_kProtected] = ACTIONS(1368),
    [sym_kPrivate] = ACTIONS(1368),
    [sym_kStrict] = ACTIONS(1368),
    [sym_kRequired] = ACTIONS(1368),
    [sym_kOptional] = ACTIONS(1368),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [346] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2274),
    [sym_kEnd] = ACTIONS(1375),
    [sym_kVar] = ACTIONS(1377),
    [sym_kThreadvar] = ACTIONS(1375),
    [sym_kConst] = ACTIONS(1377),
    [sym_kResourcestring] = ACTIONS(1375),
    [sym_kType] = ACTIONS(1375),
    [sym_kProperty] = ACTIONS(1375),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1375),
    [sym_kGeneric] = ACTIONS(1375),
    [sym_kCase] = ACTIONS(1375),
    [sym_kFunction] = ACTIONS(1375),
    [sym_kProcedure] = ACTIONS(1375),
    [sym_kConstructor] = ACTIONS(1375),
    [sym_kDestructor] = ACTIONS(1375),
    [sym_kOperator] = ACTIONS(1375),
    [sym_kPublished] = ACTIONS(1375),
    [sym_kPublic] = ACTIONS(2277),
    [sym_kProtected] = ACTIONS(1375),
    [sym_kPrivate] = ACTIONS(1375),
    [sym_kStrict] = ACTIONS(1375),
    [sym_kRequired] = ACTIONS(1375),
    [sym_kOptional] = ACTIONS(1375),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [347] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(363),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [sym_kEnd] = ACTIONS(1382),
    [sym_kVar] = ACTIONS(1384),
    [sym_kThreadvar] = ACTIONS(1382),
    [sym_kConst] = ACTIONS(1384),
    [sym_kResourcestring] = ACTIONS(1382),
    [sym_kType] = ACTIONS(1382),
    [sym_kProperty] = ACTIONS(1382),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1382),
    [sym_kGeneric] = ACTIONS(1382),
    [sym_kCase] = ACTIONS(1382),
    [sym_kFunction] = ACTIONS(1382),
    [sym_kProcedure] = ACTIONS(1382),
    [sym_kConstructor] = ACTIONS(1382),
    [sym_kDestructor] = ACTIONS(1382),
    [sym_kOperator] = ACTIONS(1382),
    [sym_kPublished] = ACTIONS(1382),
    [sym_kPublic] = ACTIONS(2283),
    [sym_kProtected] = ACTIONS(1382),
    [sym_kPrivate] = ACTIONS(1382),
    [sym_kStrict] = ACTIONS(1382),
    [sym_kRequired] = ACTIONS(1382),
    [sym_kOptional] = ACTIONS(1382),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [348] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(364),
    [anon_sym_LBRACK] = ACTIONS(2286),
    [sym_kEnd] = ACTIONS(1734),
    [sym_kVar] = ACTIONS(1736),
    [sym_kThreadvar] = ACTIONS(1734),
    [sym_kConst] = ACTIONS(1736),
    [sym_kResourcestring] = ACTIONS(1734),
    [sym_kType] = ACTIONS(1734),
    [sym_kProperty] = ACTIONS(1734),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1734),
    [sym_kGeneric] = ACTIONS(1734),
    [sym_kCase] = ACTIONS(1734),
    [sym_kFunction] = ACTIONS(1734),
    [sym_kProcedure] = ACTIONS(1734),
    [sym_kConstructor] = ACTIONS(1734),
    [sym_kDestructor] = ACTIONS(1734),
    [sym_kOperator] = ACTIONS(1734),
    [sym_kPublished] = ACTIONS(1734),
    [sym_kPublic] = ACTIONS(2289),
    [sym_kProtected] = ACTIONS(1734),
    [sym_kPrivate] = ACTIONS(1734),
    [sym_kStrict] = ACTIONS(1734),
    [sym_kRequired] = ACTIONS(1734),
    [sym_kOptional] = ACTIONS(1734),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [349] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2292),
    [sym_kEnd] = ACTIONS(1389),
    [sym_kVar] = ACTIONS(1391),
    [sym_kThreadvar] = ACTIONS(1389),
    [sym_kConst] = ACTIONS(1391),
    [sym_kResourcestring] = ACTIONS(1389),
    [sym_kType] = ACTIONS(1389),
    [sym_kProperty] = ACTIONS(1389),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1389),
    [sym_kGeneric] = ACTIONS(1389),
    [sym_kCase] = ACTIONS(1389),
    [sym_kFunction] = ACTIONS(1389),
    [sym_kProcedure] = ACTIONS(1389),
    [sym_kConstructor] = ACTIONS(1389),
    [sym_kDestructor] = ACTIONS(1389),
    [sym_kOperator] = ACTIONS(1389),
    [sym_kPublished] = ACTIONS(1389),
    [sym_kPublic] = ACTIONS(2295),
    [sym_kProtected] = ACTIONS(1389),
    [sym_kPrivate] = ACTIONS(1389),
    [sym_kStrict] = ACTIONS(1389),
    [sym_kRequired] = ACTIONS(1389),
    [sym_kOptional] = ACTIONS(1389),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [350] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(369),
    [anon_sym_LBRACK] = ACTIONS(2298),
    [sym_kEnd] = ACTIONS(1424),
    [sym_kVar] = ACTIONS(1426),
    [sym_kThreadvar] = ACTIONS(1424),
    [sym_kConst] = ACTIONS(1426),
    [sym_kResourcestring] = ACTIONS(1424),
    [sym_kType] = ACTIONS(1424),
    [sym_kProperty] = ACTIONS(1424),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1424),
    [sym_kGeneric] = ACTIONS(1424),
    [sym_kCase] = ACTIONS(1424),
    [sym_kFunction] = ACTIONS(1424),
    [sym_kProcedure] = ACTIONS(1424),
    [sym_kConstructor] = ACTIONS(1424),
    [sym_kDestructor] = ACTIONS(1424),
    [sym_kOperator] = ACTIONS(1424),
    [sym_kPublished] = ACTIONS(1424),
    [sym_kPublic] = ACTIONS(2301),
    [sym_kProtected] = ACTIONS(1424),
    [sym_kPrivate] = ACTIONS(1424),
    [sym_kStrict] = ACTIONS(1424),
    [sym_kRequired] = ACTIONS(1424),
    [sym_kOptional] = ACTIONS(1424),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [351] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(370),
    [anon_sym_LBRACK] = ACTIONS(2304),
    [sym_kEnd] = ACTIONS(1457),
    [sym_kVar] = ACTIONS(1459),
    [sym_kThreadvar] = ACTIONS(1457),
    [sym_kConst] = ACTIONS(1459),
    [sym_kResourcestring] = ACTIONS(1457),
    [sym_kType] = ACTIONS(1457),
    [sym_kProperty] = ACTIONS(1457),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1457),
    [sym_kGeneric] = ACTIONS(1457),
    [sym_kCase] = ACTIONS(1457),
    [sym_kFunction] = ACTIONS(1457),
    [sym_kProcedure] = ACTIONS(1457),
    [sym_kConstructor] = ACTIONS(1457),
    [sym_kDestructor] = ACTIONS(1457),
    [sym_kOperator] = ACTIONS(1457),
    [sym_kPublished] = ACTIONS(1457),
    [sym_kPublic] = ACTIONS(2307),
    [sym_kProtected] = ACTIONS(1457),
    [sym_kPrivate] = ACTIONS(1457),
    [sym_kStrict] = ACTIONS(1457),
    [sym_kRequired] = ACTIONS(1457),
    [sym_kOptional] = ACTIONS(1457),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [352] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2310),
    [sym_kEnd] = ACTIONS(1464),
    [sym_kVar] = ACTIONS(1466),
    [sym_kThreadvar] = ACTIONS(1464),
    [sym_kConst] = ACTIONS(1466),
    [sym_kResourcestring] = ACTIONS(1464),
    [sym_kType] = ACTIONS(1464),
    [sym_kProperty] = ACTIONS(1464),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1464),
    [sym_kGeneric] = ACTIONS(1464),
    [sym_kCase] = ACTIONS(1464),
    [sym_kFunction] = ACTIONS(1464),
    [sym_kProcedure] = ACTIONS(1464),
    [sym_kConstructor] = ACTIONS(1464),
    [sym_kDestructor] = ACTIONS(1464),
    [sym_kOperator] = ACTIONS(1464),
    [sym_kPublished] = ACTIONS(1464),
    [sym_kPublic] = ACTIONS(2313),
    [sym_kProtected] = ACTIONS(1464),
    [sym_kPrivate] = ACTIONS(1464),
    [sym_kStrict] = ACTIONS(1464),
    [sym_kRequired] = ACTIONS(1464),
    [sym_kOptional] = ACTIONS(1464),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [353] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(372),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [sym_kEnd] = ACTIONS(1486),
    [sym_kVar] = ACTIONS(1488),
    [sym_kThreadvar] = ACTIONS(1486),
    [sym_kConst] = ACTIONS(1488),
    [sym_kResourcestring] = ACTIONS(1486),
    [sym_kType] = ACTIONS(1486),
    [sym_kProperty] = ACTIONS(1486),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1486),
    [sym_kGeneric] = ACTIONS(1486),
    [sym_kCase] = ACTIONS(1486),
    [sym_kFunction] = ACTIONS(1486),
    [sym_kProcedure] = ACTIONS(1486),
    [sym_kConstructor] = ACTIONS(1486),
    [sym_kDestructor] = ACTIONS(1486),
    [sym_kOperator] = ACTIONS(1486),
    [sym_kPublished] = ACTIONS(1486),
    [sym_kPublic] = ACTIONS(2319),
    [sym_kProtected] = ACTIONS(1486),
    [sym_kPrivate] = ACTIONS(1486),
    [sym_kStrict] = ACTIONS(1486),
    [sym_kRequired] = ACTIONS(1486),
    [sym_kOptional] = ACTIONS(1486),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [354] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(373),
    [anon_sym_LBRACK] = ACTIONS(2322),
    [sym_kEnd] = ACTIONS(1493),
    [sym_kVar] = ACTIONS(1495),
    [sym_kThreadvar] = ACTIONS(1493),
    [sym_kConst] = ACTIONS(1495),
    [sym_kResourcestring] = ACTIONS(1493),
    [sym_kType] = ACTIONS(1493),
    [sym_kProperty] = ACTIONS(1493),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1493),
    [sym_kGeneric] = ACTIONS(1493),
    [sym_kCase] = ACTIONS(1493),
    [sym_kFunction] = ACTIONS(1493),
    [sym_kProcedure] = ACTIONS(1493),
    [sym_kConstructor] = ACTIONS(1493),
    [sym_kDestructor] = ACTIONS(1493),
    [sym_kOperator] = ACTIONS(1493),
    [sym_kPublished] = ACTIONS(1493),
    [sym_kPublic] = ACTIONS(2325),
    [sym_kProtected] = ACTIONS(1493),
    [sym_kPrivate] = ACTIONS(1493),
    [sym_kStrict] = ACTIONS(1493),
    [sym_kRequired] = ACTIONS(1493),
    [sym_kOptional] = ACTIONS(1493),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [355] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [sym_kEnd] = ACTIONS(1115),
    [sym_kVar] = ACTIONS(1117),
    [sym_kThreadvar] = ACTIONS(1115),
    [sym_kConst] = ACTIONS(1117),
    [sym_kResourcestring] = ACTIONS(1115),
    [sym_kType] = ACTIONS(1115),
    [sym_kProperty] = ACTIONS(1115),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1115),
    [sym_kGeneric] = ACTIONS(1115),
    [sym_kCase] = ACTIONS(1115),
    [sym_kFunction] = ACTIONS(1115),
    [sym_kProcedure] = ACTIONS(1115),
    [sym_kConstructor] = ACTIONS(1115),
    [sym_kDestructor] = ACTIONS(1115),
    [sym_kOperator] = ACTIONS(1115),
    [sym_kPublished] = ACTIONS(1115),
    [sym_kPublic] = ACTIONS(2331),
    [sym_kProtected] = ACTIONS(1115),
    [sym_kPrivate] = ACTIONS(1115),
    [sym_kStrict] = ACTIONS(1115),
    [sym_kRequired] = ACTIONS(1115),
    [sym_kOptional] = ACTIONS(1115),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [356] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2334),
    [sym_kEnd] = ACTIONS(1741),
    [sym_kVar] = ACTIONS(1743),
    [sym_kThreadvar] = ACTIONS(1741),
    [sym_kConst] = ACTIONS(1743),
    [sym_kResourcestring] = ACTIONS(1741),
    [sym_kType] = ACTIONS(1741),
    [sym_kProperty] = ACTIONS(1741),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1741),
    [sym_kGeneric] = ACTIONS(1741),
    [sym_kCase] = ACTIONS(1741),
    [sym_kFunction] = ACTIONS(1741),
    [sym_kProcedure] = ACTIONS(1741),
    [sym_kConstructor] = ACTIONS(1741),
    [sym_kDestructor] = ACTIONS(1741),
    [sym_kOperator] = ACTIONS(1741),
    [sym_kPublished] = ACTIONS(1741),
    [sym_kPublic] = ACTIONS(2337),
    [sym_kProtected] = ACTIONS(1741),
    [sym_kPrivate] = ACTIONS(1741),
    [sym_kStrict] = ACTIONS(1741),
    [sym_kRequired] = ACTIONS(1741),
    [sym_kOptional] = ACTIONS(1741),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [357] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(375),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [sym_kEnd] = ACTIONS(1748),
    [sym_kVar] = ACTIONS(1750),
    [sym_kThreadvar] = ACTIONS(1748),
    [sym_kConst] = ACTIONS(1750),
    [sym_kResourcestring] = ACTIONS(1748),
    [sym_kType] = ACTIONS(1748),
    [sym_kProperty] = ACTIONS(1748),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1748),
    [sym_kGeneric] = ACTIONS(1748),
    [sym_kCase] = ACTIONS(1748),
    [sym_kFunction] = ACTIONS(1748),
    [sym_kProcedure] = ACTIONS(1748),
    [sym_kConstructor] = ACTIONS(1748),
    [sym_kDestructor] = ACTIONS(1748),
    [sym_kOperator] = ACTIONS(1748),
    [sym_kPublished] = ACTIONS(1748),
    [sym_kPublic] = ACTIONS(2343),
    [sym_kProtected] = ACTIONS(1748),
    [sym_kPrivate] = ACTIONS(1748),
    [sym_kStrict] = ACTIONS(1748),
    [sym_kRequired] = ACTIONS(1748),
    [sym_kOptional] = ACTIONS(1748),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [358] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(376),
    [anon_sym_LBRACK] = ACTIONS(2346),
    [sym_kEnd] = ACTIONS(1755),
    [sym_kVar] = ACTIONS(1757),
    [sym_kThreadvar] = ACTIONS(1755),
    [sym_kConst] = ACTIONS(1757),
    [sym_kResourcestring] = ACTIONS(1755),
    [sym_kType] = ACTIONS(1755),
    [sym_kProperty] = ACTIONS(1755),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1755),
    [sym_kGeneric] = ACTIONS(1755),
    [sym_kCase] = ACTIONS(1755),
    [sym_kFunction] = ACTIONS(1755),
    [sym_kProcedure] = ACTIONS(1755),
    [sym_kConstructor] = ACTIONS(1755),
    [sym_kDestructor] = ACTIONS(1755),
    [sym_kOperator] = ACTIONS(1755),
    [sym_kPublished] = ACTIONS(1755),
    [sym_kPublic] = ACTIONS(2349),
    [sym_kProtected] = ACTIONS(1755),
    [sym_kPrivate] = ACTIONS(1755),
    [sym_kStrict] = ACTIONS(1755),
    [sym_kRequired] = ACTIONS(1755),
    [sym_kOptional] = ACTIONS(1755),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [359] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(378),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [sym_kEnd] = ACTIONS(1762),
    [sym_kVar] = ACTIONS(1764),
    [sym_kThreadvar] = ACTIONS(1762),
    [sym_kConst] = ACTIONS(1764),
    [sym_kResourcestring] = ACTIONS(1762),
    [sym_kType] = ACTIONS(1762),
    [sym_kProperty] = ACTIONS(1762),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1762),
    [sym_kGeneric] = ACTIONS(1762),
    [sym_kCase] = ACTIONS(1762),
    [sym_kFunction] = ACTIONS(1762),
    [sym_kProcedure] = ACTIONS(1762),
    [sym_kConstructor] = ACTIONS(1762),
    [sym_kDestructor] = ACTIONS(1762),
    [sym_kOperator] = ACTIONS(1762),
    [sym_kPublished] = ACTIONS(1762),
    [sym_kPublic] = ACTIONS(2355),
    [sym_kProtected] = ACTIONS(1762),
    [sym_kPrivate] = ACTIONS(1762),
    [sym_kStrict] = ACTIONS(1762),
    [sym_kRequired] = ACTIONS(1762),
    [sym_kOptional] = ACTIONS(1762),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [360] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2358),
    [sym_kEnd] = ACTIONS(1192),
    [sym_kVar] = ACTIONS(1194),
    [sym_kThreadvar] = ACTIONS(1192),
    [sym_kConst] = ACTIONS(1194),
    [sym_kResourcestring] = ACTIONS(1192),
    [sym_kType] = ACTIONS(1192),
    [sym_kProperty] = ACTIONS(1192),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1192),
    [sym_kGeneric] = ACTIONS(1192),
    [sym_kCase] = ACTIONS(1192),
    [sym_kFunction] = ACTIONS(1192),
    [sym_kProcedure] = ACTIONS(1192),
    [sym_kConstructor] = ACTIONS(1192),
    [sym_kDestructor] = ACTIONS(1192),
    [sym_kOperator] = ACTIONS(1192),
    [sym_kPublished] = ACTIONS(1192),
    [sym_kPublic] = ACTIONS(2361),
    [sym_kProtected] = ACTIONS(1192),
    [sym_kPrivate] = ACTIONS(1192),
    [sym_kStrict] = ACTIONS(1192),
    [sym_kRequired] = ACTIONS(1192),
    [sym_kOptional] = ACTIONS(1192),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [361] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(381),
    [anon_sym_LBRACK] = ACTIONS(2364),
    [sym_kEnd] = ACTIONS(1199),
    [sym_kVar] = ACTIONS(1201),
    [sym_kThreadvar] = ACTIONS(1199),
    [sym_kConst] = ACTIONS(1201),
    [sym_kResourcestring] = ACTIONS(1199),
    [sym_kType] = ACTIONS(1199),
    [sym_kProperty] = ACTIONS(1199),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1199),
    [sym_kGeneric] = ACTIONS(1199),
    [sym_kCase] = ACTIONS(1199),
    [sym_kFunction] = ACTIONS(1199),
    [sym_kProcedure] = ACTIONS(1199),
    [sym_kConstructor] = ACTIONS(1199),
    [sym_kDestructor] = ACTIONS(1199),
    [sym_kOperator] = ACTIONS(1199),
    [sym_kPublished] = ACTIONS(1199),
    [sym_kPublic] = ACTIONS(2367),
    [sym_kProtected] = ACTIONS(1199),
    [sym_kPrivate] = ACTIONS(1199),
    [sym_kStrict] = ACTIONS(1199),
    [sym_kRequired] = ACTIONS(1199),
    [sym_kOptional] = ACTIONS(1199),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [362] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(382),
    [anon_sym_LBRACK] = ACTIONS(2370),
    [sym_kEnd] = ACTIONS(1206),
    [sym_kVar] = ACTIONS(1208),
    [sym_kThreadvar] = ACTIONS(1206),
    [sym_kConst] = ACTIONS(1208),
    [sym_kResourcestring] = ACTIONS(1206),
    [sym_kType] = ACTIONS(1206),
    [sym_kProperty] = ACTIONS(1206),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1206),
    [sym_kGeneric] = ACTIONS(1206),
    [sym_kCase] = ACTIONS(1206),
    [sym_kFunction] = ACTIONS(1206),
    [sym_kProcedure] = ACTIONS(1206),
    [sym_kConstructor] = ACTIONS(1206),
    [sym_kDestructor] = ACTIONS(1206),
    [sym_kOperator] = ACTIONS(1206),
    [sym_kPublished] = ACTIONS(1206),
    [sym_kPublic] = ACTIONS(2373),
    [sym_kProtected] = ACTIONS(1206),
    [sym_kPrivate] = ACTIONS(1206),
    [sym_kStrict] = ACTIONS(1206),
    [sym_kRequired] = ACTIONS(1206),
    [sym_kOptional] = ACTIONS(1206),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [363] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2376),
    [sym_kEnd] = ACTIONS(1213),
    [sym_kVar] = ACTIONS(1215),
    [sym_kThreadvar] = ACTIONS(1213),
    [sym_kConst] = ACTIONS(1215),
    [sym_kResourcestring] = ACTIONS(1213),
    [sym_kType] = ACTIONS(1213),
    [sym_kProperty] = ACTIONS(1213),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1213),
    [sym_kGeneric] = ACTIONS(1213),
    [sym_kCase] = ACTIONS(1213),
    [sym_kFunction] = ACTIONS(1213),
    [sym_kProcedure] = ACTIONS(1213),
    [sym_kConstructor] = ACTIONS(1213),
    [sym_kDestructor] = ACTIONS(1213),
    [sym_kOperator] = ACTIONS(1213),
    [sym_kPublished] = ACTIONS(1213),
    [sym_kPublic] = ACTIONS(2379),
    [sym_kProtected] = ACTIONS(1213),
    [sym_kPrivate] = ACTIONS(1213),
    [sym_kStrict] = ACTIONS(1213),
    [sym_kRequired] = ACTIONS(1213),
    [sym_kOptional] = ACTIONS(1213),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [364] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2382),
    [sym_kEnd] = ACTIONS(1804),
    [sym_kVar] = ACTIONS(1806),
    [sym_kThreadvar] = ACTIONS(1804),
    [sym_kConst] = ACTIONS(1806),
    [sym_kResourcestring] = ACTIONS(1804),
    [sym_kType] = ACTIONS(1804),
    [sym_kProperty] = ACTIONS(1804),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1804),
    [sym_kGeneric] = ACTIONS(1804),
    [sym_kCase] = ACTIONS(1804),
    [sym_kFunction] = ACTIONS(1804),
    [sym_kProcedure] = ACTIONS(1804),
    [sym_kConstructor] = ACTIONS(1804),
    [sym_kDestructor] = ACTIONS(1804),
    [sym_kOperator] = ACTIONS(1804),
    [sym_kPublished] = ACTIONS(1804),
    [sym_kPublic] = ACTIONS(2385),
    [sym_kProtected] = ACTIONS(1804),
    [sym_kPrivate] = ACTIONS(1804),
    [sym_kStrict] = ACTIONS(1804),
    [sym_kRequired] = ACTIONS(1804),
    [sym_kOptional] = ACTIONS(1804),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [365] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(384),
    [anon_sym_LBRACK] = ACTIONS(2388),
    [sym_kEnd] = ACTIONS(1811),
    [sym_kVar] = ACTIONS(1813),
    [sym_kThreadvar] = ACTIONS(1811),
    [sym_kConst] = ACTIONS(1813),
    [sym_kResourcestring] = ACTIONS(1811),
    [sym_kType] = ACTIONS(1811),
    [sym_kProperty] = ACTIONS(1811),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1811),
    [sym_kGeneric] = ACTIONS(1811),
    [sym_kCase] = ACTIONS(1811),
    [sym_kFunction] = ACTIONS(1811),
    [sym_kProcedure] = ACTIONS(1811),
    [sym_kConstructor] = ACTIONS(1811),
    [sym_kDestructor] = ACTIONS(1811),
    [sym_kOperator] = ACTIONS(1811),
    [sym_kPublished] = ACTIONS(1811),
    [sym_kPublic] = ACTIONS(2391),
    [sym_kProtected] = ACTIONS(1811),
    [sym_kPrivate] = ACTIONS(1811),
    [sym_kStrict] = ACTIONS(1811),
    [sym_kRequired] = ACTIONS(1811),
    [sym_kOptional] = ACTIONS(1811),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [366] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(385),
    [anon_sym_LBRACK] = ACTIONS(2394),
    [sym_kEnd] = ACTIONS(1818),
    [sym_kVar] = ACTIONS(1820),
    [sym_kThreadvar] = ACTIONS(1818),
    [sym_kConst] = ACTIONS(1820),
    [sym_kResourcestring] = ACTIONS(1818),
    [sym_kType] = ACTIONS(1818),
    [sym_kProperty] = ACTIONS(1818),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1818),
    [sym_kGeneric] = ACTIONS(1818),
    [sym_kCase] = ACTIONS(1818),
    [sym_kFunction] = ACTIONS(1818),
    [sym_kProcedure] = ACTIONS(1818),
    [sym_kConstructor] = ACTIONS(1818),
    [sym_kDestructor] = ACTIONS(1818),
    [sym_kOperator] = ACTIONS(1818),
    [sym_kPublished] = ACTIONS(1818),
    [sym_kPublic] = ACTIONS(2397),
    [sym_kProtected] = ACTIONS(1818),
    [sym_kPrivate] = ACTIONS(1818),
    [sym_kStrict] = ACTIONS(1818),
    [sym_kRequired] = ACTIONS(1818),
    [sym_kOptional] = ACTIONS(1818),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [367] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(387),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [sym_kEnd] = ACTIONS(1825),
    [sym_kVar] = ACTIONS(1827),
    [sym_kThreadvar] = ACTIONS(1825),
    [sym_kConst] = ACTIONS(1827),
    [sym_kResourcestring] = ACTIONS(1825),
    [sym_kType] = ACTIONS(1825),
    [sym_kProperty] = ACTIONS(1825),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1825),
    [sym_kGeneric] = ACTIONS(1825),
    [sym_kCase] = ACTIONS(1825),
    [sym_kFunction] = ACTIONS(1825),
    [sym_kProcedure] = ACTIONS(1825),
    [sym_kConstructor] = ACTIONS(1825),
    [sym_kDestructor] = ACTIONS(1825),
    [sym_kOperator] = ACTIONS(1825),
    [sym_kPublished] = ACTIONS(1825),
    [sym_kPublic] = ACTIONS(2403),
    [sym_kProtected] = ACTIONS(1825),
    [sym_kPrivate] = ACTIONS(1825),
    [sym_kStrict] = ACTIONS(1825),
    [sym_kRequired] = ACTIONS(1825),
    [sym_kOptional] = ACTIONS(1825),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [368] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(390),
    [anon_sym_LBRACK] = ACTIONS(2406),
    [sym_kEnd] = ACTIONS(1220),
    [sym_kVar] = ACTIONS(1222),
    [sym_kThreadvar] = ACTIONS(1220),
    [sym_kConst] = ACTIONS(1222),
    [sym_kResourcestring] = ACTIONS(1220),
    [sym_kType] = ACTIONS(1220),
    [sym_kProperty] = ACTIONS(1220),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1220),
    [sym_kGeneric] = ACTIONS(1220),
    [sym_kCase] = ACTIONS(1220),
    [sym_kFunction] = ACTIONS(1220),
    [sym_kProcedure] = ACTIONS(1220),
    [sym_kConstructor] = ACTIONS(1220),
    [sym_kDestructor] = ACTIONS(1220),
    [sym_kOperator] = ACTIONS(1220),
    [sym_kPublished] = ACTIONS(1220),
    [sym_kPublic] = ACTIONS(2409),
    [sym_kProtected] = ACTIONS(1220),
    [sym_kPrivate] = ACTIONS(1220),
    [sym_kStrict] = ACTIONS(1220),
    [sym_kRequired] = ACTIONS(1220),
    [sym_kOptional] = ACTIONS(1220),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [369] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [sym_kEnd] = ACTIONS(1227),
    [sym_kVar] = ACTIONS(1229),
    [sym_kThreadvar] = ACTIONS(1227),
    [sym_kConst] = ACTIONS(1229),
    [sym_kResourcestring] = ACTIONS(1227),
    [sym_kType] = ACTIONS(1227),
    [sym_kProperty] = ACTIONS(1227),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1227),
    [sym_kGeneric] = ACTIONS(1227),
    [sym_kCase] = ACTIONS(1227),
    [sym_kFunction] = ACTIONS(1227),
    [sym_kProcedure] = ACTIONS(1227),
    [sym_kConstructor] = ACTIONS(1227),
    [sym_kDestructor] = ACTIONS(1227),
    [sym_kOperator] = ACTIONS(1227),
    [sym_kPublished] = ACTIONS(1227),
    [sym_kPublic] = ACTIONS(2415),
    [sym_kProtected] = ACTIONS(1227),
    [sym_kPrivate] = ACTIONS(1227),
    [sym_kStrict] = ACTIONS(1227),
    [sym_kRequired] = ACTIONS(1227),
    [sym_kOptional] = ACTIONS(1227),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [370] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2418),
    [sym_kEnd] = ACTIONS(1234),
    [sym_kVar] = ACTIONS(1236),
    [sym_kThreadvar] = ACTIONS(1234),
    [sym_kConst] = ACTIONS(1236),
    [sym_kResourcestring] = ACTIONS(1234),
    [sym_kType] = ACTIONS(1234),
    [sym_kProperty] = ACTIONS(1234),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1234),
    [sym_kGeneric] = ACTIONS(1234),
    [sym_kCase] = ACTIONS(1234),
    [sym_kFunction] = ACTIONS(1234),
    [sym_kProcedure] = ACTIONS(1234),
    [sym_kConstructor] = ACTIONS(1234),
    [sym_kDestructor] = ACTIONS(1234),
    [sym_kOperator] = ACTIONS(1234),
    [sym_kPublished] = ACTIONS(1234),
    [sym_kPublic] = ACTIONS(2421),
    [sym_kProtected] = ACTIONS(1234),
    [sym_kPrivate] = ACTIONS(1234),
    [sym_kStrict] = ACTIONS(1234),
    [sym_kRequired] = ACTIONS(1234),
    [sym_kOptional] = ACTIONS(1234),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [371] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(393),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [sym_kEnd] = ACTIONS(1241),
    [sym_kVar] = ACTIONS(1243),
    [sym_kThreadvar] = ACTIONS(1241),
    [sym_kConst] = ACTIONS(1243),
    [sym_kResourcestring] = ACTIONS(1241),
    [sym_kType] = ACTIONS(1241),
    [sym_kProperty] = ACTIONS(1241),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1241),
    [sym_kGeneric] = ACTIONS(1241),
    [sym_kCase] = ACTIONS(1241),
    [sym_kFunction] = ACTIONS(1241),
    [sym_kProcedure] = ACTIONS(1241),
    [sym_kConstructor] = ACTIONS(1241),
    [sym_kDestructor] = ACTIONS(1241),
    [sym_kOperator] = ACTIONS(1241),
    [sym_kPublished] = ACTIONS(1241),
    [sym_kPublic] = ACTIONS(2427),
    [sym_kProtected] = ACTIONS(1241),
    [sym_kPrivate] = ACTIONS(1241),
    [sym_kStrict] = ACTIONS(1241),
    [sym_kRequired] = ACTIONS(1241),
    [sym_kOptional] = ACTIONS(1241),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [372] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2430),
    [sym_kEnd] = ACTIONS(1248),
    [sym_kVar] = ACTIONS(1250),
    [sym_kThreadvar] = ACTIONS(1248),
    [sym_kConst] = ACTIONS(1250),
    [sym_kResourcestring] = ACTIONS(1248),
    [sym_kType] = ACTIONS(1248),
    [sym_kProperty] = ACTIONS(1248),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1248),
    [sym_kGeneric] = ACTIONS(1248),
    [sym_kCase] = ACTIONS(1248),
    [sym_kFunction] = ACTIONS(1248),
    [sym_kProcedure] = ACTIONS(1248),
    [sym_kConstructor] = ACTIONS(1248),
    [sym_kDestructor] = ACTIONS(1248),
    [sym_kOperator] = ACTIONS(1248),
    [sym_kPublished] = ACTIONS(1248),
    [sym_kPublic] = ACTIONS(2433),
    [sym_kProtected] = ACTIONS(1248),
    [sym_kPrivate] = ACTIONS(1248),
    [sym_kStrict] = ACTIONS(1248),
    [sym_kRequired] = ACTIONS(1248),
    [sym_kOptional] = ACTIONS(1248),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [373] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [sym_kEnd] = ACTIONS(1108),
    [sym_kVar] = ACTIONS(1110),
    [sym_kThreadvar] = ACTIONS(1108),
    [sym_kConst] = ACTIONS(1110),
    [sym_kResourcestring] = ACTIONS(1108),
    [sym_kType] = ACTIONS(1108),
    [sym_kProperty] = ACTIONS(1108),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1108),
    [sym_kGeneric] = ACTIONS(1108),
    [sym_kCase] = ACTIONS(1108),
    [sym_kFunction] = ACTIONS(1108),
    [sym_kProcedure] = ACTIONS(1108),
    [sym_kConstructor] = ACTIONS(1108),
    [sym_kDestructor] = ACTIONS(1108),
    [sym_kOperator] = ACTIONS(1108),
    [sym_kPublished] = ACTIONS(1108),
    [sym_kPublic] = ACTIONS(2439),
    [sym_kProtected] = ACTIONS(1108),
    [sym_kPrivate] = ACTIONS(1108),
    [sym_kStrict] = ACTIONS(1108),
    [sym_kRequired] = ACTIONS(1108),
    [sym_kOptional] = ACTIONS(1108),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [374] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(394),
    [anon_sym_LBRACK] = ACTIONS(2442),
    [sym_kEnd] = ACTIONS(1255),
    [sym_kVar] = ACTIONS(1257),
    [sym_kThreadvar] = ACTIONS(1255),
    [sym_kConst] = ACTIONS(1257),
    [sym_kResourcestring] = ACTIONS(1255),
    [sym_kType] = ACTIONS(1255),
    [sym_kProperty] = ACTIONS(1255),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1255),
    [sym_kGeneric] = ACTIONS(1255),
    [sym_kCase] = ACTIONS(1255),
    [sym_kFunction] = ACTIONS(1255),
    [sym_kProcedure] = ACTIONS(1255),
    [sym_kConstructor] = ACTIONS(1255),
    [sym_kDestructor] = ACTIONS(1255),
    [sym_kOperator] = ACTIONS(1255),
    [sym_kPublished] = ACTIONS(1255),
    [sym_kPublic] = ACTIONS(2445),
    [sym_kProtected] = ACTIONS(1255),
    [sym_kPrivate] = ACTIONS(1255),
    [sym_kStrict] = ACTIONS(1255),
    [sym_kRequired] = ACTIONS(1255),
    [sym_kOptional] = ACTIONS(1255),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [375] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [sym_kEnd] = ACTIONS(1832),
    [sym_kVar] = ACTIONS(1834),
    [sym_kThreadvar] = ACTIONS(1832),
    [sym_kConst] = ACTIONS(1834),
    [sym_kResourcestring] = ACTIONS(1832),
    [sym_kType] = ACTIONS(1832),
    [sym_kProperty] = ACTIONS(1832),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1832),
    [sym_kGeneric] = ACTIONS(1832),
    [sym_kCase] = ACTIONS(1832),
    [sym_kFunction] = ACTIONS(1832),
    [sym_kProcedure] = ACTIONS(1832),
    [sym_kConstructor] = ACTIONS(1832),
    [sym_kDestructor] = ACTIONS(1832),
    [sym_kOperator] = ACTIONS(1832),
    [sym_kPublished] = ACTIONS(1832),
    [sym_kPublic] = ACTIONS(2451),
    [sym_kProtected] = ACTIONS(1832),
    [sym_kPrivate] = ACTIONS(1832),
    [sym_kStrict] = ACTIONS(1832),
    [sym_kRequired] = ACTIONS(1832),
    [sym_kOptional] = ACTIONS(1832),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [376] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [sym_kEnd] = ACTIONS(1839),
    [sym_kVar] = ACTIONS(1841),
    [sym_kThreadvar] = ACTIONS(1839),
    [sym_kConst] = ACTIONS(1841),
    [sym_kResourcestring] = ACTIONS(1839),
    [sym_kType] = ACTIONS(1839),
    [sym_kProperty] = ACTIONS(1839),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1839),
    [sym_kGeneric] = ACTIONS(1839),
    [sym_kCase] = ACTIONS(1839),
    [sym_kFunction] = ACTIONS(1839),
    [sym_kProcedure] = ACTIONS(1839),
    [sym_kConstructor] = ACTIONS(1839),
    [sym_kDestructor] = ACTIONS(1839),
    [sym_kOperator] = ACTIONS(1839),
    [sym_kPublished] = ACTIONS(1839),
    [sym_kPublic] = ACTIONS(2457),
    [sym_kProtected] = ACTIONS(1839),
    [sym_kPrivate] = ACTIONS(1839),
    [sym_kStrict] = ACTIONS(1839),
    [sym_kRequired] = ACTIONS(1839),
    [sym_kOptional] = ACTIONS(1839),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [377] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(395),
    [anon_sym_LBRACK] = ACTIONS(2460),
    [sym_kEnd] = ACTIONS(1846),
    [sym_kVar] = ACTIONS(1848),
    [sym_kThreadvar] = ACTIONS(1846),
    [sym_kConst] = ACTIONS(1848),
    [sym_kResourcestring] = ACTIONS(1846),
    [sym_kType] = ACTIONS(1846),
    [sym_kProperty] = ACTIONS(1846),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1846),
    [sym_kGeneric] = ACTIONS(1846),
    [sym_kCase] = ACTIONS(1846),
    [sym_kFunction] = ACTIONS(1846),
    [sym_kProcedure] = ACTIONS(1846),
    [sym_kConstructor] = ACTIONS(1846),
    [sym_kDestructor] = ACTIONS(1846),
    [sym_kOperator] = ACTIONS(1846),
    [sym_kPublished] = ACTIONS(1846),
    [sym_kPublic] = ACTIONS(2463),
    [sym_kProtected] = ACTIONS(1846),
    [sym_kPrivate] = ACTIONS(1846),
    [sym_kStrict] = ACTIONS(1846),
    [sym_kRequired] = ACTIONS(1846),
    [sym_kOptional] = ACTIONS(1846),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [378] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [sym_kEnd] = ACTIONS(1853),
    [sym_kVar] = ACTIONS(1855),
    [sym_kThreadvar] = ACTIONS(1853),
    [sym_kConst] = ACTIONS(1855),
    [sym_kResourcestring] = ACTIONS(1853),
    [sym_kType] = ACTIONS(1853),
    [sym_kProperty] = ACTIONS(1853),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1853),
    [sym_kGeneric] = ACTIONS(1853),
    [sym_kCase] = ACTIONS(1853),
    [sym_kFunction] = ACTIONS(1853),
    [sym_kProcedure] = ACTIONS(1853),
    [sym_kConstructor] = ACTIONS(1853),
    [sym_kDestructor] = ACTIONS(1853),
    [sym_kOperator] = ACTIONS(1853),
    [sym_kPublished] = ACTIONS(1853),
    [sym_kPublic] = ACTIONS(2469),
    [sym_kProtected] = ACTIONS(1853),
    [sym_kPrivate] = ACTIONS(1853),
    [sym_kStrict] = ACTIONS(1853),
    [sym_kRequired] = ACTIONS(1853),
    [sym_kOptional] = ACTIONS(1853),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [379] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(396),
    [anon_sym_LBRACK] = ACTIONS(2472),
    [sym_kEnd] = ACTIONS(1860),
    [sym_kVar] = ACTIONS(1862),
    [sym_kThreadvar] = ACTIONS(1860),
    [sym_kConst] = ACTIONS(1862),
    [sym_kResourcestring] = ACTIONS(1860),
    [sym_kType] = ACTIONS(1860),
    [sym_kProperty] = ACTIONS(1860),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1860),
    [sym_kGeneric] = ACTIONS(1860),
    [sym_kCase] = ACTIONS(1860),
    [sym_kFunction] = ACTIONS(1860),
    [sym_kProcedure] = ACTIONS(1860),
    [sym_kConstructor] = ACTIONS(1860),
    [sym_kDestructor] = ACTIONS(1860),
    [sym_kOperator] = ACTIONS(1860),
    [sym_kPublished] = ACTIONS(1860),
    [sym_kPublic] = ACTIONS(2475),
    [sym_kProtected] = ACTIONS(1860),
    [sym_kPrivate] = ACTIONS(1860),
    [sym_kStrict] = ACTIONS(1860),
    [sym_kRequired] = ACTIONS(1860),
    [sym_kOptional] = ACTIONS(1860),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [380] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(397),
    [anon_sym_LBRACK] = ACTIONS(2478),
    [sym_kEnd] = ACTIONS(1867),
    [sym_kVar] = ACTIONS(1869),
    [sym_kThreadvar] = ACTIONS(1867),
    [sym_kConst] = ACTIONS(1869),
    [sym_kResourcestring] = ACTIONS(1867),
    [sym_kType] = ACTIONS(1867),
    [sym_kProperty] = ACTIONS(1867),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1867),
    [sym_kGeneric] = ACTIONS(1867),
    [sym_kCase] = ACTIONS(1867),
    [sym_kFunction] = ACTIONS(1867),
    [sym_kProcedure] = ACTIONS(1867),
    [sym_kConstructor] = ACTIONS(1867),
    [sym_kDestructor] = ACTIONS(1867),
    [sym_kOperator] = ACTIONS(1867),
    [sym_kPublished] = ACTIONS(1867),
    [sym_kPublic] = ACTIONS(2481),
    [sym_kProtected] = ACTIONS(1867),
    [sym_kPrivate] = ACTIONS(1867),
    [sym_kStrict] = ACTIONS(1867),
    [sym_kRequired] = ACTIONS(1867),
    [sym_kOptional] = ACTIONS(1867),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [381] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2484),
    [sym_kEnd] = ACTIONS(1305),
    [sym_kVar] = ACTIONS(1307),
    [sym_kThreadvar] = ACTIONS(1305),
    [sym_kConst] = ACTIONS(1307),
    [sym_kResourcestring] = ACTIONS(1305),
    [sym_kType] = ACTIONS(1305),
    [sym_kProperty] = ACTIONS(1305),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1305),
    [sym_kGeneric] = ACTIONS(1305),
    [sym_kCase] = ACTIONS(1305),
    [sym_kFunction] = ACTIONS(1305),
    [sym_kProcedure] = ACTIONS(1305),
    [sym_kConstructor] = ACTIONS(1305),
    [sym_kDestructor] = ACTIONS(1305),
    [sym_kOperator] = ACTIONS(1305),
    [sym_kPublished] = ACTIONS(1305),
    [sym_kPublic] = ACTIONS(2487),
    [sym_kProtected] = ACTIONS(1305),
    [sym_kPrivate] = ACTIONS(1305),
    [sym_kStrict] = ACTIONS(1305),
    [sym_kRequired] = ACTIONS(1305),
    [sym_kOptional] = ACTIONS(1305),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [382] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [sym_kEnd] = ACTIONS(1312),
    [sym_kVar] = ACTIONS(1314),
    [sym_kThreadvar] = ACTIONS(1312),
    [sym_kConst] = ACTIONS(1314),
    [sym_kResourcestring] = ACTIONS(1312),
    [sym_kType] = ACTIONS(1312),
    [sym_kProperty] = ACTIONS(1312),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1312),
    [sym_kGeneric] = ACTIONS(1312),
    [sym_kCase] = ACTIONS(1312),
    [sym_kFunction] = ACTIONS(1312),
    [sym_kProcedure] = ACTIONS(1312),
    [sym_kConstructor] = ACTIONS(1312),
    [sym_kDestructor] = ACTIONS(1312),
    [sym_kOperator] = ACTIONS(1312),
    [sym_kPublished] = ACTIONS(1312),
    [sym_kPublic] = ACTIONS(2493),
    [sym_kProtected] = ACTIONS(1312),
    [sym_kPrivate] = ACTIONS(1312),
    [sym_kStrict] = ACTIONS(1312),
    [sym_kRequired] = ACTIONS(1312),
    [sym_kOptional] = ACTIONS(1312),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [383] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(399),
    [anon_sym_LBRACK] = ACTIONS(2496),
    [sym_kEnd] = ACTIONS(1319),
    [sym_kVar] = ACTIONS(1321),
    [sym_kThreadvar] = ACTIONS(1319),
    [sym_kConst] = ACTIONS(1321),
    [sym_kResourcestring] = ACTIONS(1319),
    [sym_kType] = ACTIONS(1319),
    [sym_kProperty] = ACTIONS(1319),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1319),
    [sym_kGeneric] = ACTIONS(1319),
    [sym_kCase] = ACTIONS(1319),
    [sym_kFunction] = ACTIONS(1319),
    [sym_kProcedure] = ACTIONS(1319),
    [sym_kConstructor] = ACTIONS(1319),
    [sym_kDestructor] = ACTIONS(1319),
    [sym_kOperator] = ACTIONS(1319),
    [sym_kPublished] = ACTIONS(1319),
    [sym_kPublic] = ACTIONS(2499),
    [sym_kProtected] = ACTIONS(1319),
    [sym_kPrivate] = ACTIONS(1319),
    [sym_kStrict] = ACTIONS(1319),
    [sym_kRequired] = ACTIONS(1319),
    [sym_kOptional] = ACTIONS(1319),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [384] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [sym_kEnd] = ACTIONS(1909),
    [sym_kVar] = ACTIONS(1911),
    [sym_kThreadvar] = ACTIONS(1909),
    [sym_kConst] = ACTIONS(1911),
    [sym_kResourcestring] = ACTIONS(1909),
    [sym_kType] = ACTIONS(1909),
    [sym_kProperty] = ACTIONS(1909),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1909),
    [sym_kGeneric] = ACTIONS(1909),
    [sym_kCase] = ACTIONS(1909),
    [sym_kFunction] = ACTIONS(1909),
    [sym_kProcedure] = ACTIONS(1909),
    [sym_kConstructor] = ACTIONS(1909),
    [sym_kDestructor] = ACTIONS(1909),
    [sym_kOperator] = ACTIONS(1909),
    [sym_kPublished] = ACTIONS(1909),
    [sym_kPublic] = ACTIONS(2505),
    [sym_kProtected] = ACTIONS(1909),
    [sym_kPrivate] = ACTIONS(1909),
    [sym_kStrict] = ACTIONS(1909),
    [sym_kRequired] = ACTIONS(1909),
    [sym_kOptional] = ACTIONS(1909),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [385] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2508),
    [sym_kEnd] = ACTIONS(1916),
    [sym_kVar] = ACTIONS(1918),
    [sym_kThreadvar] = ACTIONS(1916),
    [sym_kConst] = ACTIONS(1918),
    [sym_kResourcestring] = ACTIONS(1916),
    [sym_kType] = ACTIONS(1916),
    [sym_kProperty] = ACTIONS(1916),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1916),
    [sym_kGeneric] = ACTIONS(1916),
    [sym_kCase] = ACTIONS(1916),
    [sym_kFunction] = ACTIONS(1916),
    [sym_kProcedure] = ACTIONS(1916),
    [sym_kConstructor] = ACTIONS(1916),
    [sym_kDestructor] = ACTIONS(1916),
    [sym_kOperator] = ACTIONS(1916),
    [sym_kPublished] = ACTIONS(1916),
    [sym_kPublic] = ACTIONS(2511),
    [sym_kProtected] = ACTIONS(1916),
    [sym_kPrivate] = ACTIONS(1916),
    [sym_kStrict] = ACTIONS(1916),
    [sym_kRequired] = ACTIONS(1916),
    [sym_kOptional] = ACTIONS(1916),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [386] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(400),
    [anon_sym_LBRACK] = ACTIONS(2514),
    [sym_kEnd] = ACTIONS(1923),
    [sym_kVar] = ACTIONS(1925),
    [sym_kThreadvar] = ACTIONS(1923),
    [sym_kConst] = ACTIONS(1925),
    [sym_kResourcestring] = ACTIONS(1923),
    [sym_kType] = ACTIONS(1923),
    [sym_kProperty] = ACTIONS(1923),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1923),
    [sym_kGeneric] = ACTIONS(1923),
    [sym_kCase] = ACTIONS(1923),
    [sym_kFunction] = ACTIONS(1923),
    [sym_kProcedure] = ACTIONS(1923),
    [sym_kConstructor] = ACTIONS(1923),
    [sym_kDestructor] = ACTIONS(1923),
    [sym_kOperator] = ACTIONS(1923),
    [sym_kPublished] = ACTIONS(1923),
    [sym_kPublic] = ACTIONS(2517),
    [sym_kProtected] = ACTIONS(1923),
    [sym_kPrivate] = ACTIONS(1923),
    [sym_kStrict] = ACTIONS(1923),
    [sym_kRequired] = ACTIONS(1923),
    [sym_kOptional] = ACTIONS(1923),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [387] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2520),
    [sym_kEnd] = ACTIONS(1930),
    [sym_kVar] = ACTIONS(1932),
    [sym_kThreadvar] = ACTIONS(1930),
    [sym_kConst] = ACTIONS(1932),
    [sym_kResourcestring] = ACTIONS(1930),
    [sym_kType] = ACTIONS(1930),
    [sym_kProperty] = ACTIONS(1930),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1930),
    [sym_kGeneric] = ACTIONS(1930),
    [sym_kCase] = ACTIONS(1930),
    [sym_kFunction] = ACTIONS(1930),
    [sym_kProcedure] = ACTIONS(1930),
    [sym_kConstructor] = ACTIONS(1930),
    [sym_kDestructor] = ACTIONS(1930),
    [sym_kOperator] = ACTIONS(1930),
    [sym_kPublished] = ACTIONS(1930),
    [sym_kPublic] = ACTIONS(2523),
    [sym_kProtected] = ACTIONS(1930),
    [sym_kPrivate] = ACTIONS(1930),
    [sym_kStrict] = ACTIONS(1930),
    [sym_kRequired] = ACTIONS(1930),
    [sym_kOptional] = ACTIONS(1930),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [388] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(401),
    [anon_sym_LBRACK] = ACTIONS(2526),
    [sym_kEnd] = ACTIONS(1937),
    [sym_kVar] = ACTIONS(1939),
    [sym_kThreadvar] = ACTIONS(1937),
    [sym_kConst] = ACTIONS(1939),
    [sym_kResourcestring] = ACTIONS(1937),
    [sym_kType] = ACTIONS(1937),
    [sym_kProperty] = ACTIONS(1937),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1937),
    [sym_kGeneric] = ACTIONS(1937),
    [sym_kCase] = ACTIONS(1937),
    [sym_kFunction] = ACTIONS(1937),
    [sym_kProcedure] = ACTIONS(1937),
    [sym_kConstructor] = ACTIONS(1937),
    [sym_kDestructor] = ACTIONS(1937),
    [sym_kOperator] = ACTIONS(1937),
    [sym_kPublished] = ACTIONS(1937),
    [sym_kPublic] = ACTIONS(2529),
    [sym_kProtected] = ACTIONS(1937),
    [sym_kPrivate] = ACTIONS(1937),
    [sym_kStrict] = ACTIONS(1937),
    [sym_kRequired] = ACTIONS(1937),
    [sym_kOptional] = ACTIONS(1937),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [389] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(402),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [sym_kEnd] = ACTIONS(1944),
    [sym_kVar] = ACTIONS(1946),
    [sym_kThreadvar] = ACTIONS(1944),
    [sym_kConst] = ACTIONS(1946),
    [sym_kResourcestring] = ACTIONS(1944),
    [sym_kType] = ACTIONS(1944),
    [sym_kProperty] = ACTIONS(1944),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1944),
    [sym_kGeneric] = ACTIONS(1944),
    [sym_kCase] = ACTIONS(1944),
    [sym_kFunction] = ACTIONS(1944),
    [sym_kProcedure] = ACTIONS(1944),
    [sym_kConstructor] = ACTIONS(1944),
    [sym_kDestructor] = ACTIONS(1944),
    [sym_kOperator] = ACTIONS(1944),
    [sym_kPublished] = ACTIONS(1944),
    [sym_kPublic] = ACTIONS(2535),
    [sym_kProtected] = ACTIONS(1944),
    [sym_kPrivate] = ACTIONS(1944),
    [sym_kStrict] = ACTIONS(1944),
    [sym_kRequired] = ACTIONS(1944),
    [sym_kOptional] = ACTIONS(1944),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [390] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [sym_kEnd] = ACTIONS(1326),
    [sym_kVar] = ACTIONS(1328),
    [sym_kThreadvar] = ACTIONS(1326),
    [sym_kConst] = ACTIONS(1328),
    [sym_kResourcestring] = ACTIONS(1326),
    [sym_kType] = ACTIONS(1326),
    [sym_kProperty] = ACTIONS(1326),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1326),
    [sym_kGeneric] = ACTIONS(1326),
    [sym_kCase] = ACTIONS(1326),
    [sym_kFunction] = ACTIONS(1326),
    [sym_kProcedure] = ACTIONS(1326),
    [sym_kConstructor] = ACTIONS(1326),
    [sym_kDestructor] = ACTIONS(1326),
    [sym_kOperator] = ACTIONS(1326),
    [sym_kPublished] = ACTIONS(1326),
    [sym_kPublic] = ACTIONS(2541),
    [sym_kProtected] = ACTIONS(1326),
    [sym_kPrivate] = ACTIONS(1326),
    [sym_kStrict] = ACTIONS(1326),
    [sym_kRequired] = ACTIONS(1326),
    [sym_kOptional] = ACTIONS(1326),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [391] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(404),
    [anon_sym_LBRACK] = ACTIONS(2544),
    [sym_kEnd] = ACTIONS(1333),
    [sym_kVar] = ACTIONS(1335),
    [sym_kThreadvar] = ACTIONS(1333),
    [sym_kConst] = ACTIONS(1335),
    [sym_kResourcestring] = ACTIONS(1333),
    [sym_kType] = ACTIONS(1333),
    [sym_kProperty] = ACTIONS(1333),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1333),
    [sym_kGeneric] = ACTIONS(1333),
    [sym_kCase] = ACTIONS(1333),
    [sym_kFunction] = ACTIONS(1333),
    [sym_kProcedure] = ACTIONS(1333),
    [sym_kConstructor] = ACTIONS(1333),
    [sym_kDestructor] = ACTIONS(1333),
    [sym_kOperator] = ACTIONS(1333),
    [sym_kPublished] = ACTIONS(1333),
    [sym_kPublic] = ACTIONS(2547),
    [sym_kProtected] = ACTIONS(1333),
    [sym_kPrivate] = ACTIONS(1333),
    [sym_kStrict] = ACTIONS(1333),
    [sym_kRequired] = ACTIONS(1333),
    [sym_kOptional] = ACTIONS(1333),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [392] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(405),
    [anon_sym_LBRACK] = ACTIONS(2550),
    [sym_kEnd] = ACTIONS(1340),
    [sym_kVar] = ACTIONS(1342),
    [sym_kThreadvar] = ACTIONS(1340),
    [sym_kConst] = ACTIONS(1342),
    [sym_kResourcestring] = ACTIONS(1340),
    [sym_kType] = ACTIONS(1340),
    [sym_kProperty] = ACTIONS(1340),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1340),
    [sym_kGeneric] = ACTIONS(1340),
    [sym_kCase] = ACTIONS(1340),
    [sym_kFunction] = ACTIONS(1340),
    [sym_kProcedure] = ACTIONS(1340),
    [sym_kConstructor] = ACTIONS(1340),
    [sym_kDestructor] = ACTIONS(1340),
    [sym_kOperator] = ACTIONS(1340),
    [sym_kPublished] = ACTIONS(1340),
    [sym_kPublic] = ACTIONS(2553),
    [sym_kProtected] = ACTIONS(1340),
    [sym_kPrivate] = ACTIONS(1340),
    [sym_kStrict] = ACTIONS(1340),
    [sym_kRequired] = ACTIONS(1340),
    [sym_kOptional] = ACTIONS(1340),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [393] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2556),
    [sym_kEnd] = ACTIONS(1347),
    [sym_kVar] = ACTIONS(1349),
    [sym_kThreadvar] = ACTIONS(1347),
    [sym_kConst] = ACTIONS(1349),
    [sym_kResourcestring] = ACTIONS(1347),
    [sym_kType] = ACTIONS(1347),
    [sym_kProperty] = ACTIONS(1347),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1347),
    [sym_kGeneric] = ACTIONS(1347),
    [sym_kCase] = ACTIONS(1347),
    [sym_kFunction] = ACTIONS(1347),
    [sym_kProcedure] = ACTIONS(1347),
    [sym_kConstructor] = ACTIONS(1347),
    [sym_kDestructor] = ACTIONS(1347),
    [sym_kOperator] = ACTIONS(1347),
    [sym_kPublished] = ACTIONS(1347),
    [sym_kPublic] = ACTIONS(2559),
    [sym_kProtected] = ACTIONS(1347),
    [sym_kPrivate] = ACTIONS(1347),
    [sym_kStrict] = ACTIONS(1347),
    [sym_kRequired] = ACTIONS(1347),
    [sym_kOptional] = ACTIONS(1347),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [394] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2562),
    [sym_kEnd] = ACTIONS(1354),
    [sym_kVar] = ACTIONS(1356),
    [sym_kThreadvar] = ACTIONS(1354),
    [sym_kConst] = ACTIONS(1356),
    [sym_kResourcestring] = ACTIONS(1354),
    [sym_kType] = ACTIONS(1354),
    [sym_kProperty] = ACTIONS(1354),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1354),
    [sym_kGeneric] = ACTIONS(1354),
    [sym_kCase] = ACTIONS(1354),
    [sym_kFunction] = ACTIONS(1354),
    [sym_kProcedure] = ACTIONS(1354),
    [sym_kConstructor] = ACTIONS(1354),
    [sym_kDestructor] = ACTIONS(1354),
    [sym_kOperator] = ACTIONS(1354),
    [sym_kPublished] = ACTIONS(1354),
    [sym_kPublic] = ACTIONS(2565),
    [sym_kProtected] = ACTIONS(1354),
    [sym_kPrivate] = ACTIONS(1354),
    [sym_kStrict] = ACTIONS(1354),
    [sym_kRequired] = ACTIONS(1354),
    [sym_kOptional] = ACTIONS(1354),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [395] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2568),
    [sym_kEnd] = ACTIONS(1951),
    [sym_kVar] = ACTIONS(1953),
    [sym_kThreadvar] = ACTIONS(1951),
    [sym_kConst] = ACTIONS(1953),
    [sym_kResourcestring] = ACTIONS(1951),
    [sym_kType] = ACTIONS(1951),
    [sym_kProperty] = ACTIONS(1951),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1951),
    [sym_kGeneric] = ACTIONS(1951),
    [sym_kCase] = ACTIONS(1951),
    [sym_kFunction] = ACTIONS(1951),
    [sym_kProcedure] = ACTIONS(1951),
    [sym_kConstructor] = ACTIONS(1951),
    [sym_kDestructor] = ACTIONS(1951),
    [sym_kOperator] = ACTIONS(1951),
    [sym_kPublished] = ACTIONS(1951),
    [sym_kPublic] = ACTIONS(2571),
    [sym_kProtected] = ACTIONS(1951),
    [sym_kPrivate] = ACTIONS(1951),
    [sym_kStrict] = ACTIONS(1951),
    [sym_kRequired] = ACTIONS(1951),
    [sym_kOptional] = ACTIONS(1951),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [396] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2574),
    [sym_kEnd] = ACTIONS(1958),
    [sym_kVar] = ACTIONS(1960),
    [sym_kThreadvar] = ACTIONS(1958),
    [sym_kConst] = ACTIONS(1960),
    [sym_kResourcestring] = ACTIONS(1958),
    [sym_kType] = ACTIONS(1958),
    [sym_kProperty] = ACTIONS(1958),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1958),
    [sym_kGeneric] = ACTIONS(1958),
    [sym_kCase] = ACTIONS(1958),
    [sym_kFunction] = ACTIONS(1958),
    [sym_kProcedure] = ACTIONS(1958),
    [sym_kConstructor] = ACTIONS(1958),
    [sym_kDestructor] = ACTIONS(1958),
    [sym_kOperator] = ACTIONS(1958),
    [sym_kPublished] = ACTIONS(1958),
    [sym_kPublic] = ACTIONS(2577),
    [sym_kProtected] = ACTIONS(1958),
    [sym_kPrivate] = ACTIONS(1958),
    [sym_kStrict] = ACTIONS(1958),
    [sym_kRequired] = ACTIONS(1958),
    [sym_kOptional] = ACTIONS(1958),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [397] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2580),
    [sym_kEnd] = ACTIONS(1965),
    [sym_kVar] = ACTIONS(1967),
    [sym_kThreadvar] = ACTIONS(1965),
    [sym_kConst] = ACTIONS(1967),
    [sym_kResourcestring] = ACTIONS(1965),
    [sym_kType] = ACTIONS(1965),
    [sym_kProperty] = ACTIONS(1965),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1965),
    [sym_kGeneric] = ACTIONS(1965),
    [sym_kCase] = ACTIONS(1965),
    [sym_kFunction] = ACTIONS(1965),
    [sym_kProcedure] = ACTIONS(1965),
    [sym_kConstructor] = ACTIONS(1965),
    [sym_kDestructor] = ACTIONS(1965),
    [sym_kOperator] = ACTIONS(1965),
    [sym_kPublished] = ACTIONS(1965),
    [sym_kPublic] = ACTIONS(2583),
    [sym_kProtected] = ACTIONS(1965),
    [sym_kPrivate] = ACTIONS(1965),
    [sym_kStrict] = ACTIONS(1965),
    [sym_kRequired] = ACTIONS(1965),
    [sym_kOptional] = ACTIONS(1965),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [398] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(407),
    [anon_sym_LBRACK] = ACTIONS(2586),
    [sym_kEnd] = ACTIONS(1643),
    [sym_kVar] = ACTIONS(1645),
    [sym_kThreadvar] = ACTIONS(1643),
    [sym_kConst] = ACTIONS(1645),
    [sym_kResourcestring] = ACTIONS(1643),
    [sym_kType] = ACTIONS(1643),
    [sym_kProperty] = ACTIONS(1643),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1643),
    [sym_kGeneric] = ACTIONS(1643),
    [sym_kCase] = ACTIONS(1643),
    [sym_kFunction] = ACTIONS(1643),
    [sym_kProcedure] = ACTIONS(1643),
    [sym_kConstructor] = ACTIONS(1643),
    [sym_kDestructor] = ACTIONS(1643),
    [sym_kOperator] = ACTIONS(1643),
    [sym_kPublished] = ACTIONS(1643),
    [sym_kPublic] = ACTIONS(2589),
    [sym_kProtected] = ACTIONS(1643),
    [sym_kPrivate] = ACTIONS(1643),
    [sym_kStrict] = ACTIONS(1643),
    [sym_kRequired] = ACTIONS(1643),
    [sym_kOptional] = ACTIONS(1643),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [399] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2592),
    [sym_kEnd] = ACTIONS(1396),
    [sym_kVar] = ACTIONS(1398),
    [sym_kThreadvar] = ACTIONS(1396),
    [sym_kConst] = ACTIONS(1398),
    [sym_kResourcestring] = ACTIONS(1396),
    [sym_kType] = ACTIONS(1396),
    [sym_kProperty] = ACTIONS(1396),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1396),
    [sym_kGeneric] = ACTIONS(1396),
    [sym_kCase] = ACTIONS(1396),
    [sym_kFunction] = ACTIONS(1396),
    [sym_kProcedure] = ACTIONS(1396),
    [sym_kConstructor] = ACTIONS(1396),
    [sym_kDestructor] = ACTIONS(1396),
    [sym_kOperator] = ACTIONS(1396),
    [sym_kPublished] = ACTIONS(1396),
    [sym_kPublic] = ACTIONS(2595),
    [sym_kProtected] = ACTIONS(1396),
    [sym_kPrivate] = ACTIONS(1396),
    [sym_kStrict] = ACTIONS(1396),
    [sym_kRequired] = ACTIONS(1396),
    [sym_kOptional] = ACTIONS(1396),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [400] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2598),
    [sym_kEnd] = ACTIONS(1998),
    [sym_kVar] = ACTIONS(2000),
    [sym_kThreadvar] = ACTIONS(1998),
    [sym_kConst] = ACTIONS(2000),
    [sym_kResourcestring] = ACTIONS(1998),
    [sym_kType] = ACTIONS(1998),
    [sym_kProperty] = ACTIONS(1998),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1998),
    [sym_kGeneric] = ACTIONS(1998),
    [sym_kCase] = ACTIONS(1998),
    [sym_kFunction] = ACTIONS(1998),
    [sym_kProcedure] = ACTIONS(1998),
    [sym_kConstructor] = ACTIONS(1998),
    [sym_kDestructor] = ACTIONS(1998),
    [sym_kOperator] = ACTIONS(1998),
    [sym_kPublished] = ACTIONS(1998),
    [sym_kPublic] = ACTIONS(2601),
    [sym_kProtected] = ACTIONS(1998),
    [sym_kPrivate] = ACTIONS(1998),
    [sym_kStrict] = ACTIONS(1998),
    [sym_kRequired] = ACTIONS(1998),
    [sym_kOptional] = ACTIONS(1998),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [401] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2604),
    [sym_kEnd] = ACTIONS(2005),
    [sym_kVar] = ACTIONS(2007),
    [sym_kThreadvar] = ACTIONS(2005),
    [sym_kConst] = ACTIONS(2007),
    [sym_kResourcestring] = ACTIONS(2005),
    [sym_kType] = ACTIONS(2005),
    [sym_kProperty] = ACTIONS(2005),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2005),
    [sym_kGeneric] = ACTIONS(2005),
    [sym_kCase] = ACTIONS(2005),
    [sym_kFunction] = ACTIONS(2005),
    [sym_kProcedure] = ACTIONS(2005),
    [sym_kConstructor] = ACTIONS(2005),
    [sym_kDestructor] = ACTIONS(2005),
    [sym_kOperator] = ACTIONS(2005),
    [sym_kPublished] = ACTIONS(2005),
    [sym_kPublic] = ACTIONS(2607),
    [sym_kProtected] = ACTIONS(2005),
    [sym_kPrivate] = ACTIONS(2005),
    [sym_kStrict] = ACTIONS(2005),
    [sym_kRequired] = ACTIONS(2005),
    [sym_kOptional] = ACTIONS(2005),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [402] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2610),
    [sym_kEnd] = ACTIONS(2012),
    [sym_kVar] = ACTIONS(2014),
    [sym_kThreadvar] = ACTIONS(2012),
    [sym_kConst] = ACTIONS(2014),
    [sym_kResourcestring] = ACTIONS(2012),
    [sym_kType] = ACTIONS(2012),
    [sym_kProperty] = ACTIONS(2012),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2012),
    [sym_kGeneric] = ACTIONS(2012),
    [sym_kCase] = ACTIONS(2012),
    [sym_kFunction] = ACTIONS(2012),
    [sym_kProcedure] = ACTIONS(2012),
    [sym_kConstructor] = ACTIONS(2012),
    [sym_kDestructor] = ACTIONS(2012),
    [sym_kOperator] = ACTIONS(2012),
    [sym_kPublished] = ACTIONS(2012),
    [sym_kPublic] = ACTIONS(2613),
    [sym_kProtected] = ACTIONS(2012),
    [sym_kPrivate] = ACTIONS(2012),
    [sym_kStrict] = ACTIONS(2012),
    [sym_kRequired] = ACTIONS(2012),
    [sym_kOptional] = ACTIONS(2012),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [403] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(408),
    [anon_sym_LBRACK] = ACTIONS(2616),
    [sym_kEnd] = ACTIONS(2019),
    [sym_kVar] = ACTIONS(2021),
    [sym_kThreadvar] = ACTIONS(2019),
    [sym_kConst] = ACTIONS(2021),
    [sym_kResourcestring] = ACTIONS(2019),
    [sym_kType] = ACTIONS(2019),
    [sym_kProperty] = ACTIONS(2019),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2019),
    [sym_kGeneric] = ACTIONS(2019),
    [sym_kCase] = ACTIONS(2019),
    [sym_kFunction] = ACTIONS(2019),
    [sym_kProcedure] = ACTIONS(2019),
    [sym_kConstructor] = ACTIONS(2019),
    [sym_kDestructor] = ACTIONS(2019),
    [sym_kOperator] = ACTIONS(2019),
    [sym_kPublished] = ACTIONS(2019),
    [sym_kPublic] = ACTIONS(2619),
    [sym_kProtected] = ACTIONS(2019),
    [sym_kPrivate] = ACTIONS(2019),
    [sym_kStrict] = ACTIONS(2019),
    [sym_kRequired] = ACTIONS(2019),
    [sym_kOptional] = ACTIONS(2019),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [404] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2622),
    [sym_kEnd] = ACTIONS(1403),
    [sym_kVar] = ACTIONS(1405),
    [sym_kThreadvar] = ACTIONS(1403),
    [sym_kConst] = ACTIONS(1405),
    [sym_kResourcestring] = ACTIONS(1403),
    [sym_kType] = ACTIONS(1403),
    [sym_kProperty] = ACTIONS(1403),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1403),
    [sym_kGeneric] = ACTIONS(1403),
    [sym_kCase] = ACTIONS(1403),
    [sym_kFunction] = ACTIONS(1403),
    [sym_kProcedure] = ACTIONS(1403),
    [sym_kConstructor] = ACTIONS(1403),
    [sym_kDestructor] = ACTIONS(1403),
    [sym_kOperator] = ACTIONS(1403),
    [sym_kPublished] = ACTIONS(1403),
    [sym_kPublic] = ACTIONS(2625),
    [sym_kProtected] = ACTIONS(1403),
    [sym_kPrivate] = ACTIONS(1403),
    [sym_kStrict] = ACTIONS(1403),
    [sym_kRequired] = ACTIONS(1403),
    [sym_kOptional] = ACTIONS(1403),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [405] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2628),
    [sym_kEnd] = ACTIONS(1410),
    [sym_kVar] = ACTIONS(1412),
    [sym_kThreadvar] = ACTIONS(1410),
    [sym_kConst] = ACTIONS(1412),
    [sym_kResourcestring] = ACTIONS(1410),
    [sym_kType] = ACTIONS(1410),
    [sym_kProperty] = ACTIONS(1410),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1410),
    [sym_kGeneric] = ACTIONS(1410),
    [sym_kCase] = ACTIONS(1410),
    [sym_kFunction] = ACTIONS(1410),
    [sym_kProcedure] = ACTIONS(1410),
    [sym_kConstructor] = ACTIONS(1410),
    [sym_kDestructor] = ACTIONS(1410),
    [sym_kOperator] = ACTIONS(1410),
    [sym_kPublished] = ACTIONS(1410),
    [sym_kPublic] = ACTIONS(2631),
    [sym_kProtected] = ACTIONS(1410),
    [sym_kPrivate] = ACTIONS(1410),
    [sym_kStrict] = ACTIONS(1410),
    [sym_kRequired] = ACTIONS(1410),
    [sym_kOptional] = ACTIONS(1410),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [406] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(409),
    [anon_sym_LBRACK] = ACTIONS(2634),
    [sym_kEnd] = ACTIONS(1417),
    [sym_kVar] = ACTIONS(1419),
    [sym_kThreadvar] = ACTIONS(1417),
    [sym_kConst] = ACTIONS(1419),
    [sym_kResourcestring] = ACTIONS(1417),
    [sym_kType] = ACTIONS(1417),
    [sym_kProperty] = ACTIONS(1417),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1417),
    [sym_kGeneric] = ACTIONS(1417),
    [sym_kCase] = ACTIONS(1417),
    [sym_kFunction] = ACTIONS(1417),
    [sym_kProcedure] = ACTIONS(1417),
    [sym_kConstructor] = ACTIONS(1417),
    [sym_kDestructor] = ACTIONS(1417),
    [sym_kOperator] = ACTIONS(1417),
    [sym_kPublished] = ACTIONS(1417),
    [sym_kPublic] = ACTIONS(2637),
    [sym_kProtected] = ACTIONS(1417),
    [sym_kPrivate] = ACTIONS(1417),
    [sym_kStrict] = ACTIONS(1417),
    [sym_kRequired] = ACTIONS(1417),
    [sym_kOptional] = ACTIONS(1417),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [407] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2640),
    [sym_kEnd] = ACTIONS(2026),
    [sym_kVar] = ACTIONS(2028),
    [sym_kThreadvar] = ACTIONS(2026),
    [sym_kConst] = ACTIONS(2028),
    [sym_kResourcestring] = ACTIONS(2026),
    [sym_kType] = ACTIONS(2026),
    [sym_kProperty] = ACTIONS(2026),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2026),
    [sym_kGeneric] = ACTIONS(2026),
    [sym_kCase] = ACTIONS(2026),
    [sym_kFunction] = ACTIONS(2026),
    [sym_kProcedure] = ACTIONS(2026),
    [sym_kConstructor] = ACTIONS(2026),
    [sym_kDestructor] = ACTIONS(2026),
    [sym_kOperator] = ACTIONS(2026),
    [sym_kPublished] = ACTIONS(2026),
    [sym_kPublic] = ACTIONS(2643),
    [sym_kProtected] = ACTIONS(2026),
    [sym_kPrivate] = ACTIONS(2026),
    [sym_kStrict] = ACTIONS(2026),
    [sym_kRequired] = ACTIONS(2026),
    [sym_kOptional] = ACTIONS(2026),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [408] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2646),
    [sym_kEnd] = ACTIONS(2057),
    [sym_kVar] = ACTIONS(2059),
    [sym_kThreadvar] = ACTIONS(2057),
    [sym_kConst] = ACTIONS(2059),
    [sym_kResourcestring] = ACTIONS(2057),
    [sym_kType] = ACTIONS(2057),
    [sym_kProperty] = ACTIONS(2057),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2057),
    [sym_kGeneric] = ACTIONS(2057),
    [sym_kCase] = ACTIONS(2057),
    [sym_kFunction] = ACTIONS(2057),
    [sym_kProcedure] = ACTIONS(2057),
    [sym_kConstructor] = ACTIONS(2057),
    [sym_kDestructor] = ACTIONS(2057),
    [sym_kOperator] = ACTIONS(2057),
    [sym_kPublished] = ACTIONS(2057),
    [sym_kPublic] = ACTIONS(2649),
    [sym_kProtected] = ACTIONS(2057),
    [sym_kPrivate] = ACTIONS(2057),
    [sym_kStrict] = ACTIONS(2057),
    [sym_kRequired] = ACTIONS(2057),
    [sym_kOptional] = ACTIONS(2057),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [409] = {
    [sym__procAttributeNoExt] = STATE(502),
    [sym_procAttribute] = STATE(2664),
    [aux_sym__declProc_repeat1] = STATE(338),
    [anon_sym_LBRACK] = ACTIONS(2652),
    [sym_kEnd] = ACTIONS(1431),
    [sym_kVar] = ACTIONS(1433),
    [sym_kThreadvar] = ACTIONS(1431),
    [sym_kConst] = ACTIONS(1433),
    [sym_kResourcestring] = ACTIONS(1431),
    [sym_kType] = ACTIONS(1431),
    [sym_kProperty] = ACTIONS(1431),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1431),
    [sym_kGeneric] = ACTIONS(1431),
    [sym_kCase] = ACTIONS(1431),
    [sym_kFunction] = ACTIONS(1431),
    [sym_kProcedure] = ACTIONS(1431),
    [sym_kConstructor] = ACTIONS(1431),
    [sym_kDestructor] = ACTIONS(1431),
    [sym_kOperator] = ACTIONS(1431),
    [sym_kPublished] = ACTIONS(1431),
    [sym_kPublic] = ACTIONS(2655),
    [sym_kProtected] = ACTIONS(1431),
    [sym_kPrivate] = ACTIONS(1431),
    [sym_kStrict] = ACTIONS(1431),
    [sym_kRequired] = ACTIONS(1431),
    [sym_kOptional] = ACTIONS(1431),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [410] = {
    [sym__procAttribute] = STATE(477),
    [sym_procAttribute] = STATE(2555),
    [aux_sym_declProcFwd_repeat1] = STATE(318),
    [anon_sym_LBRACK] = ACTIONS(2658),
    [sym_kEnd] = ACTIONS(1797),
    [sym_kVar] = ACTIONS(1799),
    [sym_kThreadvar] = ACTIONS(1797),
    [sym_kConst] = ACTIONS(1799),
    [sym_kResourcestring] = ACTIONS(1797),
    [sym_kType] = ACTIONS(1797),
    [sym_kProperty] = ACTIONS(1797),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1797),
    [sym_kGeneric] = ACTIONS(1797),
    [sym_kCase] = ACTIONS(1797),
    [sym_kFunction] = ACTIONS(1797),
    [sym_kProcedure] = ACTIONS(1797),
    [sym_kConstructor] = ACTIONS(1797),
    [sym_kDestructor] = ACTIONS(1797),
    [sym_kOperator] = ACTIONS(1797),
    [sym_kPublished] = ACTIONS(1797),
    [sym_kPublic] = ACTIONS(2661),
    [sym_kProtected] = ACTIONS(1797),
    [sym_kPrivate] = ACTIONS(1797),
    [sym_kStrict] = ACTIONS(1797),
    [sym_kRequired] = ACTIONS(1797),
    [sym_kOptional] = ACTIONS(1797),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(1979),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [411] = {
    [anon_sym_LBRACK] = ACTIONS(2664),
    [sym_kUses] = ACTIONS(2664),
    [sym_kInterface] = ACTIONS(2664),
    [sym_kImplementation] = ACTIONS(2664),
    [sym_kInitialization] = ACTIONS(2664),
    [sym_kFinalization] = ACTIONS(2664),
    [sym_kEnd] = ACTIONS(2664),
    [sym_kVar] = ACTIONS(2666),
    [sym_kThreadvar] = ACTIONS(2664),
    [sym_kConst] = ACTIONS(2666),
    [sym_kResourcestring] = ACTIONS(2664),
    [sym_kType] = ACTIONS(2664),
    [sym_kLabel] = ACTIONS(2664),
    [sym_kExports] = ACTIONS(2664),
    [sym_kProperty] = ACTIONS(2664),
    [sym_kDefault] = ACTIONS(2664),
    [sym_kNodefault] = ACTIONS(2664),
    [sym_kDispId] = ACTIONS(2664),
    [sym_kClass] = ACTIONS(2664),
    [sym_kGeneric] = ACTIONS(2664),
    [sym_kFunction] = ACTIONS(2664),
    [sym_kProcedure] = ACTIONS(2664),
    [sym_kConstructor] = ACTIONS(2664),
    [sym_kDestructor] = ACTIONS(2664),
    [sym_kOperator] = ACTIONS(2664),
    [sym_kPublic] = ACTIONS(2664),
    [sym_kForward] = ACTIONS(2664),
    [sym_kStatic] = ACTIONS(2664),
    [sym_kVirtual] = ACTIONS(2664),
    [sym_kAbstract] = ACTIONS(2664),
    [sym_kDynamic] = ACTIONS(2664),
    [sym_kOverride] = ACTIONS(2664),
    [sym_kOverload] = ACTIONS(2664),
    [sym_kReintroduce] = ACTIONS(2664),
    [sym_kInline] = ACTIONS(2664),
    [sym_kStdcall] = ACTIONS(2664),
    [sym_kCdecl] = ACTIONS(2664),
    [sym_kCppdecl] = ACTIONS(2664),
    [sym_kPascal] = ACTIONS(2664),
    [sym_kRegister] = ACTIONS(2664),
    [sym_kMwpascal] = ACTIONS(2664),
    [sym_kExternal] = ACTIONS(2664),
    [sym_kMessage] = ACTIONS(2664),
    [sym_kDeprecated] = ACTIONS(2664),
    [sym_kExperimental] = ACTIONS(2664),
    [sym_kPlatform] = ACTIONS(2664),
    [sym_kUnimplemented] = ACTIONS(2664),
    [sym_kCvar] = ACTIONS(2664),
    [sym_kExport] = ACTIONS(2666),
    [sym_kFar] = ACTIONS(2664),
    [sym_kNear] = ACTIONS(2664),
    [sym_kSafecall] = ACTIONS(2664),
    [sym_kAssembler] = ACTIONS(2664),
    [sym_kNostackframe] = ACTIONS(2664),
    [sym_kInterrupt] = ACTIONS(2664),
    [sym_kNoreturn] = ACTIONS(2664),
    [sym_kIocheck] = ACTIONS(2664),
    [sym_kLocal] = ACTIONS(2664),
    [sym_kHardfloat] = ACTIONS(2664),
    [sym_kSoftfloat] = ACTIONS(2664),
    [sym_kMs_abi_default] = ACTIONS(2664),
    [sym_kMs_abi_cdecl] = ACTIONS(2664),
    [sym_kSaveregisters] = ACTIONS(2664),
    [sym_kSysv_abi_default] = ACTIONS(2664),
    [sym_kSysv_abi_cdecl] = ACTIONS(2664),
    [sym_kVectorcall] = ACTIONS(2664),
    [sym_kVarargs] = ACTIONS(2664),
    [sym_kWinapi] = ACTIONS(2664),
    [sym_kAlias] = ACTIONS(2664),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [412] = {
    [anon_sym_LBRACK] = ACTIONS(2668),
    [sym_kUses] = ACTIONS(2668),
    [sym_kInterface] = ACTIONS(2668),
    [sym_kImplementation] = ACTIONS(2668),
    [sym_kInitialization] = ACTIONS(2668),
    [sym_kFinalization] = ACTIONS(2668),
    [sym_kEnd] = ACTIONS(2668),
    [sym_kVar] = ACTIONS(2670),
    [sym_kThreadvar] = ACTIONS(2668),
    [sym_kConst] = ACTIONS(2670),
    [sym_kResourcestring] = ACTIONS(2668),
    [sym_kType] = ACTIONS(2668),
    [sym_kLabel] = ACTIONS(2668),
    [sym_kExports] = ACTIONS(2668),
    [sym_kProperty] = ACTIONS(2668),
    [sym_kDefault] = ACTIONS(2668),
    [sym_kNodefault] = ACTIONS(2668),
    [sym_kDispId] = ACTIONS(2668),
    [sym_kClass] = ACTIONS(2668),
    [sym_kGeneric] = ACTIONS(2668),
    [sym_kFunction] = ACTIONS(2668),
    [sym_kProcedure] = ACTIONS(2668),
    [sym_kConstructor] = ACTIONS(2668),
    [sym_kDestructor] = ACTIONS(2668),
    [sym_kOperator] = ACTIONS(2668),
    [sym_kPublic] = ACTIONS(2668),
    [sym_kForward] = ACTIONS(2668),
    [sym_kStatic] = ACTIONS(2668),
    [sym_kVirtual] = ACTIONS(2668),
    [sym_kAbstract] = ACTIONS(2668),
    [sym_kDynamic] = ACTIONS(2668),
    [sym_kOverride] = ACTIONS(2668),
    [sym_kOverload] = ACTIONS(2668),
    [sym_kReintroduce] = ACTIONS(2668),
    [sym_kInline] = ACTIONS(2668),
    [sym_kStdcall] = ACTIONS(2668),
    [sym_kCdecl] = ACTIONS(2668),
    [sym_kCppdecl] = ACTIONS(2668),
    [sym_kPascal] = ACTIONS(2668),
    [sym_kRegister] = ACTIONS(2668),
    [sym_kMwpascal] = ACTIONS(2668),
    [sym_kExternal] = ACTIONS(2668),
    [sym_kMessage] = ACTIONS(2668),
    [sym_kDeprecated] = ACTIONS(2668),
    [sym_kExperimental] = ACTIONS(2668),
    [sym_kPlatform] = ACTIONS(2668),
    [sym_kUnimplemented] = ACTIONS(2668),
    [sym_kCvar] = ACTIONS(2668),
    [sym_kExport] = ACTIONS(2670),
    [sym_kFar] = ACTIONS(2668),
    [sym_kNear] = ACTIONS(2668),
    [sym_kSafecall] = ACTIONS(2668),
    [sym_kAssembler] = ACTIONS(2668),
    [sym_kNostackframe] = ACTIONS(2668),
    [sym_kInterrupt] = ACTIONS(2668),
    [sym_kNoreturn] = ACTIONS(2668),
    [sym_kIocheck] = ACTIONS(2668),
    [sym_kLocal] = ACTIONS(2668),
    [sym_kHardfloat] = ACTIONS(2668),
    [sym_kSoftfloat] = ACTIONS(2668),
    [sym_kMs_abi_default] = ACTIONS(2668),
    [sym_kMs_abi_cdecl] = ACTIONS(2668),
    [sym_kSaveregisters] = ACTIONS(2668),
    [sym_kSysv_abi_default] = ACTIONS(2668),
    [sym_kSysv_abi_cdecl] = ACTIONS(2668),
    [sym_kVectorcall] = ACTIONS(2668),
    [sym_kVarargs] = ACTIONS(2668),
    [sym_kWinapi] = ACTIONS(2668),
    [sym_kAlias] = ACTIONS(2668),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [413] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(420),
    [anon_sym_LBRACK] = ACTIONS(2672),
    [aux_sym_type_token1] = ACTIONS(1450),
    [sym_kUses] = ACTIONS(1450),
    [sym_kBegin] = ACTIONS(1450),
    [sym_kAsm] = ACTIONS(1450),
    [sym_kVar] = ACTIONS(1452),
    [sym_kThreadvar] = ACTIONS(1450),
    [sym_kConst] = ACTIONS(1452),
    [sym_kResourcestring] = ACTIONS(1450),
    [sym_kType] = ACTIONS(1450),
    [sym_kLabel] = ACTIONS(1450),
    [sym_kExports] = ACTIONS(1450),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1450),
    [sym_kGeneric] = ACTIONS(1450),
    [sym_kFunction] = ACTIONS(1450),
    [sym_kProcedure] = ACTIONS(1450),
    [sym_kConstructor] = ACTIONS(1450),
    [sym_kDestructor] = ACTIONS(1450),
    [sym_kOperator] = ACTIONS(1450),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1450),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1450),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [414] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(439),
    [anon_sym_LBRACK] = ACTIONS(2675),
    [aux_sym_type_token1] = ACTIONS(1457),
    [sym_kUses] = ACTIONS(1457),
    [sym_kBegin] = ACTIONS(1457),
    [sym_kAsm] = ACTIONS(1457),
    [sym_kVar] = ACTIONS(1459),
    [sym_kThreadvar] = ACTIONS(1457),
    [sym_kConst] = ACTIONS(1459),
    [sym_kResourcestring] = ACTIONS(1457),
    [sym_kType] = ACTIONS(1457),
    [sym_kLabel] = ACTIONS(1457),
    [sym_kExports] = ACTIONS(1457),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1457),
    [sym_kGeneric] = ACTIONS(1457),
    [sym_kFunction] = ACTIONS(1457),
    [sym_kProcedure] = ACTIONS(1457),
    [sym_kConstructor] = ACTIONS(1457),
    [sym_kDestructor] = ACTIONS(1457),
    [sym_kOperator] = ACTIONS(1457),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1457),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1457),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [415] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(457),
    [anon_sym_LBRACK] = ACTIONS(2678),
    [aux_sym_type_token1] = ACTIONS(1475),
    [sym_kUses] = ACTIONS(1475),
    [sym_kBegin] = ACTIONS(1475),
    [sym_kAsm] = ACTIONS(1475),
    [sym_kVar] = ACTIONS(1477),
    [sym_kThreadvar] = ACTIONS(1475),
    [sym_kConst] = ACTIONS(1477),
    [sym_kResourcestring] = ACTIONS(1475),
    [sym_kType] = ACTIONS(1475),
    [sym_kLabel] = ACTIONS(1475),
    [sym_kExports] = ACTIONS(1475),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1475),
    [sym_kGeneric] = ACTIONS(1475),
    [sym_kFunction] = ACTIONS(1475),
    [sym_kProcedure] = ACTIONS(1475),
    [sym_kConstructor] = ACTIONS(1475),
    [sym_kDestructor] = ACTIONS(1475),
    [sym_kOperator] = ACTIONS(1475),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1475),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1475),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [416] = {
    [sym_identifier] = ACTIONS(598),
    [anon_sym_LBRACK] = ACTIONS(596),
    [sym_kEnd] = ACTIONS(598),
    [sym_kVar] = ACTIONS(598),
    [sym_kThreadvar] = ACTIONS(598),
    [sym_kConst] = ACTIONS(598),
    [sym_kResourcestring] = ACTIONS(598),
    [sym_kType] = ACTIONS(598),
    [sym_kProperty] = ACTIONS(598),
    [sym_kDefault] = ACTIONS(598),
    [sym_kNodefault] = ACTIONS(598),
    [sym_kDispId] = ACTIONS(598),
    [sym_kClass] = ACTIONS(598),
    [sym_kGeneric] = ACTIONS(598),
    [sym_kCase] = ACTIONS(598),
    [sym_kFunction] = ACTIONS(598),
    [sym_kProcedure] = ACTIONS(598),
    [sym_kConstructor] = ACTIONS(598),
    [sym_kDestructor] = ACTIONS(598),
    [sym_kOperator] = ACTIONS(598),
    [sym_kPublished] = ACTIONS(598),
    [sym_kPublic] = ACTIONS(598),
    [sym_kProtected] = ACTIONS(598),
    [sym_kPrivate] = ACTIONS(598),
    [sym_kStrict] = ACTIONS(598),
    [sym_kRequired] = ACTIONS(598),
    [sym_kOptional] = ACTIONS(598),
    [sym_kStatic] = ACTIONS(598),
    [sym_kVirtual] = ACTIONS(598),
    [sym_kAbstract] = ACTIONS(598),
    [sym_kDynamic] = ACTIONS(598),
    [sym_kOverride] = ACTIONS(598),
    [sym_kOverload] = ACTIONS(598),
    [sym_kReintroduce] = ACTIONS(598),
    [sym_kInline] = ACTIONS(598),
    [sym_kStdcall] = ACTIONS(598),
    [sym_kCdecl] = ACTIONS(598),
    [sym_kCppdecl] = ACTIONS(598),
    [sym_kPascal] = ACTIONS(598),
    [sym_kRegister] = ACTIONS(598),
    [sym_kMwpascal] = ACTIONS(598),
    [sym_kExternal] = ACTIONS(598),
    [sym_kMessage] = ACTIONS(598),
    [sym_kDeprecated] = ACTIONS(598),
    [sym_kExperimental] = ACTIONS(598),
    [sym_kPlatform] = ACTIONS(598),
    [sym_kUnimplemented] = ACTIONS(598),
    [sym_kCvar] = ACTIONS(598),
    [sym_kExport] = ACTIONS(598),
    [sym_kFar] = ACTIONS(598),
    [sym_kNear] = ACTIONS(598),
    [sym_kSafecall] = ACTIONS(598),
    [sym_kAssembler] = ACTIONS(598),
    [sym_kNostackframe] = ACTIONS(598),
    [sym_kInterrupt] = ACTIONS(598),
    [sym_kNoreturn] = ACTIONS(598),
    [sym_kIocheck] = ACTIONS(598),
    [sym_kLocal] = ACTIONS(598),
    [sym_kHardfloat] = ACTIONS(598),
    [sym_kSoftfloat] = ACTIONS(598),
    [sym_kMs_abi_default] = ACTIONS(598),
    [sym_kMs_abi_cdecl] = ACTIONS(598),
    [sym_kSaveregisters] = ACTIONS(598),
    [sym_kSysv_abi_default] = ACTIONS(598),
    [sym_kSysv_abi_cdecl] = ACTIONS(598),
    [sym_kVectorcall] = ACTIONS(598),
    [sym_kVarargs] = ACTIONS(598),
    [sym_kWinapi] = ACTIONS(598),
    [sym_kAlias] = ACTIONS(598),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [417] = {
    [sym_identifier] = ACTIONS(1445),
    [anon_sym_LBRACK] = ACTIONS(1443),
    [sym_kEnd] = ACTIONS(1445),
    [sym_kVar] = ACTIONS(1445),
    [sym_kThreadvar] = ACTIONS(1445),
    [sym_kConst] = ACTIONS(1445),
    [sym_kResourcestring] = ACTIONS(1445),
    [sym_kType] = ACTIONS(1445),
    [sym_kProperty] = ACTIONS(1445),
    [sym_kDefault] = ACTIONS(1445),
    [sym_kNodefault] = ACTIONS(1445),
    [sym_kDispId] = ACTIONS(1445),
    [sym_kClass] = ACTIONS(1445),
    [sym_kGeneric] = ACTIONS(1445),
    [sym_kCase] = ACTIONS(1445),
    [sym_kFunction] = ACTIONS(1445),
    [sym_kProcedure] = ACTIONS(1445),
    [sym_kConstructor] = ACTIONS(1445),
    [sym_kDestructor] = ACTIONS(1445),
    [sym_kOperator] = ACTIONS(1445),
    [sym_kPublished] = ACTIONS(1445),
    [sym_kPublic] = ACTIONS(1445),
    [sym_kProtected] = ACTIONS(1445),
    [sym_kPrivate] = ACTIONS(1445),
    [sym_kStrict] = ACTIONS(1445),
    [sym_kRequired] = ACTIONS(1445),
    [sym_kOptional] = ACTIONS(1445),
    [sym_kStatic] = ACTIONS(1445),
    [sym_kVirtual] = ACTIONS(1445),
    [sym_kAbstract] = ACTIONS(1445),
    [sym_kDynamic] = ACTIONS(1445),
    [sym_kOverride] = ACTIONS(1445),
    [sym_kOverload] = ACTIONS(1445),
    [sym_kReintroduce] = ACTIONS(1445),
    [sym_kInline] = ACTIONS(1445),
    [sym_kStdcall] = ACTIONS(1445),
    [sym_kCdecl] = ACTIONS(1445),
    [sym_kCppdecl] = ACTIONS(1445),
    [sym_kPascal] = ACTIONS(1445),
    [sym_kRegister] = ACTIONS(1445),
    [sym_kMwpascal] = ACTIONS(1445),
    [sym_kExternal] = ACTIONS(1445),
    [sym_kMessage] = ACTIONS(1445),
    [sym_kDeprecated] = ACTIONS(1445),
    [sym_kExperimental] = ACTIONS(1445),
    [sym_kPlatform] = ACTIONS(1445),
    [sym_kUnimplemented] = ACTIONS(1445),
    [sym_kCvar] = ACTIONS(1445),
    [sym_kExport] = ACTIONS(1445),
    [sym_kFar] = ACTIONS(1445),
    [sym_kNear] = ACTIONS(1445),
    [sym_kSafecall] = ACTIONS(1445),
    [sym_kAssembler] = ACTIONS(1445),
    [sym_kNostackframe] = ACTIONS(1445),
    [sym_kInterrupt] = ACTIONS(1445),
    [sym_kNoreturn] = ACTIONS(1445),
    [sym_kIocheck] = ACTIONS(1445),
    [sym_kLocal] = ACTIONS(1445),
    [sym_kHardfloat] = ACTIONS(1445),
    [sym_kSoftfloat] = ACTIONS(1445),
    [sym_kMs_abi_default] = ACTIONS(1445),
    [sym_kMs_abi_cdecl] = ACTIONS(1445),
    [sym_kSaveregisters] = ACTIONS(1445),
    [sym_kSysv_abi_default] = ACTIONS(1445),
    [sym_kSysv_abi_cdecl] = ACTIONS(1445),
    [sym_kVectorcall] = ACTIONS(1445),
    [sym_kVarargs] = ACTIONS(1445),
    [sym_kWinapi] = ACTIONS(1445),
    [sym_kAlias] = ACTIONS(1445),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [418] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2681),
    [aux_sym_type_token1] = ACTIONS(1178),
    [sym_kUses] = ACTIONS(1178),
    [sym_kBegin] = ACTIONS(1178),
    [sym_kAsm] = ACTIONS(1178),
    [sym_kVar] = ACTIONS(1180),
    [sym_kThreadvar] = ACTIONS(1178),
    [sym_kConst] = ACTIONS(1180),
    [sym_kResourcestring] = ACTIONS(1178),
    [sym_kType] = ACTIONS(1178),
    [sym_kLabel] = ACTIONS(1178),
    [sym_kExports] = ACTIONS(1178),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1178),
    [sym_kGeneric] = ACTIONS(1178),
    [sym_kFunction] = ACTIONS(1178),
    [sym_kProcedure] = ACTIONS(1178),
    [sym_kConstructor] = ACTIONS(1178),
    [sym_kDestructor] = ACTIONS(1178),
    [sym_kOperator] = ACTIONS(1178),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1178),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1178),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [419] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(435),
    [anon_sym_LBRACK] = ACTIONS(2684),
    [aux_sym_type_token1] = ACTIONS(1185),
    [sym_kUses] = ACTIONS(1185),
    [sym_kBegin] = ACTIONS(1185),
    [sym_kAsm] = ACTIONS(1185),
    [sym_kVar] = ACTIONS(1187),
    [sym_kThreadvar] = ACTIONS(1185),
    [sym_kConst] = ACTIONS(1187),
    [sym_kResourcestring] = ACTIONS(1185),
    [sym_kType] = ACTIONS(1185),
    [sym_kLabel] = ACTIONS(1185),
    [sym_kExports] = ACTIONS(1185),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1185),
    [sym_kGeneric] = ACTIONS(1185),
    [sym_kFunction] = ACTIONS(1185),
    [sym_kProcedure] = ACTIONS(1185),
    [sym_kConstructor] = ACTIONS(1185),
    [sym_kDestructor] = ACTIONS(1185),
    [sym_kOperator] = ACTIONS(1185),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1185),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1185),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [420] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2687),
    [aux_sym_type_token1] = ACTIONS(1361),
    [sym_kUses] = ACTIONS(1361),
    [sym_kBegin] = ACTIONS(1361),
    [sym_kAsm] = ACTIONS(1361),
    [sym_kVar] = ACTIONS(1363),
    [sym_kThreadvar] = ACTIONS(1361),
    [sym_kConst] = ACTIONS(1363),
    [sym_kResourcestring] = ACTIONS(1361),
    [sym_kType] = ACTIONS(1361),
    [sym_kLabel] = ACTIONS(1361),
    [sym_kExports] = ACTIONS(1361),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1361),
    [sym_kGeneric] = ACTIONS(1361),
    [sym_kFunction] = ACTIONS(1361),
    [sym_kProcedure] = ACTIONS(1361),
    [sym_kConstructor] = ACTIONS(1361),
    [sym_kDestructor] = ACTIONS(1361),
    [sym_kOperator] = ACTIONS(1361),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1361),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1361),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [421] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(466),
    [anon_sym_LBRACK] = ACTIONS(2690),
    [aux_sym_type_token1] = ACTIONS(1266),
    [sym_kUses] = ACTIONS(1266),
    [sym_kBegin] = ACTIONS(1266),
    [sym_kAsm] = ACTIONS(1266),
    [sym_kVar] = ACTIONS(1268),
    [sym_kThreadvar] = ACTIONS(1266),
    [sym_kConst] = ACTIONS(1268),
    [sym_kResourcestring] = ACTIONS(1266),
    [sym_kType] = ACTIONS(1266),
    [sym_kLabel] = ACTIONS(1266),
    [sym_kExports] = ACTIONS(1266),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1266),
    [sym_kGeneric] = ACTIONS(1266),
    [sym_kFunction] = ACTIONS(1266),
    [sym_kProcedure] = ACTIONS(1266),
    [sym_kConstructor] = ACTIONS(1266),
    [sym_kDestructor] = ACTIONS(1266),
    [sym_kOperator] = ACTIONS(1266),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1266),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1266),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [422] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2693),
    [aux_sym_type_token1] = ACTIONS(1192),
    [sym_kUses] = ACTIONS(1192),
    [sym_kBegin] = ACTIONS(1192),
    [sym_kAsm] = ACTIONS(1192),
    [sym_kVar] = ACTIONS(1194),
    [sym_kThreadvar] = ACTIONS(1192),
    [sym_kConst] = ACTIONS(1194),
    [sym_kResourcestring] = ACTIONS(1192),
    [sym_kType] = ACTIONS(1192),
    [sym_kLabel] = ACTIONS(1192),
    [sym_kExports] = ACTIONS(1192),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1192),
    [sym_kGeneric] = ACTIONS(1192),
    [sym_kFunction] = ACTIONS(1192),
    [sym_kProcedure] = ACTIONS(1192),
    [sym_kConstructor] = ACTIONS(1192),
    [sym_kDestructor] = ACTIONS(1192),
    [sym_kOperator] = ACTIONS(1192),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1192),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1192),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [423] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(468),
    [anon_sym_LBRACK] = ACTIONS(2696),
    [aux_sym_type_token1] = ACTIONS(1199),
    [sym_kUses] = ACTIONS(1199),
    [sym_kBegin] = ACTIONS(1199),
    [sym_kAsm] = ACTIONS(1199),
    [sym_kVar] = ACTIONS(1201),
    [sym_kThreadvar] = ACTIONS(1199),
    [sym_kConst] = ACTIONS(1201),
    [sym_kResourcestring] = ACTIONS(1199),
    [sym_kType] = ACTIONS(1199),
    [sym_kLabel] = ACTIONS(1199),
    [sym_kExports] = ACTIONS(1199),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1199),
    [sym_kGeneric] = ACTIONS(1199),
    [sym_kFunction] = ACTIONS(1199),
    [sym_kProcedure] = ACTIONS(1199),
    [sym_kConstructor] = ACTIONS(1199),
    [sym_kDestructor] = ACTIONS(1199),
    [sym_kOperator] = ACTIONS(1199),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1199),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1199),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [424] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(469),
    [anon_sym_LBRACK] = ACTIONS(2699),
    [aux_sym_type_token1] = ACTIONS(1206),
    [sym_kUses] = ACTIONS(1206),
    [sym_kBegin] = ACTIONS(1206),
    [sym_kAsm] = ACTIONS(1206),
    [sym_kVar] = ACTIONS(1208),
    [sym_kThreadvar] = ACTIONS(1206),
    [sym_kConst] = ACTIONS(1208),
    [sym_kResourcestring] = ACTIONS(1206),
    [sym_kType] = ACTIONS(1206),
    [sym_kLabel] = ACTIONS(1206),
    [sym_kExports] = ACTIONS(1206),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1206),
    [sym_kGeneric] = ACTIONS(1206),
    [sym_kFunction] = ACTIONS(1206),
    [sym_kProcedure] = ACTIONS(1206),
    [sym_kConstructor] = ACTIONS(1206),
    [sym_kDestructor] = ACTIONS(1206),
    [sym_kOperator] = ACTIONS(1206),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1206),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1206),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [425] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2702),
    [aux_sym_type_token1] = ACTIONS(1213),
    [sym_kUses] = ACTIONS(1213),
    [sym_kBegin] = ACTIONS(1213),
    [sym_kAsm] = ACTIONS(1213),
    [sym_kVar] = ACTIONS(1215),
    [sym_kThreadvar] = ACTIONS(1213),
    [sym_kConst] = ACTIONS(1215),
    [sym_kResourcestring] = ACTIONS(1213),
    [sym_kType] = ACTIONS(1213),
    [sym_kLabel] = ACTIONS(1213),
    [sym_kExports] = ACTIONS(1213),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1213),
    [sym_kGeneric] = ACTIONS(1213),
    [sym_kFunction] = ACTIONS(1213),
    [sym_kProcedure] = ACTIONS(1213),
    [sym_kConstructor] = ACTIONS(1213),
    [sym_kDestructor] = ACTIONS(1213),
    [sym_kOperator] = ACTIONS(1213),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1213),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1213),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [426] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2705),
    [aux_sym_type_token1] = ACTIONS(1431),
    [sym_kUses] = ACTIONS(1431),
    [sym_kBegin] = ACTIONS(1431),
    [sym_kAsm] = ACTIONS(1431),
    [sym_kVar] = ACTIONS(1433),
    [sym_kThreadvar] = ACTIONS(1431),
    [sym_kConst] = ACTIONS(1433),
    [sym_kResourcestring] = ACTIONS(1431),
    [sym_kType] = ACTIONS(1431),
    [sym_kLabel] = ACTIONS(1431),
    [sym_kExports] = ACTIONS(1431),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1431),
    [sym_kGeneric] = ACTIONS(1431),
    [sym_kFunction] = ACTIONS(1431),
    [sym_kProcedure] = ACTIONS(1431),
    [sym_kConstructor] = ACTIONS(1431),
    [sym_kDestructor] = ACTIONS(1431),
    [sym_kOperator] = ACTIONS(1431),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1431),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1431),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [427] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(418),
    [anon_sym_LBRACK] = ACTIONS(2708),
    [aux_sym_type_token1] = ACTIONS(1273),
    [sym_kUses] = ACTIONS(1273),
    [sym_kBegin] = ACTIONS(1273),
    [sym_kAsm] = ACTIONS(1273),
    [sym_kVar] = ACTIONS(1275),
    [sym_kThreadvar] = ACTIONS(1273),
    [sym_kConst] = ACTIONS(1275),
    [sym_kResourcestring] = ACTIONS(1273),
    [sym_kType] = ACTIONS(1273),
    [sym_kLabel] = ACTIONS(1273),
    [sym_kExports] = ACTIONS(1273),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1273),
    [sym_kGeneric] = ACTIONS(1273),
    [sym_kFunction] = ACTIONS(1273),
    [sym_kProcedure] = ACTIONS(1273),
    [sym_kConstructor] = ACTIONS(1273),
    [sym_kDestructor] = ACTIONS(1273),
    [sym_kOperator] = ACTIONS(1273),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1273),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1273),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [428] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [aux_sym_type_token1] = ACTIONS(1464),
    [sym_kUses] = ACTIONS(1464),
    [sym_kBegin] = ACTIONS(1464),
    [sym_kAsm] = ACTIONS(1464),
    [sym_kVar] = ACTIONS(1466),
    [sym_kThreadvar] = ACTIONS(1464),
    [sym_kConst] = ACTIONS(1466),
    [sym_kResourcestring] = ACTIONS(1464),
    [sym_kType] = ACTIONS(1464),
    [sym_kLabel] = ACTIONS(1464),
    [sym_kExports] = ACTIONS(1464),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1464),
    [sym_kGeneric] = ACTIONS(1464),
    [sym_kFunction] = ACTIONS(1464),
    [sym_kProcedure] = ACTIONS(1464),
    [sym_kConstructor] = ACTIONS(1464),
    [sym_kDestructor] = ACTIONS(1464),
    [sym_kOperator] = ACTIONS(1464),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1464),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1464),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [429] = {
    [sym_identifier] = ACTIONS(630),
    [anon_sym_LBRACK] = ACTIONS(628),
    [sym_kEnd] = ACTIONS(630),
    [sym_kVar] = ACTIONS(630),
    [sym_kThreadvar] = ACTIONS(630),
    [sym_kConst] = ACTIONS(630),
    [sym_kResourcestring] = ACTIONS(630),
    [sym_kType] = ACTIONS(630),
    [sym_kProperty] = ACTIONS(630),
    [sym_kDefault] = ACTIONS(630),
    [sym_kNodefault] = ACTIONS(630),
    [sym_kDispId] = ACTIONS(630),
    [sym_kClass] = ACTIONS(630),
    [sym_kGeneric] = ACTIONS(630),
    [sym_kCase] = ACTIONS(630),
    [sym_kFunction] = ACTIONS(630),
    [sym_kProcedure] = ACTIONS(630),
    [sym_kConstructor] = ACTIONS(630),
    [sym_kDestructor] = ACTIONS(630),
    [sym_kOperator] = ACTIONS(630),
    [sym_kPublished] = ACTIONS(630),
    [sym_kPublic] = ACTIONS(630),
    [sym_kProtected] = ACTIONS(630),
    [sym_kPrivate] = ACTIONS(630),
    [sym_kStrict] = ACTIONS(630),
    [sym_kRequired] = ACTIONS(630),
    [sym_kOptional] = ACTIONS(630),
    [sym_kStatic] = ACTIONS(630),
    [sym_kVirtual] = ACTIONS(630),
    [sym_kAbstract] = ACTIONS(630),
    [sym_kDynamic] = ACTIONS(630),
    [sym_kOverride] = ACTIONS(630),
    [sym_kOverload] = ACTIONS(630),
    [sym_kReintroduce] = ACTIONS(630),
    [sym_kInline] = ACTIONS(630),
    [sym_kStdcall] = ACTIONS(630),
    [sym_kCdecl] = ACTIONS(630),
    [sym_kCppdecl] = ACTIONS(630),
    [sym_kPascal] = ACTIONS(630),
    [sym_kRegister] = ACTIONS(630),
    [sym_kMwpascal] = ACTIONS(630),
    [sym_kExternal] = ACTIONS(630),
    [sym_kMessage] = ACTIONS(630),
    [sym_kDeprecated] = ACTIONS(630),
    [sym_kExperimental] = ACTIONS(630),
    [sym_kPlatform] = ACTIONS(630),
    [sym_kUnimplemented] = ACTIONS(630),
    [sym_kCvar] = ACTIONS(630),
    [sym_kExport] = ACTIONS(630),
    [sym_kFar] = ACTIONS(630),
    [sym_kNear] = ACTIONS(630),
    [sym_kSafecall] = ACTIONS(630),
    [sym_kAssembler] = ACTIONS(630),
    [sym_kNostackframe] = ACTIONS(630),
    [sym_kInterrupt] = ACTIONS(630),
    [sym_kNoreturn] = ACTIONS(630),
    [sym_kIocheck] = ACTIONS(630),
    [sym_kLocal] = ACTIONS(630),
    [sym_kHardfloat] = ACTIONS(630),
    [sym_kSoftfloat] = ACTIONS(630),
    [sym_kMs_abi_default] = ACTIONS(630),
    [sym_kMs_abi_cdecl] = ACTIONS(630),
    [sym_kSaveregisters] = ACTIONS(630),
    [sym_kSysv_abi_default] = ACTIONS(630),
    [sym_kSysv_abi_cdecl] = ACTIONS(630),
    [sym_kVectorcall] = ACTIONS(630),
    [sym_kVarargs] = ACTIONS(630),
    [sym_kWinapi] = ACTIONS(630),
    [sym_kAlias] = ACTIONS(630),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [430] = {
    [sym_identifier] = ACTIONS(1437),
    [anon_sym_LBRACK] = ACTIONS(1435),
    [sym_kEnd] = ACTIONS(1437),
    [sym_kVar] = ACTIONS(1437),
    [sym_kThreadvar] = ACTIONS(1437),
    [sym_kConst] = ACTIONS(1437),
    [sym_kResourcestring] = ACTIONS(1437),
    [sym_kType] = ACTIONS(1437),
    [sym_kProperty] = ACTIONS(1437),
    [sym_kDefault] = ACTIONS(1437),
    [sym_kNodefault] = ACTIONS(1437),
    [sym_kDispId] = ACTIONS(1437),
    [sym_kClass] = ACTIONS(1437),
    [sym_kGeneric] = ACTIONS(1437),
    [sym_kCase] = ACTIONS(1437),
    [sym_kFunction] = ACTIONS(1437),
    [sym_kProcedure] = ACTIONS(1437),
    [sym_kConstructor] = ACTIONS(1437),
    [sym_kDestructor] = ACTIONS(1437),
    [sym_kOperator] = ACTIONS(1437),
    [sym_kPublished] = ACTIONS(1437),
    [sym_kPublic] = ACTIONS(1437),
    [sym_kProtected] = ACTIONS(1437),
    [sym_kPrivate] = ACTIONS(1437),
    [sym_kStrict] = ACTIONS(1437),
    [sym_kRequired] = ACTIONS(1437),
    [sym_kOptional] = ACTIONS(1437),
    [sym_kStatic] = ACTIONS(1437),
    [sym_kVirtual] = ACTIONS(1437),
    [sym_kAbstract] = ACTIONS(1437),
    [sym_kDynamic] = ACTIONS(1437),
    [sym_kOverride] = ACTIONS(1437),
    [sym_kOverload] = ACTIONS(1437),
    [sym_kReintroduce] = ACTIONS(1437),
    [sym_kInline] = ACTIONS(1437),
    [sym_kStdcall] = ACTIONS(1437),
    [sym_kCdecl] = ACTIONS(1437),
    [sym_kCppdecl] = ACTIONS(1437),
    [sym_kPascal] = ACTIONS(1437),
    [sym_kRegister] = ACTIONS(1437),
    [sym_kMwpascal] = ACTIONS(1437),
    [sym_kExternal] = ACTIONS(1437),
    [sym_kMessage] = ACTIONS(1437),
    [sym_kDeprecated] = ACTIONS(1437),
    [sym_kExperimental] = ACTIONS(1437),
    [sym_kPlatform] = ACTIONS(1437),
    [sym_kUnimplemented] = ACTIONS(1437),
    [sym_kCvar] = ACTIONS(1437),
    [sym_kExport] = ACTIONS(1437),
    [sym_kFar] = ACTIONS(1437),
    [sym_kNear] = ACTIONS(1437),
    [sym_kSafecall] = ACTIONS(1437),
    [sym_kAssembler] = ACTIONS(1437),
    [sym_kNostackframe] = ACTIONS(1437),
    [sym_kInterrupt] = ACTIONS(1437),
    [sym_kNoreturn] = ACTIONS(1437),
    [sym_kIocheck] = ACTIONS(1437),
    [sym_kLocal] = ACTIONS(1437),
    [sym_kHardfloat] = ACTIONS(1437),
    [sym_kSoftfloat] = ACTIONS(1437),
    [sym_kMs_abi_default] = ACTIONS(1437),
    [sym_kMs_abi_cdecl] = ACTIONS(1437),
    [sym_kSaveregisters] = ACTIONS(1437),
    [sym_kSysv_abi_default] = ACTIONS(1437),
    [sym_kSysv_abi_cdecl] = ACTIONS(1437),
    [sym_kVectorcall] = ACTIONS(1437),
    [sym_kVarargs] = ACTIONS(1437),
    [sym_kWinapi] = ACTIONS(1437),
    [sym_kAlias] = ACTIONS(1437),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [431] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2714),
    [aux_sym_type_token1] = ACTIONS(1403),
    [sym_kUses] = ACTIONS(1403),
    [sym_kBegin] = ACTIONS(1403),
    [sym_kAsm] = ACTIONS(1403),
    [sym_kVar] = ACTIONS(1405),
    [sym_kThreadvar] = ACTIONS(1403),
    [sym_kConst] = ACTIONS(1405),
    [sym_kResourcestring] = ACTIONS(1403),
    [sym_kType] = ACTIONS(1403),
    [sym_kLabel] = ACTIONS(1403),
    [sym_kExports] = ACTIONS(1403),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1403),
    [sym_kGeneric] = ACTIONS(1403),
    [sym_kFunction] = ACTIONS(1403),
    [sym_kProcedure] = ACTIONS(1403),
    [sym_kConstructor] = ACTIONS(1403),
    [sym_kDestructor] = ACTIONS(1403),
    [sym_kOperator] = ACTIONS(1403),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1403),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1403),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [432] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(442),
    [anon_sym_LBRACK] = ACTIONS(2717),
    [aux_sym_type_token1] = ACTIONS(1486),
    [sym_kUses] = ACTIONS(1486),
    [sym_kBegin] = ACTIONS(1486),
    [sym_kAsm] = ACTIONS(1486),
    [sym_kVar] = ACTIONS(1488),
    [sym_kThreadvar] = ACTIONS(1486),
    [sym_kConst] = ACTIONS(1488),
    [sym_kResourcestring] = ACTIONS(1486),
    [sym_kType] = ACTIONS(1486),
    [sym_kLabel] = ACTIONS(1486),
    [sym_kExports] = ACTIONS(1486),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1486),
    [sym_kGeneric] = ACTIONS(1486),
    [sym_kFunction] = ACTIONS(1486),
    [sym_kProcedure] = ACTIONS(1486),
    [sym_kConstructor] = ACTIONS(1486),
    [sym_kDestructor] = ACTIONS(1486),
    [sym_kOperator] = ACTIONS(1486),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1486),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1486),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [433] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(471),
    [anon_sym_LBRACK] = ACTIONS(2720),
    [aux_sym_type_token1] = ACTIONS(1220),
    [sym_kUses] = ACTIONS(1220),
    [sym_kBegin] = ACTIONS(1220),
    [sym_kAsm] = ACTIONS(1220),
    [sym_kVar] = ACTIONS(1222),
    [sym_kThreadvar] = ACTIONS(1220),
    [sym_kConst] = ACTIONS(1222),
    [sym_kResourcestring] = ACTIONS(1220),
    [sym_kType] = ACTIONS(1220),
    [sym_kLabel] = ACTIONS(1220),
    [sym_kExports] = ACTIONS(1220),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1220),
    [sym_kGeneric] = ACTIONS(1220),
    [sym_kFunction] = ACTIONS(1220),
    [sym_kProcedure] = ACTIONS(1220),
    [sym_kConstructor] = ACTIONS(1220),
    [sym_kDestructor] = ACTIONS(1220),
    [sym_kOperator] = ACTIONS(1220),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1220),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1220),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [434] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(443),
    [anon_sym_LBRACK] = ACTIONS(2723),
    [aux_sym_type_token1] = ACTIONS(1493),
    [sym_kUses] = ACTIONS(1493),
    [sym_kBegin] = ACTIONS(1493),
    [sym_kAsm] = ACTIONS(1493),
    [sym_kVar] = ACTIONS(1495),
    [sym_kThreadvar] = ACTIONS(1493),
    [sym_kConst] = ACTIONS(1495),
    [sym_kResourcestring] = ACTIONS(1493),
    [sym_kType] = ACTIONS(1493),
    [sym_kLabel] = ACTIONS(1493),
    [sym_kExports] = ACTIONS(1493),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1493),
    [sym_kGeneric] = ACTIONS(1493),
    [sym_kFunction] = ACTIONS(1493),
    [sym_kProcedure] = ACTIONS(1493),
    [sym_kConstructor] = ACTIONS(1493),
    [sym_kDestructor] = ACTIONS(1493),
    [sym_kOperator] = ACTIONS(1493),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1493),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1493),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [435] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2726),
    [aux_sym_type_token1] = ACTIONS(1115),
    [sym_kUses] = ACTIONS(1115),
    [sym_kBegin] = ACTIONS(1115),
    [sym_kAsm] = ACTIONS(1115),
    [sym_kVar] = ACTIONS(1117),
    [sym_kThreadvar] = ACTIONS(1115),
    [sym_kConst] = ACTIONS(1117),
    [sym_kResourcestring] = ACTIONS(1115),
    [sym_kType] = ACTIONS(1115),
    [sym_kLabel] = ACTIONS(1115),
    [sym_kExports] = ACTIONS(1115),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1115),
    [sym_kGeneric] = ACTIONS(1115),
    [sym_kFunction] = ACTIONS(1115),
    [sym_kProcedure] = ACTIONS(1115),
    [sym_kConstructor] = ACTIONS(1115),
    [sym_kDestructor] = ACTIONS(1115),
    [sym_kOperator] = ACTIONS(1115),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1115),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1115),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [436] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2729),
    [aux_sym_type_token1] = ACTIONS(1410),
    [sym_kUses] = ACTIONS(1410),
    [sym_kBegin] = ACTIONS(1410),
    [sym_kAsm] = ACTIONS(1410),
    [sym_kVar] = ACTIONS(1412),
    [sym_kThreadvar] = ACTIONS(1410),
    [sym_kConst] = ACTIONS(1412),
    [sym_kResourcestring] = ACTIONS(1410),
    [sym_kType] = ACTIONS(1410),
    [sym_kLabel] = ACTIONS(1410),
    [sym_kExports] = ACTIONS(1410),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1410),
    [sym_kGeneric] = ACTIONS(1410),
    [sym_kFunction] = ACTIONS(1410),
    [sym_kProcedure] = ACTIONS(1410),
    [sym_kConstructor] = ACTIONS(1410),
    [sym_kDestructor] = ACTIONS(1410),
    [sym_kOperator] = ACTIONS(1410),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1410),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1410),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [437] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(426),
    [anon_sym_LBRACK] = ACTIONS(2732),
    [aux_sym_type_token1] = ACTIONS(1417),
    [sym_kUses] = ACTIONS(1417),
    [sym_kBegin] = ACTIONS(1417),
    [sym_kAsm] = ACTIONS(1417),
    [sym_kVar] = ACTIONS(1419),
    [sym_kThreadvar] = ACTIONS(1417),
    [sym_kConst] = ACTIONS(1419),
    [sym_kResourcestring] = ACTIONS(1417),
    [sym_kType] = ACTIONS(1417),
    [sym_kLabel] = ACTIONS(1417),
    [sym_kExports] = ACTIONS(1417),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1417),
    [sym_kGeneric] = ACTIONS(1417),
    [sym_kFunction] = ACTIONS(1417),
    [sym_kProcedure] = ACTIONS(1417),
    [sym_kConstructor] = ACTIONS(1417),
    [sym_kDestructor] = ACTIONS(1417),
    [sym_kOperator] = ACTIONS(1417),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1417),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1417),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [438] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2735),
    [aux_sym_type_token1] = ACTIONS(1227),
    [sym_kUses] = ACTIONS(1227),
    [sym_kBegin] = ACTIONS(1227),
    [sym_kAsm] = ACTIONS(1227),
    [sym_kVar] = ACTIONS(1229),
    [sym_kThreadvar] = ACTIONS(1227),
    [sym_kConst] = ACTIONS(1229),
    [sym_kResourcestring] = ACTIONS(1227),
    [sym_kType] = ACTIONS(1227),
    [sym_kLabel] = ACTIONS(1227),
    [sym_kExports] = ACTIONS(1227),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1227),
    [sym_kGeneric] = ACTIONS(1227),
    [sym_kFunction] = ACTIONS(1227),
    [sym_kProcedure] = ACTIONS(1227),
    [sym_kConstructor] = ACTIONS(1227),
    [sym_kDestructor] = ACTIONS(1227),
    [sym_kOperator] = ACTIONS(1227),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1227),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1227),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [439] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2738),
    [aux_sym_type_token1] = ACTIONS(1234),
    [sym_kUses] = ACTIONS(1234),
    [sym_kBegin] = ACTIONS(1234),
    [sym_kAsm] = ACTIONS(1234),
    [sym_kVar] = ACTIONS(1236),
    [sym_kThreadvar] = ACTIONS(1234),
    [sym_kConst] = ACTIONS(1236),
    [sym_kResourcestring] = ACTIONS(1234),
    [sym_kType] = ACTIONS(1234),
    [sym_kLabel] = ACTIONS(1234),
    [sym_kExports] = ACTIONS(1234),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1234),
    [sym_kGeneric] = ACTIONS(1234),
    [sym_kFunction] = ACTIONS(1234),
    [sym_kProcedure] = ACTIONS(1234),
    [sym_kConstructor] = ACTIONS(1234),
    [sym_kDestructor] = ACTIONS(1234),
    [sym_kOperator] = ACTIONS(1234),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1234),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1234),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [440] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(474),
    [anon_sym_LBRACK] = ACTIONS(2741),
    [aux_sym_type_token1] = ACTIONS(1241),
    [sym_kUses] = ACTIONS(1241),
    [sym_kBegin] = ACTIONS(1241),
    [sym_kAsm] = ACTIONS(1241),
    [sym_kVar] = ACTIONS(1243),
    [sym_kThreadvar] = ACTIONS(1241),
    [sym_kConst] = ACTIONS(1243),
    [sym_kResourcestring] = ACTIONS(1241),
    [sym_kType] = ACTIONS(1241),
    [sym_kLabel] = ACTIONS(1241),
    [sym_kExports] = ACTIONS(1241),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1241),
    [sym_kGeneric] = ACTIONS(1241),
    [sym_kFunction] = ACTIONS(1241),
    [sym_kProcedure] = ACTIONS(1241),
    [sym_kConstructor] = ACTIONS(1241),
    [sym_kDestructor] = ACTIONS(1241),
    [sym_kOperator] = ACTIONS(1241),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1241),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1241),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [441] = {
    [anon_sym_LBRACK] = ACTIONS(2744),
    [sym_kUses] = ACTIONS(2744),
    [sym_kInterface] = ACTIONS(2744),
    [sym_kImplementation] = ACTIONS(2744),
    [sym_kInitialization] = ACTIONS(2744),
    [sym_kFinalization] = ACTIONS(2744),
    [sym_kEnd] = ACTIONS(2744),
    [sym_kVar] = ACTIONS(2746),
    [sym_kThreadvar] = ACTIONS(2744),
    [sym_kConst] = ACTIONS(2746),
    [sym_kResourcestring] = ACTIONS(2744),
    [sym_kType] = ACTIONS(2744),
    [sym_kLabel] = ACTIONS(2744),
    [sym_kExports] = ACTIONS(2744),
    [sym_kProperty] = ACTIONS(2744),
    [sym_kDefault] = ACTIONS(2744),
    [sym_kNodefault] = ACTIONS(2744),
    [sym_kDispId] = ACTIONS(2744),
    [sym_kClass] = ACTIONS(2744),
    [sym_kGeneric] = ACTIONS(2744),
    [sym_kFunction] = ACTIONS(2744),
    [sym_kProcedure] = ACTIONS(2744),
    [sym_kConstructor] = ACTIONS(2744),
    [sym_kDestructor] = ACTIONS(2744),
    [sym_kOperator] = ACTIONS(2744),
    [sym_kPublic] = ACTIONS(2744),
    [sym_kForward] = ACTIONS(2744),
    [sym_kStatic] = ACTIONS(2744),
    [sym_kVirtual] = ACTIONS(2744),
    [sym_kAbstract] = ACTIONS(2744),
    [sym_kDynamic] = ACTIONS(2744),
    [sym_kOverride] = ACTIONS(2744),
    [sym_kOverload] = ACTIONS(2744),
    [sym_kReintroduce] = ACTIONS(2744),
    [sym_kInline] = ACTIONS(2744),
    [sym_kStdcall] = ACTIONS(2744),
    [sym_kCdecl] = ACTIONS(2744),
    [sym_kCppdecl] = ACTIONS(2744),
    [sym_kPascal] = ACTIONS(2744),
    [sym_kRegister] = ACTIONS(2744),
    [sym_kMwpascal] = ACTIONS(2744),
    [sym_kExternal] = ACTIONS(2744),
    [sym_kMessage] = ACTIONS(2744),
    [sym_kDeprecated] = ACTIONS(2744),
    [sym_kExperimental] = ACTIONS(2744),
    [sym_kPlatform] = ACTIONS(2744),
    [sym_kUnimplemented] = ACTIONS(2744),
    [sym_kCvar] = ACTIONS(2744),
    [sym_kExport] = ACTIONS(2746),
    [sym_kFar] = ACTIONS(2744),
    [sym_kNear] = ACTIONS(2744),
    [sym_kSafecall] = ACTIONS(2744),
    [sym_kAssembler] = ACTIONS(2744),
    [sym_kNostackframe] = ACTIONS(2744),
    [sym_kInterrupt] = ACTIONS(2744),
    [sym_kNoreturn] = ACTIONS(2744),
    [sym_kIocheck] = ACTIONS(2744),
    [sym_kLocal] = ACTIONS(2744),
    [sym_kHardfloat] = ACTIONS(2744),
    [sym_kSoftfloat] = ACTIONS(2744),
    [sym_kMs_abi_default] = ACTIONS(2744),
    [sym_kMs_abi_cdecl] = ACTIONS(2744),
    [sym_kSaveregisters] = ACTIONS(2744),
    [sym_kSysv_abi_default] = ACTIONS(2744),
    [sym_kSysv_abi_cdecl] = ACTIONS(2744),
    [sym_kVectorcall] = ACTIONS(2744),
    [sym_kVarargs] = ACTIONS(2744),
    [sym_kWinapi] = ACTIONS(2744),
    [sym_kAlias] = ACTIONS(2744),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [442] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2748),
    [aux_sym_type_token1] = ACTIONS(1248),
    [sym_kUses] = ACTIONS(1248),
    [sym_kBegin] = ACTIONS(1248),
    [sym_kAsm] = ACTIONS(1248),
    [sym_kVar] = ACTIONS(1250),
    [sym_kThreadvar] = ACTIONS(1248),
    [sym_kConst] = ACTIONS(1250),
    [sym_kResourcestring] = ACTIONS(1248),
    [sym_kType] = ACTIONS(1248),
    [sym_kLabel] = ACTIONS(1248),
    [sym_kExports] = ACTIONS(1248),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1248),
    [sym_kGeneric] = ACTIONS(1248),
    [sym_kFunction] = ACTIONS(1248),
    [sym_kProcedure] = ACTIONS(1248),
    [sym_kConstructor] = ACTIONS(1248),
    [sym_kDestructor] = ACTIONS(1248),
    [sym_kOperator] = ACTIONS(1248),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1248),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1248),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [443] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2751),
    [aux_sym_type_token1] = ACTIONS(1108),
    [sym_kUses] = ACTIONS(1108),
    [sym_kBegin] = ACTIONS(1108),
    [sym_kAsm] = ACTIONS(1108),
    [sym_kVar] = ACTIONS(1110),
    [sym_kThreadvar] = ACTIONS(1108),
    [sym_kConst] = ACTIONS(1110),
    [sym_kResourcestring] = ACTIONS(1108),
    [sym_kType] = ACTIONS(1108),
    [sym_kLabel] = ACTIONS(1108),
    [sym_kExports] = ACTIONS(1108),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1108),
    [sym_kGeneric] = ACTIONS(1108),
    [sym_kFunction] = ACTIONS(1108),
    [sym_kProcedure] = ACTIONS(1108),
    [sym_kConstructor] = ACTIONS(1108),
    [sym_kDestructor] = ACTIONS(1108),
    [sym_kOperator] = ACTIONS(1108),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1108),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1108),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [444] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(445),
    [anon_sym_LBRACK] = ACTIONS(2754),
    [aux_sym_type_token1] = ACTIONS(1255),
    [sym_kUses] = ACTIONS(1255),
    [sym_kBegin] = ACTIONS(1255),
    [sym_kAsm] = ACTIONS(1255),
    [sym_kVar] = ACTIONS(1257),
    [sym_kThreadvar] = ACTIONS(1255),
    [sym_kConst] = ACTIONS(1257),
    [sym_kResourcestring] = ACTIONS(1255),
    [sym_kType] = ACTIONS(1255),
    [sym_kLabel] = ACTIONS(1255),
    [sym_kExports] = ACTIONS(1255),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1255),
    [sym_kGeneric] = ACTIONS(1255),
    [sym_kFunction] = ACTIONS(1255),
    [sym_kProcedure] = ACTIONS(1255),
    [sym_kConstructor] = ACTIONS(1255),
    [sym_kDestructor] = ACTIONS(1255),
    [sym_kOperator] = ACTIONS(1255),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1255),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1255),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [445] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2757),
    [aux_sym_type_token1] = ACTIONS(1354),
    [sym_kUses] = ACTIONS(1354),
    [sym_kBegin] = ACTIONS(1354),
    [sym_kAsm] = ACTIONS(1354),
    [sym_kVar] = ACTIONS(1356),
    [sym_kThreadvar] = ACTIONS(1354),
    [sym_kConst] = ACTIONS(1356),
    [sym_kResourcestring] = ACTIONS(1354),
    [sym_kType] = ACTIONS(1354),
    [sym_kLabel] = ACTIONS(1354),
    [sym_kExports] = ACTIONS(1354),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1354),
    [sym_kGeneric] = ACTIONS(1354),
    [sym_kFunction] = ACTIONS(1354),
    [sym_kProcedure] = ACTIONS(1354),
    [sym_kConstructor] = ACTIONS(1354),
    [sym_kDestructor] = ACTIONS(1354),
    [sym_kOperator] = ACTIONS(1354),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1354),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1354),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [446] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(438),
    [anon_sym_LBRACK] = ACTIONS(2760),
    [aux_sym_type_token1] = ACTIONS(1424),
    [sym_kUses] = ACTIONS(1424),
    [sym_kBegin] = ACTIONS(1424),
    [sym_kAsm] = ACTIONS(1424),
    [sym_kVar] = ACTIONS(1426),
    [sym_kThreadvar] = ACTIONS(1424),
    [sym_kConst] = ACTIONS(1426),
    [sym_kResourcestring] = ACTIONS(1424),
    [sym_kType] = ACTIONS(1424),
    [sym_kLabel] = ACTIONS(1424),
    [sym_kExports] = ACTIONS(1424),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1424),
    [sym_kGeneric] = ACTIONS(1424),
    [sym_kFunction] = ACTIONS(1424),
    [sym_kProcedure] = ACTIONS(1424),
    [sym_kConstructor] = ACTIONS(1424),
    [sym_kDestructor] = ACTIONS(1424),
    [sym_kOperator] = ACTIONS(1424),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1424),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1424),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [447] = {
    [sym_identifier] = ACTIONS(757),
    [anon_sym_LBRACK] = ACTIONS(755),
    [sym_kEnd] = ACTIONS(757),
    [sym_kVar] = ACTIONS(757),
    [sym_kThreadvar] = ACTIONS(757),
    [sym_kConst] = ACTIONS(757),
    [sym_kResourcestring] = ACTIONS(757),
    [sym_kType] = ACTIONS(757),
    [sym_kProperty] = ACTIONS(757),
    [sym_kDefault] = ACTIONS(757),
    [sym_kNodefault] = ACTIONS(757),
    [sym_kDispId] = ACTIONS(757),
    [sym_kClass] = ACTIONS(757),
    [sym_kGeneric] = ACTIONS(757),
    [sym_kCase] = ACTIONS(757),
    [sym_kFunction] = ACTIONS(757),
    [sym_kProcedure] = ACTIONS(757),
    [sym_kConstructor] = ACTIONS(757),
    [sym_kDestructor] = ACTIONS(757),
    [sym_kOperator] = ACTIONS(757),
    [sym_kPublished] = ACTIONS(757),
    [sym_kPublic] = ACTIONS(757),
    [sym_kProtected] = ACTIONS(757),
    [sym_kPrivate] = ACTIONS(757),
    [sym_kStrict] = ACTIONS(757),
    [sym_kRequired] = ACTIONS(757),
    [sym_kOptional] = ACTIONS(757),
    [sym_kStatic] = ACTIONS(757),
    [sym_kVirtual] = ACTIONS(757),
    [sym_kAbstract] = ACTIONS(757),
    [sym_kDynamic] = ACTIONS(757),
    [sym_kOverride] = ACTIONS(757),
    [sym_kOverload] = ACTIONS(757),
    [sym_kReintroduce] = ACTIONS(757),
    [sym_kInline] = ACTIONS(757),
    [sym_kStdcall] = ACTIONS(757),
    [sym_kCdecl] = ACTIONS(757),
    [sym_kCppdecl] = ACTIONS(757),
    [sym_kPascal] = ACTIONS(757),
    [sym_kRegister] = ACTIONS(757),
    [sym_kMwpascal] = ACTIONS(757),
    [sym_kExternal] = ACTIONS(757),
    [sym_kMessage] = ACTIONS(757),
    [sym_kDeprecated] = ACTIONS(757),
    [sym_kExperimental] = ACTIONS(757),
    [sym_kPlatform] = ACTIONS(757),
    [sym_kUnimplemented] = ACTIONS(757),
    [sym_kCvar] = ACTIONS(757),
    [sym_kExport] = ACTIONS(757),
    [sym_kFar] = ACTIONS(757),
    [sym_kNear] = ACTIONS(757),
    [sym_kSafecall] = ACTIONS(757),
    [sym_kAssembler] = ACTIONS(757),
    [sym_kNostackframe] = ACTIONS(757),
    [sym_kInterrupt] = ACTIONS(757),
    [sym_kNoreturn] = ACTIONS(757),
    [sym_kIocheck] = ACTIONS(757),
    [sym_kLocal] = ACTIONS(757),
    [sym_kHardfloat] = ACTIONS(757),
    [sym_kSoftfloat] = ACTIONS(757),
    [sym_kMs_abi_default] = ACTIONS(757),
    [sym_kMs_abi_cdecl] = ACTIONS(757),
    [sym_kSaveregisters] = ACTIONS(757),
    [sym_kSysv_abi_default] = ACTIONS(757),
    [sym_kSysv_abi_cdecl] = ACTIONS(757),
    [sym_kVectorcall] = ACTIONS(757),
    [sym_kVarargs] = ACTIONS(757),
    [sym_kWinapi] = ACTIONS(757),
    [sym_kAlias] = ACTIONS(757),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [448] = {
    [sym_identifier] = ACTIONS(1441),
    [anon_sym_LBRACK] = ACTIONS(1439),
    [sym_kEnd] = ACTIONS(1441),
    [sym_kVar] = ACTIONS(1441),
    [sym_kThreadvar] = ACTIONS(1441),
    [sym_kConst] = ACTIONS(1441),
    [sym_kResourcestring] = ACTIONS(1441),
    [sym_kType] = ACTIONS(1441),
    [sym_kProperty] = ACTIONS(1441),
    [sym_kDefault] = ACTIONS(1441),
    [sym_kNodefault] = ACTIONS(1441),
    [sym_kDispId] = ACTIONS(1441),
    [sym_kClass] = ACTIONS(1441),
    [sym_kGeneric] = ACTIONS(1441),
    [sym_kCase] = ACTIONS(1441),
    [sym_kFunction] = ACTIONS(1441),
    [sym_kProcedure] = ACTIONS(1441),
    [sym_kConstructor] = ACTIONS(1441),
    [sym_kDestructor] = ACTIONS(1441),
    [sym_kOperator] = ACTIONS(1441),
    [sym_kPublished] = ACTIONS(1441),
    [sym_kPublic] = ACTIONS(1441),
    [sym_kProtected] = ACTIONS(1441),
    [sym_kPrivate] = ACTIONS(1441),
    [sym_kStrict] = ACTIONS(1441),
    [sym_kRequired] = ACTIONS(1441),
    [sym_kOptional] = ACTIONS(1441),
    [sym_kStatic] = ACTIONS(1441),
    [sym_kVirtual] = ACTIONS(1441),
    [sym_kAbstract] = ACTIONS(1441),
    [sym_kDynamic] = ACTIONS(1441),
    [sym_kOverride] = ACTIONS(1441),
    [sym_kOverload] = ACTIONS(1441),
    [sym_kReintroduce] = ACTIONS(1441),
    [sym_kInline] = ACTIONS(1441),
    [sym_kStdcall] = ACTIONS(1441),
    [sym_kCdecl] = ACTIONS(1441),
    [sym_kCppdecl] = ACTIONS(1441),
    [sym_kPascal] = ACTIONS(1441),
    [sym_kRegister] = ACTIONS(1441),
    [sym_kMwpascal] = ACTIONS(1441),
    [sym_kExternal] = ACTIONS(1441),
    [sym_kMessage] = ACTIONS(1441),
    [sym_kDeprecated] = ACTIONS(1441),
    [sym_kExperimental] = ACTIONS(1441),
    [sym_kPlatform] = ACTIONS(1441),
    [sym_kUnimplemented] = ACTIONS(1441),
    [sym_kCvar] = ACTIONS(1441),
    [sym_kExport] = ACTIONS(1441),
    [sym_kFar] = ACTIONS(1441),
    [sym_kNear] = ACTIONS(1441),
    [sym_kSafecall] = ACTIONS(1441),
    [sym_kAssembler] = ACTIONS(1441),
    [sym_kNostackframe] = ACTIONS(1441),
    [sym_kInterrupt] = ACTIONS(1441),
    [sym_kNoreturn] = ACTIONS(1441),
    [sym_kIocheck] = ACTIONS(1441),
    [sym_kLocal] = ACTIONS(1441),
    [sym_kHardfloat] = ACTIONS(1441),
    [sym_kSoftfloat] = ACTIONS(1441),
    [sym_kMs_abi_default] = ACTIONS(1441),
    [sym_kMs_abi_cdecl] = ACTIONS(1441),
    [sym_kSaveregisters] = ACTIONS(1441),
    [sym_kSysv_abi_default] = ACTIONS(1441),
    [sym_kSysv_abi_cdecl] = ACTIONS(1441),
    [sym_kVectorcall] = ACTIONS(1441),
    [sym_kVarargs] = ACTIONS(1441),
    [sym_kWinapi] = ACTIONS(1441),
    [sym_kAlias] = ACTIONS(1441),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [449] = {
    [sym_identifier] = ACTIONS(1279),
    [anon_sym_LBRACK] = ACTIONS(1277),
    [sym_kEnd] = ACTIONS(1279),
    [sym_kVar] = ACTIONS(1279),
    [sym_kThreadvar] = ACTIONS(1279),
    [sym_kConst] = ACTIONS(1279),
    [sym_kResourcestring] = ACTIONS(1279),
    [sym_kType] = ACTIONS(1279),
    [sym_kProperty] = ACTIONS(1279),
    [sym_kDefault] = ACTIONS(1279),
    [sym_kNodefault] = ACTIONS(1279),
    [sym_kDispId] = ACTIONS(1279),
    [sym_kClass] = ACTIONS(1279),
    [sym_kGeneric] = ACTIONS(1279),
    [sym_kCase] = ACTIONS(1279),
    [sym_kFunction] = ACTIONS(1279),
    [sym_kProcedure] = ACTIONS(1279),
    [sym_kConstructor] = ACTIONS(1279),
    [sym_kDestructor] = ACTIONS(1279),
    [sym_kOperator] = ACTIONS(1279),
    [sym_kPublished] = ACTIONS(1279),
    [sym_kPublic] = ACTIONS(1279),
    [sym_kProtected] = ACTIONS(1279),
    [sym_kPrivate] = ACTIONS(1279),
    [sym_kStrict] = ACTIONS(1279),
    [sym_kRequired] = ACTIONS(1279),
    [sym_kOptional] = ACTIONS(1279),
    [sym_kStatic] = ACTIONS(1279),
    [sym_kVirtual] = ACTIONS(1279),
    [sym_kAbstract] = ACTIONS(1279),
    [sym_kDynamic] = ACTIONS(1279),
    [sym_kOverride] = ACTIONS(1279),
    [sym_kOverload] = ACTIONS(1279),
    [sym_kReintroduce] = ACTIONS(1279),
    [sym_kInline] = ACTIONS(1279),
    [sym_kStdcall] = ACTIONS(1279),
    [sym_kCdecl] = ACTIONS(1279),
    [sym_kCppdecl] = ACTIONS(1279),
    [sym_kPascal] = ACTIONS(1279),
    [sym_kRegister] = ACTIONS(1279),
    [sym_kMwpascal] = ACTIONS(1279),
    [sym_kExternal] = ACTIONS(1279),
    [sym_kMessage] = ACTIONS(1279),
    [sym_kDeprecated] = ACTIONS(1279),
    [sym_kExperimental] = ACTIONS(1279),
    [sym_kPlatform] = ACTIONS(1279),
    [sym_kUnimplemented] = ACTIONS(1279),
    [sym_kCvar] = ACTIONS(1279),
    [sym_kExport] = ACTIONS(1279),
    [sym_kFar] = ACTIONS(1279),
    [sym_kNear] = ACTIONS(1279),
    [sym_kSafecall] = ACTIONS(1279),
    [sym_kAssembler] = ACTIONS(1279),
    [sym_kNostackframe] = ACTIONS(1279),
    [sym_kInterrupt] = ACTIONS(1279),
    [sym_kNoreturn] = ACTIONS(1279),
    [sym_kIocheck] = ACTIONS(1279),
    [sym_kLocal] = ACTIONS(1279),
    [sym_kHardfloat] = ACTIONS(1279),
    [sym_kSoftfloat] = ACTIONS(1279),
    [sym_kMs_abi_default] = ACTIONS(1279),
    [sym_kMs_abi_cdecl] = ACTIONS(1279),
    [sym_kSaveregisters] = ACTIONS(1279),
    [sym_kSysv_abi_default] = ACTIONS(1279),
    [sym_kSysv_abi_cdecl] = ACTIONS(1279),
    [sym_kVectorcall] = ACTIONS(1279),
    [sym_kVarargs] = ACTIONS(1279),
    [sym_kWinapi] = ACTIONS(1279),
    [sym_kAlias] = ACTIONS(1279),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [450] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [aux_sym_type_token1] = ACTIONS(1375),
    [sym_kUses] = ACTIONS(1375),
    [sym_kBegin] = ACTIONS(1375),
    [sym_kAsm] = ACTIONS(1375),
    [sym_kVar] = ACTIONS(1377),
    [sym_kThreadvar] = ACTIONS(1375),
    [sym_kConst] = ACTIONS(1377),
    [sym_kResourcestring] = ACTIONS(1375),
    [sym_kType] = ACTIONS(1375),
    [sym_kLabel] = ACTIONS(1375),
    [sym_kExports] = ACTIONS(1375),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1375),
    [sym_kGeneric] = ACTIONS(1375),
    [sym_kFunction] = ACTIONS(1375),
    [sym_kProcedure] = ACTIONS(1375),
    [sym_kConstructor] = ACTIONS(1375),
    [sym_kDestructor] = ACTIONS(1375),
    [sym_kOperator] = ACTIONS(1375),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1375),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1375),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [451] = {
    [sym_identifier] = ACTIONS(803),
    [anon_sym_LBRACK] = ACTIONS(801),
    [sym_kEnd] = ACTIONS(803),
    [sym_kVar] = ACTIONS(803),
    [sym_kThreadvar] = ACTIONS(803),
    [sym_kConst] = ACTIONS(803),
    [sym_kResourcestring] = ACTIONS(803),
    [sym_kType] = ACTIONS(803),
    [sym_kProperty] = ACTIONS(803),
    [sym_kDefault] = ACTIONS(803),
    [sym_kNodefault] = ACTIONS(803),
    [sym_kDispId] = ACTIONS(803),
    [sym_kClass] = ACTIONS(803),
    [sym_kGeneric] = ACTIONS(803),
    [sym_kCase] = ACTIONS(803),
    [sym_kFunction] = ACTIONS(803),
    [sym_kProcedure] = ACTIONS(803),
    [sym_kConstructor] = ACTIONS(803),
    [sym_kDestructor] = ACTIONS(803),
    [sym_kOperator] = ACTIONS(803),
    [sym_kPublished] = ACTIONS(803),
    [sym_kPublic] = ACTIONS(803),
    [sym_kProtected] = ACTIONS(803),
    [sym_kPrivate] = ACTIONS(803),
    [sym_kStrict] = ACTIONS(803),
    [sym_kRequired] = ACTIONS(803),
    [sym_kOptional] = ACTIONS(803),
    [sym_kStatic] = ACTIONS(803),
    [sym_kVirtual] = ACTIONS(803),
    [sym_kAbstract] = ACTIONS(803),
    [sym_kDynamic] = ACTIONS(803),
    [sym_kOverride] = ACTIONS(803),
    [sym_kOverload] = ACTIONS(803),
    [sym_kReintroduce] = ACTIONS(803),
    [sym_kInline] = ACTIONS(803),
    [sym_kStdcall] = ACTIONS(803),
    [sym_kCdecl] = ACTIONS(803),
    [sym_kCppdecl] = ACTIONS(803),
    [sym_kPascal] = ACTIONS(803),
    [sym_kRegister] = ACTIONS(803),
    [sym_kMwpascal] = ACTIONS(803),
    [sym_kExternal] = ACTIONS(803),
    [sym_kMessage] = ACTIONS(803),
    [sym_kDeprecated] = ACTIONS(803),
    [sym_kExperimental] = ACTIONS(803),
    [sym_kPlatform] = ACTIONS(803),
    [sym_kUnimplemented] = ACTIONS(803),
    [sym_kCvar] = ACTIONS(803),
    [sym_kExport] = ACTIONS(803),
    [sym_kFar] = ACTIONS(803),
    [sym_kNear] = ACTIONS(803),
    [sym_kSafecall] = ACTIONS(803),
    [sym_kAssembler] = ACTIONS(803),
    [sym_kNostackframe] = ACTIONS(803),
    [sym_kInterrupt] = ACTIONS(803),
    [sym_kNoreturn] = ACTIONS(803),
    [sym_kIocheck] = ACTIONS(803),
    [sym_kLocal] = ACTIONS(803),
    [sym_kHardfloat] = ACTIONS(803),
    [sym_kSoftfloat] = ACTIONS(803),
    [sym_kMs_abi_default] = ACTIONS(803),
    [sym_kMs_abi_cdecl] = ACTIONS(803),
    [sym_kSaveregisters] = ACTIONS(803),
    [sym_kSysv_abi_default] = ACTIONS(803),
    [sym_kSysv_abi_cdecl] = ACTIONS(803),
    [sym_kVectorcall] = ACTIONS(803),
    [sym_kVarargs] = ACTIONS(803),
    [sym_kWinapi] = ACTIONS(803),
    [sym_kAlias] = ACTIONS(803),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [452] = {
    [sym_identifier] = ACTIONS(1481),
    [anon_sym_LBRACK] = ACTIONS(1479),
    [sym_kEnd] = ACTIONS(1481),
    [sym_kVar] = ACTIONS(1481),
    [sym_kThreadvar] = ACTIONS(1481),
    [sym_kConst] = ACTIONS(1481),
    [sym_kResourcestring] = ACTIONS(1481),
    [sym_kType] = ACTIONS(1481),
    [sym_kProperty] = ACTIONS(1481),
    [sym_kDefault] = ACTIONS(1481),
    [sym_kNodefault] = ACTIONS(1481),
    [sym_kDispId] = ACTIONS(1481),
    [sym_kClass] = ACTIONS(1481),
    [sym_kGeneric] = ACTIONS(1481),
    [sym_kCase] = ACTIONS(1481),
    [sym_kFunction] = ACTIONS(1481),
    [sym_kProcedure] = ACTIONS(1481),
    [sym_kConstructor] = ACTIONS(1481),
    [sym_kDestructor] = ACTIONS(1481),
    [sym_kOperator] = ACTIONS(1481),
    [sym_kPublished] = ACTIONS(1481),
    [sym_kPublic] = ACTIONS(1481),
    [sym_kProtected] = ACTIONS(1481),
    [sym_kPrivate] = ACTIONS(1481),
    [sym_kStrict] = ACTIONS(1481),
    [sym_kRequired] = ACTIONS(1481),
    [sym_kOptional] = ACTIONS(1481),
    [sym_kStatic] = ACTIONS(1481),
    [sym_kVirtual] = ACTIONS(1481),
    [sym_kAbstract] = ACTIONS(1481),
    [sym_kDynamic] = ACTIONS(1481),
    [sym_kOverride] = ACTIONS(1481),
    [sym_kOverload] = ACTIONS(1481),
    [sym_kReintroduce] = ACTIONS(1481),
    [sym_kInline] = ACTIONS(1481),
    [sym_kStdcall] = ACTIONS(1481),
    [sym_kCdecl] = ACTIONS(1481),
    [sym_kCppdecl] = ACTIONS(1481),
    [sym_kPascal] = ACTIONS(1481),
    [sym_kRegister] = ACTIONS(1481),
    [sym_kMwpascal] = ACTIONS(1481),
    [sym_kExternal] = ACTIONS(1481),
    [sym_kMessage] = ACTIONS(1481),
    [sym_kDeprecated] = ACTIONS(1481),
    [sym_kExperimental] = ACTIONS(1481),
    [sym_kPlatform] = ACTIONS(1481),
    [sym_kUnimplemented] = ACTIONS(1481),
    [sym_kCvar] = ACTIONS(1481),
    [sym_kExport] = ACTIONS(1481),
    [sym_kFar] = ACTIONS(1481),
    [sym_kNear] = ACTIONS(1481),
    [sym_kSafecall] = ACTIONS(1481),
    [sym_kAssembler] = ACTIONS(1481),
    [sym_kNostackframe] = ACTIONS(1481),
    [sym_kInterrupt] = ACTIONS(1481),
    [sym_kNoreturn] = ACTIONS(1481),
    [sym_kIocheck] = ACTIONS(1481),
    [sym_kLocal] = ACTIONS(1481),
    [sym_kHardfloat] = ACTIONS(1481),
    [sym_kSoftfloat] = ACTIONS(1481),
    [sym_kMs_abi_default] = ACTIONS(1481),
    [sym_kMs_abi_cdecl] = ACTIONS(1481),
    [sym_kSaveregisters] = ACTIONS(1481),
    [sym_kSysv_abi_default] = ACTIONS(1481),
    [sym_kSysv_abi_cdecl] = ACTIONS(1481),
    [sym_kVectorcall] = ACTIONS(1481),
    [sym_kVarargs] = ACTIONS(1481),
    [sym_kWinapi] = ACTIONS(1481),
    [sym_kAlias] = ACTIONS(1481),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [453] = {
    [sym_identifier] = ACTIONS(1481),
    [anon_sym_LBRACK] = ACTIONS(1479),
    [sym_kEnd] = ACTIONS(1481),
    [sym_kVar] = ACTIONS(1481),
    [sym_kThreadvar] = ACTIONS(1481),
    [sym_kConst] = ACTIONS(1481),
    [sym_kResourcestring] = ACTIONS(1481),
    [sym_kType] = ACTIONS(1481),
    [sym_kProperty] = ACTIONS(1481),
    [sym_kDefault] = ACTIONS(1481),
    [sym_kNodefault] = ACTIONS(1481),
    [sym_kDispId] = ACTIONS(1481),
    [sym_kClass] = ACTIONS(1481),
    [sym_kGeneric] = ACTIONS(1481),
    [sym_kCase] = ACTIONS(1481),
    [sym_kFunction] = ACTIONS(1481),
    [sym_kProcedure] = ACTIONS(1481),
    [sym_kConstructor] = ACTIONS(1481),
    [sym_kDestructor] = ACTIONS(1481),
    [sym_kOperator] = ACTIONS(1481),
    [sym_kPublished] = ACTIONS(1481),
    [sym_kPublic] = ACTIONS(1481),
    [sym_kProtected] = ACTIONS(1481),
    [sym_kPrivate] = ACTIONS(1481),
    [sym_kStrict] = ACTIONS(1481),
    [sym_kRequired] = ACTIONS(1481),
    [sym_kOptional] = ACTIONS(1481),
    [sym_kStatic] = ACTIONS(1481),
    [sym_kVirtual] = ACTIONS(1481),
    [sym_kAbstract] = ACTIONS(1481),
    [sym_kDynamic] = ACTIONS(1481),
    [sym_kOverride] = ACTIONS(1481),
    [sym_kOverload] = ACTIONS(1481),
    [sym_kReintroduce] = ACTIONS(1481),
    [sym_kInline] = ACTIONS(1481),
    [sym_kStdcall] = ACTIONS(1481),
    [sym_kCdecl] = ACTIONS(1481),
    [sym_kCppdecl] = ACTIONS(1481),
    [sym_kPascal] = ACTIONS(1481),
    [sym_kRegister] = ACTIONS(1481),
    [sym_kMwpascal] = ACTIONS(1481),
    [sym_kExternal] = ACTIONS(1481),
    [sym_kMessage] = ACTIONS(1481),
    [sym_kDeprecated] = ACTIONS(1481),
    [sym_kExperimental] = ACTIONS(1481),
    [sym_kPlatform] = ACTIONS(1481),
    [sym_kUnimplemented] = ACTIONS(1481),
    [sym_kCvar] = ACTIONS(1481),
    [sym_kExport] = ACTIONS(1481),
    [sym_kFar] = ACTIONS(1481),
    [sym_kNear] = ACTIONS(1481),
    [sym_kSafecall] = ACTIONS(1481),
    [sym_kAssembler] = ACTIONS(1481),
    [sym_kNostackframe] = ACTIONS(1481),
    [sym_kInterrupt] = ACTIONS(1481),
    [sym_kNoreturn] = ACTIONS(1481),
    [sym_kIocheck] = ACTIONS(1481),
    [sym_kLocal] = ACTIONS(1481),
    [sym_kHardfloat] = ACTIONS(1481),
    [sym_kSoftfloat] = ACTIONS(1481),
    [sym_kMs_abi_default] = ACTIONS(1481),
    [sym_kMs_abi_cdecl] = ACTIONS(1481),
    [sym_kSaveregisters] = ACTIONS(1481),
    [sym_kSysv_abi_default] = ACTIONS(1481),
    [sym_kSysv_abi_cdecl] = ACTIONS(1481),
    [sym_kVectorcall] = ACTIONS(1481),
    [sym_kVarargs] = ACTIONS(1481),
    [sym_kWinapi] = ACTIONS(1481),
    [sym_kAlias] = ACTIONS(1481),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [454] = {
    [sym_identifier] = ACTIONS(726),
    [anon_sym_LBRACK] = ACTIONS(724),
    [sym_kEnd] = ACTIONS(726),
    [sym_kVar] = ACTIONS(726),
    [sym_kThreadvar] = ACTIONS(726),
    [sym_kConst] = ACTIONS(726),
    [sym_kResourcestring] = ACTIONS(726),
    [sym_kType] = ACTIONS(726),
    [sym_kProperty] = ACTIONS(726),
    [sym_kDefault] = ACTIONS(726),
    [sym_kNodefault] = ACTIONS(726),
    [sym_kDispId] = ACTIONS(726),
    [sym_kClass] = ACTIONS(726),
    [sym_kGeneric] = ACTIONS(726),
    [sym_kCase] = ACTIONS(726),
    [sym_kFunction] = ACTIONS(726),
    [sym_kProcedure] = ACTIONS(726),
    [sym_kConstructor] = ACTIONS(726),
    [sym_kDestructor] = ACTIONS(726),
    [sym_kOperator] = ACTIONS(726),
    [sym_kPublished] = ACTIONS(726),
    [sym_kPublic] = ACTIONS(726),
    [sym_kProtected] = ACTIONS(726),
    [sym_kPrivate] = ACTIONS(726),
    [sym_kStrict] = ACTIONS(726),
    [sym_kRequired] = ACTIONS(726),
    [sym_kOptional] = ACTIONS(726),
    [sym_kStatic] = ACTIONS(726),
    [sym_kVirtual] = ACTIONS(726),
    [sym_kAbstract] = ACTIONS(726),
    [sym_kDynamic] = ACTIONS(726),
    [sym_kOverride] = ACTIONS(726),
    [sym_kOverload] = ACTIONS(726),
    [sym_kReintroduce] = ACTIONS(726),
    [sym_kInline] = ACTIONS(726),
    [sym_kStdcall] = ACTIONS(726),
    [sym_kCdecl] = ACTIONS(726),
    [sym_kCppdecl] = ACTIONS(726),
    [sym_kPascal] = ACTIONS(726),
    [sym_kRegister] = ACTIONS(726),
    [sym_kMwpascal] = ACTIONS(726),
    [sym_kExternal] = ACTIONS(726),
    [sym_kMessage] = ACTIONS(726),
    [sym_kDeprecated] = ACTIONS(726),
    [sym_kExperimental] = ACTIONS(726),
    [sym_kPlatform] = ACTIONS(726),
    [sym_kUnimplemented] = ACTIONS(726),
    [sym_kCvar] = ACTIONS(726),
    [sym_kExport] = ACTIONS(726),
    [sym_kFar] = ACTIONS(726),
    [sym_kNear] = ACTIONS(726),
    [sym_kSafecall] = ACTIONS(726),
    [sym_kAssembler] = ACTIONS(726),
    [sym_kNostackframe] = ACTIONS(726),
    [sym_kInterrupt] = ACTIONS(726),
    [sym_kNoreturn] = ACTIONS(726),
    [sym_kIocheck] = ACTIONS(726),
    [sym_kLocal] = ACTIONS(726),
    [sym_kHardfloat] = ACTIONS(726),
    [sym_kSoftfloat] = ACTIONS(726),
    [sym_kMs_abi_default] = ACTIONS(726),
    [sym_kMs_abi_cdecl] = ACTIONS(726),
    [sym_kSaveregisters] = ACTIONS(726),
    [sym_kSysv_abi_default] = ACTIONS(726),
    [sym_kSysv_abi_cdecl] = ACTIONS(726),
    [sym_kVectorcall] = ACTIONS(726),
    [sym_kVarargs] = ACTIONS(726),
    [sym_kWinapi] = ACTIONS(726),
    [sym_kAlias] = ACTIONS(726),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [455] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(425),
    [anon_sym_LBRACK] = ACTIONS(2766),
    [aux_sym_type_token1] = ACTIONS(1382),
    [sym_kUses] = ACTIONS(1382),
    [sym_kBegin] = ACTIONS(1382),
    [sym_kAsm] = ACTIONS(1382),
    [sym_kVar] = ACTIONS(1384),
    [sym_kThreadvar] = ACTIONS(1382),
    [sym_kConst] = ACTIONS(1384),
    [sym_kResourcestring] = ACTIONS(1382),
    [sym_kType] = ACTIONS(1382),
    [sym_kLabel] = ACTIONS(1382),
    [sym_kExports] = ACTIONS(1382),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1382),
    [sym_kGeneric] = ACTIONS(1382),
    [sym_kFunction] = ACTIONS(1382),
    [sym_kProcedure] = ACTIONS(1382),
    [sym_kConstructor] = ACTIONS(1382),
    [sym_kDestructor] = ACTIONS(1382),
    [sym_kOperator] = ACTIONS(1382),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1382),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1382),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [456] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(422),
    [anon_sym_LBRACK] = ACTIONS(2769),
    [aux_sym_type_token1] = ACTIONS(1298),
    [sym_kUses] = ACTIONS(1298),
    [sym_kBegin] = ACTIONS(1298),
    [sym_kAsm] = ACTIONS(1298),
    [sym_kVar] = ACTIONS(1300),
    [sym_kThreadvar] = ACTIONS(1298),
    [sym_kConst] = ACTIONS(1300),
    [sym_kResourcestring] = ACTIONS(1298),
    [sym_kType] = ACTIONS(1298),
    [sym_kLabel] = ACTIONS(1298),
    [sym_kExports] = ACTIONS(1298),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1298),
    [sym_kGeneric] = ACTIONS(1298),
    [sym_kFunction] = ACTIONS(1298),
    [sym_kProcedure] = ACTIONS(1298),
    [sym_kConstructor] = ACTIONS(1298),
    [sym_kDestructor] = ACTIONS(1298),
    [sym_kOperator] = ACTIONS(1298),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1298),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1298),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [457] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2772),
    [aux_sym_type_token1] = ACTIONS(1284),
    [sym_kUses] = ACTIONS(1284),
    [sym_kBegin] = ACTIONS(1284),
    [sym_kAsm] = ACTIONS(1284),
    [sym_kVar] = ACTIONS(1286),
    [sym_kThreadvar] = ACTIONS(1284),
    [sym_kConst] = ACTIONS(1286),
    [sym_kResourcestring] = ACTIONS(1284),
    [sym_kType] = ACTIONS(1284),
    [sym_kLabel] = ACTIONS(1284),
    [sym_kExports] = ACTIONS(1284),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1284),
    [sym_kGeneric] = ACTIONS(1284),
    [sym_kFunction] = ACTIONS(1284),
    [sym_kProcedure] = ACTIONS(1284),
    [sym_kConstructor] = ACTIONS(1284),
    [sym_kDestructor] = ACTIONS(1284),
    [sym_kOperator] = ACTIONS(1284),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1284),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1284),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [458] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2775),
    [aux_sym_type_token1] = ACTIONS(1389),
    [sym_kUses] = ACTIONS(1389),
    [sym_kBegin] = ACTIONS(1389),
    [sym_kAsm] = ACTIONS(1389),
    [sym_kVar] = ACTIONS(1391),
    [sym_kThreadvar] = ACTIONS(1389),
    [sym_kConst] = ACTIONS(1391),
    [sym_kResourcestring] = ACTIONS(1389),
    [sym_kType] = ACTIONS(1389),
    [sym_kLabel] = ACTIONS(1389),
    [sym_kExports] = ACTIONS(1389),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1389),
    [sym_kGeneric] = ACTIONS(1389),
    [sym_kFunction] = ACTIONS(1389),
    [sym_kProcedure] = ACTIONS(1389),
    [sym_kConstructor] = ACTIONS(1389),
    [sym_kDestructor] = ACTIONS(1389),
    [sym_kOperator] = ACTIONS(1389),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1389),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1389),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [459] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(475),
    [anon_sym_LBRACK] = ACTIONS(2778),
    [aux_sym_type_token1] = ACTIONS(1291),
    [sym_kUses] = ACTIONS(1291),
    [sym_kBegin] = ACTIONS(1291),
    [sym_kAsm] = ACTIONS(1291),
    [sym_kVar] = ACTIONS(1293),
    [sym_kThreadvar] = ACTIONS(1291),
    [sym_kConst] = ACTIONS(1293),
    [sym_kResourcestring] = ACTIONS(1291),
    [sym_kType] = ACTIONS(1291),
    [sym_kLabel] = ACTIONS(1291),
    [sym_kExports] = ACTIONS(1291),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1291),
    [sym_kGeneric] = ACTIONS(1291),
    [sym_kFunction] = ACTIONS(1291),
    [sym_kProcedure] = ACTIONS(1291),
    [sym_kConstructor] = ACTIONS(1291),
    [sym_kDestructor] = ACTIONS(1291),
    [sym_kOperator] = ACTIONS(1291),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1291),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1291),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [460] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(450),
    [anon_sym_LBRACK] = ACTIONS(2781),
    [aux_sym_type_token1] = ACTIONS(1122),
    [sym_kUses] = ACTIONS(1122),
    [sym_kBegin] = ACTIONS(1122),
    [sym_kAsm] = ACTIONS(1122),
    [sym_kVar] = ACTIONS(1124),
    [sym_kThreadvar] = ACTIONS(1122),
    [sym_kConst] = ACTIONS(1124),
    [sym_kResourcestring] = ACTIONS(1122),
    [sym_kType] = ACTIONS(1122),
    [sym_kLabel] = ACTIONS(1122),
    [sym_kExports] = ACTIONS(1122),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1122),
    [sym_kGeneric] = ACTIONS(1122),
    [sym_kFunction] = ACTIONS(1122),
    [sym_kProcedure] = ACTIONS(1122),
    [sym_kConstructor] = ACTIONS(1122),
    [sym_kDestructor] = ACTIONS(1122),
    [sym_kOperator] = ACTIONS(1122),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1122),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1122),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [461] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(458),
    [anon_sym_LBRACK] = ACTIONS(2784),
    [aux_sym_type_token1] = ACTIONS(1129),
    [sym_kUses] = ACTIONS(1129),
    [sym_kBegin] = ACTIONS(1129),
    [sym_kAsm] = ACTIONS(1129),
    [sym_kVar] = ACTIONS(1131),
    [sym_kThreadvar] = ACTIONS(1129),
    [sym_kConst] = ACTIONS(1131),
    [sym_kResourcestring] = ACTIONS(1129),
    [sym_kType] = ACTIONS(1129),
    [sym_kLabel] = ACTIONS(1129),
    [sym_kExports] = ACTIONS(1129),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1129),
    [sym_kGeneric] = ACTIONS(1129),
    [sym_kFunction] = ACTIONS(1129),
    [sym_kProcedure] = ACTIONS(1129),
    [sym_kConstructor] = ACTIONS(1129),
    [sym_kDestructor] = ACTIONS(1129),
    [sym_kOperator] = ACTIONS(1129),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1129),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1129),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [462] = {
    [anon_sym_LBRACK] = ACTIONS(2787),
    [sym_kUses] = ACTIONS(2787),
    [sym_kInterface] = ACTIONS(2787),
    [sym_kImplementation] = ACTIONS(2787),
    [sym_kInitialization] = ACTIONS(2787),
    [sym_kFinalization] = ACTIONS(2787),
    [sym_kEnd] = ACTIONS(2787),
    [sym_kVar] = ACTIONS(2789),
    [sym_kThreadvar] = ACTIONS(2787),
    [sym_kConst] = ACTIONS(2789),
    [sym_kResourcestring] = ACTIONS(2787),
    [sym_kType] = ACTIONS(2787),
    [sym_kLabel] = ACTIONS(2787),
    [sym_kExports] = ACTIONS(2787),
    [sym_kProperty] = ACTIONS(2787),
    [sym_kDefault] = ACTIONS(2787),
    [sym_kNodefault] = ACTIONS(2787),
    [sym_kDispId] = ACTIONS(2787),
    [sym_kClass] = ACTIONS(2787),
    [sym_kGeneric] = ACTIONS(2787),
    [sym_kFunction] = ACTIONS(2787),
    [sym_kProcedure] = ACTIONS(2787),
    [sym_kConstructor] = ACTIONS(2787),
    [sym_kDestructor] = ACTIONS(2787),
    [sym_kOperator] = ACTIONS(2787),
    [sym_kPublic] = ACTIONS(2787),
    [sym_kForward] = ACTIONS(2787),
    [sym_kStatic] = ACTIONS(2787),
    [sym_kVirtual] = ACTIONS(2787),
    [sym_kAbstract] = ACTIONS(2787),
    [sym_kDynamic] = ACTIONS(2787),
    [sym_kOverride] = ACTIONS(2787),
    [sym_kOverload] = ACTIONS(2787),
    [sym_kReintroduce] = ACTIONS(2787),
    [sym_kInline] = ACTIONS(2787),
    [sym_kStdcall] = ACTIONS(2787),
    [sym_kCdecl] = ACTIONS(2787),
    [sym_kCppdecl] = ACTIONS(2787),
    [sym_kPascal] = ACTIONS(2787),
    [sym_kRegister] = ACTIONS(2787),
    [sym_kMwpascal] = ACTIONS(2787),
    [sym_kExternal] = ACTIONS(2787),
    [sym_kMessage] = ACTIONS(2787),
    [sym_kDeprecated] = ACTIONS(2787),
    [sym_kExperimental] = ACTIONS(2787),
    [sym_kPlatform] = ACTIONS(2787),
    [sym_kUnimplemented] = ACTIONS(2787),
    [sym_kCvar] = ACTIONS(2787),
    [sym_kExport] = ACTIONS(2789),
    [sym_kFar] = ACTIONS(2787),
    [sym_kNear] = ACTIONS(2787),
    [sym_kSafecall] = ACTIONS(2787),
    [sym_kAssembler] = ACTIONS(2787),
    [sym_kNostackframe] = ACTIONS(2787),
    [sym_kInterrupt] = ACTIONS(2787),
    [sym_kNoreturn] = ACTIONS(2787),
    [sym_kIocheck] = ACTIONS(2787),
    [sym_kLocal] = ACTIONS(2787),
    [sym_kHardfloat] = ACTIONS(2787),
    [sym_kSoftfloat] = ACTIONS(2787),
    [sym_kMs_abi_default] = ACTIONS(2787),
    [sym_kMs_abi_cdecl] = ACTIONS(2787),
    [sym_kSaveregisters] = ACTIONS(2787),
    [sym_kSysv_abi_default] = ACTIONS(2787),
    [sym_kSysv_abi_cdecl] = ACTIONS(2787),
    [sym_kVectorcall] = ACTIONS(2787),
    [sym_kVarargs] = ACTIONS(2787),
    [sym_kWinapi] = ACTIONS(2787),
    [sym_kAlias] = ACTIONS(2787),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [463] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2791),
    [aux_sym_type_token1] = ACTIONS(1136),
    [sym_kUses] = ACTIONS(1136),
    [sym_kBegin] = ACTIONS(1136),
    [sym_kAsm] = ACTIONS(1136),
    [sym_kVar] = ACTIONS(1138),
    [sym_kThreadvar] = ACTIONS(1136),
    [sym_kConst] = ACTIONS(1138),
    [sym_kResourcestring] = ACTIONS(1136),
    [sym_kType] = ACTIONS(1136),
    [sym_kLabel] = ACTIONS(1136),
    [sym_kExports] = ACTIONS(1136),
    [sym_kDefault] = ACTIONS(1140),
    [sym_kNodefault] = ACTIONS(1140),
    [sym_kDispId] = ACTIONS(1143),
    [sym_kClass] = ACTIONS(1136),
    [sym_kGeneric] = ACTIONS(1136),
    [sym_kFunction] = ACTIONS(1136),
    [sym_kProcedure] = ACTIONS(1136),
    [sym_kConstructor] = ACTIONS(1136),
    [sym_kDestructor] = ACTIONS(1136),
    [sym_kOperator] = ACTIONS(1136),
    [sym_kPublic] = ACTIONS(1146),
    [sym_kForward] = ACTIONS(1136),
    [sym_kStatic] = ACTIONS(1140),
    [sym_kVirtual] = ACTIONS(1140),
    [sym_kAbstract] = ACTIONS(1140),
    [sym_kDynamic] = ACTIONS(1140),
    [sym_kOverride] = ACTIONS(1140),
    [sym_kOverload] = ACTIONS(1140),
    [sym_kReintroduce] = ACTIONS(1140),
    [sym_kInline] = ACTIONS(1140),
    [sym_kStdcall] = ACTIONS(1140),
    [sym_kCdecl] = ACTIONS(1140),
    [sym_kCppdecl] = ACTIONS(1140),
    [sym_kPascal] = ACTIONS(1140),
    [sym_kRegister] = ACTIONS(1140),
    [sym_kMwpascal] = ACTIONS(1140),
    [sym_kExternal] = ACTIONS(1136),
    [sym_kMessage] = ACTIONS(1149),
    [sym_kDeprecated] = ACTIONS(1152),
    [sym_kExperimental] = ACTIONS(1140),
    [sym_kPlatform] = ACTIONS(1140),
    [sym_kUnimplemented] = ACTIONS(1140),
    [sym_kCvar] = ACTIONS(1140),
    [sym_kExport] = ACTIONS(1155),
    [sym_kFar] = ACTIONS(1140),
    [sym_kNear] = ACTIONS(1140),
    [sym_kSafecall] = ACTIONS(1140),
    [sym_kAssembler] = ACTIONS(1140),
    [sym_kNostackframe] = ACTIONS(1140),
    [sym_kInterrupt] = ACTIONS(1140),
    [sym_kNoreturn] = ACTIONS(1140),
    [sym_kIocheck] = ACTIONS(1140),
    [sym_kLocal] = ACTIONS(1140),
    [sym_kHardfloat] = ACTIONS(1140),
    [sym_kSoftfloat] = ACTIONS(1140),
    [sym_kMs_abi_default] = ACTIONS(1140),
    [sym_kMs_abi_cdecl] = ACTIONS(1140),
    [sym_kSaveregisters] = ACTIONS(1140),
    [sym_kSysv_abi_default] = ACTIONS(1140),
    [sym_kSysv_abi_cdecl] = ACTIONS(1140),
    [sym_kVectorcall] = ACTIONS(1140),
    [sym_kVarargs] = ACTIONS(1140),
    [sym_kWinapi] = ACTIONS(1140),
    [sym_kAlias] = ACTIONS(1158),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [464] = {
    [anon_sym_LBRACK] = ACTIONS(2794),
    [sym_kUses] = ACTIONS(2794),
    [sym_kInterface] = ACTIONS(2794),
    [sym_kImplementation] = ACTIONS(2794),
    [sym_kInitialization] = ACTIONS(2794),
    [sym_kFinalization] = ACTIONS(2794),
    [sym_kEnd] = ACTIONS(2794),
    [sym_kVar] = ACTIONS(2796),
    [sym_kThreadvar] = ACTIONS(2794),
    [sym_kConst] = ACTIONS(2796),
    [sym_kResourcestring] = ACTIONS(2794),
    [sym_kType] = ACTIONS(2794),
    [sym_kLabel] = ACTIONS(2794),
    [sym_kExports] = ACTIONS(2794),
    [sym_kProperty] = ACTIONS(2794),
    [sym_kDefault] = ACTIONS(2794),
    [sym_kNodefault] = ACTIONS(2794),
    [sym_kDispId] = ACTIONS(2794),
    [sym_kClass] = ACTIONS(2794),
    [sym_kGeneric] = ACTIONS(2794),
    [sym_kFunction] = ACTIONS(2794),
    [sym_kProcedure] = ACTIONS(2794),
    [sym_kConstructor] = ACTIONS(2794),
    [sym_kDestructor] = ACTIONS(2794),
    [sym_kOperator] = ACTIONS(2794),
    [sym_kPublic] = ACTIONS(2794),
    [sym_kForward] = ACTIONS(2794),
    [sym_kStatic] = ACTIONS(2794),
    [sym_kVirtual] = ACTIONS(2794),
    [sym_kAbstract] = ACTIONS(2794),
    [sym_kDynamic] = ACTIONS(2794),
    [sym_kOverride] = ACTIONS(2794),
    [sym_kOverload] = ACTIONS(2794),
    [sym_kReintroduce] = ACTIONS(2794),
    [sym_kInline] = ACTIONS(2794),
    [sym_kStdcall] = ACTIONS(2794),
    [sym_kCdecl] = ACTIONS(2794),
    [sym_kCppdecl] = ACTIONS(2794),
    [sym_kPascal] = ACTIONS(2794),
    [sym_kRegister] = ACTIONS(2794),
    [sym_kMwpascal] = ACTIONS(2794),
    [sym_kExternal] = ACTIONS(2794),
    [sym_kMessage] = ACTIONS(2794),
    [sym_kDeprecated] = ACTIONS(2794),
    [sym_kExperimental] = ACTIONS(2794),
    [sym_kPlatform] = ACTIONS(2794),
    [sym_kUnimplemented] = ACTIONS(2794),
    [sym_kCvar] = ACTIONS(2794),
    [sym_kExport] = ACTIONS(2796),
    [sym_kFar] = ACTIONS(2794),
    [sym_kNear] = ACTIONS(2794),
    [sym_kSafecall] = ACTIONS(2794),
    [sym_kAssembler] = ACTIONS(2794),
    [sym_kNostackframe] = ACTIONS(2794),
    [sym_kInterrupt] = ACTIONS(2794),
    [sym_kNoreturn] = ACTIONS(2794),
    [sym_kIocheck] = ACTIONS(2794),
    [sym_kLocal] = ACTIONS(2794),
    [sym_kHardfloat] = ACTIONS(2794),
    [sym_kSoftfloat] = ACTIONS(2794),
    [sym_kMs_abi_default] = ACTIONS(2794),
    [sym_kMs_abi_cdecl] = ACTIONS(2794),
    [sym_kSaveregisters] = ACTIONS(2794),
    [sym_kSysv_abi_default] = ACTIONS(2794),
    [sym_kSysv_abi_cdecl] = ACTIONS(2794),
    [sym_kVectorcall] = ACTIONS(2794),
    [sym_kVarargs] = ACTIONS(2794),
    [sym_kWinapi] = ACTIONS(2794),
    [sym_kAlias] = ACTIONS(2794),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [465] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(428),
    [anon_sym_LBRACK] = ACTIONS(2798),
    [aux_sym_type_token1] = ACTIONS(1164),
    [sym_kUses] = ACTIONS(1164),
    [sym_kBegin] = ACTIONS(1164),
    [sym_kAsm] = ACTIONS(1164),
    [sym_kVar] = ACTIONS(1166),
    [sym_kThreadvar] = ACTIONS(1164),
    [sym_kConst] = ACTIONS(1166),
    [sym_kResourcestring] = ACTIONS(1164),
    [sym_kType] = ACTIONS(1164),
    [sym_kLabel] = ACTIONS(1164),
    [sym_kExports] = ACTIONS(1164),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1164),
    [sym_kGeneric] = ACTIONS(1164),
    [sym_kFunction] = ACTIONS(1164),
    [sym_kProcedure] = ACTIONS(1164),
    [sym_kConstructor] = ACTIONS(1164),
    [sym_kDestructor] = ACTIONS(1164),
    [sym_kOperator] = ACTIONS(1164),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1164),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1164),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [466] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2801),
    [aux_sym_type_token1] = ACTIONS(1171),
    [sym_kUses] = ACTIONS(1171),
    [sym_kBegin] = ACTIONS(1171),
    [sym_kAsm] = ACTIONS(1171),
    [sym_kVar] = ACTIONS(1173),
    [sym_kThreadvar] = ACTIONS(1171),
    [sym_kConst] = ACTIONS(1173),
    [sym_kResourcestring] = ACTIONS(1171),
    [sym_kType] = ACTIONS(1171),
    [sym_kLabel] = ACTIONS(1171),
    [sym_kExports] = ACTIONS(1171),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1171),
    [sym_kGeneric] = ACTIONS(1171),
    [sym_kFunction] = ACTIONS(1171),
    [sym_kProcedure] = ACTIONS(1171),
    [sym_kConstructor] = ACTIONS(1171),
    [sym_kDestructor] = ACTIONS(1171),
    [sym_kOperator] = ACTIONS(1171),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1171),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1171),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [467] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2804),
    [aux_sym_type_token1] = ACTIONS(1396),
    [sym_kUses] = ACTIONS(1396),
    [sym_kBegin] = ACTIONS(1396),
    [sym_kAsm] = ACTIONS(1396),
    [sym_kVar] = ACTIONS(1398),
    [sym_kThreadvar] = ACTIONS(1396),
    [sym_kConst] = ACTIONS(1398),
    [sym_kResourcestring] = ACTIONS(1396),
    [sym_kType] = ACTIONS(1396),
    [sym_kLabel] = ACTIONS(1396),
    [sym_kExports] = ACTIONS(1396),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1396),
    [sym_kGeneric] = ACTIONS(1396),
    [sym_kFunction] = ACTIONS(1396),
    [sym_kProcedure] = ACTIONS(1396),
    [sym_kConstructor] = ACTIONS(1396),
    [sym_kDestructor] = ACTIONS(1396),
    [sym_kOperator] = ACTIONS(1396),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1396),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1396),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [468] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2807),
    [aux_sym_type_token1] = ACTIONS(1305),
    [sym_kUses] = ACTIONS(1305),
    [sym_kBegin] = ACTIONS(1305),
    [sym_kAsm] = ACTIONS(1305),
    [sym_kVar] = ACTIONS(1307),
    [sym_kThreadvar] = ACTIONS(1305),
    [sym_kConst] = ACTIONS(1307),
    [sym_kResourcestring] = ACTIONS(1305),
    [sym_kType] = ACTIONS(1305),
    [sym_kLabel] = ACTIONS(1305),
    [sym_kExports] = ACTIONS(1305),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1305),
    [sym_kGeneric] = ACTIONS(1305),
    [sym_kFunction] = ACTIONS(1305),
    [sym_kProcedure] = ACTIONS(1305),
    [sym_kConstructor] = ACTIONS(1305),
    [sym_kDestructor] = ACTIONS(1305),
    [sym_kOperator] = ACTIONS(1305),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1305),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1305),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [469] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2810),
    [aux_sym_type_token1] = ACTIONS(1312),
    [sym_kUses] = ACTIONS(1312),
    [sym_kBegin] = ACTIONS(1312),
    [sym_kAsm] = ACTIONS(1312),
    [sym_kVar] = ACTIONS(1314),
    [sym_kThreadvar] = ACTIONS(1312),
    [sym_kConst] = ACTIONS(1314),
    [sym_kResourcestring] = ACTIONS(1312),
    [sym_kType] = ACTIONS(1312),
    [sym_kLabel] = ACTIONS(1312),
    [sym_kExports] = ACTIONS(1312),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1312),
    [sym_kGeneric] = ACTIONS(1312),
    [sym_kFunction] = ACTIONS(1312),
    [sym_kProcedure] = ACTIONS(1312),
    [sym_kConstructor] = ACTIONS(1312),
    [sym_kDestructor] = ACTIONS(1312),
    [sym_kOperator] = ACTIONS(1312),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1312),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1312),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [470] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(467),
    [anon_sym_LBRACK] = ACTIONS(2813),
    [aux_sym_type_token1] = ACTIONS(1319),
    [sym_kUses] = ACTIONS(1319),
    [sym_kBegin] = ACTIONS(1319),
    [sym_kAsm] = ACTIONS(1319),
    [sym_kVar] = ACTIONS(1321),
    [sym_kThreadvar] = ACTIONS(1319),
    [sym_kConst] = ACTIONS(1321),
    [sym_kResourcestring] = ACTIONS(1319),
    [sym_kType] = ACTIONS(1319),
    [sym_kLabel] = ACTIONS(1319),
    [sym_kExports] = ACTIONS(1319),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1319),
    [sym_kGeneric] = ACTIONS(1319),
    [sym_kFunction] = ACTIONS(1319),
    [sym_kProcedure] = ACTIONS(1319),
    [sym_kConstructor] = ACTIONS(1319),
    [sym_kDestructor] = ACTIONS(1319),
    [sym_kOperator] = ACTIONS(1319),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1319),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1319),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [471] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2816),
    [aux_sym_type_token1] = ACTIONS(1326),
    [sym_kUses] = ACTIONS(1326),
    [sym_kBegin] = ACTIONS(1326),
    [sym_kAsm] = ACTIONS(1326),
    [sym_kVar] = ACTIONS(1328),
    [sym_kThreadvar] = ACTIONS(1326),
    [sym_kConst] = ACTIONS(1328),
    [sym_kResourcestring] = ACTIONS(1326),
    [sym_kType] = ACTIONS(1326),
    [sym_kLabel] = ACTIONS(1326),
    [sym_kExports] = ACTIONS(1326),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1326),
    [sym_kGeneric] = ACTIONS(1326),
    [sym_kFunction] = ACTIONS(1326),
    [sym_kProcedure] = ACTIONS(1326),
    [sym_kConstructor] = ACTIONS(1326),
    [sym_kDestructor] = ACTIONS(1326),
    [sym_kOperator] = ACTIONS(1326),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1326),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1326),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [472] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(431),
    [anon_sym_LBRACK] = ACTIONS(2819),
    [aux_sym_type_token1] = ACTIONS(1333),
    [sym_kUses] = ACTIONS(1333),
    [sym_kBegin] = ACTIONS(1333),
    [sym_kAsm] = ACTIONS(1333),
    [sym_kVar] = ACTIONS(1335),
    [sym_kThreadvar] = ACTIONS(1333),
    [sym_kConst] = ACTIONS(1335),
    [sym_kResourcestring] = ACTIONS(1333),
    [sym_kType] = ACTIONS(1333),
    [sym_kLabel] = ACTIONS(1333),
    [sym_kExports] = ACTIONS(1333),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1333),
    [sym_kGeneric] = ACTIONS(1333),
    [sym_kFunction] = ACTIONS(1333),
    [sym_kProcedure] = ACTIONS(1333),
    [sym_kConstructor] = ACTIONS(1333),
    [sym_kDestructor] = ACTIONS(1333),
    [sym_kOperator] = ACTIONS(1333),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1333),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1333),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [473] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(436),
    [anon_sym_LBRACK] = ACTIONS(2822),
    [aux_sym_type_token1] = ACTIONS(1340),
    [sym_kUses] = ACTIONS(1340),
    [sym_kBegin] = ACTIONS(1340),
    [sym_kAsm] = ACTIONS(1340),
    [sym_kVar] = ACTIONS(1342),
    [sym_kThreadvar] = ACTIONS(1340),
    [sym_kConst] = ACTIONS(1342),
    [sym_kResourcestring] = ACTIONS(1340),
    [sym_kType] = ACTIONS(1340),
    [sym_kLabel] = ACTIONS(1340),
    [sym_kExports] = ACTIONS(1340),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1340),
    [sym_kGeneric] = ACTIONS(1340),
    [sym_kFunction] = ACTIONS(1340),
    [sym_kProcedure] = ACTIONS(1340),
    [sym_kConstructor] = ACTIONS(1340),
    [sym_kDestructor] = ACTIONS(1340),
    [sym_kOperator] = ACTIONS(1340),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1340),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1340),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [474] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2825),
    [aux_sym_type_token1] = ACTIONS(1347),
    [sym_kUses] = ACTIONS(1347),
    [sym_kBegin] = ACTIONS(1347),
    [sym_kAsm] = ACTIONS(1347),
    [sym_kVar] = ACTIONS(1349),
    [sym_kThreadvar] = ACTIONS(1347),
    [sym_kConst] = ACTIONS(1349),
    [sym_kResourcestring] = ACTIONS(1347),
    [sym_kType] = ACTIONS(1347),
    [sym_kLabel] = ACTIONS(1347),
    [sym_kExports] = ACTIONS(1347),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1347),
    [sym_kGeneric] = ACTIONS(1347),
    [sym_kFunction] = ACTIONS(1347),
    [sym_kProcedure] = ACTIONS(1347),
    [sym_kConstructor] = ACTIONS(1347),
    [sym_kDestructor] = ACTIONS(1347),
    [sym_kOperator] = ACTIONS(1347),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1347),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1347),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [475] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2828),
    [aux_sym_type_token1] = ACTIONS(1368),
    [sym_kUses] = ACTIONS(1368),
    [sym_kBegin] = ACTIONS(1368),
    [sym_kAsm] = ACTIONS(1368),
    [sym_kVar] = ACTIONS(1370),
    [sym_kThreadvar] = ACTIONS(1368),
    [sym_kConst] = ACTIONS(1370),
    [sym_kResourcestring] = ACTIONS(1368),
    [sym_kType] = ACTIONS(1368),
    [sym_kLabel] = ACTIONS(1368),
    [sym_kExports] = ACTIONS(1368),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1368),
    [sym_kGeneric] = ACTIONS(1368),
    [sym_kFunction] = ACTIONS(1368),
    [sym_kProcedure] = ACTIONS(1368),
    [sym_kConstructor] = ACTIONS(1368),
    [sym_kDestructor] = ACTIONS(1368),
    [sym_kOperator] = ACTIONS(1368),
    [sym_kPublic] = ACTIONS(823),
    [sym_kForward] = ACTIONS(1368),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kExternal] = ACTIONS(1368),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [476] = {
    [sym_identifier] = ACTIONS(2831),
    [anon_sym_SEMI] = ACTIONS(2833),
    [anon_sym_COLON] = ACTIONS(2831),
    [anon_sym_COMMA] = ACTIONS(2833),
    [anon_sym_LBRACK] = ACTIONS(2833),
    [anon_sym_RBRACK] = ACTIONS(2833),
    [anon_sym_LPAREN] = ACTIONS(2831),
    [anon_sym_RPAREN] = ACTIONS(2833),
    [aux_sym__literalString_token1] = ACTIONS(2833),
    [anon_sym_POUND] = ACTIONS(2833),
    [anon_sym_DOT] = ACTIONS(2833),
    [sym_kEnd] = ACTIONS(2831),
    [sym_kVar] = ACTIONS(2831),
    [sym_kThreadvar] = ACTIONS(2831),
    [sym_kConst] = ACTIONS(2831),
    [sym_kResourcestring] = ACTIONS(2831),
    [sym_kType] = ACTIONS(2831),
    [sym_kAbsolute] = ACTIONS(2831),
    [sym_kProperty] = ACTIONS(2831),
    [sym_kClass] = ACTIONS(2831),
    [sym_kOf] = ACTIONS(2831),
    [sym_kGeneric] = ACTIONS(2831),
    [sym_kLt] = ACTIONS(2831),
    [sym_kEq] = ACTIONS(2833),
    [sym_kNeq] = ACTIONS(2833),
    [sym_kGt] = ACTIONS(2831),
    [sym_kLte] = ACTIONS(2833),
    [sym_kGte] = ACTIONS(2833),
    [sym_kAdd] = ACTIONS(2831),
    [sym_kSub] = ACTIONS(2831),
    [sym_kMul] = ACTIONS(2831),
    [sym_kFdiv] = ACTIONS(2831),
    [sym_kHat] = ACTIONS(2833),
    [sym_kAssign] = ACTIONS(2833),
    [sym_kAssignAdd] = ACTIONS(2833),
    [sym_kAssignSub] = ACTIONS(2833),
    [sym_kAssignMul] = ACTIONS(2833),
    [sym_kAssignDiv] = ACTIONS(2833),
    [sym_kOr] = ACTIONS(2831),
    [sym_kXor] = ACTIONS(2831),
    [sym_kDiv] = ACTIONS(2831),
    [sym_kMod] = ACTIONS(2831),
    [sym_kAnd] = ACTIONS(2831),
    [sym_kShl] = ACTIONS(2831),
    [sym_kShr] = ACTIONS(2831),
    [sym_kIs] = ACTIONS(2831),
    [sym_kAs] = ACTIONS(2831),
    [sym_kIn] = ACTIONS(2831),
    [sym_kThen] = ACTIONS(2831),
    [sym_kElse] = ACTIONS(2831),
    [sym_kDo] = ACTIONS(2831),
    [sym_kUntil] = ACTIONS(2831),
    [sym_kExcept] = ACTIONS(2831),
    [sym_kFinally] = ACTIONS(2831),
    [sym_kCase] = ACTIONS(2831),
    [sym_kFunction] = ACTIONS(2831),
    [sym_kProcedure] = ACTIONS(2831),
    [sym_kConstructor] = ACTIONS(2831),
    [sym_kDestructor] = ACTIONS(2831),
    [sym_kOperator] = ACTIONS(2831),
    [sym_kPublished] = ACTIONS(2831),
    [sym_kPublic] = ACTIONS(2831),
    [sym_kProtected] = ACTIONS(2831),
    [sym_kPrivate] = ACTIONS(2831),
    [sym_kStrict] = ACTIONS(2831),
    [sym_kRequired] = ACTIONS(2831),
    [sym_kOptional] = ACTIONS(2831),
    [sym_kDelayed] = ACTIONS(2831),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [477] = {
    [sym_identifier] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1509),
    [sym_kEnd] = ACTIONS(1511),
    [sym_kVar] = ACTIONS(1511),
    [sym_kThreadvar] = ACTIONS(1511),
    [sym_kConst] = ACTIONS(1511),
    [sym_kResourcestring] = ACTIONS(1511),
    [sym_kType] = ACTIONS(1511),
    [sym_kProperty] = ACTIONS(1511),
    [sym_kDefault] = ACTIONS(1511),
    [sym_kNodefault] = ACTIONS(1511),
    [sym_kDispId] = ACTIONS(1511),
    [sym_kClass] = ACTIONS(1511),
    [sym_kGeneric] = ACTIONS(1511),
    [sym_kCase] = ACTIONS(1511),
    [sym_kFunction] = ACTIONS(1511),
    [sym_kProcedure] = ACTIONS(1511),
    [sym_kConstructor] = ACTIONS(1511),
    [sym_kDestructor] = ACTIONS(1511),
    [sym_kOperator] = ACTIONS(1511),
    [sym_kPublished] = ACTIONS(1511),
    [sym_kPublic] = ACTIONS(1511),
    [sym_kProtected] = ACTIONS(1511),
    [sym_kPrivate] = ACTIONS(1511),
    [sym_kStrict] = ACTIONS(1511),
    [sym_kRequired] = ACTIONS(1511),
    [sym_kOptional] = ACTIONS(1511),
    [sym_kStatic] = ACTIONS(1511),
    [sym_kVirtual] = ACTIONS(1511),
    [sym_kAbstract] = ACTIONS(1511),
    [sym_kDynamic] = ACTIONS(1511),
    [sym_kOverride] = ACTIONS(1511),
    [sym_kOverload] = ACTIONS(1511),
    [sym_kReintroduce] = ACTIONS(1511),
    [sym_kInline] = ACTIONS(1511),
    [sym_kStdcall] = ACTIONS(1511),
    [sym_kCdecl] = ACTIONS(1511),
    [sym_kCppdecl] = ACTIONS(1511),
    [sym_kPascal] = ACTIONS(1511),
    [sym_kRegister] = ACTIONS(1511),
    [sym_kMwpascal] = ACTIONS(1511),
    [sym_kMessage] = ACTIONS(1511),
    [sym_kDeprecated] = ACTIONS(1511),
    [sym_kExperimental] = ACTIONS(1511),
    [sym_kPlatform] = ACTIONS(1511),
    [sym_kUnimplemented] = ACTIONS(1511),
    [sym_kCvar] = ACTIONS(1511),
    [sym_kExport] = ACTIONS(1511),
    [sym_kFar] = ACTIONS(1511),
    [sym_kNear] = ACTIONS(1511),
    [sym_kSafecall] = ACTIONS(1511),
    [sym_kAssembler] = ACTIONS(1511),
    [sym_kNostackframe] = ACTIONS(1511),
    [sym_kInterrupt] = ACTIONS(1511),
    [sym_kNoreturn] = ACTIONS(1511),
    [sym_kIocheck] = ACTIONS(1511),
    [sym_kLocal] = ACTIONS(1511),
    [sym_kHardfloat] = ACTIONS(1511),
    [sym_kSoftfloat] = ACTIONS(1511),
    [sym_kMs_abi_default] = ACTIONS(1511),
    [sym_kMs_abi_cdecl] = ACTIONS(1511),
    [sym_kSaveregisters] = ACTIONS(1511),
    [sym_kSysv_abi_default] = ACTIONS(1511),
    [sym_kSysv_abi_cdecl] = ACTIONS(1511),
    [sym_kVectorcall] = ACTIONS(1511),
    [sym_kVarargs] = ACTIONS(1511),
    [sym_kWinapi] = ACTIONS(1511),
    [sym_kAlias] = ACTIONS(1511),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [478] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2835),
    [aux_sym_type_token1] = ACTIONS(2026),
    [sym_kUses] = ACTIONS(2026),
    [sym_kBegin] = ACTIONS(2026),
    [sym_kAsm] = ACTIONS(2026),
    [sym_kVar] = ACTIONS(2028),
    [sym_kThreadvar] = ACTIONS(2026),
    [sym_kConst] = ACTIONS(2028),
    [sym_kResourcestring] = ACTIONS(2026),
    [sym_kType] = ACTIONS(2026),
    [sym_kLabel] = ACTIONS(2026),
    [sym_kExports] = ACTIONS(2026),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2026),
    [sym_kGeneric] = ACTIONS(2026),
    [sym_kFunction] = ACTIONS(2026),
    [sym_kProcedure] = ACTIONS(2026),
    [sym_kConstructor] = ACTIONS(2026),
    [sym_kDestructor] = ACTIONS(2026),
    [sym_kOperator] = ACTIONS(2026),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [479] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2838),
    [aux_sym_type_token1] = ACTIONS(1965),
    [sym_kUses] = ACTIONS(1965),
    [sym_kBegin] = ACTIONS(1965),
    [sym_kAsm] = ACTIONS(1965),
    [sym_kVar] = ACTIONS(1967),
    [sym_kThreadvar] = ACTIONS(1965),
    [sym_kConst] = ACTIONS(1967),
    [sym_kResourcestring] = ACTIONS(1965),
    [sym_kType] = ACTIONS(1965),
    [sym_kLabel] = ACTIONS(1965),
    [sym_kExports] = ACTIONS(1965),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1965),
    [sym_kGeneric] = ACTIONS(1965),
    [sym_kFunction] = ACTIONS(1965),
    [sym_kProcedure] = ACTIONS(1965),
    [sym_kConstructor] = ACTIONS(1965),
    [sym_kDestructor] = ACTIONS(1965),
    [sym_kOperator] = ACTIONS(1965),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [480] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2841),
    [aux_sym_type_token1] = ACTIONS(1804),
    [sym_kUses] = ACTIONS(1804),
    [sym_kBegin] = ACTIONS(1804),
    [sym_kAsm] = ACTIONS(1804),
    [sym_kVar] = ACTIONS(1806),
    [sym_kThreadvar] = ACTIONS(1804),
    [sym_kConst] = ACTIONS(1806),
    [sym_kResourcestring] = ACTIONS(1804),
    [sym_kType] = ACTIONS(1804),
    [sym_kLabel] = ACTIONS(1804),
    [sym_kExports] = ACTIONS(1804),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1804),
    [sym_kGeneric] = ACTIONS(1804),
    [sym_kFunction] = ACTIONS(1804),
    [sym_kProcedure] = ACTIONS(1804),
    [sym_kConstructor] = ACTIONS(1804),
    [sym_kDestructor] = ACTIONS(1804),
    [sym_kOperator] = ACTIONS(1804),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [481] = {
    [anon_sym_LBRACK] = ACTIONS(2787),
    [sym_kEnd] = ACTIONS(2787),
    [sym_kVar] = ACTIONS(2789),
    [sym_kThreadvar] = ACTIONS(2787),
    [sym_kConst] = ACTIONS(2789),
    [sym_kResourcestring] = ACTIONS(2787),
    [sym_kType] = ACTIONS(2787),
    [sym_kProperty] = ACTIONS(2787),
    [sym_kDefault] = ACTIONS(2787),
    [sym_kNodefault] = ACTIONS(2787),
    [sym_kDispId] = ACTIONS(2787),
    [sym_kClass] = ACTIONS(2787),
    [sym_kGeneric] = ACTIONS(2787),
    [sym_kCase] = ACTIONS(2787),
    [sym_kFunction] = ACTIONS(2787),
    [sym_kProcedure] = ACTIONS(2787),
    [sym_kConstructor] = ACTIONS(2787),
    [sym_kDestructor] = ACTIONS(2787),
    [sym_kOperator] = ACTIONS(2787),
    [sym_kPublished] = ACTIONS(2787),
    [sym_kPublic] = ACTIONS(2787),
    [sym_kProtected] = ACTIONS(2787),
    [sym_kPrivate] = ACTIONS(2787),
    [sym_kStrict] = ACTIONS(2787),
    [sym_kRequired] = ACTIONS(2787),
    [sym_kOptional] = ACTIONS(2787),
    [sym_kStatic] = ACTIONS(2787),
    [sym_kVirtual] = ACTIONS(2787),
    [sym_kAbstract] = ACTIONS(2787),
    [sym_kDynamic] = ACTIONS(2787),
    [sym_kOverride] = ACTIONS(2787),
    [sym_kOverload] = ACTIONS(2787),
    [sym_kReintroduce] = ACTIONS(2787),
    [sym_kInline] = ACTIONS(2787),
    [sym_kStdcall] = ACTIONS(2787),
    [sym_kCdecl] = ACTIONS(2787),
    [sym_kCppdecl] = ACTIONS(2787),
    [sym_kPascal] = ACTIONS(2787),
    [sym_kRegister] = ACTIONS(2787),
    [sym_kMwpascal] = ACTIONS(2787),
    [sym_kMessage] = ACTIONS(2787),
    [sym_kDeprecated] = ACTIONS(2787),
    [sym_kExperimental] = ACTIONS(2787),
    [sym_kPlatform] = ACTIONS(2787),
    [sym_kUnimplemented] = ACTIONS(2787),
    [sym_kCvar] = ACTIONS(2787),
    [sym_kExport] = ACTIONS(2787),
    [sym_kFar] = ACTIONS(2787),
    [sym_kNear] = ACTIONS(2787),
    [sym_kSafecall] = ACTIONS(2787),
    [sym_kAssembler] = ACTIONS(2787),
    [sym_kNostackframe] = ACTIONS(2787),
    [sym_kInterrupt] = ACTIONS(2787),
    [sym_kNoreturn] = ACTIONS(2787),
    [sym_kIocheck] = ACTIONS(2787),
    [sym_kLocal] = ACTIONS(2787),
    [sym_kHardfloat] = ACTIONS(2787),
    [sym_kSoftfloat] = ACTIONS(2787),
    [sym_kMs_abi_default] = ACTIONS(2787),
    [sym_kMs_abi_cdecl] = ACTIONS(2787),
    [sym_kSaveregisters] = ACTIONS(2787),
    [sym_kSysv_abi_default] = ACTIONS(2787),
    [sym_kSysv_abi_cdecl] = ACTIONS(2787),
    [sym_kVectorcall] = ACTIONS(2787),
    [sym_kVarargs] = ACTIONS(2787),
    [sym_kWinapi] = ACTIONS(2787),
    [sym_kAlias] = ACTIONS(2787),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [482] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(480),
    [anon_sym_LBRACK] = ACTIONS(2844),
    [aux_sym_type_token1] = ACTIONS(1734),
    [sym_kUses] = ACTIONS(1734),
    [sym_kBegin] = ACTIONS(1734),
    [sym_kAsm] = ACTIONS(1734),
    [sym_kVar] = ACTIONS(1736),
    [sym_kThreadvar] = ACTIONS(1734),
    [sym_kConst] = ACTIONS(1736),
    [sym_kResourcestring] = ACTIONS(1734),
    [sym_kType] = ACTIONS(1734),
    [sym_kLabel] = ACTIONS(1734),
    [sym_kExports] = ACTIONS(1734),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1734),
    [sym_kGeneric] = ACTIONS(1734),
    [sym_kFunction] = ACTIONS(1734),
    [sym_kProcedure] = ACTIONS(1734),
    [sym_kConstructor] = ACTIONS(1734),
    [sym_kDestructor] = ACTIONS(1734),
    [sym_kOperator] = ACTIONS(1734),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [483] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(509),
    [anon_sym_LBRACK] = ACTIONS(2847),
    [aux_sym_type_token1] = ACTIONS(1811),
    [sym_kUses] = ACTIONS(1811),
    [sym_kBegin] = ACTIONS(1811),
    [sym_kAsm] = ACTIONS(1811),
    [sym_kVar] = ACTIONS(1813),
    [sym_kThreadvar] = ACTIONS(1811),
    [sym_kConst] = ACTIONS(1813),
    [sym_kResourcestring] = ACTIONS(1811),
    [sym_kType] = ACTIONS(1811),
    [sym_kLabel] = ACTIONS(1811),
    [sym_kExports] = ACTIONS(1811),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1811),
    [sym_kGeneric] = ACTIONS(1811),
    [sym_kFunction] = ACTIONS(1811),
    [sym_kProcedure] = ACTIONS(1811),
    [sym_kConstructor] = ACTIONS(1811),
    [sym_kDestructor] = ACTIONS(1811),
    [sym_kOperator] = ACTIONS(1811),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [484] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(510),
    [anon_sym_LBRACK] = ACTIONS(2850),
    [aux_sym_type_token1] = ACTIONS(1818),
    [sym_kUses] = ACTIONS(1818),
    [sym_kBegin] = ACTIONS(1818),
    [sym_kAsm] = ACTIONS(1818),
    [sym_kVar] = ACTIONS(1820),
    [sym_kThreadvar] = ACTIONS(1818),
    [sym_kConst] = ACTIONS(1820),
    [sym_kResourcestring] = ACTIONS(1818),
    [sym_kType] = ACTIONS(1818),
    [sym_kLabel] = ACTIONS(1818),
    [sym_kExports] = ACTIONS(1818),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1818),
    [sym_kGeneric] = ACTIONS(1818),
    [sym_kFunction] = ACTIONS(1818),
    [sym_kProcedure] = ACTIONS(1818),
    [sym_kConstructor] = ACTIONS(1818),
    [sym_kDestructor] = ACTIONS(1818),
    [sym_kOperator] = ACTIONS(1818),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [485] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(512),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [aux_sym_type_token1] = ACTIONS(1825),
    [sym_kUses] = ACTIONS(1825),
    [sym_kBegin] = ACTIONS(1825),
    [sym_kAsm] = ACTIONS(1825),
    [sym_kVar] = ACTIONS(1827),
    [sym_kThreadvar] = ACTIONS(1825),
    [sym_kConst] = ACTIONS(1827),
    [sym_kResourcestring] = ACTIONS(1825),
    [sym_kType] = ACTIONS(1825),
    [sym_kLabel] = ACTIONS(1825),
    [sym_kExports] = ACTIONS(1825),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1825),
    [sym_kGeneric] = ACTIONS(1825),
    [sym_kFunction] = ACTIONS(1825),
    [sym_kProcedure] = ACTIONS(1825),
    [sym_kConstructor] = ACTIONS(1825),
    [sym_kDestructor] = ACTIONS(1825),
    [sym_kOperator] = ACTIONS(1825),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [486] = {
    [anon_sym_LBRACK] = ACTIONS(2744),
    [sym_kEnd] = ACTIONS(2744),
    [sym_kVar] = ACTIONS(2746),
    [sym_kThreadvar] = ACTIONS(2744),
    [sym_kConst] = ACTIONS(2746),
    [sym_kResourcestring] = ACTIONS(2744),
    [sym_kType] = ACTIONS(2744),
    [sym_kProperty] = ACTIONS(2744),
    [sym_kDefault] = ACTIONS(2744),
    [sym_kNodefault] = ACTIONS(2744),
    [sym_kDispId] = ACTIONS(2744),
    [sym_kClass] = ACTIONS(2744),
    [sym_kGeneric] = ACTIONS(2744),
    [sym_kCase] = ACTIONS(2744),
    [sym_kFunction] = ACTIONS(2744),
    [sym_kProcedure] = ACTIONS(2744),
    [sym_kConstructor] = ACTIONS(2744),
    [sym_kDestructor] = ACTIONS(2744),
    [sym_kOperator] = ACTIONS(2744),
    [sym_kPublished] = ACTIONS(2744),
    [sym_kPublic] = ACTIONS(2744),
    [sym_kProtected] = ACTIONS(2744),
    [sym_kPrivate] = ACTIONS(2744),
    [sym_kStrict] = ACTIONS(2744),
    [sym_kRequired] = ACTIONS(2744),
    [sym_kOptional] = ACTIONS(2744),
    [sym_kStatic] = ACTIONS(2744),
    [sym_kVirtual] = ACTIONS(2744),
    [sym_kAbstract] = ACTIONS(2744),
    [sym_kDynamic] = ACTIONS(2744),
    [sym_kOverride] = ACTIONS(2744),
    [sym_kOverload] = ACTIONS(2744),
    [sym_kReintroduce] = ACTIONS(2744),
    [sym_kInline] = ACTIONS(2744),
    [sym_kStdcall] = ACTIONS(2744),
    [sym_kCdecl] = ACTIONS(2744),
    [sym_kCppdecl] = ACTIONS(2744),
    [sym_kPascal] = ACTIONS(2744),
    [sym_kRegister] = ACTIONS(2744),
    [sym_kMwpascal] = ACTIONS(2744),
    [sym_kMessage] = ACTIONS(2744),
    [sym_kDeprecated] = ACTIONS(2744),
    [sym_kExperimental] = ACTIONS(2744),
    [sym_kPlatform] = ACTIONS(2744),
    [sym_kUnimplemented] = ACTIONS(2744),
    [sym_kCvar] = ACTIONS(2744),
    [sym_kExport] = ACTIONS(2744),
    [sym_kFar] = ACTIONS(2744),
    [sym_kNear] = ACTIONS(2744),
    [sym_kSafecall] = ACTIONS(2744),
    [sym_kAssembler] = ACTIONS(2744),
    [sym_kNostackframe] = ACTIONS(2744),
    [sym_kInterrupt] = ACTIONS(2744),
    [sym_kNoreturn] = ACTIONS(2744),
    [sym_kIocheck] = ACTIONS(2744),
    [sym_kLocal] = ACTIONS(2744),
    [sym_kHardfloat] = ACTIONS(2744),
    [sym_kSoftfloat] = ACTIONS(2744),
    [sym_kMs_abi_default] = ACTIONS(2744),
    [sym_kMs_abi_cdecl] = ACTIONS(2744),
    [sym_kSaveregisters] = ACTIONS(2744),
    [sym_kSysv_abi_default] = ACTIONS(2744),
    [sym_kSysv_abi_cdecl] = ACTIONS(2744),
    [sym_kVectorcall] = ACTIONS(2744),
    [sym_kVarargs] = ACTIONS(2744),
    [sym_kWinapi] = ACTIONS(2744),
    [sym_kAlias] = ACTIONS(2744),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [487] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2856),
    [aux_sym_type_token1] = ACTIONS(2057),
    [sym_kUses] = ACTIONS(2057),
    [sym_kBegin] = ACTIONS(2057),
    [sym_kAsm] = ACTIONS(2057),
    [sym_kVar] = ACTIONS(2059),
    [sym_kThreadvar] = ACTIONS(2057),
    [sym_kConst] = ACTIONS(2059),
    [sym_kResourcestring] = ACTIONS(2057),
    [sym_kType] = ACTIONS(2057),
    [sym_kLabel] = ACTIONS(2057),
    [sym_kExports] = ACTIONS(2057),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2057),
    [sym_kGeneric] = ACTIONS(2057),
    [sym_kFunction] = ACTIONS(2057),
    [sym_kProcedure] = ACTIONS(2057),
    [sym_kConstructor] = ACTIONS(2057),
    [sym_kDestructor] = ACTIONS(2057),
    [sym_kOperator] = ACTIONS(2057),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [488] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2859),
    [aux_sym_type_token1] = ACTIONS(1998),
    [sym_kUses] = ACTIONS(1998),
    [sym_kBegin] = ACTIONS(1998),
    [sym_kAsm] = ACTIONS(1998),
    [sym_kVar] = ACTIONS(2000),
    [sym_kThreadvar] = ACTIONS(1998),
    [sym_kConst] = ACTIONS(2000),
    [sym_kResourcestring] = ACTIONS(1998),
    [sym_kType] = ACTIONS(1998),
    [sym_kLabel] = ACTIONS(1998),
    [sym_kExports] = ACTIONS(1998),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1998),
    [sym_kGeneric] = ACTIONS(1998),
    [sym_kFunction] = ACTIONS(1998),
    [sym_kProcedure] = ACTIONS(1998),
    [sym_kConstructor] = ACTIONS(1998),
    [sym_kDestructor] = ACTIONS(1998),
    [sym_kOperator] = ACTIONS(1998),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [489] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2862),
    [aux_sym_type_token1] = ACTIONS(2005),
    [sym_kUses] = ACTIONS(2005),
    [sym_kBegin] = ACTIONS(2005),
    [sym_kAsm] = ACTIONS(2005),
    [sym_kVar] = ACTIONS(2007),
    [sym_kThreadvar] = ACTIONS(2005),
    [sym_kConst] = ACTIONS(2007),
    [sym_kResourcestring] = ACTIONS(2005),
    [sym_kType] = ACTIONS(2005),
    [sym_kLabel] = ACTIONS(2005),
    [sym_kExports] = ACTIONS(2005),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2005),
    [sym_kGeneric] = ACTIONS(2005),
    [sym_kFunction] = ACTIONS(2005),
    [sym_kProcedure] = ACTIONS(2005),
    [sym_kConstructor] = ACTIONS(2005),
    [sym_kDestructor] = ACTIONS(2005),
    [sym_kOperator] = ACTIONS(2005),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [490] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2865),
    [aux_sym_type_token1] = ACTIONS(2012),
    [sym_kUses] = ACTIONS(2012),
    [sym_kBegin] = ACTIONS(2012),
    [sym_kAsm] = ACTIONS(2012),
    [sym_kVar] = ACTIONS(2014),
    [sym_kThreadvar] = ACTIONS(2012),
    [sym_kConst] = ACTIONS(2014),
    [sym_kResourcestring] = ACTIONS(2012),
    [sym_kType] = ACTIONS(2012),
    [sym_kLabel] = ACTIONS(2012),
    [sym_kExports] = ACTIONS(2012),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2012),
    [sym_kGeneric] = ACTIONS(2012),
    [sym_kFunction] = ACTIONS(2012),
    [sym_kProcedure] = ACTIONS(2012),
    [sym_kConstructor] = ACTIONS(2012),
    [sym_kDestructor] = ACTIONS(2012),
    [sym_kOperator] = ACTIONS(2012),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [491] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(487),
    [anon_sym_LBRACK] = ACTIONS(2868),
    [aux_sym_type_token1] = ACTIONS(2019),
    [sym_kUses] = ACTIONS(2019),
    [sym_kBegin] = ACTIONS(2019),
    [sym_kAsm] = ACTIONS(2019),
    [sym_kVar] = ACTIONS(2021),
    [sym_kThreadvar] = ACTIONS(2019),
    [sym_kConst] = ACTIONS(2021),
    [sym_kResourcestring] = ACTIONS(2019),
    [sym_kType] = ACTIONS(2019),
    [sym_kLabel] = ACTIONS(2019),
    [sym_kExports] = ACTIONS(2019),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(2019),
    [sym_kGeneric] = ACTIONS(2019),
    [sym_kFunction] = ACTIONS(2019),
    [sym_kProcedure] = ACTIONS(2019),
    [sym_kConstructor] = ACTIONS(2019),
    [sym_kDestructor] = ACTIONS(2019),
    [sym_kOperator] = ACTIONS(2019),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [492] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(478),
    [anon_sym_LBRACK] = ACTIONS(2871),
    [aux_sym_type_token1] = ACTIONS(1643),
    [sym_kUses] = ACTIONS(1643),
    [sym_kBegin] = ACTIONS(1643),
    [sym_kAsm] = ACTIONS(1643),
    [sym_kVar] = ACTIONS(1645),
    [sym_kThreadvar] = ACTIONS(1643),
    [sym_kConst] = ACTIONS(1645),
    [sym_kResourcestring] = ACTIONS(1643),
    [sym_kType] = ACTIONS(1643),
    [sym_kLabel] = ACTIONS(1643),
    [sym_kExports] = ACTIONS(1643),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1643),
    [sym_kGeneric] = ACTIONS(1643),
    [sym_kFunction] = ACTIONS(1643),
    [sym_kProcedure] = ACTIONS(1643),
    [sym_kConstructor] = ACTIONS(1643),
    [sym_kDestructor] = ACTIONS(1643),
    [sym_kOperator] = ACTIONS(1643),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [493] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2874),
    [aux_sym_type_token1] = ACTIONS(1832),
    [sym_kUses] = ACTIONS(1832),
    [sym_kBegin] = ACTIONS(1832),
    [sym_kAsm] = ACTIONS(1832),
    [sym_kVar] = ACTIONS(1834),
    [sym_kThreadvar] = ACTIONS(1832),
    [sym_kConst] = ACTIONS(1834),
    [sym_kResourcestring] = ACTIONS(1832),
    [sym_kType] = ACTIONS(1832),
    [sym_kLabel] = ACTIONS(1832),
    [sym_kExports] = ACTIONS(1832),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1832),
    [sym_kGeneric] = ACTIONS(1832),
    [sym_kFunction] = ACTIONS(1832),
    [sym_kProcedure] = ACTIONS(1832),
    [sym_kConstructor] = ACTIONS(1832),
    [sym_kDestructor] = ACTIONS(1832),
    [sym_kOperator] = ACTIONS(1832),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [494] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2877),
    [aux_sym_type_token1] = ACTIONS(1951),
    [sym_kUses] = ACTIONS(1951),
    [sym_kBegin] = ACTIONS(1951),
    [sym_kAsm] = ACTIONS(1951),
    [sym_kVar] = ACTIONS(1953),
    [sym_kThreadvar] = ACTIONS(1951),
    [sym_kConst] = ACTIONS(1953),
    [sym_kResourcestring] = ACTIONS(1951),
    [sym_kType] = ACTIONS(1951),
    [sym_kLabel] = ACTIONS(1951),
    [sym_kExports] = ACTIONS(1951),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1951),
    [sym_kGeneric] = ACTIONS(1951),
    [sym_kFunction] = ACTIONS(1951),
    [sym_kProcedure] = ACTIONS(1951),
    [sym_kConstructor] = ACTIONS(1951),
    [sym_kDestructor] = ACTIONS(1951),
    [sym_kOperator] = ACTIONS(1951),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [495] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(494),
    [anon_sym_LBRACK] = ACTIONS(2880),
    [aux_sym_type_token1] = ACTIONS(1846),
    [sym_kUses] = ACTIONS(1846),
    [sym_kBegin] = ACTIONS(1846),
    [sym_kAsm] = ACTIONS(1846),
    [sym_kVar] = ACTIONS(1848),
    [sym_kThreadvar] = ACTIONS(1846),
    [sym_kConst] = ACTIONS(1848),
    [sym_kResourcestring] = ACTIONS(1846),
    [sym_kType] = ACTIONS(1846),
    [sym_kLabel] = ACTIONS(1846),
    [sym_kExports] = ACTIONS(1846),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1846),
    [sym_kGeneric] = ACTIONS(1846),
    [sym_kFunction] = ACTIONS(1846),
    [sym_kProcedure] = ACTIONS(1846),
    [sym_kConstructor] = ACTIONS(1846),
    [sym_kDestructor] = ACTIONS(1846),
    [sym_kOperator] = ACTIONS(1846),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [496] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2883),
    [aux_sym_type_token1] = ACTIONS(1853),
    [sym_kUses] = ACTIONS(1853),
    [sym_kBegin] = ACTIONS(1853),
    [sym_kAsm] = ACTIONS(1853),
    [sym_kVar] = ACTIONS(1855),
    [sym_kThreadvar] = ACTIONS(1853),
    [sym_kConst] = ACTIONS(1855),
    [sym_kResourcestring] = ACTIONS(1853),
    [sym_kType] = ACTIONS(1853),
    [sym_kLabel] = ACTIONS(1853),
    [sym_kExports] = ACTIONS(1853),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1853),
    [sym_kGeneric] = ACTIONS(1853),
    [sym_kFunction] = ACTIONS(1853),
    [sym_kProcedure] = ACTIONS(1853),
    [sym_kConstructor] = ACTIONS(1853),
    [sym_kDestructor] = ACTIONS(1853),
    [sym_kOperator] = ACTIONS(1853),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [497] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(508),
    [anon_sym_LBRACK] = ACTIONS(2886),
    [aux_sym_type_token1] = ACTIONS(1860),
    [sym_kUses] = ACTIONS(1860),
    [sym_kBegin] = ACTIONS(1860),
    [sym_kAsm] = ACTIONS(1860),
    [sym_kVar] = ACTIONS(1862),
    [sym_kThreadvar] = ACTIONS(1860),
    [sym_kConst] = ACTIONS(1862),
    [sym_kResourcestring] = ACTIONS(1860),
    [sym_kType] = ACTIONS(1860),
    [sym_kLabel] = ACTIONS(1860),
    [sym_kExports] = ACTIONS(1860),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1860),
    [sym_kGeneric] = ACTIONS(1860),
    [sym_kFunction] = ACTIONS(1860),
    [sym_kProcedure] = ACTIONS(1860),
    [sym_kConstructor] = ACTIONS(1860),
    [sym_kDestructor] = ACTIONS(1860),
    [sym_kOperator] = ACTIONS(1860),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [498] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(479),
    [anon_sym_LBRACK] = ACTIONS(2889),
    [aux_sym_type_token1] = ACTIONS(1867),
    [sym_kUses] = ACTIONS(1867),
    [sym_kBegin] = ACTIONS(1867),
    [sym_kAsm] = ACTIONS(1867),
    [sym_kVar] = ACTIONS(1869),
    [sym_kThreadvar] = ACTIONS(1867),
    [sym_kConst] = ACTIONS(1869),
    [sym_kResourcestring] = ACTIONS(1867),
    [sym_kType] = ACTIONS(1867),
    [sym_kLabel] = ACTIONS(1867),
    [sym_kExports] = ACTIONS(1867),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1867),
    [sym_kGeneric] = ACTIONS(1867),
    [sym_kFunction] = ACTIONS(1867),
    [sym_kProcedure] = ACTIONS(1867),
    [sym_kConstructor] = ACTIONS(1867),
    [sym_kDestructor] = ACTIONS(1867),
    [sym_kOperator] = ACTIONS(1867),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [499] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(501),
    [anon_sym_LBRACK] = ACTIONS(2892),
    [aux_sym_type_token1] = ACTIONS(1699),
    [sym_kUses] = ACTIONS(1699),
    [sym_kBegin] = ACTIONS(1699),
    [sym_kAsm] = ACTIONS(1699),
    [sym_kVar] = ACTIONS(1701),
    [sym_kThreadvar] = ACTIONS(1699),
    [sym_kConst] = ACTIONS(1701),
    [sym_kResourcestring] = ACTIONS(1699),
    [sym_kType] = ACTIONS(1699),
    [sym_kLabel] = ACTIONS(1699),
    [sym_kExports] = ACTIONS(1699),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1699),
    [sym_kGeneric] = ACTIONS(1699),
    [sym_kFunction] = ACTIONS(1699),
    [sym_kProcedure] = ACTIONS(1699),
    [sym_kConstructor] = ACTIONS(1699),
    [sym_kDestructor] = ACTIONS(1699),
    [sym_kOperator] = ACTIONS(1699),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [500] = {
    [anon_sym_LBRACK] = ACTIONS(2794),
    [sym_kEnd] = ACTIONS(2794),
    [sym_kVar] = ACTIONS(2796),
    [sym_kThreadvar] = ACTIONS(2794),
    [sym_kConst] = ACTIONS(2796),
    [sym_kResourcestring] = ACTIONS(2794),
    [sym_kType] = ACTIONS(2794),
    [sym_kProperty] = ACTIONS(2794),
    [sym_kDefault] = ACTIONS(2794),
    [sym_kNodefault] = ACTIONS(2794),
    [sym_kDispId] = ACTIONS(2794),
    [sym_kClass] = ACTIONS(2794),
    [sym_kGeneric] = ACTIONS(2794),
    [sym_kCase] = ACTIONS(2794),
    [sym_kFunction] = ACTIONS(2794),
    [sym_kProcedure] = ACTIONS(2794),
    [sym_kConstructor] = ACTIONS(2794),
    [sym_kDestructor] = ACTIONS(2794),
    [sym_kOperator] = ACTIONS(2794),
    [sym_kPublished] = ACTIONS(2794),
    [sym_kPublic] = ACTIONS(2794),
    [sym_kProtected] = ACTIONS(2794),
    [sym_kPrivate] = ACTIONS(2794),
    [sym_kStrict] = ACTIONS(2794),
    [sym_kRequired] = ACTIONS(2794),
    [sym_kOptional] = ACTIONS(2794),
    [sym_kStatic] = ACTIONS(2794),
    [sym_kVirtual] = ACTIONS(2794),
    [sym_kAbstract] = ACTIONS(2794),
    [sym_kDynamic] = ACTIONS(2794),
    [sym_kOverride] = ACTIONS(2794),
    [sym_kOverload] = ACTIONS(2794),
    [sym_kReintroduce] = ACTIONS(2794),
    [sym_kInline] = ACTIONS(2794),
    [sym_kStdcall] = ACTIONS(2794),
    [sym_kCdecl] = ACTIONS(2794),
    [sym_kCppdecl] = ACTIONS(2794),
    [sym_kPascal] = ACTIONS(2794),
    [sym_kRegister] = ACTIONS(2794),
    [sym_kMwpascal] = ACTIONS(2794),
    [sym_kMessage] = ACTIONS(2794),
    [sym_kDeprecated] = ACTIONS(2794),
    [sym_kExperimental] = ACTIONS(2794),
    [sym_kPlatform] = ACTIONS(2794),
    [sym_kUnimplemented] = ACTIONS(2794),
    [sym_kCvar] = ACTIONS(2794),
    [sym_kExport] = ACTIONS(2794),
    [sym_kFar] = ACTIONS(2794),
    [sym_kNear] = ACTIONS(2794),
    [sym_kSafecall] = ACTIONS(2794),
    [sym_kAssembler] = ACTIONS(2794),
    [sym_kNostackframe] = ACTIONS(2794),
    [sym_kInterrupt] = ACTIONS(2794),
    [sym_kNoreturn] = ACTIONS(2794),
    [sym_kIocheck] = ACTIONS(2794),
    [sym_kLocal] = ACTIONS(2794),
    [sym_kHardfloat] = ACTIONS(2794),
    [sym_kSoftfloat] = ACTIONS(2794),
    [sym_kMs_abi_default] = ACTIONS(2794),
    [sym_kMs_abi_cdecl] = ACTIONS(2794),
    [sym_kSaveregisters] = ACTIONS(2794),
    [sym_kSysv_abi_default] = ACTIONS(2794),
    [sym_kSysv_abi_cdecl] = ACTIONS(2794),
    [sym_kVectorcall] = ACTIONS(2794),
    [sym_kVarargs] = ACTIONS(2794),
    [sym_kWinapi] = ACTIONS(2794),
    [sym_kAlias] = ACTIONS(2794),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [501] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2895),
    [aux_sym_type_token1] = ACTIONS(1741),
    [sym_kUses] = ACTIONS(1741),
    [sym_kBegin] = ACTIONS(1741),
    [sym_kAsm] = ACTIONS(1741),
    [sym_kVar] = ACTIONS(1743),
    [sym_kThreadvar] = ACTIONS(1741),
    [sym_kConst] = ACTIONS(1743),
    [sym_kResourcestring] = ACTIONS(1741),
    [sym_kType] = ACTIONS(1741),
    [sym_kLabel] = ACTIONS(1741),
    [sym_kExports] = ACTIONS(1741),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1741),
    [sym_kGeneric] = ACTIONS(1741),
    [sym_kFunction] = ACTIONS(1741),
    [sym_kProcedure] = ACTIONS(1741),
    [sym_kConstructor] = ACTIONS(1741),
    [sym_kDestructor] = ACTIONS(1741),
    [sym_kOperator] = ACTIONS(1741),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [502] = {
    [anon_sym_LBRACK] = ACTIONS(2668),
    [sym_kEnd] = ACTIONS(2668),
    [sym_kVar] = ACTIONS(2670),
    [sym_kThreadvar] = ACTIONS(2668),
    [sym_kConst] = ACTIONS(2670),
    [sym_kResourcestring] = ACTIONS(2668),
    [sym_kType] = ACTIONS(2668),
    [sym_kProperty] = ACTIONS(2668),
    [sym_kDefault] = ACTIONS(2668),
    [sym_kNodefault] = ACTIONS(2668),
    [sym_kDispId] = ACTIONS(2668),
    [sym_kClass] = ACTIONS(2668),
    [sym_kGeneric] = ACTIONS(2668),
    [sym_kCase] = ACTIONS(2668),
    [sym_kFunction] = ACTIONS(2668),
    [sym_kProcedure] = ACTIONS(2668),
    [sym_kConstructor] = ACTIONS(2668),
    [sym_kDestructor] = ACTIONS(2668),
    [sym_kOperator] = ACTIONS(2668),
    [sym_kPublished] = ACTIONS(2668),
    [sym_kPublic] = ACTIONS(2668),
    [sym_kProtected] = ACTIONS(2668),
    [sym_kPrivate] = ACTIONS(2668),
    [sym_kStrict] = ACTIONS(2668),
    [sym_kRequired] = ACTIONS(2668),
    [sym_kOptional] = ACTIONS(2668),
    [sym_kStatic] = ACTIONS(2668),
    [sym_kVirtual] = ACTIONS(2668),
    [sym_kAbstract] = ACTIONS(2668),
    [sym_kDynamic] = ACTIONS(2668),
    [sym_kOverride] = ACTIONS(2668),
    [sym_kOverload] = ACTIONS(2668),
    [sym_kReintroduce] = ACTIONS(2668),
    [sym_kInline] = ACTIONS(2668),
    [sym_kStdcall] = ACTIONS(2668),
    [sym_kCdecl] = ACTIONS(2668),
    [sym_kCppdecl] = ACTIONS(2668),
    [sym_kPascal] = ACTIONS(2668),
    [sym_kRegister] = ACTIONS(2668),
    [sym_kMwpascal] = ACTIONS(2668),
    [sym_kMessage] = ACTIONS(2668),
    [sym_kDeprecated] = ACTIONS(2668),
    [sym_kExperimental] = ACTIONS(2668),
    [sym_kPlatform] = ACTIONS(2668),
    [sym_kUnimplemented] = ACTIONS(2668),
    [sym_kCvar] = ACTIONS(2668),
    [sym_kExport] = ACTIONS(2668),
    [sym_kFar] = ACTIONS(2668),
    [sym_kNear] = ACTIONS(2668),
    [sym_kSafecall] = ACTIONS(2668),
    [sym_kAssembler] = ACTIONS(2668),
    [sym_kNostackframe] = ACTIONS(2668),
    [sym_kInterrupt] = ACTIONS(2668),
    [sym_kNoreturn] = ACTIONS(2668),
    [sym_kIocheck] = ACTIONS(2668),
    [sym_kLocal] = ACTIONS(2668),
    [sym_kHardfloat] = ACTIONS(2668),
    [sym_kSoftfloat] = ACTIONS(2668),
    [sym_kMs_abi_default] = ACTIONS(2668),
    [sym_kMs_abi_cdecl] = ACTIONS(2668),
    [sym_kSaveregisters] = ACTIONS(2668),
    [sym_kSysv_abi_default] = ACTIONS(2668),
    [sym_kSysv_abi_cdecl] = ACTIONS(2668),
    [sym_kVectorcall] = ACTIONS(2668),
    [sym_kVarargs] = ACTIONS(2668),
    [sym_kWinapi] = ACTIONS(2668),
    [sym_kAlias] = ACTIONS(2668),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [503] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(493),
    [anon_sym_LBRACK] = ACTIONS(2898),
    [aux_sym_type_token1] = ACTIONS(1748),
    [sym_kUses] = ACTIONS(1748),
    [sym_kBegin] = ACTIONS(1748),
    [sym_kAsm] = ACTIONS(1748),
    [sym_kVar] = ACTIONS(1750),
    [sym_kThreadvar] = ACTIONS(1748),
    [sym_kConst] = ACTIONS(1750),
    [sym_kResourcestring] = ACTIONS(1748),
    [sym_kType] = ACTIONS(1748),
    [sym_kLabel] = ACTIONS(1748),
    [sym_kExports] = ACTIONS(1748),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1748),
    [sym_kGeneric] = ACTIONS(1748),
    [sym_kFunction] = ACTIONS(1748),
    [sym_kProcedure] = ACTIONS(1748),
    [sym_kConstructor] = ACTIONS(1748),
    [sym_kDestructor] = ACTIONS(1748),
    [sym_kOperator] = ACTIONS(1748),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [504] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(515),
    [anon_sym_LBRACK] = ACTIONS(2901),
    [aux_sym_type_token1] = ACTIONS(1755),
    [sym_kUses] = ACTIONS(1755),
    [sym_kBegin] = ACTIONS(1755),
    [sym_kAsm] = ACTIONS(1755),
    [sym_kVar] = ACTIONS(1757),
    [sym_kThreadvar] = ACTIONS(1755),
    [sym_kConst] = ACTIONS(1757),
    [sym_kResourcestring] = ACTIONS(1755),
    [sym_kType] = ACTIONS(1755),
    [sym_kLabel] = ACTIONS(1755),
    [sym_kExports] = ACTIONS(1755),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1755),
    [sym_kGeneric] = ACTIONS(1755),
    [sym_kFunction] = ACTIONS(1755),
    [sym_kProcedure] = ACTIONS(1755),
    [sym_kConstructor] = ACTIONS(1755),
    [sym_kDestructor] = ACTIONS(1755),
    [sym_kOperator] = ACTIONS(1755),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [505] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(496),
    [anon_sym_LBRACK] = ACTIONS(2904),
    [aux_sym_type_token1] = ACTIONS(1762),
    [sym_kUses] = ACTIONS(1762),
    [sym_kBegin] = ACTIONS(1762),
    [sym_kAsm] = ACTIONS(1762),
    [sym_kVar] = ACTIONS(1764),
    [sym_kThreadvar] = ACTIONS(1762),
    [sym_kConst] = ACTIONS(1764),
    [sym_kResourcestring] = ACTIONS(1762),
    [sym_kType] = ACTIONS(1762),
    [sym_kLabel] = ACTIONS(1762),
    [sym_kExports] = ACTIONS(1762),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1762),
    [sym_kGeneric] = ACTIONS(1762),
    [sym_kFunction] = ACTIONS(1762),
    [sym_kProcedure] = ACTIONS(1762),
    [sym_kConstructor] = ACTIONS(1762),
    [sym_kDestructor] = ACTIONS(1762),
    [sym_kOperator] = ACTIONS(1762),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [506] = {
    [sym_identifier] = ACTIONS(2907),
    [anon_sym_SEMI] = ACTIONS(2909),
    [anon_sym_COLON] = ACTIONS(2907),
    [anon_sym_COMMA] = ACTIONS(2909),
    [anon_sym_LBRACK] = ACTIONS(2909),
    [anon_sym_RBRACK] = ACTIONS(2909),
    [anon_sym_LPAREN] = ACTIONS(2907),
    [anon_sym_RPAREN] = ACTIONS(2909),
    [anon_sym_DOT_DOT] = ACTIONS(2909),
    [anon_sym_DOT] = ACTIONS(2907),
    [sym_kEnd] = ACTIONS(2907),
    [sym_kVar] = ACTIONS(2907),
    [sym_kThreadvar] = ACTIONS(2907),
    [sym_kConst] = ACTIONS(2907),
    [sym_kResourcestring] = ACTIONS(2907),
    [sym_kType] = ACTIONS(2907),
    [sym_kAbsolute] = ACTIONS(2907),
    [sym_kProperty] = ACTIONS(2907),
    [sym_kClass] = ACTIONS(2907),
    [sym_kOf] = ACTIONS(2907),
    [sym_kGeneric] = ACTIONS(2907),
    [sym_kLt] = ACTIONS(2907),
    [sym_kEq] = ACTIONS(2909),
    [sym_kNeq] = ACTIONS(2909),
    [sym_kGt] = ACTIONS(2907),
    [sym_kLte] = ACTIONS(2909),
    [sym_kGte] = ACTIONS(2909),
    [sym_kAdd] = ACTIONS(2907),
    [sym_kSub] = ACTIONS(2907),
    [sym_kMul] = ACTIONS(2907),
    [sym_kFdiv] = ACTIONS(2907),
    [sym_kHat] = ACTIONS(2909),
    [sym_kAssign] = ACTIONS(2909),
    [sym_kAssignAdd] = ACTIONS(2909),
    [sym_kAssignSub] = ACTIONS(2909),
    [sym_kAssignMul] = ACTIONS(2909),
    [sym_kAssignDiv] = ACTIONS(2909),
    [sym_kOr] = ACTIONS(2907),
    [sym_kXor] = ACTIONS(2907),
    [sym_kDiv] = ACTIONS(2907),
    [sym_kMod] = ACTIONS(2907),
    [sym_kAnd] = ACTIONS(2907),
    [sym_kShl] = ACTIONS(2907),
    [sym_kShr] = ACTIONS(2907),
    [sym_kIs] = ACTIONS(2907),
    [sym_kAs] = ACTIONS(2907),
    [sym_kIn] = ACTIONS(2907),
    [sym_kThen] = ACTIONS(2907),
    [sym_kElse] = ACTIONS(2907),
    [sym_kDo] = ACTIONS(2907),
    [sym_kUntil] = ACTIONS(2907),
    [sym_kExcept] = ACTIONS(2907),
    [sym_kFinally] = ACTIONS(2907),
    [sym_kCase] = ACTIONS(2907),
    [sym_kFunction] = ACTIONS(2907),
    [sym_kProcedure] = ACTIONS(2907),
    [sym_kConstructor] = ACTIONS(2907),
    [sym_kDestructor] = ACTIONS(2907),
    [sym_kOperator] = ACTIONS(2907),
    [sym_kPublished] = ACTIONS(2907),
    [sym_kPublic] = ACTIONS(2907),
    [sym_kProtected] = ACTIONS(2907),
    [sym_kPrivate] = ACTIONS(2907),
    [sym_kStrict] = ACTIONS(2907),
    [sym_kRequired] = ACTIONS(2907),
    [sym_kOptional] = ACTIONS(2907),
    [sym_kDelayed] = ACTIONS(2907),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [507] = {
    [anon_sym_LBRACK] = ACTIONS(2664),
    [sym_kEnd] = ACTIONS(2664),
    [sym_kVar] = ACTIONS(2666),
    [sym_kThreadvar] = ACTIONS(2664),
    [sym_kConst] = ACTIONS(2666),
    [sym_kResourcestring] = ACTIONS(2664),
    [sym_kType] = ACTIONS(2664),
    [sym_kProperty] = ACTIONS(2664),
    [sym_kDefault] = ACTIONS(2664),
    [sym_kNodefault] = ACTIONS(2664),
    [sym_kDispId] = ACTIONS(2664),
    [sym_kClass] = ACTIONS(2664),
    [sym_kGeneric] = ACTIONS(2664),
    [sym_kCase] = ACTIONS(2664),
    [sym_kFunction] = ACTIONS(2664),
    [sym_kProcedure] = ACTIONS(2664),
    [sym_kConstructor] = ACTIONS(2664),
    [sym_kDestructor] = ACTIONS(2664),
    [sym_kOperator] = ACTIONS(2664),
    [sym_kPublished] = ACTIONS(2664),
    [sym_kPublic] = ACTIONS(2664),
    [sym_kProtected] = ACTIONS(2664),
    [sym_kPrivate] = ACTIONS(2664),
    [sym_kStrict] = ACTIONS(2664),
    [sym_kRequired] = ACTIONS(2664),
    [sym_kOptional] = ACTIONS(2664),
    [sym_kStatic] = ACTIONS(2664),
    [sym_kVirtual] = ACTIONS(2664),
    [sym_kAbstract] = ACTIONS(2664),
    [sym_kDynamic] = ACTIONS(2664),
    [sym_kOverride] = ACTIONS(2664),
    [sym_kOverload] = ACTIONS(2664),
    [sym_kReintroduce] = ACTIONS(2664),
    [sym_kInline] = ACTIONS(2664),
    [sym_kStdcall] = ACTIONS(2664),
    [sym_kCdecl] = ACTIONS(2664),
    [sym_kCppdecl] = ACTIONS(2664),
    [sym_kPascal] = ACTIONS(2664),
    [sym_kRegister] = ACTIONS(2664),
    [sym_kMwpascal] = ACTIONS(2664),
    [sym_kMessage] = ACTIONS(2664),
    [sym_kDeprecated] = ACTIONS(2664),
    [sym_kExperimental] = ACTIONS(2664),
    [sym_kPlatform] = ACTIONS(2664),
    [sym_kUnimplemented] = ACTIONS(2664),
    [sym_kCvar] = ACTIONS(2664),
    [sym_kExport] = ACTIONS(2664),
    [sym_kFar] = ACTIONS(2664),
    [sym_kNear] = ACTIONS(2664),
    [sym_kSafecall] = ACTIONS(2664),
    [sym_kAssembler] = ACTIONS(2664),
    [sym_kNostackframe] = ACTIONS(2664),
    [sym_kInterrupt] = ACTIONS(2664),
    [sym_kNoreturn] = ACTIONS(2664),
    [sym_kIocheck] = ACTIONS(2664),
    [sym_kLocal] = ACTIONS(2664),
    [sym_kHardfloat] = ACTIONS(2664),
    [sym_kSoftfloat] = ACTIONS(2664),
    [sym_kMs_abi_default] = ACTIONS(2664),
    [sym_kMs_abi_cdecl] = ACTIONS(2664),
    [sym_kSaveregisters] = ACTIONS(2664),
    [sym_kSysv_abi_default] = ACTIONS(2664),
    [sym_kSysv_abi_cdecl] = ACTIONS(2664),
    [sym_kVectorcall] = ACTIONS(2664),
    [sym_kVarargs] = ACTIONS(2664),
    [sym_kWinapi] = ACTIONS(2664),
    [sym_kAlias] = ACTIONS(2664),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [508] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2911),
    [aux_sym_type_token1] = ACTIONS(1958),
    [sym_kUses] = ACTIONS(1958),
    [sym_kBegin] = ACTIONS(1958),
    [sym_kAsm] = ACTIONS(1958),
    [sym_kVar] = ACTIONS(1960),
    [sym_kThreadvar] = ACTIONS(1958),
    [sym_kConst] = ACTIONS(1960),
    [sym_kResourcestring] = ACTIONS(1958),
    [sym_kType] = ACTIONS(1958),
    [sym_kLabel] = ACTIONS(1958),
    [sym_kExports] = ACTIONS(1958),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1958),
    [sym_kGeneric] = ACTIONS(1958),
    [sym_kFunction] = ACTIONS(1958),
    [sym_kProcedure] = ACTIONS(1958),
    [sym_kConstructor] = ACTIONS(1958),
    [sym_kDestructor] = ACTIONS(1958),
    [sym_kOperator] = ACTIONS(1958),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [509] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2914),
    [aux_sym_type_token1] = ACTIONS(1909),
    [sym_kUses] = ACTIONS(1909),
    [sym_kBegin] = ACTIONS(1909),
    [sym_kAsm] = ACTIONS(1909),
    [sym_kVar] = ACTIONS(1911),
    [sym_kThreadvar] = ACTIONS(1909),
    [sym_kConst] = ACTIONS(1911),
    [sym_kResourcestring] = ACTIONS(1909),
    [sym_kType] = ACTIONS(1909),
    [sym_kLabel] = ACTIONS(1909),
    [sym_kExports] = ACTIONS(1909),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1909),
    [sym_kGeneric] = ACTIONS(1909),
    [sym_kFunction] = ACTIONS(1909),
    [sym_kProcedure] = ACTIONS(1909),
    [sym_kConstructor] = ACTIONS(1909),
    [sym_kDestructor] = ACTIONS(1909),
    [sym_kOperator] = ACTIONS(1909),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [510] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2917),
    [aux_sym_type_token1] = ACTIONS(1916),
    [sym_kUses] = ACTIONS(1916),
    [sym_kBegin] = ACTIONS(1916),
    [sym_kAsm] = ACTIONS(1916),
    [sym_kVar] = ACTIONS(1918),
    [sym_kThreadvar] = ACTIONS(1916),
    [sym_kConst] = ACTIONS(1918),
    [sym_kResourcestring] = ACTIONS(1916),
    [sym_kType] = ACTIONS(1916),
    [sym_kLabel] = ACTIONS(1916),
    [sym_kExports] = ACTIONS(1916),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1916),
    [sym_kGeneric] = ACTIONS(1916),
    [sym_kFunction] = ACTIONS(1916),
    [sym_kProcedure] = ACTIONS(1916),
    [sym_kConstructor] = ACTIONS(1916),
    [sym_kDestructor] = ACTIONS(1916),
    [sym_kOperator] = ACTIONS(1916),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [511] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(488),
    [anon_sym_LBRACK] = ACTIONS(2920),
    [aux_sym_type_token1] = ACTIONS(1923),
    [sym_kUses] = ACTIONS(1923),
    [sym_kBegin] = ACTIONS(1923),
    [sym_kAsm] = ACTIONS(1923),
    [sym_kVar] = ACTIONS(1925),
    [sym_kThreadvar] = ACTIONS(1923),
    [sym_kConst] = ACTIONS(1925),
    [sym_kResourcestring] = ACTIONS(1923),
    [sym_kType] = ACTIONS(1923),
    [sym_kLabel] = ACTIONS(1923),
    [sym_kExports] = ACTIONS(1923),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1923),
    [sym_kGeneric] = ACTIONS(1923),
    [sym_kFunction] = ACTIONS(1923),
    [sym_kProcedure] = ACTIONS(1923),
    [sym_kConstructor] = ACTIONS(1923),
    [sym_kDestructor] = ACTIONS(1923),
    [sym_kOperator] = ACTIONS(1923),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [512] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2923),
    [aux_sym_type_token1] = ACTIONS(1930),
    [sym_kUses] = ACTIONS(1930),
    [sym_kBegin] = ACTIONS(1930),
    [sym_kAsm] = ACTIONS(1930),
    [sym_kVar] = ACTIONS(1932),
    [sym_kThreadvar] = ACTIONS(1930),
    [sym_kConst] = ACTIONS(1932),
    [sym_kResourcestring] = ACTIONS(1930),
    [sym_kType] = ACTIONS(1930),
    [sym_kLabel] = ACTIONS(1930),
    [sym_kExports] = ACTIONS(1930),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1930),
    [sym_kGeneric] = ACTIONS(1930),
    [sym_kFunction] = ACTIONS(1930),
    [sym_kProcedure] = ACTIONS(1930),
    [sym_kConstructor] = ACTIONS(1930),
    [sym_kDestructor] = ACTIONS(1930),
    [sym_kOperator] = ACTIONS(1930),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [513] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(489),
    [anon_sym_LBRACK] = ACTIONS(2926),
    [aux_sym_type_token1] = ACTIONS(1937),
    [sym_kUses] = ACTIONS(1937),
    [sym_kBegin] = ACTIONS(1937),
    [sym_kAsm] = ACTIONS(1937),
    [sym_kVar] = ACTIONS(1939),
    [sym_kThreadvar] = ACTIONS(1937),
    [sym_kConst] = ACTIONS(1939),
    [sym_kResourcestring] = ACTIONS(1937),
    [sym_kType] = ACTIONS(1937),
    [sym_kLabel] = ACTIONS(1937),
    [sym_kExports] = ACTIONS(1937),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1937),
    [sym_kGeneric] = ACTIONS(1937),
    [sym_kFunction] = ACTIONS(1937),
    [sym_kProcedure] = ACTIONS(1937),
    [sym_kConstructor] = ACTIONS(1937),
    [sym_kDestructor] = ACTIONS(1937),
    [sym_kOperator] = ACTIONS(1937),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [514] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(490),
    [anon_sym_LBRACK] = ACTIONS(2929),
    [aux_sym_type_token1] = ACTIONS(1944),
    [sym_kUses] = ACTIONS(1944),
    [sym_kBegin] = ACTIONS(1944),
    [sym_kAsm] = ACTIONS(1944),
    [sym_kVar] = ACTIONS(1946),
    [sym_kThreadvar] = ACTIONS(1944),
    [sym_kConst] = ACTIONS(1946),
    [sym_kResourcestring] = ACTIONS(1944),
    [sym_kType] = ACTIONS(1944),
    [sym_kLabel] = ACTIONS(1944),
    [sym_kExports] = ACTIONS(1944),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1944),
    [sym_kGeneric] = ACTIONS(1944),
    [sym_kFunction] = ACTIONS(1944),
    [sym_kProcedure] = ACTIONS(1944),
    [sym_kConstructor] = ACTIONS(1944),
    [sym_kDestructor] = ACTIONS(1944),
    [sym_kOperator] = ACTIONS(1944),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [515] = {
    [sym__procAttributeNoExt] = STATE(527),
    [sym_procAttribute] = STATE(2580),
    [aux_sym__declProc_repeat1] = STATE(463),
    [anon_sym_LBRACK] = ACTIONS(2932),
    [aux_sym_type_token1] = ACTIONS(1839),
    [sym_kUses] = ACTIONS(1839),
    [sym_kBegin] = ACTIONS(1839),
    [sym_kAsm] = ACTIONS(1839),
    [sym_kVar] = ACTIONS(1841),
    [sym_kThreadvar] = ACTIONS(1839),
    [sym_kConst] = ACTIONS(1841),
    [sym_kResourcestring] = ACTIONS(1839),
    [sym_kType] = ACTIONS(1839),
    [sym_kLabel] = ACTIONS(1839),
    [sym_kExports] = ACTIONS(1839),
    [sym_kDefault] = ACTIONS(819),
    [sym_kNodefault] = ACTIONS(819),
    [sym_kDispId] = ACTIONS(821),
    [sym_kClass] = ACTIONS(1839),
    [sym_kGeneric] = ACTIONS(1839),
    [sym_kFunction] = ACTIONS(1839),
    [sym_kProcedure] = ACTIONS(1839),
    [sym_kConstructor] = ACTIONS(1839),
    [sym_kDestructor] = ACTIONS(1839),
    [sym_kOperator] = ACTIONS(1839),
    [sym_kPublic] = ACTIONS(823),
    [sym_kStatic] = ACTIONS(819),
    [sym_kVirtual] = ACTIONS(819),
    [sym_kAbstract] = ACTIONS(819),
    [sym_kDynamic] = ACTIONS(819),
    [sym_kOverride] = ACTIONS(819),
    [sym_kOverload] = ACTIONS(819),
    [sym_kReintroduce] = ACTIONS(819),
    [sym_kInline] = ACTIONS(819),
    [sym_kStdcall] = ACTIONS(819),
    [sym_kCdecl] = ACTIONS(819),
    [sym_kCppdecl] = ACTIONS(819),
    [sym_kPascal] = ACTIONS(819),
    [sym_kRegister] = ACTIONS(819),
    [sym_kMwpascal] = ACTIONS(819),
    [sym_kMessage] = ACTIONS(825),
    [sym_kDeprecated] = ACTIONS(827),
    [sym_kExperimental] = ACTIONS(819),
    [sym_kPlatform] = ACTIONS(819),
    [sym_kUnimplemented] = ACTIONS(819),
    [sym_kCvar] = ACTIONS(819),
    [sym_kExport] = ACTIONS(330),
    [sym_kFar] = ACTIONS(819),
    [sym_kNear] = ACTIONS(819),
    [sym_kSafecall] = ACTIONS(819),
    [sym_kAssembler] = ACTIONS(819),
    [sym_kNostackframe] = ACTIONS(819),
    [sym_kInterrupt] = ACTIONS(819),
    [sym_kNoreturn] = ACTIONS(819),
    [sym_kIocheck] = ACTIONS(819),
    [sym_kLocal] = ACTIONS(819),
    [sym_kHardfloat] = ACTIONS(819),
    [sym_kSoftfloat] = ACTIONS(819),
    [sym_kMs_abi_default] = ACTIONS(819),
    [sym_kMs_abi_cdecl] = ACTIONS(819),
    [sym_kSaveregisters] = ACTIONS(819),
    [sym_kSysv_abi_default] = ACTIONS(819),
    [sym_kSysv_abi_cdecl] = ACTIONS(819),
    [sym_kVectorcall] = ACTIONS(819),
    [sym_kVarargs] = ACTIONS(819),
    [sym_kWinapi] = ACTIONS(819),
    [sym_kAlias] = ACTIONS(829),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [516] = {
    [sym_identifier] = ACTIONS(2935),
    [anon_sym_SEMI] = ACTIONS(2937),
    [anon_sym_COLON] = ACTIONS(2935),
    [anon_sym_COMMA] = ACTIONS(2937),
    [anon_sym_LBRACK] = ACTIONS(2937),
    [anon_sym_RBRACK] = ACTIONS(2937),
    [anon_sym_LPAREN] = ACTIONS(2935),
    [anon_sym_RPAREN] = ACTIONS(2937),
    [anon_sym_DOT] = ACTIONS(2937),
    [sym_kEnd] = ACTIONS(2935),
    [sym_kVar] = ACTIONS(2935),
    [sym_kThreadvar] = ACTIONS(2935),
    [sym_kConst] = ACTIONS(2935),
    [sym_kResourcestring] = ACTIONS(2935),
    [sym_kType] = ACTIONS(2935),
    [sym_kAbsolute] = ACTIONS(2935),
    [sym_kProperty] = ACTIONS(2935),
    [sym_kClass] = ACTIONS(2935),
    [sym_kOf] = ACTIONS(2935),
    [sym_kGeneric] = ACTIONS(2935),
    [sym_kLt] = ACTIONS(2935),
    [sym_kEq] = ACTIONS(2937),
    [sym_kNeq] = ACTIONS(2937),
    [sym_kGt] = ACTIONS(2935),
    [sym_kLte] = ACTIONS(2937),
    [sym_kGte] = ACTIONS(2937),
    [sym_kAdd] = ACTIONS(2935),
    [sym_kSub] = ACTIONS(2935),
    [sym_kMul] = ACTIONS(2935),
    [sym_kFdiv] = ACTIONS(2935),
    [sym_kHat] = ACTIONS(2937),
    [sym_kAssign] = ACTIONS(2937),
    [sym_kAssignAdd] = ACTIONS(2937),
    [sym_kAssignSub] = ACTIONS(2937),
    [sym_kAssignMul] = ACTIONS(2937),
    [sym_kAssignDiv] = ACTIONS(2937),
    [sym_kOr] = ACTIONS(2935),
    [sym_kXor] = ACTIONS(2935),
    [sym_kDiv] = ACTIONS(2935),
    [sym_kMod] = ACTIONS(2935),
    [sym_kAnd] = ACTIONS(2935),
    [sym_kShl] = ACTIONS(2935),
    [sym_kShr] = ACTIONS(2935),
    [sym_kIs] = ACTIONS(2935),
    [sym_kAs] = ACTIONS(2935),
    [sym_kIn] = ACTIONS(2935),
    [sym_kThen] = ACTIONS(2935),
    [sym_kElse] = ACTIONS(2935),
    [sym_kDo] = ACTIONS(2935),
    [sym_kUntil] = ACTIONS(2935),
    [sym_kExcept] = ACTIONS(2935),
    [sym_kFinally] = ACTIONS(2935),
    [sym_kCase] = ACTIONS(2935),
    [sym_kFunction] = ACTIONS(2935),
    [sym_kProcedure] = ACTIONS(2935),
    [sym_kConstructor] = ACTIONS(2935),
    [sym_kDestructor] = ACTIONS(2935),
    [sym_kOperator] = ACTIONS(2935),
    [sym_kPublished] = ACTIONS(2935),
    [sym_kPublic] = ACTIONS(2935),
    [sym_kProtected] = ACTIONS(2935),
    [sym_kPrivate] = ACTIONS(2935),
    [sym_kStrict] = ACTIONS(2935),
    [sym_kRequired] = ACTIONS(2935),
    [sym_kOptional] = ACTIONS(2935),
    [sym_kDelayed] = ACTIONS(2935),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [517] = {
    [sym_identifier] = ACTIONS(2939),
    [anon_sym_SEMI] = ACTIONS(2941),
    [anon_sym_COLON] = ACTIONS(2939),
    [anon_sym_COMMA] = ACTIONS(2941),
    [anon_sym_LBRACK] = ACTIONS(2941),
    [anon_sym_RBRACK] = ACTIONS(2941),
    [anon_sym_LPAREN] = ACTIONS(2939),
    [anon_sym_RPAREN] = ACTIONS(2941),
    [anon_sym_DOT] = ACTIONS(2941),
    [sym_kEnd] = ACTIONS(2939),
    [sym_kVar] = ACTIONS(2939),
    [sym_kThreadvar] = ACTIONS(2939),
    [sym_kConst] = ACTIONS(2939),
    [sym_kResourcestring] = ACTIONS(2939),
    [sym_kType] = ACTIONS(2939),
    [sym_kAbsolute] = ACTIONS(2939),
    [sym_kProperty] = ACTIONS(2939),
    [sym_kClass] = ACTIONS(2939),
    [sym_kOf] = ACTIONS(2939),
    [sym_kGeneric] = ACTIONS(2939),
    [sym_kLt] = ACTIONS(2939),
    [sym_kEq] = ACTIONS(2941),
    [sym_kNeq] = ACTIONS(2941),
    [sym_kGt] = ACTIONS(2939),
    [sym_kLte] = ACTIONS(2941),
    [sym_kGte] = ACTIONS(2941),
    [sym_kAdd] = ACTIONS(2939),
    [sym_kSub] = ACTIONS(2939),
    [sym_kMul] = ACTIONS(2939),
    [sym_kFdiv] = ACTIONS(2939),
    [sym_kHat] = ACTIONS(2941),
    [sym_kAssign] = ACTIONS(2941),
    [sym_kAssignAdd] = ACTIONS(2941),
    [sym_kAssignSub] = ACTIONS(2941),
    [sym_kAssignMul] = ACTIONS(2941),
    [sym_kAssignDiv] = ACTIONS(2941),
    [sym_kOr] = ACTIONS(2939),
    [sym_kXor] = ACTIONS(2939),
    [sym_kDiv] = ACTIONS(2939),
    [sym_kMod] = ACTIONS(2939),
    [sym_kAnd] = ACTIONS(2939),
    [sym_kShl] = ACTIONS(2939),
    [sym_kShr] = ACTIONS(2939),
    [sym_kIs] = ACTIONS(2939),
    [sym_kAs] = ACTIONS(2939),
    [sym_kIn] = ACTIONS(2939),
    [sym_kThen] = ACTIONS(2939),
    [sym_kElse] = ACTIONS(2939),
    [sym_kDo] = ACTIONS(2939),
    [sym_kUntil] = ACTIONS(2939),
    [sym_kExcept] = ACTIONS(2939),
    [sym_kFinally] = ACTIONS(2939),
    [sym_kCase] = ACTIONS(2939),
    [sym_kFunction] = ACTIONS(2939),
    [sym_kProcedure] = ACTIONS(2939),
    [sym_kConstructor] = ACTIONS(2939),
    [sym_kDestructor] = ACTIONS(2939),
    [sym_kOperator] = ACTIONS(2939),
    [sym_kPublished] = ACTIONS(2939),
    [sym_kPublic] = ACTIONS(2939),
    [sym_kProtected] = ACTIONS(2939),
    [sym_kPrivate] = ACTIONS(2939),
    [sym_kStrict] = ACTIONS(2939),
    [sym_kRequired] = ACTIONS(2939),
    [sym_kOptional] = ACTIONS(2939),
    [sym_kDelayed] = ACTIONS(2939),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [518] = {
    [sym_identifier] = ACTIONS(2943),
    [anon_sym_SEMI] = ACTIONS(2945),
    [anon_sym_COLON] = ACTIONS(2943),
    [anon_sym_COMMA] = ACTIONS(2945),
    [anon_sym_LBRACK] = ACTIONS(2945),
    [anon_sym_RBRACK] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2943),
    [anon_sym_RPAREN] = ACTIONS(2945),
    [anon_sym_DOT] = ACTIONS(2945),
    [sym_kEnd] = ACTIONS(2943),
    [sym_kVar] = ACTIONS(2943),
    [sym_kThreadvar] = ACTIONS(2943),
    [sym_kConst] = ACTIONS(2943),
    [sym_kResourcestring] = ACTIONS(2943),
    [sym_kType] = ACTIONS(2943),
    [sym_kAbsolute] = ACTIONS(2943),
    [sym_kProperty] = ACTIONS(2943),
    [sym_kClass] = ACTIONS(2943),
    [sym_kOf] = ACTIONS(2943),
    [sym_kGeneric] = ACTIONS(2943),
    [sym_kLt] = ACTIONS(2943),
    [sym_kEq] = ACTIONS(2945),
    [sym_kNeq] = ACTIONS(2945),
    [sym_kGt] = ACTIONS(2943),
    [sym_kLte] = ACTIONS(2945),
    [sym_kGte] = ACTIONS(2945),
    [sym_kAdd] = ACTIONS(2943),
    [sym_kSub] = ACTIONS(2943),
    [sym_kMul] = ACTIONS(2943),
    [sym_kFdiv] = ACTIONS(2943),
    [sym_kHat] = ACTIONS(2945),
    [sym_kAssign] = ACTIONS(2945),
    [sym_kAssignAdd] = ACTIONS(2945),
    [sym_kAssignSub] = ACTIONS(2945),
    [sym_kAssignMul] = ACTIONS(2945),
    [sym_kAssignDiv] = ACTIONS(2945),
    [sym_kOr] = ACTIONS(2943),
    [sym_kXor] = ACTIONS(2943),
    [sym_kDiv] = ACTIONS(2943),
    [sym_kMod] = ACTIONS(2943),
    [sym_kAnd] = ACTIONS(2943),
    [sym_kShl] = ACTIONS(2943),
    [sym_kShr] = ACTIONS(2943),
    [sym_kIs] = ACTIONS(2943),
    [sym_kAs] = ACTIONS(2943),
    [sym_kIn] = ACTIONS(2943),
    [sym_kThen] = ACTIONS(2943),
    [sym_kElse] = ACTIONS(2943),
    [sym_kDo] = ACTIONS(2943),
    [sym_kUntil] = ACTIONS(2943),
    [sym_kExcept] = ACTIONS(2943),
    [sym_kFinally] = ACTIONS(2943),
    [sym_kCase] = ACTIONS(2943),
    [sym_kFunction] = ACTIONS(2943),
    [sym_kProcedure] = ACTIONS(2943),
    [sym_kConstructor] = ACTIONS(2943),
    [sym_kDestructor] = ACTIONS(2943),
    [sym_kOperator] = ACTIONS(2943),
    [sym_kPublished] = ACTIONS(2943),
    [sym_kPublic] = ACTIONS(2943),
    [sym_kProtected] = ACTIONS(2943),
    [sym_kPrivate] = ACTIONS(2943),
    [sym_kStrict] = ACTIONS(2943),
    [sym_kRequired] = ACTIONS(2943),
    [sym_kOptional] = ACTIONS(2943),
    [sym_kDelayed] = ACTIONS(2943),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [519] = {
    [sym_identifier] = ACTIONS(2947),
    [anon_sym_SEMI] = ACTIONS(2949),
    [anon_sym_COLON] = ACTIONS(2947),
    [anon_sym_COMMA] = ACTIONS(2949),
    [anon_sym_LBRACK] = ACTIONS(2949),
    [anon_sym_RBRACK] = ACTIONS(2949),
    [anon_sym_LPAREN] = ACTIONS(2947),
    [anon_sym_RPAREN] = ACTIONS(2949),
    [anon_sym_DOT] = ACTIONS(2949),
    [sym_kEnd] = ACTIONS(2947),
    [sym_kVar] = ACTIONS(2947),
    [sym_kThreadvar] = ACTIONS(2947),
    [sym_kConst] = ACTIONS(2947),
    [sym_kResourcestring] = ACTIONS(2947),
    [sym_kType] = ACTIONS(2947),
    [sym_kAbsolute] = ACTIONS(2947),
    [sym_kProperty] = ACTIONS(2947),
    [sym_kClass] = ACTIONS(2947),
    [sym_kOf] = ACTIONS(2947),
    [sym_kGeneric] = ACTIONS(2947),
    [sym_kLt] = ACTIONS(2947),
    [sym_kEq] = ACTIONS(2949),
    [sym_kNeq] = ACTIONS(2949),
    [sym_kGt] = ACTIONS(2947),
    [sym_kLte] = ACTIONS(2949),
    [sym_kGte] = ACTIONS(2949),
    [sym_kAdd] = ACTIONS(2947),
    [sym_kSub] = ACTIONS(2947),
    [sym_kMul] = ACTIONS(2947),
    [sym_kFdiv] = ACTIONS(2947),
    [sym_kHat] = ACTIONS(2949),
    [sym_kAssign] = ACTIONS(2949),
    [sym_kAssignAdd] = ACTIONS(2949),
    [sym_kAssignSub] = ACTIONS(2949),
    [sym_kAssignMul] = ACTIONS(2949),
    [sym_kAssignDiv] = ACTIONS(2949),
    [sym_kOr] = ACTIONS(2947),
    [sym_kXor] = ACTIONS(2947),
    [sym_kDiv] = ACTIONS(2947),
    [sym_kMod] = ACTIONS(2947),
    [sym_kAnd] = ACTIONS(2947),
    [sym_kShl] = ACTIONS(2947),
    [sym_kShr] = ACTIONS(2947),
    [sym_kIs] = ACTIONS(2947),
    [sym_kAs] = ACTIONS(2947),
    [sym_kIn] = ACTIONS(2947),
    [sym_kThen] = ACTIONS(2947),
    [sym_kElse] = ACTIONS(2947),
    [sym_kDo] = ACTIONS(2947),
    [sym_kUntil] = ACTIONS(2947),
    [sym_kExcept] = ACTIONS(2947),
    [sym_kFinally] = ACTIONS(2947),
    [sym_kCase] = ACTIONS(2947),
    [sym_kFunction] = ACTIONS(2947),
    [sym_kProcedure] = ACTIONS(2947),
    [sym_kConstructor] = ACTIONS(2947),
    [sym_kDestructor] = ACTIONS(2947),
    [sym_kOperator] = ACTIONS(2947),
    [sym_kPublished] = ACTIONS(2947),
    [sym_kPublic] = ACTIONS(2947),
    [sym_kProtected] = ACTIONS(2947),
    [sym_kPrivate] = ACTIONS(2947),
    [sym_kStrict] = ACTIONS(2947),
    [sym_kRequired] = ACTIONS(2947),
    [sym_kOptional] = ACTIONS(2947),
    [sym_kDelayed] = ACTIONS(2947),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [520] = {
    [anon_sym_LBRACK] = ACTIONS(2664),
    [aux_sym_type_token1] = ACTIONS(2664),
    [sym_kUses] = ACTIONS(2664),
    [sym_kBegin] = ACTIONS(2664),
    [sym_kAsm] = ACTIONS(2664),
    [sym_kVar] = ACTIONS(2666),
    [sym_kThreadvar] = ACTIONS(2664),
    [sym_kConst] = ACTIONS(2666),
    [sym_kResourcestring] = ACTIONS(2664),
    [sym_kType] = ACTIONS(2664),
    [sym_kLabel] = ACTIONS(2664),
    [sym_kExports] = ACTIONS(2664),
    [sym_kDefault] = ACTIONS(2664),
    [sym_kNodefault] = ACTIONS(2664),
    [sym_kDispId] = ACTIONS(2664),
    [sym_kClass] = ACTIONS(2664),
    [sym_kGeneric] = ACTIONS(2664),
    [sym_kFunction] = ACTIONS(2664),
    [sym_kProcedure] = ACTIONS(2664),
    [sym_kConstructor] = ACTIONS(2664),
    [sym_kDestructor] = ACTIONS(2664),
    [sym_kOperator] = ACTIONS(2664),
    [sym_kPublic] = ACTIONS(2664),
    [sym_kForward] = ACTIONS(2664),
    [sym_kStatic] = ACTIONS(2664),
    [sym_kVirtual] = ACTIONS(2664),
    [sym_kAbstract] = ACTIONS(2664),
    [sym_kDynamic] = ACTIONS(2664),
    [sym_kOverride] = ACTIONS(2664),
    [sym_kOverload] = ACTIONS(2664),
    [sym_kReintroduce] = ACTIONS(2664),
    [sym_kInline] = ACTIONS(2664),
    [sym_kStdcall] = ACTIONS(2664),
    [sym_kCdecl] = ACTIONS(2664),
    [sym_kCppdecl] = ACTIONS(2664),
    [sym_kPascal] = ACTIONS(2664),
    [sym_kRegister] = ACTIONS(2664),
    [sym_kMwpascal] = ACTIONS(2664),
    [sym_kExternal] = ACTIONS(2664),
    [sym_kMessage] = ACTIONS(2664),
    [sym_kDeprecated] = ACTIONS(2664),
    [sym_kExperimental] = ACTIONS(2664),
    [sym_kPlatform] = ACTIONS(2664),
    [sym_kUnimplemented] = ACTIONS(2664),
    [sym_kCvar] = ACTIONS(2664),
    [sym_kExport] = ACTIONS(2666),
    [sym_kFar] = ACTIONS(2664),
    [sym_kNear] = ACTIONS(2664),
    [sym_kSafecall] = ACTIONS(2664),
    [sym_kAssembler] = ACTIONS(2664),
    [sym_kNostackframe] = ACTIONS(2664),
    [sym_kInterrupt] = ACTIONS(2664),
    [sym_kNoreturn] = ACTIONS(2664),
    [sym_kIocheck] = ACTIONS(2664),
    [sym_kLocal] = ACTIONS(2664),
    [sym_kHardfloat] = ACTIONS(2664),
    [sym_kSoftfloat] = ACTIONS(2664),
    [sym_kMs_abi_default] = ACTIONS(2664),
    [sym_kMs_abi_cdecl] = ACTIONS(2664),
    [sym_kSaveregisters] = ACTIONS(2664),
    [sym_kSysv_abi_default] = ACTIONS(2664),
    [sym_kSysv_abi_cdecl] = ACTIONS(2664),
    [sym_kVectorcall] = ACTIONS(2664),
    [sym_kVarargs] = ACTIONS(2664),
    [sym_kWinapi] = ACTIONS(2664),
    [sym_kAlias] = ACTIONS(2664),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [521] = {
    [sym_identifier] = ACTIONS(2951),
    [anon_sym_SEMI] = ACTIONS(2953),
    [anon_sym_COLON] = ACTIONS(2951),
    [anon_sym_COMMA] = ACTIONS(2953),
    [anon_sym_LBRACK] = ACTIONS(2953),
    [anon_sym_RBRACK] = ACTIONS(2953),
    [anon_sym_LPAREN] = ACTIONS(2951),
    [anon_sym_RPAREN] = ACTIONS(2953),
    [anon_sym_DOT] = ACTIONS(2953),
    [sym_kEnd] = ACTIONS(2951),
    [sym_kVar] = ACTIONS(2951),
    [sym_kThreadvar] = ACTIONS(2951),
    [sym_kConst] = ACTIONS(2951),
    [sym_kResourcestring] = ACTIONS(2951),
    [sym_kType] = ACTIONS(2951),
    [sym_kAbsolute] = ACTIONS(2951),
    [sym_kProperty] = ACTIONS(2951),
    [sym_kClass] = ACTIONS(2951),
    [sym_kOf] = ACTIONS(2951),
    [sym_kGeneric] = ACTIONS(2951),
    [sym_kLt] = ACTIONS(2951),
    [sym_kEq] = ACTIONS(2953),
    [sym_kNeq] = ACTIONS(2953),
    [sym_kGt] = ACTIONS(2951),
    [sym_kLte] = ACTIONS(2953),
    [sym_kGte] = ACTIONS(2953),
    [sym_kAdd] = ACTIONS(2951),
    [sym_kSub] = ACTIONS(2951),
    [sym_kMul] = ACTIONS(2951),
    [sym_kFdiv] = ACTIONS(2951),
    [sym_kHat] = ACTIONS(2953),
    [sym_kAssign] = ACTIONS(2953),
    [sym_kAssignAdd] = ACTIONS(2953),
    [sym_kAssignSub] = ACTIONS(2953),
    [sym_kAssignMul] = ACTIONS(2953),
    [sym_kAssignDiv] = ACTIONS(2953),
    [sym_kOr] = ACTIONS(2951),
    [sym_kXor] = ACTIONS(2951),
    [sym_kDiv] = ACTIONS(2951),
    [sym_kMod] = ACTIONS(2951),
    [sym_kAnd] = ACTIONS(2951),
    [sym_kShl] = ACTIONS(2951),
    [sym_kShr] = ACTIONS(2951),
    [sym_kIs] = ACTIONS(2951),
    [sym_kAs] = ACTIONS(2951),
    [sym_kIn] = ACTIONS(2951),
    [sym_kThen] = ACTIONS(2951),
    [sym_kElse] = ACTIONS(2951),
    [sym_kDo] = ACTIONS(2951),
    [sym_kUntil] = ACTIONS(2951),
    [sym_kExcept] = ACTIONS(2951),
    [sym_kFinally] = ACTIONS(2951),
    [sym_kCase] = ACTIONS(2951),
    [sym_kFunction] = ACTIONS(2951),
    [sym_kProcedure] = ACTIONS(2951),
    [sym_kConstructor] = ACTIONS(2951),
    [sym_kDestructor] = ACTIONS(2951),
    [sym_kOperator] = ACTIONS(2951),
    [sym_kPublished] = ACTIONS(2951),
    [sym_kPublic] = ACTIONS(2951),
    [sym_kProtected] = ACTIONS(2951),
    [sym_kPrivate] = ACTIONS(2951),
    [sym_kStrict] = ACTIONS(2951),
    [sym_kRequired] = ACTIONS(2951),
    [sym_kOptional] = ACTIONS(2951),
    [sym_kDelayed] = ACTIONS(2951),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [522] = {
    [sym_identifier] = ACTIONS(2955),
    [anon_sym_SEMI] = ACTIONS(2957),
    [anon_sym_COLON] = ACTIONS(2955),
    [anon_sym_COMMA] = ACTIONS(2957),
    [anon_sym_LBRACK] = ACTIONS(2957),
    [anon_sym_RBRACK] = ACTIONS(2957),
    [anon_sym_LPAREN] = ACTIONS(2955),
    [anon_sym_RPAREN] = ACTIONS(2957),
    [anon_sym_DOT] = ACTIONS(2957),
    [sym_kEnd] = ACTIONS(2955),
    [sym_kVar] = ACTIONS(2955),
    [sym_kThreadvar] = ACTIONS(2955),
    [sym_kConst] = ACTIONS(2955),
    [sym_kResourcestring] = ACTIONS(2955),
    [sym_kType] = ACTIONS(2955),
    [sym_kAbsolute] = ACTIONS(2955),
    [sym_kProperty] = ACTIONS(2955),
    [sym_kClass] = ACTIONS(2955),
    [sym_kOf] = ACTIONS(2955),
    [sym_kGeneric] = ACTIONS(2955),
    [sym_kLt] = ACTIONS(2955),
    [sym_kEq] = ACTIONS(2957),
    [sym_kNeq] = ACTIONS(2957),
    [sym_kGt] = ACTIONS(2955),
    [sym_kLte] = ACTIONS(2957),
    [sym_kGte] = ACTIONS(2957),
    [sym_kAdd] = ACTIONS(2955),
    [sym_kSub] = ACTIONS(2955),
    [sym_kMul] = ACTIONS(2955),
    [sym_kFdiv] = ACTIONS(2955),
    [sym_kHat] = ACTIONS(2957),
    [sym_kAssign] = ACTIONS(2957),
    [sym_kAssignAdd] = ACTIONS(2957),
    [sym_kAssignSub] = ACTIONS(2957),
    [sym_kAssignMul] = ACTIONS(2957),
    [sym_kAssignDiv] = ACTIONS(2957),
    [sym_kOr] = ACTIONS(2955),
    [sym_kXor] = ACTIONS(2955),
    [sym_kDiv] = ACTIONS(2955),
    [sym_kMod] = ACTIONS(2955),
    [sym_kAnd] = ACTIONS(2955),
    [sym_kShl] = ACTIONS(2955),
    [sym_kShr] = ACTIONS(2955),
    [sym_kIs] = ACTIONS(2955),
    [sym_kAs] = ACTIONS(2955),
    [sym_kIn] = ACTIONS(2955),
    [sym_kThen] = ACTIONS(2955),
    [sym_kElse] = ACTIONS(2955),
    [sym_kDo] = ACTIONS(2955),
    [sym_kUntil] = ACTIONS(2955),
    [sym_kExcept] = ACTIONS(2955),
    [sym_kFinally] = ACTIONS(2955),
    [sym_kCase] = ACTIONS(2955),
    [sym_kFunction] = ACTIONS(2955),
    [sym_kProcedure] = ACTIONS(2955),
    [sym_kConstructor] = ACTIONS(2955),
    [sym_kDestructor] = ACTIONS(2955),
    [sym_kOperator] = ACTIONS(2955),
    [sym_kPublished] = ACTIONS(2955),
    [sym_kPublic] = ACTIONS(2955),
    [sym_kProtected] = ACTIONS(2955),
    [sym_kPrivate] = ACTIONS(2955),
    [sym_kStrict] = ACTIONS(2955),
    [sym_kRequired] = ACTIONS(2955),
    [sym_kOptional] = ACTIONS(2955),
    [sym_kDelayed] = ACTIONS(2955),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [523] = {
    [sym_identifier] = ACTIONS(2959),
    [anon_sym_SEMI] = ACTIONS(2961),
    [anon_sym_COLON] = ACTIONS(2959),
    [anon_sym_COMMA] = ACTIONS(2961),
    [anon_sym_LBRACK] = ACTIONS(2961),
    [anon_sym_RBRACK] = ACTIONS(2961),
    [anon_sym_LPAREN] = ACTIONS(2959),
    [anon_sym_RPAREN] = ACTIONS(2961),
    [anon_sym_DOT] = ACTIONS(2961),
    [sym_kEnd] = ACTIONS(2959),
    [sym_kVar] = ACTIONS(2959),
    [sym_kThreadvar] = ACTIONS(2959),
    [sym_kConst] = ACTIONS(2959),
    [sym_kResourcestring] = ACTIONS(2959),
    [sym_kType] = ACTIONS(2959),
    [sym_kAbsolute] = ACTIONS(2959),
    [sym_kProperty] = ACTIONS(2959),
    [sym_kClass] = ACTIONS(2959),
    [sym_kOf] = ACTIONS(2959),
    [sym_kGeneric] = ACTIONS(2959),
    [sym_kLt] = ACTIONS(2959),
    [sym_kEq] = ACTIONS(2961),
    [sym_kNeq] = ACTIONS(2961),
    [sym_kGt] = ACTIONS(2959),
    [sym_kLte] = ACTIONS(2961),
    [sym_kGte] = ACTIONS(2961),
    [sym_kAdd] = ACTIONS(2959),
    [sym_kSub] = ACTIONS(2959),
    [sym_kMul] = ACTIONS(2959),
    [sym_kFdiv] = ACTIONS(2959),
    [sym_kHat] = ACTIONS(2961),
    [sym_kAssign] = ACTIONS(2961),
    [sym_kAssignAdd] = ACTIONS(2961),
    [sym_kAssignSub] = ACTIONS(2961),
    [sym_kAssignMul] = ACTIONS(2961),
    [sym_kAssignDiv] = ACTIONS(2961),
    [sym_kOr] = ACTIONS(2959),
    [sym_kXor] = ACTIONS(2959),
    [sym_kDiv] = ACTIONS(2959),
    [sym_kMod] = ACTIONS(2959),
    [sym_kAnd] = ACTIONS(2959),
    [sym_kShl] = ACTIONS(2959),
    [sym_kShr] = ACTIONS(2959),
    [sym_kIs] = ACTIONS(2959),
    [sym_kAs] = ACTIONS(2959),
    [sym_kIn] = ACTIONS(2959),
    [sym_kThen] = ACTIONS(2959),
    [sym_kElse] = ACTIONS(2959),
    [sym_kDo] = ACTIONS(2959),
    [sym_kUntil] = ACTIONS(2959),
    [sym_kExcept] = ACTIONS(2959),
    [sym_kFinally] = ACTIONS(2959),
    [sym_kCase] = ACTIONS(2959),
    [sym_kFunction] = ACTIONS(2959),
    [sym_kProcedure] = ACTIONS(2959),
    [sym_kConstructor] = ACTIONS(2959),
    [sym_kDestructor] = ACTIONS(2959),
    [sym_kOperator] = ACTIONS(2959),
    [sym_kPublished] = ACTIONS(2959),
    [sym_kPublic] = ACTIONS(2959),
    [sym_kProtected] = ACTIONS(2959),
    [sym_kPrivate] = ACTIONS(2959),
    [sym_kStrict] = ACTIONS(2959),
    [sym_kRequired] = ACTIONS(2959),
    [sym_kOptional] = ACTIONS(2959),
    [sym_kDelayed] = ACTIONS(2959),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [524] = {
    [sym_identifier] = ACTIONS(2963),
    [anon_sym_SEMI] = ACTIONS(2965),
    [anon_sym_COLON] = ACTIONS(2963),
    [anon_sym_COMMA] = ACTIONS(2965),
    [anon_sym_LBRACK] = ACTIONS(2965),
    [anon_sym_RBRACK] = ACTIONS(2965),
    [anon_sym_LPAREN] = ACTIONS(2963),
    [anon_sym_RPAREN] = ACTIONS(2965),
    [anon_sym_DOT] = ACTIONS(2965),
    [sym_kEnd] = ACTIONS(2963),
    [sym_kVar] = ACTIONS(2963),
    [sym_kThreadvar] = ACTIONS(2963),
    [sym_kConst] = ACTIONS(2963),
    [sym_kResourcestring] = ACTIONS(2963),
    [sym_kType] = ACTIONS(2963),
    [sym_kAbsolute] = ACTIONS(2963),
    [sym_kProperty] = ACTIONS(2963),
    [sym_kClass] = ACTIONS(2963),
    [sym_kOf] = ACTIONS(2963),
    [sym_kGeneric] = ACTIONS(2963),
    [sym_kLt] = ACTIONS(2963),
    [sym_kEq] = ACTIONS(2965),
    [sym_kNeq] = ACTIONS(2965),
    [sym_kGt] = ACTIONS(2963),
    [sym_kLte] = ACTIONS(2965),
    [sym_kGte] = ACTIONS(2965),
    [sym_kAdd] = ACTIONS(2963),
    [sym_kSub] = ACTIONS(2963),
    [sym_kMul] = ACTIONS(2963),
    [sym_kFdiv] = ACTIONS(2963),
    [sym_kHat] = ACTIONS(2965),
    [sym_kAssign] = ACTIONS(2965),
    [sym_kAssignAdd] = ACTIONS(2965),
    [sym_kAssignSub] = ACTIONS(2965),
    [sym_kAssignMul] = ACTIONS(2965),
    [sym_kAssignDiv] = ACTIONS(2965),
    [sym_kOr] = ACTIONS(2963),
    [sym_kXor] = ACTIONS(2963),
    [sym_kDiv] = ACTIONS(2963),
    [sym_kMod] = ACTIONS(2963),
    [sym_kAnd] = ACTIONS(2963),
    [sym_kShl] = ACTIONS(2963),
    [sym_kShr] = ACTIONS(2963),
    [sym_kIs] = ACTIONS(2963),
    [sym_kAs] = ACTIONS(2963),
    [sym_kIn] = ACTIONS(2963),
    [sym_kThen] = ACTIONS(2963),
    [sym_kElse] = ACTIONS(2963),
    [sym_kDo] = ACTIONS(2963),
    [sym_kUntil] = ACTIONS(2963),
    [sym_kExcept] = ACTIONS(2963),
    [sym_kFinally] = ACTIONS(2963),
    [sym_kCase] = ACTIONS(2963),
    [sym_kFunction] = ACTIONS(2963),
    [sym_kProcedure] = ACTIONS(2963),
    [sym_kConstructor] = ACTIONS(2963),
    [sym_kDestructor] = ACTIONS(2963),
    [sym_kOperator] = ACTIONS(2963),
    [sym_kPublished] = ACTIONS(2963),
    [sym_kPublic] = ACTIONS(2963),
    [sym_kProtected] = ACTIONS(2963),
    [sym_kPrivate] = ACTIONS(2963),
    [sym_kStrict] = ACTIONS(2963),
    [sym_kRequired] = ACTIONS(2963),
    [sym_kOptional] = ACTIONS(2963),
    [sym_kDelayed] = ACTIONS(2963),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [525] = {
    [sym_identifier] = ACTIONS(2967),
    [anon_sym_SEMI] = ACTIONS(2969),
    [anon_sym_COLON] = ACTIONS(2967),
    [anon_sym_COMMA] = ACTIONS(2969),
    [anon_sym_LBRACK] = ACTIONS(2969),
    [anon_sym_RBRACK] = ACTIONS(2969),
    [anon_sym_LPAREN] = ACTIONS(2967),
    [anon_sym_RPAREN] = ACTIONS(2969),
    [anon_sym_DOT] = ACTIONS(2969),
    [sym_kEnd] = ACTIONS(2967),
    [sym_kVar] = ACTIONS(2967),
    [sym_kThreadvar] = ACTIONS(2967),
    [sym_kConst] = ACTIONS(2967),
    [sym_kResourcestring] = ACTIONS(2967),
    [sym_kType] = ACTIONS(2967),
    [sym_kAbsolute] = ACTIONS(2967),
    [sym_kProperty] = ACTIONS(2967),
    [sym_kClass] = ACTIONS(2967),
    [sym_kOf] = ACTIONS(2967),
    [sym_kGeneric] = ACTIONS(2967),
    [sym_kLt] = ACTIONS(2967),
    [sym_kEq] = ACTIONS(2969),
    [sym_kNeq] = ACTIONS(2969),
    [sym_kGt] = ACTIONS(2967),
    [sym_kLte] = ACTIONS(2969),
    [sym_kGte] = ACTIONS(2969),
    [sym_kAdd] = ACTIONS(2967),
    [sym_kSub] = ACTIONS(2967),
    [sym_kMul] = ACTIONS(2967),
    [sym_kFdiv] = ACTIONS(2967),
    [sym_kHat] = ACTIONS(2969),
    [sym_kAssign] = ACTIONS(2969),
    [sym_kAssignAdd] = ACTIONS(2969),
    [sym_kAssignSub] = ACTIONS(2969),
    [sym_kAssignMul] = ACTIONS(2969),
    [sym_kAssignDiv] = ACTIONS(2969),
    [sym_kOr] = ACTIONS(2967),
    [sym_kXor] = ACTIONS(2967),
    [sym_kDiv] = ACTIONS(2967),
    [sym_kMod] = ACTIONS(2967),
    [sym_kAnd] = ACTIONS(2967),
    [sym_kShl] = ACTIONS(2967),
    [sym_kShr] = ACTIONS(2967),
    [sym_kIs] = ACTIONS(2967),
    [sym_kAs] = ACTIONS(2967),
    [sym_kIn] = ACTIONS(2967),
    [sym_kThen] = ACTIONS(2967),
    [sym_kElse] = ACTIONS(2967),
    [sym_kDo] = ACTIONS(2967),
    [sym_kUntil] = ACTIONS(2967),
    [sym_kExcept] = ACTIONS(2967),
    [sym_kFinally] = ACTIONS(2967),
    [sym_kCase] = ACTIONS(2967),
    [sym_kFunction] = ACTIONS(2967),
    [sym_kProcedure] = ACTIONS(2967),
    [sym_kConstructor] = ACTIONS(2967),
    [sym_kDestructor] = ACTIONS(2967),
    [sym_kOperator] = ACTIONS(2967),
    [sym_kPublished] = ACTIONS(2967),
    [sym_kPublic] = ACTIONS(2967),
    [sym_kProtected] = ACTIONS(2967),
    [sym_kPrivate] = ACTIONS(2967),
    [sym_kStrict] = ACTIONS(2967),
    [sym_kRequired] = ACTIONS(2967),
    [sym_kOptional] = ACTIONS(2967),
    [sym_kDelayed] = ACTIONS(2967),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [526] = {
    [sym_identifier] = ACTIONS(2971),
    [anon_sym_SEMI] = ACTIONS(2973),
    [anon_sym_COLON] = ACTIONS(2971),
    [anon_sym_COMMA] = ACTIONS(2973),
    [anon_sym_LBRACK] = ACTIONS(2973),
    [anon_sym_RBRACK] = ACTIONS(2973),
    [anon_sym_LPAREN] = ACTIONS(2971),
    [anon_sym_RPAREN] = ACTIONS(2973),
    [anon_sym_DOT] = ACTIONS(2973),
    [sym_kEnd] = ACTIONS(2971),
    [sym_kVar] = ACTIONS(2971),
    [sym_kThreadvar] = ACTIONS(2971),
    [sym_kConst] = ACTIONS(2971),
    [sym_kResourcestring] = ACTIONS(2971),
    [sym_kType] = ACTIONS(2971),
    [sym_kAbsolute] = ACTIONS(2971),
    [sym_kProperty] = ACTIONS(2971),
    [sym_kClass] = ACTIONS(2971),
    [sym_kOf] = ACTIONS(2971),
    [sym_kGeneric] = ACTIONS(2971),
    [sym_kLt] = ACTIONS(2971),
    [sym_kEq] = ACTIONS(2973),
    [sym_kNeq] = ACTIONS(2973),
    [sym_kGt] = ACTIONS(2971),
    [sym_kLte] = ACTIONS(2973),
    [sym_kGte] = ACTIONS(2973),
    [sym_kAdd] = ACTIONS(2971),
    [sym_kSub] = ACTIONS(2971),
    [sym_kMul] = ACTIONS(2971),
    [sym_kFdiv] = ACTIONS(2971),
    [sym_kHat] = ACTIONS(2973),
    [sym_kAssign] = ACTIONS(2973),
    [sym_kAssignAdd] = ACTIONS(2973),
    [sym_kAssignSub] = ACTIONS(2973),
    [sym_kAssignMul] = ACTIONS(2973),
    [sym_kAssignDiv] = ACTIONS(2973),
    [sym_kOr] = ACTIONS(2971),
    [sym_kXor] = ACTIONS(2971),
    [sym_kDiv] = ACTIONS(2971),
    [sym_kMod] = ACTIONS(2971),
    [sym_kAnd] = ACTIONS(2971),
    [sym_kShl] = ACTIONS(2971),
    [sym_kShr] = ACTIONS(2971),
    [sym_kIs] = ACTIONS(2971),
    [sym_kAs] = ACTIONS(2971),
    [sym_kIn] = ACTIONS(2971),
    [sym_kThen] = ACTIONS(2971),
    [sym_kElse] = ACTIONS(2971),
    [sym_kDo] = ACTIONS(2971),
    [sym_kUntil] = ACTIONS(2971),
    [sym_kExcept] = ACTIONS(2971),
    [sym_kFinally] = ACTIONS(2971),
    [sym_kCase] = ACTIONS(2971),
    [sym_kFunction] = ACTIONS(2971),
    [sym_kProcedure] = ACTIONS(2971),
    [sym_kConstructor] = ACTIONS(2971),
    [sym_kDestructor] = ACTIONS(2971),
    [sym_kOperator] = ACTIONS(2971),
    [sym_kPublished] = ACTIONS(2971),
    [sym_kPublic] = ACTIONS(2971),
    [sym_kProtected] = ACTIONS(2971),
    [sym_kPrivate] = ACTIONS(2971),
    [sym_kStrict] = ACTIONS(2971),
    [sym_kRequired] = ACTIONS(2971),
    [sym_kOptional] = ACTIONS(2971),
    [sym_kDelayed] = ACTIONS(2971),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [527] = {
    [anon_sym_LBRACK] = ACTIONS(2668),
    [aux_sym_type_token1] = ACTIONS(2668),
    [sym_kUses] = ACTIONS(2668),
    [sym_kBegin] = ACTIONS(2668),
    [sym_kAsm] = ACTIONS(2668),
    [sym_kVar] = ACTIONS(2670),
    [sym_kThreadvar] = ACTIONS(2668),
    [sym_kConst] = ACTIONS(2670),
    [sym_kResourcestring] = ACTIONS(2668),
    [sym_kType] = ACTIONS(2668),
    [sym_kLabel] = ACTIONS(2668),
    [sym_kExports] = ACTIONS(2668),
    [sym_kDefault] = ACTIONS(2668),
    [sym_kNodefault] = ACTIONS(2668),
    [sym_kDispId] = ACTIONS(2668),
    [sym_kClass] = ACTIONS(2668),
    [sym_kGeneric] = ACTIONS(2668),
    [sym_kFunction] = ACTIONS(2668),
    [sym_kProcedure] = ACTIONS(2668),
    [sym_kConstructor] = ACTIONS(2668),
    [sym_kDestructor] = ACTIONS(2668),
    [sym_kOperator] = ACTIONS(2668),
    [sym_kPublic] = ACTIONS(2668),
    [sym_kForward] = ACTIONS(2668),
    [sym_kStatic] = ACTIONS(2668),
    [sym_kVirtual] = ACTIONS(2668),
    [sym_kAbstract] = ACTIONS(2668),
    [sym_kDynamic] = ACTIONS(2668),
    [sym_kOverride] = ACTIONS(2668),
    [sym_kOverload] = ACTIONS(2668),
    [sym_kReintroduce] = ACTIONS(2668),
    [sym_kInline] = ACTIONS(2668),
    [sym_kStdcall] = ACTIONS(2668),
    [sym_kCdecl] = ACTIONS(2668),
    [sym_kCppdecl] = ACTIONS(2668),
    [sym_kPascal] = ACTIONS(2668),
    [sym_kRegister] = ACTIONS(2668),
    [sym_kMwpascal] = ACTIONS(2668),
    [sym_kExternal] = ACTIONS(2668),
    [sym_kMessage] = ACTIONS(2668),
    [sym_kDeprecated] = ACTIONS(2668),
    [sym_kExperimental] = ACTIONS(2668),
    [sym_kPlatform] = ACTIONS(2668),
    [sym_kUnimplemented] = ACTIONS(2668),
    [sym_kCvar] = ACTIONS(2668),
    [sym_kExport] = ACTIONS(2670),
    [sym_kFar] = ACTIONS(2668),
    [sym_kNear] = ACTIONS(2668),
    [sym_kSafecall] = ACTIONS(2668),
    [sym_kAssembler] = ACTIONS(2668),
    [sym_kNostackframe] = ACTIONS(2668),
    [sym_kInterrupt] = ACTIONS(2668),
    [sym_kNoreturn] = ACTIONS(2668),
    [sym_kIocheck] = ACTIONS(2668),
    [sym_kLocal] = ACTIONS(2668),
    [sym_kHardfloat] = ACTIONS(2668),
    [sym_kSoftfloat] = ACTIONS(2668),
    [sym_kMs_abi_default] = ACTIONS(2668),
    [sym_kMs_abi_cdecl] = ACTIONS(2668),
    [sym_kSaveregisters] = ACTIONS(2668),
    [sym_kSysv_abi_default] = ACTIONS(2668),
    [sym_kSysv_abi_cdecl] = ACTIONS(2668),
    [sym_kVectorcall] = ACTIONS(2668),
    [sym_kVarargs] = ACTIONS(2668),
    [sym_kWinapi] = ACTIONS(2668),
    [sym_kAlias] = ACTIONS(2668),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [528] = {
    [sym_identifier] = ACTIONS(2975),
    [anon_sym_SEMI] = ACTIONS(2977),
    [anon_sym_COLON] = ACTIONS(2975),
    [anon_sym_COMMA] = ACTIONS(2977),
    [anon_sym_LBRACK] = ACTIONS(2977),
    [anon_sym_RBRACK] = ACTIONS(2977),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_RPAREN] = ACTIONS(2977),
    [anon_sym_DOT] = ACTIONS(2977),
    [sym_kEnd] = ACTIONS(2975),
    [sym_kVar] = ACTIONS(2975),
    [sym_kThreadvar] = ACTIONS(2975),
    [sym_kConst] = ACTIONS(2975),
    [sym_kResourcestring] = ACTIONS(2975),
    [sym_kType] = ACTIONS(2975),
    [sym_kAbsolute] = ACTIONS(2975),
    [sym_kProperty] = ACTIONS(2975),
    [sym_kClass] = ACTIONS(2975),
    [sym_kOf] = ACTIONS(2975),
    [sym_kGeneric] = ACTIONS(2975),
    [sym_kLt] = ACTIONS(2975),
    [sym_kEq] = ACTIONS(2977),
    [sym_kNeq] = ACTIONS(2977),
    [sym_kGt] = ACTIONS(2975),
    [sym_kLte] = ACTIONS(2977),
    [sym_kGte] = ACTIONS(2977),
    [sym_kAdd] = ACTIONS(2975),
    [sym_kSub] = ACTIONS(2975),
    [sym_kMul] = ACTIONS(2975),
    [sym_kFdiv] = ACTIONS(2975),
    [sym_kHat] = ACTIONS(2977),
    [sym_kAssign] = ACTIONS(2977),
    [sym_kAssignAdd] = ACTIONS(2977),
    [sym_kAssignSub] = ACTIONS(2977),
    [sym_kAssignMul] = ACTIONS(2977),
    [sym_kAssignDiv] = ACTIONS(2977),
    [sym_kOr] = ACTIONS(2975),
    [sym_kXor] = ACTIONS(2975),
    [sym_kDiv] = ACTIONS(2975),
    [sym_kMod] = ACTIONS(2975),
    [sym_kAnd] = ACTIONS(2975),
    [sym_kShl] = ACTIONS(2975),
    [sym_kShr] = ACTIONS(2975),
    [sym_kIs] = ACTIONS(2975),
    [sym_kAs] = ACTIONS(2975),
    [sym_kIn] = ACTIONS(2975),
    [sym_kThen] = ACTIONS(2975),
    [sym_kElse] = ACTIONS(2975),
    [sym_kDo] = ACTIONS(2975),
    [sym_kUntil] = ACTIONS(2975),
    [sym_kExcept] = ACTIONS(2975),
    [sym_kFinally] = ACTIONS(2975),
    [sym_kCase] = ACTIONS(2975),
    [sym_kFunction] = ACTIONS(2975),
    [sym_kProcedure] = ACTIONS(2975),
    [sym_kConstructor] = ACTIONS(2975),
    [sym_kDestructor] = ACTIONS(2975),
    [sym_kOperator] = ACTIONS(2975),
    [sym_kPublished] = ACTIONS(2975),
    [sym_kPublic] = ACTIONS(2975),
    [sym_kProtected] = ACTIONS(2975),
    [sym_kPrivate] = ACTIONS(2975),
    [sym_kStrict] = ACTIONS(2975),
    [sym_kRequired] = ACTIONS(2975),
    [sym_kOptional] = ACTIONS(2975),
    [sym_kDelayed] = ACTIONS(2975),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [529] = {
    [sym_identifier] = ACTIONS(2979),
    [anon_sym_SEMI] = ACTIONS(2981),
    [anon_sym_COLON] = ACTIONS(2979),
    [anon_sym_COMMA] = ACTIONS(2981),
    [anon_sym_LBRACK] = ACTIONS(2981),
    [anon_sym_RBRACK] = ACTIONS(2981),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_RPAREN] = ACTIONS(2981),
    [anon_sym_DOT] = ACTIONS(2981),
    [sym_kEnd] = ACTIONS(2979),
    [sym_kVar] = ACTIONS(2979),
    [sym_kThreadvar] = ACTIONS(2979),
    [sym_kConst] = ACTIONS(2979),
    [sym_kResourcestring] = ACTIONS(2979),
    [sym_kType] = ACTIONS(2979),
    [sym_kAbsolute] = ACTIONS(2979),
    [sym_kProperty] = ACTIONS(2979),
    [sym_kClass] = ACTIONS(2979),
    [sym_kOf] = ACTIONS(2979),
    [sym_kGeneric] = ACTIONS(2979),
    [sym_kLt] = ACTIONS(2979),
    [sym_kEq] = ACTIONS(2981),
    [sym_kNeq] = ACTIONS(2981),
    [sym_kGt] = ACTIONS(2979),
    [sym_kLte] = ACTIONS(2981),
    [sym_kGte] = ACTIONS(2981),
    [sym_kAdd] = ACTIONS(2979),
    [sym_kSub] = ACTIONS(2979),
    [sym_kMul] = ACTIONS(2979),
    [sym_kFdiv] = ACTIONS(2979),
    [sym_kHat] = ACTIONS(2981),
    [sym_kAssign] = ACTIONS(2981),
    [sym_kAssignAdd] = ACTIONS(2981),
    [sym_kAssignSub] = ACTIONS(2981),
    [sym_kAssignMul] = ACTIONS(2981),
    [sym_kAssignDiv] = ACTIONS(2981),
    [sym_kOr] = ACTIONS(2979),
    [sym_kXor] = ACTIONS(2979),
    [sym_kDiv] = ACTIONS(2979),
    [sym_kMod] = ACTIONS(2979),
    [sym_kAnd] = ACTIONS(2979),
    [sym_kShl] = ACTIONS(2979),
    [sym_kShr] = ACTIONS(2979),
    [sym_kIs] = ACTIONS(2979),
    [sym_kAs] = ACTIONS(2979),
    [sym_kIn] = ACTIONS(2979),
    [sym_kThen] = ACTIONS(2979),
    [sym_kElse] = ACTIONS(2979),
    [sym_kDo] = ACTIONS(2979),
    [sym_kUntil] = ACTIONS(2979),
    [sym_kExcept] = ACTIONS(2979),
    [sym_kFinally] = ACTIONS(2979),
    [sym_kCase] = ACTIONS(2979),
    [sym_kFunction] = ACTIONS(2979),
    [sym_kProcedure] = ACTIONS(2979),
    [sym_kConstructor] = ACTIONS(2979),
    [sym_kDestructor] = ACTIONS(2979),
    [sym_kOperator] = ACTIONS(2979),
    [sym_kPublished] = ACTIONS(2979),
    [sym_kPublic] = ACTIONS(2979),
    [sym_kProtected] = ACTIONS(2979),
    [sym_kPrivate] = ACTIONS(2979),
    [sym_kStrict] = ACTIONS(2979),
    [sym_kRequired] = ACTIONS(2979),
    [sym_kOptional] = ACTIONS(2979),
    [sym_kDelayed] = ACTIONS(2979),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [530] = {
    [sym_identifier] = ACTIONS(2983),
    [anon_sym_SEMI] = ACTIONS(2985),
    [anon_sym_COLON] = ACTIONS(2983),
    [anon_sym_COMMA] = ACTIONS(2985),
    [anon_sym_LBRACK] = ACTIONS(2985),
    [anon_sym_RBRACK] = ACTIONS(2985),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_RPAREN] = ACTIONS(2985),
    [anon_sym_DOT] = ACTIONS(2985),
    [sym_kEnd] = ACTIONS(2983),
    [sym_kVar] = ACTIONS(2983),
    [sym_kThreadvar] = ACTIONS(2983),
    [sym_kConst] = ACTIONS(2983),
    [sym_kResourcestring] = ACTIONS(2983),
    [sym_kType] = ACTIONS(2983),
    [sym_kAbsolute] = ACTIONS(2983),
    [sym_kProperty] = ACTIONS(2983),
    [sym_kClass] = ACTIONS(2983),
    [sym_kOf] = ACTIONS(2983),
    [sym_kGeneric] = ACTIONS(2983),
    [sym_kLt] = ACTIONS(2983),
    [sym_kEq] = ACTIONS(2985),
    [sym_kNeq] = ACTIONS(2985),
    [sym_kGt] = ACTIONS(2983),
    [sym_kLte] = ACTIONS(2985),
    [sym_kGte] = ACTIONS(2985),
    [sym_kAdd] = ACTIONS(2983),
    [sym_kSub] = ACTIONS(2983),
    [sym_kMul] = ACTIONS(2983),
    [sym_kFdiv] = ACTIONS(2983),
    [sym_kHat] = ACTIONS(2987),
    [sym_kAssign] = ACTIONS(2985),
    [sym_kAssignAdd] = ACTIONS(2985),
    [sym_kAssignSub] = ACTIONS(2985),
    [sym_kAssignMul] = ACTIONS(2985),
    [sym_kAssignDiv] = ACTIONS(2985),
    [sym_kOr] = ACTIONS(2983),
    [sym_kXor] = ACTIONS(2983),
    [sym_kDiv] = ACTIONS(2983),
    [sym_kMod] = ACTIONS(2983),
    [sym_kAnd] = ACTIONS(2983),
    [sym_kShl] = ACTIONS(2983),
    [sym_kShr] = ACTIONS(2983),
    [sym_kIs] = ACTIONS(2983),
    [sym_kAs] = ACTIONS(2983),
    [sym_kIn] = ACTIONS(2983),
    [sym_kThen] = ACTIONS(2983),
    [sym_kElse] = ACTIONS(2983),
    [sym_kDo] = ACTIONS(2983),
    [sym_kUntil] = ACTIONS(2983),
    [sym_kExcept] = ACTIONS(2983),
    [sym_kFinally] = ACTIONS(2983),
    [sym_kCase] = ACTIONS(2983),
    [sym_kFunction] = ACTIONS(2983),
    [sym_kProcedure] = ACTIONS(2983),
    [sym_kConstructor] = ACTIONS(2983),
    [sym_kDestructor] = ACTIONS(2983),
    [sym_kOperator] = ACTIONS(2983),
    [sym_kPublished] = ACTIONS(2983),
    [sym_kPublic] = ACTIONS(2983),
    [sym_kProtected] = ACTIONS(2983),
    [sym_kPrivate] = ACTIONS(2983),
    [sym_kStrict] = ACTIONS(2983),
    [sym_kRequired] = ACTIONS(2983),
    [sym_kOptional] = ACTIONS(2983),
    [sym_kDelayed] = ACTIONS(2983),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [531] = {
    [sym_identifier] = ACTIONS(2989),
    [anon_sym_SEMI] = ACTIONS(2991),
    [anon_sym_COLON] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2991),
    [anon_sym_LBRACK] = ACTIONS(2991),
    [anon_sym_RBRACK] = ACTIONS(2991),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_RPAREN] = ACTIONS(2991),
    [anon_sym_DOT] = ACTIONS(2991),
    [sym_kEnd] = ACTIONS(2993),
    [sym_kVar] = ACTIONS(2993),
    [sym_kThreadvar] = ACTIONS(2993),
    [sym_kConst] = ACTIONS(2993),
    [sym_kResourcestring] = ACTIONS(2993),
    [sym_kType] = ACTIONS(2993),
    [sym_kAbsolute] = ACTIONS(2993),
    [sym_kProperty] = ACTIONS(2993),
    [sym_kClass] = ACTIONS(2993),
    [sym_kOf] = ACTIONS(2993),
    [sym_kGeneric] = ACTIONS(2993),
    [sym_kLt] = ACTIONS(2993),
    [sym_kEq] = ACTIONS(2991),
    [sym_kNeq] = ACTIONS(2991),
    [sym_kGt] = ACTIONS(2993),
    [sym_kLte] = ACTIONS(2991),
    [sym_kGte] = ACTIONS(2991),
    [sym_kAdd] = ACTIONS(2993),
    [sym_kSub] = ACTIONS(2993),
    [sym_kMul] = ACTIONS(2993),
    [sym_kFdiv] = ACTIONS(2993),
    [sym_kHat] = ACTIONS(2991),
    [sym_kAssign] = ACTIONS(2991),
    [sym_kAssignAdd] = ACTIONS(2991),
    [sym_kAssignSub] = ACTIONS(2991),
    [sym_kAssignMul] = ACTIONS(2991),
    [sym_kAssignDiv] = ACTIONS(2991),
    [sym_kOr] = ACTIONS(2993),
    [sym_kXor] = ACTIONS(2993),
    [sym_kDiv] = ACTIONS(2993),
    [sym_kMod] = ACTIONS(2993),
    [sym_kAnd] = ACTIONS(2993),
    [sym_kShl] = ACTIONS(2993),
    [sym_kShr] = ACTIONS(2993),
    [sym_kIs] = ACTIONS(2993),
    [sym_kAs] = ACTIONS(2993),
    [sym_kIn] = ACTIONS(2993),
    [sym_kThen] = ACTIONS(2993),
    [sym_kElse] = ACTIONS(2993),
    [sym_kDo] = ACTIONS(2993),
    [sym_kUntil] = ACTIONS(2993),
    [sym_kExcept] = ACTIONS(2993),
    [sym_kFinally] = ACTIONS(2993),
    [sym_kCase] = ACTIONS(2993),
    [sym_kFunction] = ACTIONS(2993),
    [sym_kProcedure] = ACTIONS(2993),
    [sym_kConstructor] = ACTIONS(2993),
    [sym_kDestructor] = ACTIONS(2993),
    [sym_kOperator] = ACTIONS(2993),
    [sym_kPublished] = ACTIONS(2993),
    [sym_kPublic] = ACTIONS(2993),
    [sym_kProtected] = ACTIONS(2993),
    [sym_kPrivate] = ACTIONS(2993),
    [sym_kStrict] = ACTIONS(2993),
    [sym_kRequired] = ACTIONS(2993),
    [sym_kOptional] = ACTIONS(2993),
    [sym_kDelayed] = ACTIONS(2993),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [532] = {
    [sym_identifier] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2995),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2995),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2997),
    [sym_kEnd] = ACTIONS(2995),
    [sym_kVar] = ACTIONS(2995),
    [sym_kThreadvar] = ACTIONS(2995),
    [sym_kConst] = ACTIONS(2995),
    [sym_kResourcestring] = ACTIONS(2995),
    [sym_kType] = ACTIONS(2995),
    [sym_kAbsolute] = ACTIONS(2995),
    [sym_kProperty] = ACTIONS(2995),
    [sym_kClass] = ACTIONS(2995),
    [sym_kOf] = ACTIONS(2995),
    [sym_kGeneric] = ACTIONS(2995),
    [sym_kLt] = ACTIONS(2995),
    [sym_kEq] = ACTIONS(2997),
    [sym_kNeq] = ACTIONS(2997),
    [sym_kGt] = ACTIONS(2995),
    [sym_kLte] = ACTIONS(2997),
    [sym_kGte] = ACTIONS(2997),
    [sym_kAdd] = ACTIONS(2995),
    [sym_kSub] = ACTIONS(2995),
    [sym_kMul] = ACTIONS(2995),
    [sym_kFdiv] = ACTIONS(2995),
    [sym_kHat] = ACTIONS(2987),
    [sym_kAssign] = ACTIONS(2997),
    [sym_kAssignAdd] = ACTIONS(2997),
    [sym_kAssignSub] = ACTIONS(2997),
    [sym_kAssignMul] = ACTIONS(2997),
    [sym_kAssignDiv] = ACTIONS(2997),
    [sym_kOr] = ACTIONS(2995),
    [sym_kXor] = ACTIONS(2995),
    [sym_kDiv] = ACTIONS(2995),
    [sym_kMod] = ACTIONS(2995),
    [sym_kAnd] = ACTIONS(2995),
    [sym_kShl] = ACTIONS(2995),
    [sym_kShr] = ACTIONS(2995),
    [sym_kIs] = ACTIONS(2995),
    [sym_kAs] = ACTIONS(2995),
    [sym_kIn] = ACTIONS(2995),
    [sym_kThen] = ACTIONS(2995),
    [sym_kElse] = ACTIONS(2995),
    [sym_kDo] = ACTIONS(2995),
    [sym_kUntil] = ACTIONS(2995),
    [sym_kExcept] = ACTIONS(2995),
    [sym_kFinally] = ACTIONS(2995),
    [sym_kCase] = ACTIONS(2995),
    [sym_kFunction] = ACTIONS(2995),
    [sym_kProcedure] = ACTIONS(2995),
    [sym_kConstructor] = ACTIONS(2995),
    [sym_kDestructor] = ACTIONS(2995),
    [sym_kOperator] = ACTIONS(2995),
    [sym_kPublished] = ACTIONS(2995),
    [sym_kPublic] = ACTIONS(2995),
    [sym_kProtected] = ACTIONS(2995),
    [sym_kPrivate] = ACTIONS(2995),
    [sym_kStrict] = ACTIONS(2995),
    [sym_kRequired] = ACTIONS(2995),
    [sym_kOptional] = ACTIONS(2995),
    [sym_kDelayed] = ACTIONS(2995),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [533] = {
    [sym_identifier] = ACTIONS(2999),
    [anon_sym_SEMI] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(2999),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_RBRACK] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(2999),
    [anon_sym_RPAREN] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(3001),
    [sym_kEnd] = ACTIONS(2999),
    [sym_kVar] = ACTIONS(2999),
    [sym_kThreadvar] = ACTIONS(2999),
    [sym_kConst] = ACTIONS(2999),
    [sym_kResourcestring] = ACTIONS(2999),
    [sym_kType] = ACTIONS(2999),
    [sym_kAbsolute] = ACTIONS(2999),
    [sym_kProperty] = ACTIONS(2999),
    [sym_kClass] = ACTIONS(2999),
    [sym_kOf] = ACTIONS(2999),
    [sym_kGeneric] = ACTIONS(2999),
    [sym_kLt] = ACTIONS(2999),
    [sym_kEq] = ACTIONS(3001),
    [sym_kNeq] = ACTIONS(3001),
    [sym_kGt] = ACTIONS(2999),
    [sym_kLte] = ACTIONS(3001),
    [sym_kGte] = ACTIONS(3001),
    [sym_kAdd] = ACTIONS(2999),
    [sym_kSub] = ACTIONS(2999),
    [sym_kMul] = ACTIONS(2999),
    [sym_kFdiv] = ACTIONS(2999),
    [sym_kHat] = ACTIONS(3001),
    [sym_kAssign] = ACTIONS(3001),
    [sym_kAssignAdd] = ACTIONS(3001),
    [sym_kAssignSub] = ACTIONS(3001),
    [sym_kAssignMul] = ACTIONS(3001),
    [sym_kAssignDiv] = ACTIONS(3001),
    [sym_kOr] = ACTIONS(2999),
    [sym_kXor] = ACTIONS(2999),
    [sym_kDiv] = ACTIONS(2999),
    [sym_kMod] = ACTIONS(2999),
    [sym_kAnd] = ACTIONS(2999),
    [sym_kShl] = ACTIONS(2999),
    [sym_kShr] = ACTIONS(2999),
    [sym_kIs] = ACTIONS(2999),
    [sym_kAs] = ACTIONS(2999),
    [sym_kIn] = ACTIONS(2999),
    [sym_kThen] = ACTIONS(2999),
    [sym_kElse] = ACTIONS(2999),
    [sym_kDo] = ACTIONS(2999),
    [sym_kUntil] = ACTIONS(2999),
    [sym_kExcept] = ACTIONS(2999),
    [sym_kFinally] = ACTIONS(2999),
    [sym_kCase] = ACTIONS(2999),
    [sym_kFunction] = ACTIONS(2999),
    [sym_kProcedure] = ACTIONS(2999),
    [sym_kConstructor] = ACTIONS(2999),
    [sym_kDestructor] = ACTIONS(2999),
    [sym_kOperator] = ACTIONS(2999),
    [sym_kPublished] = ACTIONS(2999),
    [sym_kPublic] = ACTIONS(2999),
    [sym_kProtected] = ACTIONS(2999),
    [sym_kPrivate] = ACTIONS(2999),
    [sym_kStrict] = ACTIONS(2999),
    [sym_kRequired] = ACTIONS(2999),
    [sym_kOptional] = ACTIONS(2999),
    [sym_kDelayed] = ACTIONS(2999),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [534] = {
    [sym_identifier] = ACTIONS(3003),
    [anon_sym_SEMI] = ACTIONS(3005),
    [anon_sym_COLON] = ACTIONS(3003),
    [anon_sym_COMMA] = ACTIONS(3005),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_RBRACK] = ACTIONS(3005),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_RPAREN] = ACTIONS(3005),
    [anon_sym_DOT] = ACTIONS(3005),
    [sym_kEnd] = ACTIONS(3003),
    [sym_kVar] = ACTIONS(3003),
    [sym_kThreadvar] = ACTIONS(3003),
    [sym_kConst] = ACTIONS(3003),
    [sym_kResourcestring] = ACTIONS(3003),
    [sym_kType] = ACTIONS(3003),
    [sym_kAbsolute] = ACTIONS(3003),
    [sym_kProperty] = ACTIONS(3003),
    [sym_kClass] = ACTIONS(3003),
    [sym_kOf] = ACTIONS(3003),
    [sym_kGeneric] = ACTIONS(3003),
    [sym_kLt] = ACTIONS(3003),
    [sym_kEq] = ACTIONS(3005),
    [sym_kNeq] = ACTIONS(3005),
    [sym_kGt] = ACTIONS(3003),
    [sym_kLte] = ACTIONS(3005),
    [sym_kGte] = ACTIONS(3005),
    [sym_kAdd] = ACTIONS(3003),
    [sym_kSub] = ACTIONS(3003),
    [sym_kMul] = ACTIONS(3003),
    [sym_kFdiv] = ACTIONS(3003),
    [sym_kHat] = ACTIONS(3005),
    [sym_kAssign] = ACTIONS(3005),
    [sym_kAssignAdd] = ACTIONS(3005),
    [sym_kAssignSub] = ACTIONS(3005),
    [sym_kAssignMul] = ACTIONS(3005),
    [sym_kAssignDiv] = ACTIONS(3005),
    [sym_kOr] = ACTIONS(3003),
    [sym_kXor] = ACTIONS(3003),
    [sym_kDiv] = ACTIONS(3003),
    [sym_kMod] = ACTIONS(3003),
    [sym_kAnd] = ACTIONS(3003),
    [sym_kShl] = ACTIONS(3003),
    [sym_kShr] = ACTIONS(3003),
    [sym_kIs] = ACTIONS(3003),
    [sym_kAs] = ACTIONS(3003),
    [sym_kIn] = ACTIONS(3003),
    [sym_kThen] = ACTIONS(3003),
    [sym_kElse] = ACTIONS(3003),
    [sym_kDo] = ACTIONS(3003),
    [sym_kUntil] = ACTIONS(3003),
    [sym_kExcept] = ACTIONS(3003),
    [sym_kFinally] = ACTIONS(3003),
    [sym_kCase] = ACTIONS(3003),
    [sym_kFunction] = ACTIONS(3003),
    [sym_kProcedure] = ACTIONS(3003),
    [sym_kConstructor] = ACTIONS(3003),
    [sym_kDestructor] = ACTIONS(3003),
    [sym_kOperator] = ACTIONS(3003),
    [sym_kPublished] = ACTIONS(3003),
    [sym_kPublic] = ACTIONS(3003),
    [sym_kProtected] = ACTIONS(3003),
    [sym_kPrivate] = ACTIONS(3003),
    [sym_kStrict] = ACTIONS(3003),
    [sym_kRequired] = ACTIONS(3003),
    [sym_kOptional] = ACTIONS(3003),
    [sym_kDelayed] = ACTIONS(3003),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [535] = {
    [sym_identifier] = ACTIONS(3007),
    [anon_sym_SEMI] = ACTIONS(3009),
    [anon_sym_COLON] = ACTIONS(3007),
    [anon_sym_COMMA] = ACTIONS(3009),
    [anon_sym_LBRACK] = ACTIONS(3009),
    [anon_sym_RBRACK] = ACTIONS(3009),
    [anon_sym_LPAREN] = ACTIONS(3007),
    [anon_sym_RPAREN] = ACTIONS(3009),
    [anon_sym_DOT] = ACTIONS(3009),
    [sym_kEnd] = ACTIONS(3007),
    [sym_kVar] = ACTIONS(3007),
    [sym_kThreadvar] = ACTIONS(3007),
    [sym_kConst] = ACTIONS(3007),
    [sym_kResourcestring] = ACTIONS(3007),
    [sym_kType] = ACTIONS(3007),
    [sym_kAbsolute] = ACTIONS(3007),
    [sym_kProperty] = ACTIONS(3007),
    [sym_kClass] = ACTIONS(3007),
    [sym_kOf] = ACTIONS(3007),
    [sym_kGeneric] = ACTIONS(3007),
    [sym_kLt] = ACTIONS(3007),
    [sym_kEq] = ACTIONS(3009),
    [sym_kNeq] = ACTIONS(3009),
    [sym_kGt] = ACTIONS(3007),
    [sym_kLte] = ACTIONS(3009),
    [sym_kGte] = ACTIONS(3009),
    [sym_kAdd] = ACTIONS(3007),
    [sym_kSub] = ACTIONS(3007),
    [sym_kMul] = ACTIONS(3007),
    [sym_kFdiv] = ACTIONS(3007),
    [sym_kHat] = ACTIONS(3009),
    [sym_kAssign] = ACTIONS(3009),
    [sym_kAssignAdd] = ACTIONS(3009),
    [sym_kAssignSub] = ACTIONS(3009),
    [sym_kAssignMul] = ACTIONS(3009),
    [sym_kAssignDiv] = ACTIONS(3009),
    [sym_kOr] = ACTIONS(3007),
    [sym_kXor] = ACTIONS(3007),
    [sym_kDiv] = ACTIONS(3007),
    [sym_kMod] = ACTIONS(3007),
    [sym_kAnd] = ACTIONS(3007),
    [sym_kShl] = ACTIONS(3007),
    [sym_kShr] = ACTIONS(3007),
    [sym_kIs] = ACTIONS(3007),
    [sym_kAs] = ACTIONS(3007),
    [sym_kIn] = ACTIONS(3007),
    [sym_kThen] = ACTIONS(3007),
    [sym_kElse] = ACTIONS(3007),
    [sym_kDo] = ACTIONS(3007),
    [sym_kUntil] = ACTIONS(3007),
    [sym_kExcept] = ACTIONS(3007),
    [sym_kFinally] = ACTIONS(3007),
    [sym_kCase] = ACTIONS(3007),
    [sym_kFunction] = ACTIONS(3007),
    [sym_kProcedure] = ACTIONS(3007),
    [sym_kConstructor] = ACTIONS(3007),
    [sym_kDestructor] = ACTIONS(3007),
    [sym_kOperator] = ACTIONS(3007),
    [sym_kPublished] = ACTIONS(3007),
    [sym_kPublic] = ACTIONS(3007),
    [sym_kProtected] = ACTIONS(3007),
    [sym_kPrivate] = ACTIONS(3007),
    [sym_kStrict] = ACTIONS(3007),
    [sym_kRequired] = ACTIONS(3007),
    [sym_kOptional] = ACTIONS(3007),
    [sym_kDelayed] = ACTIONS(3007),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [536] = {
    [sym_identifier] = ACTIONS(2907),
    [anon_sym_SEMI] = ACTIONS(2909),
    [anon_sym_COLON] = ACTIONS(2907),
    [anon_sym_COMMA] = ACTIONS(2909),
    [anon_sym_LBRACK] = ACTIONS(2909),
    [anon_sym_RBRACK] = ACTIONS(2909),
    [anon_sym_LPAREN] = ACTIONS(2907),
    [anon_sym_RPAREN] = ACTIONS(2909),
    [anon_sym_DOT] = ACTIONS(2909),
    [sym_kEnd] = ACTIONS(2907),
    [sym_kVar] = ACTIONS(2907),
    [sym_kThreadvar] = ACTIONS(2907),
    [sym_kConst] = ACTIONS(2907),
    [sym_kResourcestring] = ACTIONS(2907),
    [sym_kType] = ACTIONS(2907),
    [sym_kAbsolute] = ACTIONS(2907),
    [sym_kProperty] = ACTIONS(2907),
    [sym_kClass] = ACTIONS(2907),
    [sym_kOf] = ACTIONS(2907),
    [sym_kGeneric] = ACTIONS(2907),
    [sym_kLt] = ACTIONS(2907),
    [sym_kEq] = ACTIONS(2909),
    [sym_kNeq] = ACTIONS(2909),
    [sym_kGt] = ACTIONS(2907),
    [sym_kLte] = ACTIONS(2909),
    [sym_kGte] = ACTIONS(2909),
    [sym_kAdd] = ACTIONS(2907),
    [sym_kSub] = ACTIONS(2907),
    [sym_kMul] = ACTIONS(2907),
    [sym_kFdiv] = ACTIONS(2907),
    [sym_kHat] = ACTIONS(2909),
    [sym_kAssign] = ACTIONS(2909),
    [sym_kAssignAdd] = ACTIONS(2909),
    [sym_kAssignSub] = ACTIONS(2909),
    [sym_kAssignMul] = ACTIONS(2909),
    [sym_kAssignDiv] = ACTIONS(2909),
    [sym_kOr] = ACTIONS(2907),
    [sym_kXor] = ACTIONS(2907),
    [sym_kDiv] = ACTIONS(2907),
    [sym_kMod] = ACTIONS(2907),
    [sym_kAnd] = ACTIONS(2907),
    [sym_kShl] = ACTIONS(2907),
    [sym_kShr] = ACTIONS(2907),
    [sym_kIs] = ACTIONS(2907),
    [sym_kAs] = ACTIONS(2907),
    [sym_kIn] = ACTIONS(2907),
    [sym_kThen] = ACTIONS(2907),
    [sym_kElse] = ACTIONS(2907),
    [sym_kDo] = ACTIONS(2907),
    [sym_kUntil] = ACTIONS(2907),
    [sym_kExcept] = ACTIONS(2907),
    [sym_kFinally] = ACTIONS(2907),
    [sym_kCase] = ACTIONS(2907),
    [sym_kFunction] = ACTIONS(2907),
    [sym_kProcedure] = ACTIONS(2907),
    [sym_kConstructor] = ACTIONS(2907),
    [sym_kDestructor] = ACTIONS(2907),
    [sym_kOperator] = ACTIONS(2907),
    [sym_kPublished] = ACTIONS(2907),
    [sym_kPublic] = ACTIONS(2907),
    [sym_kProtected] = ACTIONS(2907),
    [sym_kPrivate] = ACTIONS(2907),
    [sym_kStrict] = ACTIONS(2907),
    [sym_kRequired] = ACTIONS(2907),
    [sym_kOptional] = ACTIONS(2907),
    [sym_kDelayed] = ACTIONS(2907),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [537] = {
    [sym_identifier] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_COLON] = ACTIONS(3011),
    [anon_sym_COMMA] = ACTIONS(3013),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_RBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3011),
    [anon_sym_RPAREN] = ACTIONS(3013),
    [anon_sym_DOT] = ACTIONS(3013),
    [sym_kEnd] = ACTIONS(3011),
    [sym_kVar] = ACTIONS(3011),
    [sym_kThreadvar] = ACTIONS(3011),
    [sym_kConst] = ACTIONS(3011),
    [sym_kResourcestring] = ACTIONS(3011),
    [sym_kType] = ACTIONS(3011),
    [sym_kAbsolute] = ACTIONS(3011),
    [sym_kProperty] = ACTIONS(3011),
    [sym_kClass] = ACTIONS(3011),
    [sym_kOf] = ACTIONS(3011),
    [sym_kGeneric] = ACTIONS(3011),
    [sym_kLt] = ACTIONS(3011),
    [sym_kEq] = ACTIONS(3013),
    [sym_kNeq] = ACTIONS(3013),
    [sym_kGt] = ACTIONS(3011),
    [sym_kLte] = ACTIONS(3013),
    [sym_kGte] = ACTIONS(3013),
    [sym_kAdd] = ACTIONS(3011),
    [sym_kSub] = ACTIONS(3011),
    [sym_kMul] = ACTIONS(3011),
    [sym_kFdiv] = ACTIONS(3011),
    [sym_kHat] = ACTIONS(3013),
    [sym_kAssign] = ACTIONS(3013),
    [sym_kAssignAdd] = ACTIONS(3013),
    [sym_kAssignSub] = ACTIONS(3013),
    [sym_kAssignMul] = ACTIONS(3013),
    [sym_kAssignDiv] = ACTIONS(3013),
    [sym_kOr] = ACTIONS(3011),
    [sym_kXor] = ACTIONS(3011),
    [sym_kDiv] = ACTIONS(3011),
    [sym_kMod] = ACTIONS(3011),
    [sym_kAnd] = ACTIONS(3011),
    [sym_kShl] = ACTIONS(3011),
    [sym_kShr] = ACTIONS(3011),
    [sym_kIs] = ACTIONS(3011),
    [sym_kAs] = ACTIONS(3011),
    [sym_kIn] = ACTIONS(3011),
    [sym_kThen] = ACTIONS(3011),
    [sym_kElse] = ACTIONS(3011),
    [sym_kDo] = ACTIONS(3011),
    [sym_kUntil] = ACTIONS(3011),
    [sym_kExcept] = ACTIONS(3011),
    [sym_kFinally] = ACTIONS(3011),
    [sym_kCase] = ACTIONS(3011),
    [sym_kFunction] = ACTIONS(3011),
    [sym_kProcedure] = ACTIONS(3011),
    [sym_kConstructor] = ACTIONS(3011),
    [sym_kDestructor] = ACTIONS(3011),
    [sym_kOperator] = ACTIONS(3011),
    [sym_kPublished] = ACTIONS(3011),
    [sym_kPublic] = ACTIONS(3011),
    [sym_kProtected] = ACTIONS(3011),
    [sym_kPrivate] = ACTIONS(3011),
    [sym_kStrict] = ACTIONS(3011),
    [sym_kRequired] = ACTIONS(3011),
    [sym_kOptional] = ACTIONS(3011),
    [sym_kDelayed] = ACTIONS(3011),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [538] = {
    [sym_identifier] = ACTIONS(3015),
    [anon_sym_SEMI] = ACTIONS(3017),
    [anon_sym_COLON] = ACTIONS(3015),
    [anon_sym_COMMA] = ACTIONS(3017),
    [anon_sym_LBRACK] = ACTIONS(3017),
    [anon_sym_RBRACK] = ACTIONS(3017),
    [anon_sym_LPAREN] = ACTIONS(3015),
    [anon_sym_RPAREN] = ACTIONS(3017),
    [anon_sym_DOT] = ACTIONS(3017),
    [sym_kEnd] = ACTIONS(3015),
    [sym_kVar] = ACTIONS(3015),
    [sym_kThreadvar] = ACTIONS(3015),
    [sym_kConst] = ACTIONS(3015),
    [sym_kResourcestring] = ACTIONS(3015),
    [sym_kType] = ACTIONS(3015),
    [sym_kAbsolute] = ACTIONS(3015),
    [sym_kProperty] = ACTIONS(3015),
    [sym_kClass] = ACTIONS(3015),
    [sym_kOf] = ACTIONS(3015),
    [sym_kGeneric] = ACTIONS(3015),
    [sym_kLt] = ACTIONS(3015),
    [sym_kEq] = ACTIONS(3017),
    [sym_kNeq] = ACTIONS(3017),
    [sym_kGt] = ACTIONS(3015),
    [sym_kLte] = ACTIONS(3017),
    [sym_kGte] = ACTIONS(3017),
    [sym_kAdd] = ACTIONS(3015),
    [sym_kSub] = ACTIONS(3015),
    [sym_kMul] = ACTIONS(3015),
    [sym_kFdiv] = ACTIONS(3015),
    [sym_kHat] = ACTIONS(3017),
    [sym_kAssign] = ACTIONS(3017),
    [sym_kAssignAdd] = ACTIONS(3017),
    [sym_kAssignSub] = ACTIONS(3017),
    [sym_kAssignMul] = ACTIONS(3017),
    [sym_kAssignDiv] = ACTIONS(3017),
    [sym_kOr] = ACTIONS(3015),
    [sym_kXor] = ACTIONS(3015),
    [sym_kDiv] = ACTIONS(3015),
    [sym_kMod] = ACTIONS(3015),
    [sym_kAnd] = ACTIONS(3015),
    [sym_kShl] = ACTIONS(3015),
    [sym_kShr] = ACTIONS(3015),
    [sym_kIs] = ACTIONS(3015),
    [sym_kAs] = ACTIONS(3015),
    [sym_kIn] = ACTIONS(3015),
    [sym_kThen] = ACTIONS(3015),
    [sym_kElse] = ACTIONS(3015),
    [sym_kDo] = ACTIONS(3015),
    [sym_kUntil] = ACTIONS(3015),
    [sym_kExcept] = ACTIONS(3015),
    [sym_kFinally] = ACTIONS(3015),
    [sym_kCase] = ACTIONS(3015),
    [sym_kFunction] = ACTIONS(3015),
    [sym_kProcedure] = ACTIONS(3015),
    [sym_kConstructor] = ACTIONS(3015),
    [sym_kDestructor] = ACTIONS(3015),
    [sym_kOperator] = ACTIONS(3015),
    [sym_kPublished] = ACTIONS(3015),
    [sym_kPublic] = ACTIONS(3015),
    [sym_kProtected] = ACTIONS(3015),
    [sym_kPrivate] = ACTIONS(3015),
    [sym_kStrict] = ACTIONS(3015),
    [sym_kRequired] = ACTIONS(3015),
    [sym_kOptional] = ACTIONS(3015),
    [sym_kDelayed] = ACTIONS(3015),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [539] = {
    [anon_sym_LBRACK] = ACTIONS(2744),
    [aux_sym_type_token1] = ACTIONS(2744),
    [sym_kUses] = ACTIONS(2744),
    [sym_kBegin] = ACTIONS(2744),
    [sym_kAsm] = ACTIONS(2744),
    [sym_kVar] = ACTIONS(2746),
    [sym_kThreadvar] = ACTIONS(2744),
    [sym_kConst] = ACTIONS(2746),
    [sym_kResourcestring] = ACTIONS(2744),
    [sym_kType] = ACTIONS(2744),
    [sym_kLabel] = ACTIONS(2744),
    [sym_kExports] = ACTIONS(2744),
    [sym_kDefault] = ACTIONS(2744),
    [sym_kNodefault] = ACTIONS(2744),
    [sym_kDispId] = ACTIONS(2744),
    [sym_kClass] = ACTIONS(2744),
    [sym_kGeneric] = ACTIONS(2744),
    [sym_kFunction] = ACTIONS(2744),
    [sym_kProcedure] = ACTIONS(2744),
    [sym_kConstructor] = ACTIONS(2744),
    [sym_kDestructor] = ACTIONS(2744),
    [sym_kOperator] = ACTIONS(2744),
    [sym_kPublic] = ACTIONS(2744),
    [sym_kForward] = ACTIONS(2744),
    [sym_kStatic] = ACTIONS(2744),
    [sym_kVirtual] = ACTIONS(2744),
    [sym_kAbstract] = ACTIONS(2744),
    [sym_kDynamic] = ACTIONS(2744),
    [sym_kOverride] = ACTIONS(2744),
    [sym_kOverload] = ACTIONS(2744),
    [sym_kReintroduce] = ACTIONS(2744),
    [sym_kInline] = ACTIONS(2744),
    [sym_kStdcall] = ACTIONS(2744),
    [sym_kCdecl] = ACTIONS(2744),
    [sym_kCppdecl] = ACTIONS(2744),
    [sym_kPascal] = ACTIONS(2744),
    [sym_kRegister] = ACTIONS(2744),
    [sym_kMwpascal] = ACTIONS(2744),
    [sym_kExternal] = ACTIONS(2744),
    [sym_kMessage] = ACTIONS(2744),
    [sym_kDeprecated] = ACTIONS(2744),
    [sym_kExperimental] = ACTIONS(2744),
    [sym_kPlatform] = ACTIONS(2744),
    [sym_kUnimplemented] = ACTIONS(2744),
    [sym_kCvar] = ACTIONS(2744),
    [sym_kExport] = ACTIONS(2746),
    [sym_kFar] = ACTIONS(2744),
    [sym_kNear] = ACTIONS(2744),
    [sym_kSafecall] = ACTIONS(2744),
    [sym_kAssembler] = ACTIONS(2744),
    [sym_kNostackframe] = ACTIONS(2744),
    [sym_kInterrupt] = ACTIONS(2744),
    [sym_kNoreturn] = ACTIONS(2744),
    [sym_kIocheck] = ACTIONS(2744),
    [sym_kLocal] = ACTIONS(2744),
    [sym_kHardfloat] = ACTIONS(2744),
    [sym_kSoftfloat] = ACTIONS(2744),
    [sym_kMs_abi_default] = ACTIONS(2744),
    [sym_kMs_abi_cdecl] = ACTIONS(2744),
    [sym_kSaveregisters] = ACTIONS(2744),
    [sym_kSysv_abi_default] = ACTIONS(2744),
    [sym_kSysv_abi_cdecl] = ACTIONS(2744),
    [sym_kVectorcall] = ACTIONS(2744),
    [sym_kVarargs] = ACTIONS(2744),
    [sym_kWinapi] = ACTIONS(2744),
    [sym_kAlias] = ACTIONS(2744),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [540] = {
    [anon_sym_LBRACK] = ACTIONS(2787),
    [aux_sym_type_token1] = ACTIONS(2787),
    [sym_kUses] = ACTIONS(2787),
    [sym_kBegin] = ACTIONS(2787),
    [sym_kAsm] = ACTIONS(2787),
    [sym_kVar] = ACTIONS(2789),
    [sym_kThreadvar] = ACTIONS(2787),
    [sym_kConst] = ACTIONS(2789),
    [sym_kResourcestring] = ACTIONS(2787),
    [sym_kType] = ACTIONS(2787),
    [sym_kLabel] = ACTIONS(2787),
    [sym_kExports] = ACTIONS(2787),
    [sym_kDefault] = ACTIONS(2787),
    [sym_kNodefault] = ACTIONS(2787),
    [sym_kDispId] = ACTIONS(2787),
    [sym_kClass] = ACTIONS(2787),
    [sym_kGeneric] = ACTIONS(2787),
    [sym_kFunction] = ACTIONS(2787),
    [sym_kProcedure] = ACTIONS(2787),
    [sym_kConstructor] = ACTIONS(2787),
    [sym_kDestructor] = ACTIONS(2787),
    [sym_kOperator] = ACTIONS(2787),
    [sym_kPublic] = ACTIONS(2787),
    [sym_kForward] = ACTIONS(2787),
    [sym_kStatic] = ACTIONS(2787),
    [sym_kVirtual] = ACTIONS(2787),
    [sym_kAbstract] = ACTIONS(2787),
    [sym_kDynamic] = ACTIONS(2787),
    [sym_kOverride] = ACTIONS(2787),
    [sym_kOverload] = ACTIONS(2787),
    [sym_kReintroduce] = ACTIONS(2787),
    [sym_kInline] = ACTIONS(2787),
    [sym_kStdcall] = ACTIONS(2787),
    [sym_kCdecl] = ACTIONS(2787),
    [sym_kCppdecl] = ACTIONS(2787),
    [sym_kPascal] = ACTIONS(2787),
    [sym_kRegister] = ACTIONS(2787),
    [sym_kMwpascal] = ACTIONS(2787),
    [sym_kExternal] = ACTIONS(2787),
    [sym_kMessage] = ACTIONS(2787),
    [sym_kDeprecated] = ACTIONS(2787),
    [sym_kExperimental] = ACTIONS(2787),
    [sym_kPlatform] = ACTIONS(2787),
    [sym_kUnimplemented] = ACTIONS(2787),
    [sym_kCvar] = ACTIONS(2787),
    [sym_kExport] = ACTIONS(2789),
    [sym_kFar] = ACTIONS(2787),
    [sym_kNear] = ACTIONS(2787),
    [sym_kSafecall] = ACTIONS(2787),
    [sym_kAssembler] = ACTIONS(2787),
    [sym_kNostackframe] = ACTIONS(2787),
    [sym_kInterrupt] = ACTIONS(2787),
    [sym_kNoreturn] = ACTIONS(2787),
    [sym_kIocheck] = ACTIONS(2787),
    [sym_kLocal] = ACTIONS(2787),
    [sym_kHardfloat] = ACTIONS(2787),
    [sym_kSoftfloat] = ACTIONS(2787),
    [sym_kMs_abi_default] = ACTIONS(2787),
    [sym_kMs_abi_cdecl] = ACTIONS(2787),
    [sym_kSaveregisters] = ACTIONS(2787),
    [sym_kSysv_abi_default] = ACTIONS(2787),
    [sym_kSysv_abi_cdecl] = ACTIONS(2787),
    [sym_kVectorcall] = ACTIONS(2787),
    [sym_kVarargs] = ACTIONS(2787),
    [sym_kWinapi] = ACTIONS(2787),
    [sym_kAlias] = ACTIONS(2787),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [541] = {
    [sym_identifier] = ACTIONS(3019),
    [anon_sym_SEMI] = ACTIONS(3021),
    [anon_sym_COLON] = ACTIONS(3019),
    [anon_sym_COMMA] = ACTIONS(3021),
    [anon_sym_LBRACK] = ACTIONS(3021),
    [anon_sym_RBRACK] = ACTIONS(3021),
    [anon_sym_LPAREN] = ACTIONS(3019),
    [anon_sym_RPAREN] = ACTIONS(3021),
    [anon_sym_DOT] = ACTIONS(3021),
    [sym_kEnd] = ACTIONS(3019),
    [sym_kVar] = ACTIONS(3019),
    [sym_kThreadvar] = ACTIONS(3019),
    [sym_kConst] = ACTIONS(3019),
    [sym_kResourcestring] = ACTIONS(3019),
    [sym_kType] = ACTIONS(3019),
    [sym_kAbsolute] = ACTIONS(3019),
    [sym_kProperty] = ACTIONS(3019),
    [sym_kClass] = ACTIONS(3019),
    [sym_kOf] = ACTIONS(3019),
    [sym_kGeneric] = ACTIONS(3019),
    [sym_kLt] = ACTIONS(3019),
    [sym_kEq] = ACTIONS(3021),
    [sym_kNeq] = ACTIONS(3021),
    [sym_kGt] = ACTIONS(3019),
    [sym_kLte] = ACTIONS(3021),
    [sym_kGte] = ACTIONS(3021),
    [sym_kAdd] = ACTIONS(3019),
    [sym_kSub] = ACTIONS(3019),
    [sym_kMul] = ACTIONS(3019),
    [sym_kFdiv] = ACTIONS(3019),
    [sym_kHat] = ACTIONS(3021),
    [sym_kAssign] = ACTIONS(3021),
    [sym_kAssignAdd] = ACTIONS(3021),
    [sym_kAssignSub] = ACTIONS(3021),
    [sym_kAssignMul] = ACTIONS(3021),
    [sym_kAssignDiv] = ACTIONS(3021),
    [sym_kOr] = ACTIONS(3019),
    [sym_kXor] = ACTIONS(3019),
    [sym_kDiv] = ACTIONS(3019),
    [sym_kMod] = ACTIONS(3019),
    [sym_kAnd] = ACTIONS(3019),
    [sym_kShl] = ACTIONS(3019),
    [sym_kShr] = ACTIONS(3019),
    [sym_kIs] = ACTIONS(3019),
    [sym_kAs] = ACTIONS(3019),
    [sym_kIn] = ACTIONS(3019),
    [sym_kThen] = ACTIONS(3019),
    [sym_kElse] = ACTIONS(3019),
    [sym_kDo] = ACTIONS(3019),
    [sym_kUntil] = ACTIONS(3019),
    [sym_kExcept] = ACTIONS(3019),
    [sym_kFinally] = ACTIONS(3019),
    [sym_kCase] = ACTIONS(3019),
    [sym_kFunction] = ACTIONS(3019),
    [sym_kProcedure] = ACTIONS(3019),
    [sym_kConstructor] = ACTIONS(3019),
    [sym_kDestructor] = ACTIONS(3019),
    [sym_kOperator] = ACTIONS(3019),
    [sym_kPublished] = ACTIONS(3019),
    [sym_kPublic] = ACTIONS(3019),
    [sym_kProtected] = ACTIONS(3019),
    [sym_kPrivate] = ACTIONS(3019),
    [sym_kStrict] = ACTIONS(3019),
    [sym_kRequired] = ACTIONS(3019),
    [sym_kOptional] = ACTIONS(3019),
    [sym_kDelayed] = ACTIONS(3019),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [542] = {
    [sym_identifier] = ACTIONS(3023),
    [anon_sym_SEMI] = ACTIONS(3025),
    [anon_sym_COLON] = ACTIONS(3023),
    [anon_sym_COMMA] = ACTIONS(3025),
    [anon_sym_LBRACK] = ACTIONS(3025),
    [anon_sym_RBRACK] = ACTIONS(3025),
    [anon_sym_LPAREN] = ACTIONS(3023),
    [anon_sym_RPAREN] = ACTIONS(3025),
    [anon_sym_DOT] = ACTIONS(3025),
    [sym_kEnd] = ACTIONS(3023),
    [sym_kVar] = ACTIONS(3023),
    [sym_kThreadvar] = ACTIONS(3023),
    [sym_kConst] = ACTIONS(3023),
    [sym_kResourcestring] = ACTIONS(3023),
    [sym_kType] = ACTIONS(3023),
    [sym_kAbsolute] = ACTIONS(3023),
    [sym_kProperty] = ACTIONS(3023),
    [sym_kClass] = ACTIONS(3023),
    [sym_kOf] = ACTIONS(3023),
    [sym_kGeneric] = ACTIONS(3023),
    [sym_kLt] = ACTIONS(3023),
    [sym_kEq] = ACTIONS(3025),
    [sym_kNeq] = ACTIONS(3025),
    [sym_kGt] = ACTIONS(3023),
    [sym_kLte] = ACTIONS(3025),
    [sym_kGte] = ACTIONS(3025),
    [sym_kAdd] = ACTIONS(3023),
    [sym_kSub] = ACTIONS(3023),
    [sym_kMul] = ACTIONS(3023),
    [sym_kFdiv] = ACTIONS(3023),
    [sym_kHat] = ACTIONS(3025),
    [sym_kAssign] = ACTIONS(3025),
    [sym_kAssignAdd] = ACTIONS(3025),
    [sym_kAssignSub] = ACTIONS(3025),
    [sym_kAssignMul] = ACTIONS(3025),
    [sym_kAssignDiv] = ACTIONS(3025),
    [sym_kOr] = ACTIONS(3023),
    [sym_kXor] = ACTIONS(3023),
    [sym_kDiv] = ACTIONS(3023),
    [sym_kMod] = ACTIONS(3023),
    [sym_kAnd] = ACTIONS(3023),
    [sym_kShl] = ACTIONS(3023),
    [sym_kShr] = ACTIONS(3023),
    [sym_kIs] = ACTIONS(3023),
    [sym_kAs] = ACTIONS(3023),
    [sym_kIn] = ACTIONS(3023),
    [sym_kThen] = ACTIONS(3023),
    [sym_kElse] = ACTIONS(3023),
    [sym_kDo] = ACTIONS(3023),
    [sym_kUntil] = ACTIONS(3023),
    [sym_kExcept] = ACTIONS(3023),
    [sym_kFinally] = ACTIONS(3023),
    [sym_kCase] = ACTIONS(3023),
    [sym_kFunction] = ACTIONS(3023),
    [sym_kProcedure] = ACTIONS(3023),
    [sym_kConstructor] = ACTIONS(3023),
    [sym_kDestructor] = ACTIONS(3023),
    [sym_kOperator] = ACTIONS(3023),
    [sym_kPublished] = ACTIONS(3023),
    [sym_kPublic] = ACTIONS(3023),
    [sym_kProtected] = ACTIONS(3023),
    [sym_kPrivate] = ACTIONS(3023),
    [sym_kStrict] = ACTIONS(3023),
    [sym_kRequired] = ACTIONS(3023),
    [sym_kOptional] = ACTIONS(3023),
    [sym_kDelayed] = ACTIONS(3023),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [543] = {
    [anon_sym_LBRACK] = ACTIONS(2794),
    [aux_sym_type_token1] = ACTIONS(2794),
    [sym_kUses] = ACTIONS(2794),
    [sym_kBegin] = ACTIONS(2794),
    [sym_kAsm] = ACTIONS(2794),
    [sym_kVar] = ACTIONS(2796),
    [sym_kThreadvar] = ACTIONS(2794),
    [sym_kConst] = ACTIONS(2796),
    [sym_kResourcestring] = ACTIONS(2794),
    [sym_kType] = ACTIONS(2794),
    [sym_kLabel] = ACTIONS(2794),
    [sym_kExports] = ACTIONS(2794),
    [sym_kDefault] = ACTIONS(2794),
    [sym_kNodefault] = ACTIONS(2794),
    [sym_kDispId] = ACTIONS(2794),
    [sym_kClass] = ACTIONS(2794),
    [sym_kGeneric] = ACTIONS(2794),
    [sym_kFunction] = ACTIONS(2794),
    [sym_kProcedure] = ACTIONS(2794),
    [sym_kConstructor] = ACTIONS(2794),
    [sym_kDestructor] = ACTIONS(2794),
    [sym_kOperator] = ACTIONS(2794),
    [sym_kPublic] = ACTIONS(2794),
    [sym_kForward] = ACTIONS(2794),
    [sym_kStatic] = ACTIONS(2794),
    [sym_kVirtual] = ACTIONS(2794),
    [sym_kAbstract] = ACTIONS(2794),
    [sym_kDynamic] = ACTIONS(2794),
    [sym_kOverride] = ACTIONS(2794),
    [sym_kOverload] = ACTIONS(2794),
    [sym_kReintroduce] = ACTIONS(2794),
    [sym_kInline] = ACTIONS(2794),
    [sym_kStdcall] = ACTIONS(2794),
    [sym_kCdecl] = ACTIONS(2794),
    [sym_kCppdecl] = ACTIONS(2794),
    [sym_kPascal] = ACTIONS(2794),
    [sym_kRegister] = ACTIONS(2794),
    [sym_kMwpascal] = ACTIONS(2794),
    [sym_kExternal] = ACTIONS(2794),
    [sym_kMessage] = ACTIONS(2794),
    [sym_kDeprecated] = ACTIONS(2794),
    [sym_kExperimental] = ACTIONS(2794),
    [sym_kPlatform] = ACTIONS(2794),
    [sym_kUnimplemented] = ACTIONS(2794),
    [sym_kCvar] = ACTIONS(2794),
    [sym_kExport] = ACTIONS(2796),
    [sym_kFar] = ACTIONS(2794),
    [sym_kNear] = ACTIONS(2794),
    [sym_kSafecall] = ACTIONS(2794),
    [sym_kAssembler] = ACTIONS(2794),
    [sym_kNostackframe] = ACTIONS(2794),
    [sym_kInterrupt] = ACTIONS(2794),
    [sym_kNoreturn] = ACTIONS(2794),
    [sym_kIocheck] = ACTIONS(2794),
    [sym_kLocal] = ACTIONS(2794),
    [sym_kHardfloat] = ACTIONS(2794),
    [sym_kSoftfloat] = ACTIONS(2794),
    [sym_kMs_abi_default] = ACTIONS(2794),
    [sym_kMs_abi_cdecl] = ACTIONS(2794),
    [sym_kSaveregisters] = ACTIONS(2794),
    [sym_kSysv_abi_default] = ACTIONS(2794),
    [sym_kSysv_abi_cdecl] = ACTIONS(2794),
    [sym_kVectorcall] = ACTIONS(2794),
    [sym_kVarargs] = ACTIONS(2794),
    [sym_kWinapi] = ACTIONS(2794),
    [sym_kAlias] = ACTIONS(2794),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [544] = {
    [sym_identifier] = ACTIONS(3027),
    [anon_sym_SEMI] = ACTIONS(3029),
    [anon_sym_COLON] = ACTIONS(3027),
    [anon_sym_COMMA] = ACTIONS(3029),
    [anon_sym_LBRACK] = ACTIONS(3029),
    [anon_sym_RBRACK] = ACTIONS(3029),
    [anon_sym_LPAREN] = ACTIONS(3027),
    [anon_sym_RPAREN] = ACTIONS(3029),
    [anon_sym_DOT] = ACTIONS(3029),
    [sym_kEnd] = ACTIONS(3027),
    [sym_kVar] = ACTIONS(3027),
    [sym_kThreadvar] = ACTIONS(3027),
    [sym_kConst] = ACTIONS(3027),
    [sym_kResourcestring] = ACTIONS(3027),
    [sym_kType] = ACTIONS(3027),
    [sym_kAbsolute] = ACTIONS(3027),
    [sym_kProperty] = ACTIONS(3027),
    [sym_kClass] = ACTIONS(3027),
    [sym_kOf] = ACTIONS(3027),
    [sym_kGeneric] = ACTIONS(3027),
    [sym_kLt] = ACTIONS(3027),
    [sym_kEq] = ACTIONS(3029),
    [sym_kNeq] = ACTIONS(3029),
    [sym_kGt] = ACTIONS(3027),
    [sym_kLte] = ACTIONS(3029),
    [sym_kGte] = ACTIONS(3029),
    [sym_kAdd] = ACTIONS(3027),
    [sym_kSub] = ACTIONS(3027),
    [sym_kMul] = ACTIONS(3027),
    [sym_kFdiv] = ACTIONS(3027),
    [sym_kHat] = ACTIONS(3029),
    [sym_kAssign] = ACTIONS(3029),
    [sym_kAssignAdd] = ACTIONS(3029),
    [sym_kAssignSub] = ACTIONS(3029),
    [sym_kAssignMul] = ACTIONS(3029),
    [sym_kAssignDiv] = ACTIONS(3029),
    [sym_kOr] = ACTIONS(3027),
    [sym_kXor] = ACTIONS(3027),
    [sym_kDiv] = ACTIONS(3027),
    [sym_kMod] = ACTIONS(3027),
    [sym_kAnd] = ACTIONS(3027),
    [sym_kShl] = ACTIONS(3027),
    [sym_kShr] = ACTIONS(3027),
    [sym_kIs] = ACTIONS(3027),
    [sym_kAs] = ACTIONS(3027),
    [sym_kIn] = ACTIONS(3027),
    [sym_kThen] = ACTIONS(3027),
    [sym_kElse] = ACTIONS(3027),
    [sym_kDo] = ACTIONS(3027),
    [sym_kUntil] = ACTIONS(3027),
    [sym_kExcept] = ACTIONS(3027),
    [sym_kFinally] = ACTIONS(3027),
    [sym_kCase] = ACTIONS(3027),
    [sym_kFunction] = ACTIONS(3027),
    [sym_kProcedure] = ACTIONS(3027),
    [sym_kConstructor] = ACTIONS(3027),
    [sym_kDestructor] = ACTIONS(3027),
    [sym_kOperator] = ACTIONS(3027),
    [sym_kPublished] = ACTIONS(3027),
    [sym_kPublic] = ACTIONS(3027),
    [sym_kProtected] = ACTIONS(3027),
    [sym_kPrivate] = ACTIONS(3027),
    [sym_kStrict] = ACTIONS(3027),
    [sym_kRequired] = ACTIONS(3027),
    [sym_kOptional] = ACTIONS(3027),
    [sym_kDelayed] = ACTIONS(3027),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [545] = {
    [sym_identifier] = ACTIONS(3031),
    [anon_sym_SEMI] = ACTIONS(3033),
    [anon_sym_COLON] = ACTIONS(3031),
    [anon_sym_COMMA] = ACTIONS(3033),
    [anon_sym_LBRACK] = ACTIONS(3033),
    [anon_sym_RBRACK] = ACTIONS(3033),
    [anon_sym_LPAREN] = ACTIONS(3031),
    [anon_sym_RPAREN] = ACTIONS(3033),
    [anon_sym_DOT] = ACTIONS(3033),
    [sym_kEnd] = ACTIONS(3031),
    [sym_kVar] = ACTIONS(3031),
    [sym_kThreadvar] = ACTIONS(3031),
    [sym_kConst] = ACTIONS(3031),
    [sym_kResourcestring] = ACTIONS(3031),
    [sym_kType] = ACTIONS(3031),
    [sym_kAbsolute] = ACTIONS(3031),
    [sym_kProperty] = ACTIONS(3031),
    [sym_kClass] = ACTIONS(3031),
    [sym_kOf] = ACTIONS(3031),
    [sym_kGeneric] = ACTIONS(3031),
    [sym_kLt] = ACTIONS(3031),
    [sym_kEq] = ACTIONS(3033),
    [sym_kNeq] = ACTIONS(3033),
    [sym_kGt] = ACTIONS(3031),
    [sym_kLte] = ACTIONS(3033),
    [sym_kGte] = ACTIONS(3033),
    [sym_kAdd] = ACTIONS(3031),
    [sym_kSub] = ACTIONS(3031),
    [sym_kMul] = ACTIONS(3031),
    [sym_kFdiv] = ACTIONS(3031),
    [sym_kHat] = ACTIONS(3033),
    [sym_kAssign] = ACTIONS(3033),
    [sym_kAssignAdd] = ACTIONS(3033),
    [sym_kAssignSub] = ACTIONS(3033),
    [sym_kAssignMul] = ACTIONS(3033),
    [sym_kAssignDiv] = ACTIONS(3033),
    [sym_kOr] = ACTIONS(3031),
    [sym_kXor] = ACTIONS(3031),
    [sym_kDiv] = ACTIONS(3031),
    [sym_kMod] = ACTIONS(3031),
    [sym_kAnd] = ACTIONS(3031),
    [sym_kShl] = ACTIONS(3031),
    [sym_kShr] = ACTIONS(3031),
    [sym_kIs] = ACTIONS(3031),
    [sym_kAs] = ACTIONS(3031),
    [sym_kIn] = ACTIONS(3031),
    [sym_kThen] = ACTIONS(3031),
    [sym_kElse] = ACTIONS(3031),
    [sym_kDo] = ACTIONS(3031),
    [sym_kUntil] = ACTIONS(3031),
    [sym_kExcept] = ACTIONS(3031),
    [sym_kFinally] = ACTIONS(3031),
    [sym_kCase] = ACTIONS(3031),
    [sym_kFunction] = ACTIONS(3031),
    [sym_kProcedure] = ACTIONS(3031),
    [sym_kConstructor] = ACTIONS(3031),
    [sym_kDestructor] = ACTIONS(3031),
    [sym_kOperator] = ACTIONS(3031),
    [sym_kPublished] = ACTIONS(3031),
    [sym_kPublic] = ACTIONS(3031),
    [sym_kProtected] = ACTIONS(3031),
    [sym_kPrivate] = ACTIONS(3031),
    [sym_kStrict] = ACTIONS(3031),
    [sym_kRequired] = ACTIONS(3031),
    [sym_kOptional] = ACTIONS(3031),
    [sym_kDelayed] = ACTIONS(3031),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [546] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COLON] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT_DOT] = ACTIONS(267),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [547] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym_type_token2] = ACTIONS(279),
    [aux_sym_type_token3] = ACTIONS(279),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kOf] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [548] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_RBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT_DOT] = ACTIONS(279),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [549] = {
    [sym__expr] = STATE(1328),
    [sym__ref] = STATE(1250),
    [sym_lambda] = STATE(1250),
    [sym_inherited] = STATE(1250),
    [sym_exprDot] = STATE(1250),
    [sym_exprDeref] = STATE(1250),
    [sym_exprAs] = STATE(1250),
    [sym_exprTpl] = STATE(1250),
    [sym_exprSubscript] = STATE(1250),
    [sym_exprCall] = STATE(1250),
    [sym_exprBinary] = STATE(1328),
    [sym_exprUnary] = STATE(1328),
    [sym_exprParens] = STATE(1250),
    [sym_exprBrackets] = STATE(1250),
    [sym__literal] = STATE(1250),
    [sym_literalString] = STATE(1250),
    [sym__literalString] = STATE(1203),
    [sym_literalChar] = STATE(1203),
    [sym_literalNumber] = STATE(1250),
    [sym__literalInt] = STATE(1299),
    [sym__literalFloat] = STATE(1299),
    [aux_sym_literalString_repeat1] = STATE(1203),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym_type_token2] = ACTIONS(267),
    [aux_sym_type_token3] = ACTIONS(267),
    [aux_sym__literalString_token1] = ACTIONS(3037),
    [anon_sym_POUND] = ACTIONS(3039),
    [aux_sym__literalInt_token1] = ACTIONS(3041),
    [aux_sym__literalInt_token2] = ACTIONS(3043),
    [aux_sym__literalFloat_token1] = ACTIONS(3041),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(3045),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(3047),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(3049),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(3051),
    [sym_kProcedure] = ACTIONS(3051),
    [sym_kInherited] = ACTIONS(3053),
    [sym_kNil] = ACTIONS(3035),
    [sym_kTrue] = ACTIONS(3035),
    [sym_kFalse] = ACTIONS(3035),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [550] = {
    [sym__visibility] = STATE(1077),
    [aux_sym__classDeclarations] = STATE(1081),
    [sym_declTypes] = STATE(1081),
    [sym_declVars] = STATE(1081),
    [sym_declConsts] = STATE(1081),
    [sym_declProc] = STATE(1081),
    [sym__declClass] = STATE(2450),
    [sym_declSection] = STATE(1676),
    [aux_sym__declFields] = STATE(930),
    [sym_declField] = STATE(930),
    [sym_declProp] = STATE(1081),
    [sym_declVariant] = STATE(2351),
    [sym__declProc] = STATE(1545),
    [sym__declOperator] = STATE(1233),
    [sym_rttiAttributes] = STATE(1679),
    [aux_sym_genericArg_repeat1] = STATE(2168),
    [aux_sym__declClass_repeat1] = STATE(1676),
    [aux_sym_rttiAttributes_repeat2] = STATE(1680),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_SEMI] = ACTIONS(3057),
    [anon_sym_LBRACK] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(3059),
    [sym_kEnd] = ACTIONS(3061),
    [sym_kVar] = ACTIONS(3063),
    [sym_kThreadvar] = ACTIONS(3063),
    [sym_kConst] = ACTIONS(3065),
    [sym_kResourcestring] = ACTIONS(3065),
    [sym_kType] = ACTIONS(3067),
    [sym_kProperty] = ACTIONS(3069),
    [sym_kClass] = ACTIONS(3071),
    [sym_kGeneric] = ACTIONS(3073),
    [sym_kLt] = ACTIONS(3075),
    [sym_kEq] = ACTIONS(3077),
    [sym_kNeq] = ACTIONS(3077),
    [sym_kGt] = ACTIONS(3075),
    [sym_kLte] = ACTIONS(3077),
    [sym_kGte] = ACTIONS(3077),
    [sym_kAdd] = ACTIONS(3079),
    [sym_kSub] = ACTIONS(3079),
    [sym_kMul] = ACTIONS(3081),
    [sym_kFdiv] = ACTIONS(3083),
    [sym_kHat] = ACTIONS(2987),
    [sym_kOr] = ACTIONS(3085),
    [sym_kXor] = ACTIONS(3085),
    [sym_kDiv] = ACTIONS(3083),
    [sym_kMod] = ACTIONS(3083),
    [sym_kAnd] = ACTIONS(3083),
    [sym_kShl] = ACTIONS(3083),
    [sym_kShr] = ACTIONS(3083),
    [sym_kIs] = ACTIONS(3075),
    [sym_kAs] = ACTIONS(3087),
    [sym_kIn] = ACTIONS(3075),
    [sym_kCase] = ACTIONS(3089),
    [sym_kFunction] = ACTIONS(3091),
    [sym_kProcedure] = ACTIONS(3091),
    [sym_kConstructor] = ACTIONS(3091),
    [sym_kDestructor] = ACTIONS(3091),
    [sym_kOperator] = ACTIONS(3093),
    [sym_kPublished] = ACTIONS(3095),
    [sym_kPublic] = ACTIONS(3095),
    [sym_kProtected] = ACTIONS(3095),
    [sym_kPrivate] = ACTIONS(3095),
    [sym_kStrict] = ACTIONS(3097),
    [sym_kRequired] = ACTIONS(3095),
    [sym_kOptional] = ACTIONS(3095),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [551] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym_type_token2] = ACTIONS(267),
    [aux_sym_type_token3] = ACTIONS(267),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kOf] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [552] = {
    [sym__visibility] = STATE(1077),
    [aux_sym__classDeclarations] = STATE(1081),
    [sym_declTypes] = STATE(1081),
    [sym_declVars] = STATE(1081),
    [sym_declConsts] = STATE(1081),
    [sym_declProc] = STATE(1081),
    [sym__declClass] = STATE(2689),
    [sym_declSection] = STATE(1676),
    [aux_sym__declFields] = STATE(930),
    [sym_declField] = STATE(930),
    [sym_declProp] = STATE(1081),
    [sym_declVariant] = STATE(2351),
    [sym__declProc] = STATE(1545),
    [sym__declOperator] = STATE(1233),
    [sym_rttiAttributes] = STATE(1679),
    [aux_sym_genericArg_repeat1] = STATE(2168),
    [aux_sym__declClass_repeat1] = STATE(1676),
    [aux_sym_rttiAttributes_repeat2] = STATE(1680),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_SEMI] = ACTIONS(3099),
    [anon_sym_LBRACK] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(3101),
    [sym_kEnd] = ACTIONS(3103),
    [sym_kVar] = ACTIONS(3063),
    [sym_kThreadvar] = ACTIONS(3063),
    [sym_kConst] = ACTIONS(3065),
    [sym_kResourcestring] = ACTIONS(3065),
    [sym_kType] = ACTIONS(3067),
    [sym_kProperty] = ACTIONS(3069),
    [sym_kClass] = ACTIONS(3071),
    [sym_kGeneric] = ACTIONS(3073),
    [sym_kLt] = ACTIONS(3075),
    [sym_kEq] = ACTIONS(3077),
    [sym_kNeq] = ACTIONS(3077),
    [sym_kGt] = ACTIONS(3075),
    [sym_kLte] = ACTIONS(3077),
    [sym_kGte] = ACTIONS(3077),
    [sym_kAdd] = ACTIONS(3079),
    [sym_kSub] = ACTIONS(3079),
    [sym_kMul] = ACTIONS(3081),
    [sym_kFdiv] = ACTIONS(3083),
    [sym_kHat] = ACTIONS(2987),
    [sym_kOr] = ACTIONS(3085),
    [sym_kXor] = ACTIONS(3085),
    [sym_kDiv] = ACTIONS(3083),
    [sym_kMod] = ACTIONS(3083),
    [sym_kAnd] = ACTIONS(3083),
    [sym_kShl] = ACTIONS(3083),
    [sym_kShr] = ACTIONS(3083),
    [sym_kIs] = ACTIONS(3075),
    [sym_kAs] = ACTIONS(3087),
    [sym_kIn] = ACTIONS(3075),
    [sym_kCase] = ACTIONS(3089),
    [sym_kFunction] = ACTIONS(3091),
    [sym_kProcedure] = ACTIONS(3091),
    [sym_kConstructor] = ACTIONS(3091),
    [sym_kDestructor] = ACTIONS(3091),
    [sym_kOperator] = ACTIONS(3093),
    [sym_kPublished] = ACTIONS(3095),
    [sym_kPublic] = ACTIONS(3095),
    [sym_kProtected] = ACTIONS(3095),
    [sym_kPrivate] = ACTIONS(3095),
    [sym_kStrict] = ACTIONS(3097),
    [sym_kRequired] = ACTIONS(3095),
    [sym_kOptional] = ACTIONS(3095),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [553] = {
    [sym__expr] = STATE(1267),
    [sym__ref] = STATE(1254),
    [sym_lambda] = STATE(1254),
    [sym_inherited] = STATE(1254),
    [sym_exprDot] = STATE(1254),
    [sym_exprDeref] = STATE(1254),
    [sym_exprAs] = STATE(1254),
    [sym_exprTpl] = STATE(1254),
    [sym_exprSubscript] = STATE(1254),
    [sym_exprCall] = STATE(1254),
    [sym_exprBinary] = STATE(1267),
    [sym_exprUnary] = STATE(1267),
    [sym_exprParens] = STATE(1254),
    [sym_exprBrackets] = STATE(1254),
    [sym__literal] = STATE(1254),
    [sym_literalString] = STATE(1254),
    [sym__literalString] = STATE(1196),
    [sym_literalChar] = STATE(1196),
    [sym_literalNumber] = STATE(1254),
    [sym__literalInt] = STATE(1289),
    [sym__literalFloat] = STATE(1289),
    [aux_sym_literalString_repeat1] = STATE(1196),
    [sym_identifier] = ACTIONS(3105),
    [anon_sym_COLON] = ACTIONS(267),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(3107),
    [anon_sym_POUND] = ACTIONS(3109),
    [aux_sym__literalInt_token1] = ACTIONS(3111),
    [aux_sym__literalInt_token2] = ACTIONS(3113),
    [aux_sym__literalFloat_token1] = ACTIONS(3111),
    [anon_sym_DOT_DOT] = ACTIONS(267),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(3115),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(3117),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(3119),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(3121),
    [sym_kProcedure] = ACTIONS(3121),
    [sym_kInherited] = ACTIONS(3123),
    [sym_kNil] = ACTIONS(3105),
    [sym_kTrue] = ACTIONS(3105),
    [sym_kFalse] = ACTIONS(3105),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [554] = {
    [sym__expr] = STATE(1373),
    [sym__ref] = STATE(1257),
    [sym_lambda] = STATE(1257),
    [sym_inherited] = STATE(1257),
    [sym_exprDot] = STATE(1257),
    [sym_exprDeref] = STATE(1257),
    [sym_exprAs] = STATE(1257),
    [sym_exprTpl] = STATE(1257),
    [sym_exprSubscript] = STATE(1257),
    [sym_exprCall] = STATE(1257),
    [sym_exprBinary] = STATE(1373),
    [sym_exprUnary] = STATE(1373),
    [sym_exprParens] = STATE(1257),
    [sym_exprBrackets] = STATE(1257),
    [sym__literal] = STATE(1257),
    [sym_literalString] = STATE(1257),
    [sym__literalString] = STATE(1205),
    [sym_literalChar] = STATE(1205),
    [sym_literalNumber] = STATE(1257),
    [sym__literalInt] = STATE(1385),
    [sym__literalFloat] = STATE(1385),
    [aux_sym_literalString_repeat1] = STATE(1205),
    [sym_identifier] = ACTIONS(3125),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(3127),
    [anon_sym_POUND] = ACTIONS(3129),
    [aux_sym__literalInt_token1] = ACTIONS(3131),
    [aux_sym__literalInt_token2] = ACTIONS(3133),
    [aux_sym__literalFloat_token1] = ACTIONS(3131),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(3135),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(3137),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(3139),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kTo] = ACTIONS(265),
    [sym_kDownto] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(3141),
    [sym_kProcedure] = ACTIONS(3141),
    [sym_kInherited] = ACTIONS(3143),
    [sym_kNil] = ACTIONS(3125),
    [sym_kTrue] = ACTIONS(3125),
    [sym_kFalse] = ACTIONS(3125),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [555] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(265),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(265),
    [sym_kEq] = ACTIONS(267),
    [sym_kNeq] = ACTIONS(267),
    [sym_kGt] = ACTIONS(265),
    [sym_kLte] = ACTIONS(267),
    [sym_kGte] = ACTIONS(267),
    [sym_kAdd] = ACTIONS(265),
    [sym_kSub] = ACTIONS(265),
    [sym_kMul] = ACTIONS(267),
    [sym_kFdiv] = ACTIONS(265),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(267),
    [sym_kOr] = ACTIONS(265),
    [sym_kXor] = ACTIONS(265),
    [sym_kDiv] = ACTIONS(265),
    [sym_kMod] = ACTIONS(265),
    [sym_kAnd] = ACTIONS(265),
    [sym_kShl] = ACTIONS(265),
    [sym_kShr] = ACTIONS(265),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(265),
    [sym_kAs] = ACTIONS(265),
    [sym_kIn] = ACTIONS(265),
    [sym_kTo] = ACTIONS(265),
    [sym_kDownto] = ACTIONS(265),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [556] = {
    [sym__expr] = STATE(886),
    [sym__ref] = STATE(669),
    [sym_lambda] = STATE(669),
    [sym_inherited] = STATE(669),
    [sym_exprDot] = STATE(669),
    [sym_exprDeref] = STATE(669),
    [sym_exprAs] = STATE(669),
    [sym_exprTpl] = STATE(669),
    [sym_exprSubscript] = STATE(669),
    [sym_exprCall] = STATE(669),
    [sym_exprBinary] = STATE(886),
    [sym_exprUnary] = STATE(886),
    [sym_exprParens] = STATE(669),
    [sym_exprBrackets] = STATE(669),
    [sym__literal] = STATE(669),
    [sym_literalString] = STATE(669),
    [sym__literalString] = STATE(249),
    [sym_literalChar] = STATE(249),
    [sym_literalNumber] = STATE(669),
    [sym__literalInt] = STATE(523),
    [sym__literalFloat] = STATE(523),
    [aux_sym_literalString_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(277),
    [aux_sym__literalString_token1] = ACTIONS(49),
    [anon_sym_POUND] = ACTIONS(51),
    [aux_sym__literalInt_token1] = ACTIONS(53),
    [aux_sym__literalInt_token2] = ACTIONS(55),
    [aux_sym__literalFloat_token1] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(277),
    [sym_kSpecialize] = ACTIONS(65),
    [sym_kLt] = ACTIONS(277),
    [sym_kEq] = ACTIONS(279),
    [sym_kNeq] = ACTIONS(279),
    [sym_kGt] = ACTIONS(277),
    [sym_kLte] = ACTIONS(279),
    [sym_kGte] = ACTIONS(279),
    [sym_kAdd] = ACTIONS(277),
    [sym_kSub] = ACTIONS(277),
    [sym_kMul] = ACTIONS(279),
    [sym_kFdiv] = ACTIONS(277),
    [sym_kAt] = ACTIONS(69),
    [sym_kHat] = ACTIONS(279),
    [sym_kOr] = ACTIONS(277),
    [sym_kXor] = ACTIONS(277),
    [sym_kDiv] = ACTIONS(277),
    [sym_kMod] = ACTIONS(277),
    [sym_kAnd] = ACTIONS(277),
    [sym_kShl] = ACTIONS(277),
    [sym_kShr] = ACTIONS(277),
    [sym_kNot] = ACTIONS(67),
    [sym_kIs] = ACTIONS(277),
    [sym_kAs] = ACTIONS(277),
    [sym_kIn] = ACTIONS(277),
    [sym_kTo] = ACTIONS(277),
    [sym_kDownto] = ACTIONS(277),
    [sym_kFunction] = ACTIONS(91),
    [sym_kProcedure] = ACTIONS(91),
    [sym_kInherited] = ACTIONS(93),
    [sym_kNil] = ACTIONS(95),
    [sym_kTrue] = ACTIONS(95),
    [sym_kFalse] = ACTIONS(95),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [557] = {
    [sym_kDot] = STATE(1889),
    [sym_identifier] = ACTIONS(3145),
    [anon_sym_SEMI] = ACTIONS(3147),
    [anon_sym_COMMA] = ACTIONS(3147),
    [anon_sym_LBRACK] = ACTIONS(3147),
    [anon_sym_RBRACK] = ACTIONS(3147),
    [anon_sym_RPAREN] = ACTIONS(3147),
    [sym_kUses] = ACTIONS(3145),
    [sym_kInterface] = ACTIONS(3145),
    [sym_kImplementation] = ACTIONS(3145),
    [sym_kInitialization] = ACTIONS(3145),
    [sym_kFinalization] = ACTIONS(3145),
    [anon_sym_DOT] = ACTIONS(3147),
    [sym_kBegin] = ACTIONS(3145),
    [sym_kEnd] = ACTIONS(3145),
    [sym_kAsm] = ACTIONS(3145),
    [sym_kVar] = ACTIONS(3145),
    [sym_kThreadvar] = ACTIONS(3145),
    [sym_kConst] = ACTIONS(3145),
    [sym_kResourcestring] = ACTIONS(3145),
    [sym_kType] = ACTIONS(3145),
    [sym_kLabel] = ACTIONS(3145),
    [sym_kExports] = ACTIONS(3145),
    [sym_kAbsolute] = ACTIONS(3145),
    [sym_kProperty] = ACTIONS(3145),
    [sym_kRead] = ACTIONS(3145),
    [sym_kWrite] = ACTIONS(3145),
    [sym_kImplements] = ACTIONS(3145),
    [sym_kDefault] = ACTIONS(3145),
    [sym_kNodefault] = ACTIONS(3145),
    [sym_kStored] = ACTIONS(3145),
    [sym_kIndex] = ACTIONS(3145),
    [sym_kDispId] = ACTIONS(3145),
    [sym_kClass] = ACTIONS(3145),
    [sym_kOf] = ACTIONS(3145),
    [sym_kGeneric] = ACTIONS(3145),
    [sym_kLt] = ACTIONS(3147),
    [sym_kEq] = ACTIONS(3147),
    [sym_kGt] = ACTIONS(3147),
    [sym_kAssign] = ACTIONS(3147),
    [sym_kAssignAdd] = ACTIONS(3147),
    [sym_kAssignSub] = ACTIONS(3147),
    [sym_kAssignMul] = ACTIONS(3147),
    [sym_kAssignDiv] = ACTIONS(3147),
    [sym_kElse] = ACTIONS(3145),
    [sym_kDo] = ACTIONS(3145),
    [sym_kUntil] = ACTIONS(3145),
    [sym_kExcept] = ACTIONS(3145),
    [sym_kFinally] = ACTIONS(3145),
    [sym_kCase] = ACTIONS(3145),
    [sym_kFunction] = ACTIONS(3145),
    [sym_kProcedure] = ACTIONS(3145),
    [sym_kConstructor] = ACTIONS(3145),
    [sym_kDestructor] = ACTIONS(3145),
    [sym_kOperator] = ACTIONS(3145),
    [sym_kPublished] = ACTIONS(3145),
    [sym_kPublic] = ACTIONS(3145),
    [sym_kProtected] = ACTIONS(3145),
    [sym_kPrivate] = ACTIONS(3145),
    [sym_kStrict] = ACTIONS(3145),
    [sym_kRequired] = ACTIONS(3145),
    [sym_kOptional] = ACTIONS(3145),
    [sym_kDeprecated] = ACTIONS(3145),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [558] = {
    [sym_kDot] = STATE(1889),
    [sym_identifier] = ACTIONS(3149),
    [anon_sym_SEMI] = ACTIONS(3151),
    [anon_sym_COMMA] = ACTIONS(3151),
    [anon_sym_LBRACK] = ACTIONS(3151),
    [anon_sym_RBRACK] = ACTIONS(3151),
    [anon_sym_RPAREN] = ACTIONS(3151),
    [sym_kUses] = ACTIONS(3149),
    [sym_kInterface] = ACTIONS(3149),
    [sym_kImplementation] = ACTIONS(3149),
    [sym_kInitialization] = ACTIONS(3149),
    [sym_kFinalization] = ACTIONS(3149),
    [anon_sym_DOT] = ACTIONS(3151),
    [sym_kBegin] = ACTIONS(3149),
    [sym_kEnd] = ACTIONS(3149),
    [sym_kAsm] = ACTIONS(3149),
    [sym_kVar] = ACTIONS(3149),
    [sym_kThreadvar] = ACTIONS(3149),
    [sym_kConst] = ACTIONS(3149),
    [sym_kResourcestring] = ACTIONS(3149),
    [sym_kType] = ACTIONS(3149),
    [sym_kLabel] = ACTIONS(3149),
    [sym_kExports] = ACTIONS(3149),
    [sym_kAbsolute] = ACTIONS(3149),
    [sym_kProperty] = ACTIONS(3149),
    [sym_kRead] = ACTIONS(3149),
    [sym_kWrite] = ACTIONS(3149),
    [sym_kImplements] = ACTIONS(3149),
    [sym_kDefault] = ACTIONS(3149),
    [sym_kNodefault] = ACTIONS(3149),
    [sym_kStored] = ACTIONS(3149),
    [sym_kIndex] = ACTIONS(3149),
    [sym_kDispId] = ACTIONS(3149),
    [sym_kClass] = ACTIONS(3149),
    [sym_kOf] = ACTIONS(3149),
    [sym_kGeneric] = ACTIONS(3149),
    [sym_kLt] = ACTIONS(3151),
    [sym_kEq] = ACTIONS(3151),
    [sym_kGt] = ACTIONS(3151),
    [sym_kAssign] = ACTIONS(3151),
    [sym_kAssignAdd] = ACTIONS(3151),
    [sym_kAssignSub] = ACTIONS(3151),
    [sym_kAssignMul] = ACTIONS(3151),
    [sym_kAssignDiv] = ACTIONS(3151),
    [sym_kElse] = ACTIONS(3149),
    [sym_kDo] = ACTIONS(3149),
    [sym_kUntil] = ACTIONS(3149),
    [sym_kExcept] = ACTIONS(3149),
    [sym_kFinally] = ACTIONS(3149),
    [sym_kCase] = ACTIONS(3149),
    [sym_kFunction] = ACTIONS(3149),
    [sym_kProcedure] = ACTIONS(3149),
    [sym_kConstructor] = ACTIONS(3149),
    [sym_kDestructor] = ACTIONS(3149),
    [sym_kOperator] = ACTIONS(3149),
    [sym_kPublished] = ACTIONS(3149),
    [sym_kPublic] = ACTIONS(3149),
    [sym_kProtected] = ACTIONS(3149),
    [sym_kPrivate] = ACTIONS(3149),
    [sym_kStrict] = ACTIONS(3149),
    [sym_kRequired] = ACTIONS(3149),
    [sym_kOptional] = ACTIONS(3149),
    [sym_kDeprecated] = ACTIONS(3149),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
  [559] = {
    [sym_identifier] = ACTIONS(3153),
    [anon_sym_SEMI] = ACTIONS(3155),
    [anon_sym_COMMA] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3155),
    [anon_sym_RBRACK] = ACTIONS(3155),
    [anon_sym_RPAREN] = ACTIONS(3155),
    [sym_kUses] = ACTIONS(3153),
    [sym_kInterface] = ACTIONS(3153),
    [sym_kImplementation] = ACTIONS(3153),
    [sym_kInitialization] = ACTIONS(3153),
    [sym_kFinalization] = ACTIONS(3153),
    [anon_sym_DOT] = ACTIONS(3155),
    [sym_kBegin] = ACTIONS(3153),
    [sym_kEnd] = ACTIONS(3153),
    [sym_kAsm] = ACTIONS(3153),
    [sym_kVar] = ACTIONS(3153),
    [sym_kThreadvar] = ACTIONS(3153),
    [sym_kConst] = ACTIONS(3153),
    [sym_kResourcestring] = ACTIONS(3153),
    [sym_kType] = ACTIONS(3153),
    [sym_kLabel] = ACTIONS(3153),
    [sym_kExports] = ACTIONS(3153),
    [sym_kAbsolute] = ACTIONS(3153),
    [sym_kProperty] = ACTIONS(3153),
    [sym_kRead] = ACTIONS(3153),
    [sym_kWrite] = ACTIONS(3153),
    [sym_kImplements] = ACTIONS(3153),
    [sym_kDefault] = ACTIONS(3153),
    [sym_kNodefault] = ACTIONS(3153),
    [sym_kStored] = ACTIONS(3153),
    [sym_kIndex] = ACTIONS(3153),
    [sym_kDispId] = ACTIONS(3153),
    [sym_kClass] = ACTIONS(3153),
    [sym_kOf] = ACTIONS(3153),
    [sym_kGeneric] = ACTIONS(3153),
    [sym_kLt] = ACTIONS(3155),
    [sym_kEq] = ACTIONS(3155),
    [sym_kGt] = ACTIONS(3155),
    [sym_kAssign] = ACTIONS(3155),
    [sym_kAssignAdd] = ACTIONS(3155),
    [sym_kAssignSub] = ACTIONS(3155),
    [sym_kAssignMul] = ACTIONS(3155),
    [sym_kAssignDiv] = ACTIONS(3155),
    [sym_kElse] = ACTIONS(3153),
    [sym_kDo] = ACTIONS(3153),
    [sym_kUntil] = ACTIONS(3153),
    [sym_kExcept] = ACTIONS(3153),
    [sym_kFinally] = ACTIONS(3153),
    [sym_kCase] = ACTIONS(3153),
    [sym_kFunction] = ACTIONS(3153),
    [sym_kProcedure] = ACTIONS(3153),
    [sym_kConstructor] = ACTIONS(3153),
    [sym_kDestructor] = ACTIONS(3153),
    [sym_kOperator] = ACTIONS(3153),
    [sym_kPublished] = ACTIONS(3153),
    [sym_kPublic] = ACTIONS(3153),
    [sym_kProtected] = ACTIONS(3153),
    [sym_kPrivate] = ACTIONS(3153),
    [sym_kStrict] = ACTIONS(3153),
    [sym_kRequired] = ACTIONS(3153),
    [sym_kOptional] = ACTIONS(3153),
    [sym_kDeprecated] = ACTIONS(3153),
    [sym__space] = ACTIONS(3),
    [sym_pp] = ACTIONS(3),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [75] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [150] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [225] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [300] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [375] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [450] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [525] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 9,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [600] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3185), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3187), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [666] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [734] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1470), 10,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(1468), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [798] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3165), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3167), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [864] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3181), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3183), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [930] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3173), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3175), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [996] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3157), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3159), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [1062] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3169), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3171), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [1128] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [1196] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [1264] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3189), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3191), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [1330] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [1398] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3163), 5,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kLabel,
      sym_kExports,
    ACTIONS(3177), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3179), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [1464] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [1532] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [1600] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1261), 10,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(1259), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [1664] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [1732] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [1800] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1261), 7,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(1259), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kName,
      sym_kDelayed,
  [1864] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [1932] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [2000] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1470), 7,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(1468), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kName,
      sym_kDelayed,
  [2064] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [2132] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [2200] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [2268] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [2336] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [2404] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 9,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kAs,
      sym_kIn,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kElse,
  [2472] = 20,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3193), 1,
      anon_sym_SEMI,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    STATE(813), 1,
      aux_sym_declProp_repeat1,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1213), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    ACTIONS(3199), 8,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [2567] = 12,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3201), 1,
      anon_sym_RBRACK,
    ACTIONS(3203), 1,
      sym_kExternal,
    STATE(606), 1,
      aux_sym__procAttribute_repeat1,
    STATE(2242), 2,
      sym_procAttribute,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [2645] = 12,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3203), 1,
      sym_kExternal,
    ACTIONS(3205), 1,
      anon_sym_RBRACK,
    STATE(613), 1,
      aux_sym__procAttribute_repeat1,
    STATE(2254), 2,
      sym_procAttribute,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [2723] = 8,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3217), 1,
      sym_kLt,
    STATE(948), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3207), 35,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [2793] = 4,
    STATE(948), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3221), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3219), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [2855] = 8,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3223), 1,
      sym_kLt,
    STATE(948), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3207), 35,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [2925] = 11,
    ACTIONS(3228), 1,
      sym_kDispId,
    ACTIONS(3231), 1,
      sym_kPublic,
    ACTIONS(3234), 1,
      sym_kExternal,
    ACTIONS(3237), 1,
      sym_kMessage,
    ACTIONS(3240), 1,
      sym_kDeprecated,
    ACTIONS(3243), 1,
      sym_kExport,
    ACTIONS(3246), 1,
      sym_kAlias,
    STATE(602), 1,
      aux_sym__procAttribute_repeat1,
    STATE(2545), 2,
      sym_procAttribute,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3225), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [3000] = 32,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3249), 1,
      anon_sym_SEMI,
    ACTIONS(3251), 1,
      anon_sym_LPAREN,
    ACTIONS(3253), 1,
      sym_kEnd,
    ACTIONS(3255), 1,
      sym_kOf,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(3261), 1,
      sym_kExternal,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2391), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    ACTIONS(3259), 2,
      sym_kAbstract,
      sym_kSealed,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [3117] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 37,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [3176] = 24,
    ACTIONS(191), 1,
      sym_kEnd,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3271), 1,
      sym_kElse,
    STATE(55), 1,
      sym_caseLabel,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2234), 1,
      sym_caseCaseTr,
    STATE(2315), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(615), 2,
      sym_caseCase,
      aux_sym_case_repeat1,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [3277] = 12,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3203), 1,
      sym_kExternal,
    STATE(602), 1,
      aux_sym__procAttribute_repeat1,
    STATE(2216), 1,
      sym_procAttribute,
    STATE(2220), 1,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [3354] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3275), 1,
      sym_kMul,
    ACTIONS(3273), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3279), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3277), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(2983), 28,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [3425] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3275), 1,
      sym_kMul,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3283), 1,
      sym_kGt,
    ACTIONS(3273), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3279), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3277), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 7,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(2983), 27,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [3500] = 24,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3285), 1,
      sym_kEnd,
    ACTIONS(3287), 1,
      sym_kElse,
    STATE(55), 1,
      sym_caseLabel,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2307), 1,
      sym_caseCaseTr,
    STATE(2315), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(605), 2,
      sym_caseCase,
      aux_sym_case_repeat1,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [3601] = 24,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3289), 1,
      sym_kEnd,
    ACTIONS(3291), 1,
      sym_kElse,
    STATE(55), 1,
      sym_caseLabel,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2215), 1,
      sym_caseCaseTr,
    STATE(2315), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(611), 2,
      sym_caseCase,
      aux_sym_case_repeat1,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [3702] = 24,
    ACTIONS(209), 1,
      sym_kEnd,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3293), 1,
      sym_kElse,
    STATE(55), 1,
      sym_caseLabel,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2315), 1,
      sym_range,
    STATE(2316), 1,
      sym_caseCaseTr,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(615), 2,
      sym_caseCase,
      aux_sym_case_repeat1,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [3803] = 7,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3275), 1,
      sym_kMul,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3277), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
    ACTIONS(2983), 30,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [3870] = 12,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3203), 1,
      sym_kExternal,
    STATE(602), 1,
      aux_sym__procAttribute_repeat1,
    STATE(2263), 1,
      sym_procAttribute,
    STATE(2264), 1,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [3947] = 31,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3249), 1,
      anon_sym_SEMI,
    ACTIONS(3251), 1,
      anon_sym_LPAREN,
    ACTIONS(3253), 1,
      sym_kEnd,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(3261), 1,
      sym_kExternal,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2391), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    ACTIONS(3259), 2,
      sym_kAbstract,
      sym_kSealed,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [4061] = 22,
    ACTIONS(3298), 1,
      anon_sym_LBRACK,
    ACTIONS(3301), 1,
      anon_sym_LPAREN,
    ACTIONS(3304), 1,
      aux_sym__literalString_token1,
    ACTIONS(3307), 1,
      anon_sym_POUND,
    ACTIONS(3313), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3318), 1,
      sym_kSpecialize,
    ACTIONS(3324), 1,
      sym_kAt,
    ACTIONS(3330), 1,
      sym_kInherited,
    STATE(206), 1,
      sym_caseLabel,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2315), 1,
      sym_range,
    ACTIONS(3310), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3316), 2,
      sym_kEnd,
      sym_kElse,
    ACTIONS(3327), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(615), 2,
      sym_caseCase,
      aux_sym_case_repeat1,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3321), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3295), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [4157] = 11,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3333), 1,
      anon_sym_RBRACK,
    STATE(624), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2292), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [4231] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3081), 1,
      sym_kMul,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3079), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3085), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3083), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(2983), 28,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [4301] = 11,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3335), 1,
      anon_sym_RBRACK,
    STATE(626), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2262), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [4375] = 7,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3081), 1,
      sym_kMul,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3083), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
    ACTIONS(2983), 30,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [4441] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3081), 1,
      sym_kMul,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3337), 1,
      sym_kGt,
    ACTIONS(3079), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3085), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2985), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(3083), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2983), 27,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kIs,
      sym_kIn,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [4515] = 11,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    ACTIONS(3339), 1,
      anon_sym_RBRACK,
    STATE(628), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2284), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [4589] = 30,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3249), 1,
      anon_sym_SEMI,
    ACTIONS(3251), 1,
      anon_sym_LPAREN,
    ACTIONS(3253), 1,
      sym_kEnd,
    ACTIONS(3261), 1,
      sym_kExternal,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2391), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    ACTIONS(3259), 2,
      sym_kAbstract,
      sym_kSealed,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [4700] = 30,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3341), 1,
      anon_sym_SEMI,
    ACTIONS(3343), 1,
      anon_sym_LPAREN,
    ACTIONS(3345), 1,
      sym_kEnd,
    ACTIONS(3349), 1,
      sym_kExternal,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2457), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    ACTIONS(3347), 2,
      sym_kAbstract,
      sym_kSealed,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [4811] = 10,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    STATE(629), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2149), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [4882] = 6,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(3351), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(627), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1636), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [4945] = 10,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    STATE(629), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2269), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [5016] = 6,
    ACTIONS(3353), 1,
      aux_sym__literalString_token1,
    ACTIONS(3356), 1,
      anon_sym_POUND,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(627), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1626), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [5079] = 10,
    ACTIONS(821), 1,
      sym_kDispId,
    ACTIONS(823), 1,
      sym_kPublic,
    ACTIONS(825), 1,
      sym_kMessage,
    ACTIONS(827), 1,
      sym_kDeprecated,
    ACTIONS(829), 1,
      sym_kAlias,
    ACTIONS(1979), 1,
      sym_kExport,
    STATE(629), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2287), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(819), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [5150] = 10,
    ACTIONS(3362), 1,
      sym_kDispId,
    ACTIONS(3365), 1,
      sym_kPublic,
    ACTIONS(3368), 1,
      sym_kMessage,
    ACTIONS(3371), 1,
      sym_kDeprecated,
    ACTIONS(3374), 1,
      sym_kExport,
    ACTIONS(3377), 1,
      sym_kAlias,
    STATE(629), 1,
      aux_sym__procAttributeNoExt_repeat1,
    STATE(2587), 1,
      sym_procAttribute,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3359), 39,
      sym_kDefault,
      sym_kNodefault,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
  [5221] = 22,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3380), 1,
      sym_identifier,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    STATE(632), 1,
      aux_sym_recInitializer_repeat1,
    STATE(673), 1,
      aux_sym_arrInitializer_repeat1,
    STATE(2324), 1,
      sym_recInitializerField,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(95), 3,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1489), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2133), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5316] = 22,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(637), 1,
      aux_sym_declVariant_repeat1,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2098), 1,
      sym_declVariantClause,
    STATE(2315), 1,
      sym_range,
    STATE(2400), 1,
      sym_caseLabel,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5410] = 21,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3380), 1,
      sym_identifier,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    STATE(633), 1,
      aux_sym_recInitializer_repeat1,
    STATE(2193), 1,
      sym_recInitializerField,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(95), 3,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2185), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5502] = 21,
    ACTIONS(3384), 1,
      sym_identifier,
    ACTIONS(3387), 1,
      anon_sym_LBRACK,
    ACTIONS(3390), 1,
      anon_sym_LPAREN,
    ACTIONS(3393), 1,
      aux_sym__literalString_token1,
    ACTIONS(3396), 1,
      anon_sym_POUND,
    ACTIONS(3402), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3405), 1,
      sym_kSpecialize,
    ACTIONS(3411), 1,
      sym_kAt,
    ACTIONS(3417), 1,
      sym_kInherited,
    STATE(633), 1,
      aux_sym_recInitializer_repeat1,
    STATE(2473), 1,
      sym_recInitializerField,
    ACTIONS(3399), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3414), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3408), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(3420), 3,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2185), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5594] = 22,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      aux_sym_declVariant_repeat1,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2024), 1,
      sym_declVariantClause,
    STATE(2315), 1,
      sym_range,
    STATE(2400), 1,
      sym_caseLabel,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5688] = 22,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(637), 1,
      aux_sym_declVariant_repeat1,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2090), 1,
      sym_declVariantClause,
    STATE(2315), 1,
      sym_range,
    STATE(2400), 1,
      sym_caseLabel,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5782] = 22,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(631), 1,
      aux_sym_declVariant_repeat1,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2114), 1,
      sym_declVariantClause,
    STATE(2315), 1,
      sym_range,
    STATE(2400), 1,
      sym_caseLabel,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5876] = 22,
    ACTIONS(3426), 1,
      anon_sym_LBRACK,
    ACTIONS(3429), 1,
      anon_sym_LPAREN,
    ACTIONS(3432), 1,
      aux_sym__literalString_token1,
    ACTIONS(3435), 1,
      anon_sym_POUND,
    ACTIONS(3441), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3444), 1,
      sym_kSpecialize,
    ACTIONS(3450), 1,
      sym_kAt,
    ACTIONS(3456), 1,
      sym_kInherited,
    STATE(637), 1,
      aux_sym_declVariant_repeat1,
    STATE(752), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2315), 1,
      sym_range,
    STATE(2400), 1,
      sym_caseLabel,
    STATE(2608), 1,
      sym_declVariantClause,
    ACTIONS(3438), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3453), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3447), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1535), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3423), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [5970] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3459), 46,
      sym_kDefault,
      sym_kNodefault,
      sym_kDispId,
      sym_kPublic,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kExternal,
      sym_kMessage,
      sym_kDeprecated,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kExport,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
      sym_kAlias,
  [6024] = 8,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3461), 1,
      sym_kLt,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3207), 6,
      anon_sym_COLON,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3209), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [6089] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3081), 1,
      sym_kMul,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3465), 1,
      anon_sym_LBRACK,
    ACTIONS(3079), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3085), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3075), 4,
      sym_kLt,
      sym_kGt,
      sym_kIs,
      sym_kIn,
    ACTIONS(3077), 4,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(3083), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(3463), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [6160] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3081), 1,
      sym_kMul,
    ACTIONS(3087), 1,
      sym_kAs,
    ACTIONS(3469), 1,
      anon_sym_LBRACK,
    ACTIONS(3079), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3085), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3075), 4,
      sym_kLt,
      sym_kGt,
      sym_kIs,
      sym_kIn,
    ACTIONS(3077), 4,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
    ACTIONS(3083), 6,
      sym_kFdiv,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(3467), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [6231] = 19,
    ACTIONS(3474), 1,
      anon_sym_LBRACK,
    ACTIONS(3477), 1,
      anon_sym_LPAREN,
    ACTIONS(3480), 1,
      aux_sym__literalString_token1,
    ACTIONS(3483), 1,
      anon_sym_POUND,
    ACTIONS(3489), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3492), 1,
      sym_kSpecialize,
    ACTIONS(3498), 1,
      sym_kAt,
    ACTIONS(3504), 1,
      sym_kInherited,
    STATE(642), 1,
      aux_sym_arrInitializer_repeat1,
    ACTIONS(3486), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3501), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3495), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2475), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    ACTIONS(3471), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [6318] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3167), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6379] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6438] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3183), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6499] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3175), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6560] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3159), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6621] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3171), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6682] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3187), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6743] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3191), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6804] = 6,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3179), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [6865] = 4,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 8,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3221), 36,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [6922] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(1470), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1468), 39,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [6979] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [7038] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [7097] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1261), 7,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1259), 38,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [7152] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1470), 7,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1468), 38,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [7207] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [7266] = 29,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3341), 1,
      anon_sym_SEMI,
    ACTIONS(3343), 1,
      anon_sym_LPAREN,
    ACTIONS(3345), 1,
      sym_kEnd,
    ACTIONS(3507), 1,
      sym_kName,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2457), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [7373] = 20,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(3509), 1,
      anon_sym_SEMI,
    ACTIONS(3513), 1,
      sym_kDelayed,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3511), 2,
      sym_kIndex,
      sym_kName,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1474), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [7462] = 29,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3515), 1,
      anon_sym_SEMI,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3519), 1,
      anon_sym_LPAREN,
    ACTIONS(3521), 1,
      sym_kEnd,
    STATE(744), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2502), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [7569] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [7628] = 29,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3523), 1,
      anon_sym_SEMI,
    ACTIONS(3525), 1,
      anon_sym_LPAREN,
    ACTIONS(3527), 1,
      sym_kEnd,
    STATE(745), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2672), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [7735] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [7794] = 29,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3529), 1,
      anon_sym_SEMI,
    ACTIONS(3531), 1,
      anon_sym_LPAREN,
    ACTIONS(3533), 1,
      sym_kEnd,
    ACTIONS(3535), 1,
      sym_kName,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2714), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [7901] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3537), 45,
      sym_kDefault,
      sym_kNodefault,
      sym_kDispId,
      sym_kPublic,
      sym_kStatic,
      sym_kVirtual,
      sym_kAbstract,
      sym_kDynamic,
      sym_kOverride,
      sym_kOverload,
      sym_kReintroduce,
      sym_kInline,
      sym_kStdcall,
      sym_kCdecl,
      sym_kCppdecl,
      sym_kPascal,
      sym_kRegister,
      sym_kMwpascal,
      sym_kMessage,
      sym_kDeprecated,
      sym_kExperimental,
      sym_kPlatform,
      sym_kUnimplemented,
      sym_kCvar,
      sym_kExport,
      sym_kFar,
      sym_kNear,
      sym_kSafecall,
      sym_kAssembler,
      sym_kNostackframe,
      sym_kInterrupt,
      sym_kNoreturn,
      sym_kIocheck,
      sym_kLocal,
      sym_kHardfloat,
      sym_kSoftfloat,
      sym_kMs_abi_default,
      sym_kMs_abi_cdecl,
      sym_kSaveregisters,
      sym_kSysv_abi_default,
      sym_kSysv_abi_cdecl,
      sym_kVectorcall,
      sym_kVarargs,
      sym_kWinapi,
      sym_kAlias,
  [7954] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [8013] = 20,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(3539), 1,
      anon_sym_SEMI,
    ACTIONS(3543), 1,
      sym_kDelayed,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3541), 2,
      sym_kIndex,
      sym_kName,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1469), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [8102] = 8,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3207), 6,
      anon_sym_COLON,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3209), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [8167] = 4,
    ACTIONS(3547), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(3263), 28,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [8224] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(1261), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1259), 39,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [8281] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 6,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
  [8340] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    STATE(642), 1,
      aux_sym_arrInitializer_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2299), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [8427] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3549), 1,
      anon_sym_SEMI,
    ACTIONS(3551), 1,
      sym_kEnd,
    STATE(733), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2489), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [8531] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3553), 1,
      anon_sym_SEMI,
    ACTIONS(3555), 1,
      sym_kEnd,
    STATE(730), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2704), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [8635] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3557), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2506), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [8723] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3559), 1,
      sym_kVar,
    STATE(1925), 1,
      sym_varAssignDef,
    STATE(2246), 1,
      sym_assignment,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1468), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [8811] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2831), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2833), 38,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [8865] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1261), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1259), 38,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [8919] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3561), 1,
      anon_sym_SEMI,
    ACTIONS(3563), 1,
      sym_kEnd,
    STATE(734), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2383), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [9023] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1470), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(1468), 38,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [9077] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3565), 1,
      anon_sym_SEMI,
    ACTIONS(3567), 1,
      sym_kEnd,
    STATE(751), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2435), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [9181] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3569), 1,
      anon_sym_RBRACK,
    STATE(746), 1,
      aux_sym_declArray_repeat1,
    STATE(2283), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1526), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [9269] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(2239), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [9353] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3571), 1,
      anon_sym_RBRACK,
    STATE(769), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2227), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1516), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [9441] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3165), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9499] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3181), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9557] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3173), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9615] = 28,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3341), 1,
      anon_sym_SEMI,
    ACTIONS(3343), 1,
      anon_sym_LPAREN,
    ACTIONS(3345), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2457), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [9719] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3157), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9777] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3169), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9835] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3185), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9893] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3189), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [9951] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3161), 16,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
    ACTIONS(3177), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [10009] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3573), 1,
      anon_sym_RBRACK,
    STATE(748), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2214), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1530), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10097] = 28,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3529), 1,
      anon_sym_SEMI,
    ACTIONS(3531), 1,
      anon_sym_LPAREN,
    ACTIONS(3533), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2714), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [10201] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3559), 1,
      sym_kVar,
    STATE(1925), 1,
      sym_varAssignDef,
    STATE(2276), 1,
      sym_assignment,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1458), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10289] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(3575), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1501), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10373] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1595), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(1938), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10457] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(3577), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3579), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3581), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
    ACTIONS(3583), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 27,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [10523] = 7,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(3579), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3583), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2983), 6,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
    ACTIONS(2985), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [10585] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(3587), 1,
      sym_kGt,
    ACTIONS(3577), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(3579), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3581), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      sym_kLt,
    ACTIONS(3583), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 26,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [10655] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3382), 1,
      anon_sym_LPAREN,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1482), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(1938), 3,
      sym__initializer,
      sym_recInitializer,
      sym_arrInitializer,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10739] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3589), 1,
      anon_sym_RBRACK,
    STATE(754), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2183), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1499), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [10827] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3591), 1,
      anon_sym_SEMI,
    ACTIONS(3593), 1,
      sym_kEnd,
    STATE(747), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2614), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [10931] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3595), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2650), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11019] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3597), 1,
      anon_sym_RBRACK,
    STATE(757), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2201), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1502), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11107] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3599), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2377), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11195] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3601), 1,
      anon_sym_RBRACK,
    STATE(759), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2211), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1504), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11283] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3603), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2404), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11371] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3605), 1,
      anon_sym_RBRACK,
    STATE(761), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2218), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1509), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11459] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3607), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2429), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11547] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3609), 1,
      anon_sym_RBRACK,
    STATE(763), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2228), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1511), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11635] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3611), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2452), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11723] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3613), 1,
      anon_sym_RBRACK,
    STATE(768), 1,
      aux_sym_declArray_repeat1,
    STATE(2266), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1520), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11811] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3615), 1,
      anon_sym_RBRACK,
    STATE(770), 1,
      aux_sym_declArray_repeat1,
    STATE(2270), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1523), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [11899] = 28,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3517), 1,
      anon_sym_LBRACK,
    ACTIONS(3617), 1,
      anon_sym_SEMI,
    ACTIONS(3619), 1,
      sym_kEnd,
    STATE(743), 1,
      sym_guid,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2630), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [12003] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_RBRACK,
    STATE(737), 1,
      aux_sym_declArray_repeat1,
    STATE(2226), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1524), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12091] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3623), 1,
      anon_sym_RBRACK,
    STATE(773), 1,
      aux_sym_declArray_repeat1,
    STATE(2314), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1536), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12179] = 20,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_RBRACK,
    STATE(774), 1,
      aux_sym_declArray_repeat1,
    STATE(2317), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1537), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12267] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3559), 1,
      sym_kVar,
    STATE(1925), 1,
      sym_varAssignDef,
    STATE(2302), 1,
      sym_assignment,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1457), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12355] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3627), 1,
      anon_sym_RPAREN,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2609), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12443] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2428), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12528] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3629), 1,
      anon_sym_SEMI,
    ACTIONS(3631), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2516), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [12629] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3633), 1,
      anon_sym_SEMI,
    ACTIONS(3635), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2521), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [12730] = 19,
    ACTIONS(3640), 1,
      anon_sym_LBRACK,
    ACTIONS(3643), 1,
      anon_sym_LPAREN,
    ACTIONS(3646), 1,
      aux_sym__literalString_token1,
    ACTIONS(3649), 1,
      anon_sym_POUND,
    ACTIONS(3655), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3658), 1,
      sym_kSpecialize,
    ACTIONS(3664), 1,
      sym_kAt,
    ACTIONS(3670), 1,
      sym_kInherited,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2684), 1,
      sym_range,
    ACTIONS(3652), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3667), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3661), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1543), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3637), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12815] = 19,
    ACTIONS(3676), 1,
      anon_sym_LBRACK,
    ACTIONS(3679), 1,
      anon_sym_LPAREN,
    ACTIONS(3682), 1,
      aux_sym__literalString_token1,
    ACTIONS(3685), 1,
      anon_sym_POUND,
    ACTIONS(3691), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3694), 1,
      sym_kSpecialize,
    ACTIONS(3700), 1,
      sym_kAt,
    ACTIONS(3706), 1,
      sym_kInherited,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2643), 1,
      sym_range,
    ACTIONS(3688), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3703), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3697), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1548), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3673), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [12900] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3709), 1,
      anon_sym_SEMI,
    ACTIONS(3711), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2420), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13001] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3713), 1,
      anon_sym_SEMI,
    ACTIONS(3715), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2421), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13102] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3717), 1,
      anon_sym_SEMI,
    ACTIONS(3719), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2432), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13203] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3723), 1,
      anon_sym_RBRACK,
    STATE(878), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3721), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1351), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [13288] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3725), 1,
      anon_sym_SEMI,
    ACTIONS(3727), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2531), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13389] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3729), 1,
      anon_sym_SEMI,
    ACTIONS(3731), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2334), 1,
      sym__declClass,
    STATE(2351), 1,
      sym_declVariant,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13490] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3733), 1,
      anon_sym_SEMI,
    ACTIONS(3735), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2553), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13591] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3737), 1,
      anon_sym_SEMI,
    ACTIONS(3739), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2443), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13692] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3741), 1,
      anon_sym_SEMI,
    ACTIONS(3743), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2419), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13793] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2320), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1534), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [13878] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3745), 1,
      anon_sym_SEMI,
    ACTIONS(3747), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2367), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [13979] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2491), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14064] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3749), 1,
      sym_identifier,
    ACTIONS(3751), 1,
      anon_sym_RBRACK,
    STATE(849), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(3753), 3,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(1356), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14151] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3755), 1,
      anon_sym_SEMI,
    ACTIONS(3757), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2542), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [14252] = 20,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3749), 1,
      sym_identifier,
    ACTIONS(3751), 1,
      anon_sym_RBRACK,
    STATE(849), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    ACTIONS(3759), 3,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(1391), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14339] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3761), 1,
      anon_sym_SEMI,
    ACTIONS(3763), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2571), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [14440] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3765), 1,
      anon_sym_SEMI,
    ACTIONS(3767), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2538), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [14541] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3769), 1,
      anon_sym_SEMI,
    ACTIONS(3771), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2339), 1,
      sym__declClass,
    STATE(2351), 1,
      sym_declVariant,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [14642] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2226), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1524), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14727] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3773), 1,
      anon_sym_SEMI,
    ACTIONS(3775), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2380), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [14828] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2272), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1490), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14913] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2606), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [14998] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3777), 1,
      anon_sym_SEMI,
    ACTIONS(3779), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2621), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [15099] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3781), 1,
      anon_sym_SEMI,
    ACTIONS(3783), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2626), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [15200] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2244), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1494), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15285] = 4,
    ACTIONS(3785), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 31,
      anon_sym_LPAREN,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [15340] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2186), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1500), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15425] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2649), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15510] = 4,
    ACTIONS(3787), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2991), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(2993), 31,
      anon_sym_LPAREN,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [15565] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2205), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1503), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15650] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2376), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15735] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2213), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1488), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15820] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2403), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15905] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2221), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1510), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [15990] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3789), 1,
      anon_sym_LBRACK,
    ACTIONS(3791), 1,
      anon_sym_LPAREN,
    ACTIONS(3793), 1,
      sym_kLt,
    STATE(937), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3207), 4,
      sym_kConst,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3209), 34,
      anon_sym_COMMA,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [16053] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2232), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1512), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [16138] = 19,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(834), 1,
      aux_sym_exprArgs_repeat1,
    STATE(2451), 1,
      sym_exprArgs,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1352), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [16223] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3795), 1,
      anon_sym_SEMI,
    ACTIONS(3797), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2634), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [16324] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3799), 1,
      anon_sym_SEMI,
    ACTIONS(3801), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2387), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [16425] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3803), 1,
      anon_sym_SEMI,
    ACTIONS(3805), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2623), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [16526] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2270), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1523), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [16611] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      aux_sym_caseLabel_repeat1,
    STATE(2245), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1518), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [16696] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2273), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1525), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [16781] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3807), 1,
      anon_sym_SEMI,
    ACTIONS(3809), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2645), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [16882] = 4,
    STATE(937), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3221), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [16937] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2317), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1537), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [17022] = 19,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(726), 1,
      aux_sym_declArray_repeat1,
    STATE(2319), 1,
      sym_range,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1497), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [17107] = 27,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3811), 1,
      anon_sym_SEMI,
    ACTIONS(3813), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2620), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [17208] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3003), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3005), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17260] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2999), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3001), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17312] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3187), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3185), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17364] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3023), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3025), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17416] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3191), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3189), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17468] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2943), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2945), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17520] = 18,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    STATE(854), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1301), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [17602] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3179), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3177), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17654] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2935), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2937), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [17706] = 18,
    ACTIONS(3818), 1,
      anon_sym_LBRACK,
    ACTIONS(3821), 1,
      anon_sym_LPAREN,
    ACTIONS(3824), 1,
      aux_sym__literalString_token1,
    ACTIONS(3827), 1,
      anon_sym_POUND,
    ACTIONS(3833), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3836), 1,
      sym_kSpecialize,
    ACTIONS(3842), 1,
      sym_kAt,
    ACTIONS(3848), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(3830), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3845), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3839), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1599), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3815), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [17788] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3853), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3851), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [17840] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3857), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3855), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [17892] = 18,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    STATE(870), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(798), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [17974] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3867), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3865), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18026] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3871), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3869), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18078] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2951), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2953), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18130] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3875), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3873), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18182] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3879), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3877), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18234] = 8,
    ACTIONS(3885), 1,
      sym_kFdiv,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3889), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
    ACTIONS(3881), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(3883), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 25,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18296] = 7,
    ACTIONS(3885), 1,
      sym_kFdiv,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3889), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
    ACTIONS(3883), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 29,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18356] = 4,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2985), 35,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18410] = 4,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2995), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2997), 35,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18464] = 10,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3885), 1,
      sym_kFdiv,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3889), 1,
      sym_kAs,
    ACTIONS(3891), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
    ACTIONS(3881), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(3883), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 24,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18530] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3019), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3021), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [18582] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3895), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3893), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18634] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3899), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3897), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18686] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3901), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2615), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [18784] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(842), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1553), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [18866] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3905), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3903), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18918] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3909), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3907), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [18970] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    STATE(874), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(620), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [19052] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3915), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3913), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19104] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3919), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3917), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19156] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(803), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1544), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [19238] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3923), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3921), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19290] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3927), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3925), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19342] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3931), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3929), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19394] = 18,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    STATE(823), 1,
      aux_sym_declProp_repeat1,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1210), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [19476] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(3933), 1,
      sym_kName,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1501), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [19558] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3937), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3935), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19610] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3941), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3939), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19662] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3945), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3943), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19714] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3947), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2464), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [19812] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3951), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3949), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19864] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3955), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3953), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19916] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3959), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3957), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [19968] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(3961), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2617), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [20066] = 18,
    ACTIONS(3966), 1,
      anon_sym_LBRACK,
    ACTIONS(3969), 1,
      anon_sym_LPAREN,
    ACTIONS(3972), 1,
      aux_sym__literalString_token1,
    ACTIONS(3975), 1,
      anon_sym_POUND,
    ACTIONS(3981), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3984), 1,
      sym_kSpecialize,
    ACTIONS(3990), 1,
      sym_kAt,
    ACTIONS(3996), 1,
      sym_kInherited,
    STATE(823), 1,
      aux_sym_declProp_repeat1,
    ACTIONS(3978), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3993), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3987), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1600), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3963), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20148] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(833), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1542), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20230] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(289), 1,
      sym_kAt,
    STATE(841), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(291), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(702), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(287), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(639), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20312] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4001), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3999), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [20364] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4005), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4003), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [20416] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4009), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4007), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [20468] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4013), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4011), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [20520] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(4015), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2351), 1,
      sym_declVariant,
    STATE(2594), 1,
      sym__declClass,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(930), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1676), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1081), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [20618] = 18,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    STATE(873), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1293), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20700] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3015), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3017), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [20752] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(842), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1541), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20834] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(879), 1,
      aux_sym_exprArgs_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1415), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [20916] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4023), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4021), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [20968] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4027), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4025), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21020] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4031), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4029), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21072] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4035), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4033), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21124] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4039), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4037), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21176] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4043), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4041), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21228] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1602), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21310] = 18,
    ACTIONS(4048), 1,
      anon_sym_LBRACK,
    ACTIONS(4051), 1,
      anon_sym_LPAREN,
    ACTIONS(4054), 1,
      aux_sym__literalString_token1,
    ACTIONS(4057), 1,
      anon_sym_POUND,
    ACTIONS(4063), 1,
      aux_sym__literalInt_token2,
    ACTIONS(4066), 1,
      sym_kSpecialize,
    ACTIONS(4072), 1,
      sym_kAt,
    ACTIONS(4078), 1,
      sym_kInherited,
    STATE(842), 1,
      aux_sym_with_repeat1,
    ACTIONS(4060), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(4075), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4069), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1569), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4045), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21392] = 6,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(4081), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(847), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(1636), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [21450] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4085), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4083), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [21502] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2907), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2909), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [21554] = 18,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    STATE(864), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1084), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21636] = 6,
    ACTIONS(4087), 1,
      aux_sym__literalString_token1,
    ACTIONS(4090), 1,
      anon_sym_POUND,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(847), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(1626), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [21694] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(852), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1550), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21776] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(855), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4093), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1360), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21858] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(841), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(887), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [21940] = 6,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(4095), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(859), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(1636), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [21998] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(842), 1,
      aux_sym_with_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1555), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22080] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4099), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4097), 36,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [22132] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1590), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22214] = 18,
    ACTIONS(4104), 1,
      anon_sym_LBRACK,
    ACTIONS(4107), 1,
      anon_sym_LPAREN,
    ACTIONS(4110), 1,
      aux_sym__literalString_token1,
    ACTIONS(4113), 1,
      anon_sym_POUND,
    ACTIONS(4119), 1,
      aux_sym__literalInt_token2,
    ACTIONS(4122), 1,
      sym_kSpecialize,
    ACTIONS(4128), 1,
      sym_kAt,
    ACTIONS(4134), 1,
      sym_kInherited,
    STATE(855), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(4116), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(4131), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4125), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4101), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1460), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22296] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2959), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2961), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22348] = 18,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    STATE(860), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1078), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22430] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2947), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2949), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22482] = 6,
    ACTIONS(4137), 1,
      aux_sym__literalString_token1,
    ACTIONS(4140), 1,
      anon_sym_POUND,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(859), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(1626), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [22540] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1558), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22622] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2963), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2965), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22674] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3167), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3165), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22726] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3027), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3029), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22778] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1562), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [22860] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3031), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3033), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22912] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2939), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2941), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [22964] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1570), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23046] = 18,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    STATE(867), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1377), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23128] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3011), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3013), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23180] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1575), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23262] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2967), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2969), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23314] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3183), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3181), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23366] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1579), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23448] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(785), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1582), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23530] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2955), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2957), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23582] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3175), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3173), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23634] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2979), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2981), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23686] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    STATE(855), 1,
      aux_sym_rttiAttributes_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4147), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1410), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23768] = 18,
    ACTIONS(4152), 1,
      anon_sym_LBRACK,
    ACTIONS(4155), 1,
      anon_sym_LPAREN,
    ACTIONS(4158), 1,
      aux_sym__literalString_token1,
    ACTIONS(4161), 1,
      anon_sym_POUND,
    ACTIONS(4167), 1,
      aux_sym__literalInt_token2,
    ACTIONS(4170), 1,
      sym_kSpecialize,
    ACTIONS(4176), 1,
      sym_kAt,
    ACTIONS(4182), 1,
      sym_kInherited,
    STATE(879), 1,
      aux_sym_exprArgs_repeat1,
    ACTIONS(4164), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(4179), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4173), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1483), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4149), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [23850] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2975), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2977), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23902] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3159), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3157), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [23954] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2971), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(2973), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [24006] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3171), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3169), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [24058] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3007), 6,
      anon_sym_LPAREN,
      sym_kConst,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kAs,
    ACTIONS(3009), 36,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kUses,
      anon_sym_DOT,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kIn,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [24110] = 18,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(271), 1,
      sym_kAt,
    STATE(874), 1,
      aux_sym_exprTpl_repeat1,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(273), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(608), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(275), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(601), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24192] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_COLON,
      sym_kLt,
      sym_kGt,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [24255] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4193), 1,
      sym_kGt,
    ACTIONS(2983), 2,
      anon_sym_COLON,
      sym_kLt,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 24,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [24322] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1426), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24401] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4195), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(652), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24480] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(506), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24559] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1513), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24638] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1019), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24717] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1475), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24796] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1566), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24875] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1024), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [24954] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1358), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25033] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1577), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25112] = 17,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(506), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25191] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1281), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25270] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1056), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25349] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1584), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25428] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1075), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25507] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1079), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25586] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1080), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25665] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1082), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25744] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1611), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4197), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1036), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25823] = 17,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1267), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25902] = 17,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1282), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [25981] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1605), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26060] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1388), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26139] = 17,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1287), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26218] = 7,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 5,
      anon_sym_COLON,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 27,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kThen,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
      sym_kDelayed,
  [26277] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1362), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26356] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1594), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26435] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1373), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26514] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1374), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26593] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1375), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26672] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1376), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26751] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1613), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4199), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1330), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26830] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1585), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26909] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(552), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [26988] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1047), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27067] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1588), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27146] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1589), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27225] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1603), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27304] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4201), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1461), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27383] = 17,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3117), 1,
      sym_kAt,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3119), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1295), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3105), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1254), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27462] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(845), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27541] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4203), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1466), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27620] = 25,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(3097), 1,
      sym_kStrict,
    ACTIONS(4205), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2695), 1,
      sym_declVariant,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(1244), 2,
      aux_sym__declFields,
      sym_declField,
    STATE(1661), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(3095), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1102), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [27715] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(3107), 1,
      aux_sym__literalString_token1,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(3113), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3115), 1,
      sym_kSpecialize,
    ACTIONS(3123), 1,
      sym_kInherited,
    ACTIONS(3267), 1,
      anon_sym_LBRACK,
    ACTIONS(3269), 1,
      anon_sym_LPAREN,
    ACTIONS(3111), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3121), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1289), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1196), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1609), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4207), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1242), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27794] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(794), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27873] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(795), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [27952] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(796), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28031] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(797), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28110] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1089), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28189] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1607), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4209), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(772), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28268] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1071), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28347] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1072), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28426] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1073), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28505] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1290), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28584] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1074), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28663] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(506), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28742] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(617), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28821] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(619), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28900] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(530), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [28979] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(271), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(273), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(532), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(275), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(601), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29058] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1610), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4211), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(600), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29137] = 17,
    ACTIONS(3127), 1,
      aux_sym__literalString_token1,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(3133), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3135), 1,
      sym_kSpecialize,
    ACTIONS(3137), 1,
      sym_kAt,
    ACTIONS(3143), 1,
      sym_kInherited,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      anon_sym_LPAREN,
    ACTIONS(3131), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3141), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1385), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3139), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1205), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1549), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3125), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1257), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29216] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1606), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4213), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1034), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29295] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1591), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29374] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1366), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29453] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(289), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(291), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(532), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(287), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(639), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29532] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(289), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(291), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(536), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(287), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(639), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29611] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(289), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(291), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(701), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(287), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(639), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29690] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(289), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(291), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(530), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(287), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(639), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29769] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1227), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29848] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1228), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [29927] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1498), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30006] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1593), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30085] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1519), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30164] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1286), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30243] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1271), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30322] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1328), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30401] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1260), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30480] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1274), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30559] = 17,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3047), 1,
      sym_kAt,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3049), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1292), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(3035), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1250), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30638] = 17,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(3037), 1,
      aux_sym__literalString_token1,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(3043), 1,
      aux_sym__literalInt_token2,
    ACTIONS(3045), 1,
      sym_kSpecialize,
    ACTIONS(3053), 1,
      sym_kInherited,
    ACTIONS(4017), 1,
      anon_sym_LBRACK,
    ACTIONS(4019), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3051), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1299), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(1203), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1612), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4215), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1238), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30717] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(271), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(273), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(536), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(275), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(601), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30796] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(271), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(273), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(612), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(275), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(601), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30875] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(271), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(273), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(530), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(275), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(601), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [30954] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1221), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31033] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(640), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31112] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1302), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31191] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1231), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31270] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1219), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31349] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1209), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31428] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1192), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31507] = 17,
    ACTIONS(105), 1,
      anon_sym_LBRACK,
    ACTIONS(107), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      aux_sym__literalString_token1,
    ACTIONS(111), 1,
      anon_sym_POUND,
    ACTIONS(115), 1,
      aux_sym__literalInt_token2,
    ACTIONS(121), 1,
      sym_kSpecialize,
    ACTIONS(125), 1,
      sym_kAt,
    ACTIONS(141), 1,
      sym_kInherited,
    ACTIONS(113), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(139), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1085), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(123), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(843), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1190), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(143), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1025), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31586] = 17,
    ACTIONS(737), 1,
      aux_sym__literalString_token1,
    ACTIONS(739), 1,
      anon_sym_POUND,
    ACTIONS(743), 1,
      aux_sym__literalInt_token2,
    ACTIONS(745), 1,
      sym_kSpecialize,
    ACTIONS(747), 1,
      sym_kAt,
    ACTIONS(753), 1,
      sym_kInherited,
    ACTIONS(3195), 1,
      anon_sym_LBRACK,
    ACTIONS(3197), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(751), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1052), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(749), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(851), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1486), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(735), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1029), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31665] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1567), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31744] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1571), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31823] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1573), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31902] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4217), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1467), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [31981] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(641), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32060] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1546), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32139] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1592), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32218] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1411), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32297] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1506), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32376] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1552), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32455] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1597), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32534] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4219), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1462), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32613] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4221), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1463), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32692] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4223), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1464), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32771] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4225), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1465), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32850] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1604), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [32929] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(886), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33008] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1383), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33087] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1586), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33166] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1560), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33245] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1580), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33324] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1565), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33403] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1540), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33482] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1425), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33561] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(912), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33640] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1572), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33719] = 17,
    ACTIONS(295), 1,
      aux_sym__literalString_token1,
    ACTIONS(297), 1,
      anon_sym_POUND,
    ACTIONS(301), 1,
      aux_sym__literalInt_token2,
    ACTIONS(303), 1,
      sym_kSpecialize,
    ACTIONS(305), 1,
      sym_kAt,
    ACTIONS(309), 1,
      sym_kInherited,
    ACTIONS(3859), 1,
      anon_sym_LBRACK,
    ACTIONS(3861), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3863), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(856), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(307), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(625), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1017), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(293), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(762), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33798] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1576), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33877] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(269), 1,
      sym_kSpecialize,
    ACTIONS(281), 1,
      sym_kAt,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(3911), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(283), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(550), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(285), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(599), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [33956] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1538), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [34035] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(530), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [34114] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1551), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [34193] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1501), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(95), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(669), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [34272] = 17,
    ACTIONS(45), 1,
      anon_sym_LBRACK,
    ACTIONS(47), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      aux_sym__literalString_token1,
    ACTIONS(51), 1,
      anon_sym_POUND,
    ACTIONS(55), 1,
      aux_sym__literalInt_token2,
    ACTIONS(65), 1,
      sym_kSpecialize,
    ACTIONS(69), 1,
      sym_kAt,
    ACTIONS(93), 1,
      sym_kInherited,
    ACTIONS(53), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
    ACTIONS(91), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(523), 2,
      sym__literalInt,
      sym__literalFloat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(67), 3,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
    STATE(249), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    STATE(1615), 3,
      sym__expr,
      sym_exprBinary,
      sym_exprUnary,
    ACTIONS(4227), 4,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
    STATE(1459), 14,
      sym__ref,
      sym_lambda,
      sym_inherited,
      sym_exprDot,
      sym_exprDeref,
      sym_exprAs,
      sym_exprTpl,
      sym_exprSubscript,
      sym_exprCall,
      sym_exprParens,
      sym_exprBrackets,
      sym__literal,
      sym_literalString,
      sym_literalNumber,
  [34351] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4231), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4233), 8,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4229), 26,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [34403] = 4,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4231), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4235), 8,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4229), 26,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [34455] = 10,
    ACTIONS(3467), 1,
      sym_kConst,
    ACTIONS(3885), 1,
      sym_kFdiv,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3889), 1,
      sym_kAs,
    ACTIONS(4237), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3881), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(3883), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4239), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(3469), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [34518] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2831), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2833), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [34567] = 10,
    ACTIONS(3463), 1,
      sym_kConst,
    ACTIONS(3885), 1,
      sym_kFdiv,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(3889), 1,
      sym_kAs,
    ACTIONS(4237), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3881), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(3883), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4239), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(3465), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [34630] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2831), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2833), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [34679] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4249), 1,
      sym_kType,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2549), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [34765] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4275), 1,
      anon_sym_COLON,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(544), 1,
      sym_asmTr,
    STATE(561), 1,
      sym_blockTr,
    STATE(1110), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1126), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [34859] = 4,
    ACTIONS(4281), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2991), 14,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(2993), 23,
      anon_sym_LPAREN,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kElse,
  [34909] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(3465), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [34971] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4287), 1,
      anon_sym_LBRACK,
    ACTIONS(4289), 1,
      anon_sym_LPAREN,
    ACTIONS(4291), 1,
      sym_kLt,
    STATE(906), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3207), 6,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3209), 27,
      anon_sym_SEMI,
      anon_sym_COMMA,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [35029] = 4,
    ACTIONS(4293), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 25,
      anon_sym_LPAREN,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kName,
      sym_kDelayed,
  [35079] = 4,
    ACTIONS(4295), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 14,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(3263), 23,
      anon_sym_LPAREN,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kElse,
  [35129] = 4,
    ACTIONS(4297), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2991), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(2993), 25,
      anon_sym_LPAREN,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kName,
      sym_kDelayed,
  [35179] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4299), 1,
      anon_sym_LBRACK,
    ACTIONS(4301), 1,
      anon_sym_LPAREN,
    ACTIONS(4303), 1,
      sym_kLt,
    STATE(950), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3207), 3,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3209), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [35237] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4305), 1,
      sym_kType,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2540), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [35323] = 4,
    ACTIONS(4307), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3923), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3921), 31,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kUntil,
      sym_kTry,
      sym_kExcept,
      sym_kFinally,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [35373] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4309), 1,
      anon_sym_COLON,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(672), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1120), 1,
      sym_declArgs,
    STATE(1268), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1125), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [35467] = 21,
    ACTIONS(4315), 1,
      anon_sym_LBRACK,
    ACTIONS(4318), 1,
      sym_kUses,
    ACTIONS(4323), 1,
      sym_kBegin,
    ACTIONS(4329), 1,
      sym_kConst,
    ACTIONS(4332), 1,
      sym_kResourcestring,
    ACTIONS(4335), 1,
      sym_kType,
    ACTIONS(4338), 1,
      sym_kLabel,
    ACTIONS(4341), 1,
      sym_kExports,
    ACTIONS(4344), 1,
      sym_kClass,
    ACTIONS(4347), 1,
      sym_kGeneric,
    ACTIONS(4353), 1,
      sym_kOperator,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(4326), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4350), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4321), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1033), 11,
      sym_blockTr,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [35551] = 4,
    STATE(950), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3221), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [35601] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4356), 1,
      sym_kType,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2575), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [35687] = 4,
    STATE(906), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3221), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [35737] = 4,
    ACTIONS(4358), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3923), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3921), 31,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [35787] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4360), 1,
      anon_sym_COLON,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(582), 1,
      sym_blockTr,
    STATE(1057), 1,
      sym_asmTr,
    STATE(1117), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1135), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [35881] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4366), 1,
      anon_sym_COLON,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(587), 1,
      sym_blockTr,
    STATE(1051), 1,
      sym_asmTr,
    STATE(1115), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1143), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [35975] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4372), 1,
      sym_kType,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2496), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [36061] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4374), 1,
      anon_sym_COLON,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(686), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1121), 1,
      sym_declArgs,
    STATE(1389), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1150), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36155] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4380), 1,
      anon_sym_COLON,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(862), 1,
      sym_blockTr,
    STATE(863), 1,
      sym_asmTr,
    STATE(1111), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1155), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36249] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4384), 1,
      anon_sym_COLON,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(643), 1,
      sym_blockTr,
    STATE(1112), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1269), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1161), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36343] = 26,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(4279), 1,
      sym_kAsm,
    ACTIONS(4390), 1,
      anon_sym_COLON,
    STATE(544), 1,
      sym_asmTr,
    STATE(571), 1,
      sym_blockTr,
    STATE(1113), 1,
      sym_declArgs,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1167), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36437] = 21,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4392), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1048), 11,
      sym_blockTr,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36521] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4394), 1,
      sym_kType,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2679), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [36607] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(3469), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [36669] = 21,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4396), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1033), 11,
      sym_blockTr,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [36753] = 22,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4251), 1,
      sym_kClass,
    ACTIONS(4255), 1,
      sym_kRecord,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4265), 1,
      sym_kPacked,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4398), 1,
      sym_kType,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4247), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(4253), 4,
      sym_kObject,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2382), 4,
      sym_type,
      sym_declClass,
      sym_declIntf,
      sym_declHelper,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [36839] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2947), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2949), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [36886] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3027), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3029), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [36933] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2959), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2961), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [36980] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2947), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2949), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37027] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3031), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3033), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37074] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2963), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2965), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37121] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2907), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2909), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37168] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3027), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3029), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37215] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3031), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3033), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37262] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2939), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2941), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37309] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2939), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2941), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37356] = 19,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3093), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(1244), 2,
      aux_sym__declFields,
      sym_declField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1191), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4400), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [37435] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2951), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2953), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37482] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3011), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3013), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37529] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2967), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2969), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37576] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2955), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2957), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37623] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3011), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3013), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37670] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2967), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2969), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37717] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2979), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2981), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [37764] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2955), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2957), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37811] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2979), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2981), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [37858] = 8,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [37915] = 7,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [37970] = 4,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2985), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [38019] = 4,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2995), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2997), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [38068] = 9,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4412), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4418), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kElse,
  [38127] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3003), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3005), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [38174] = 19,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3093), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(1061), 2,
      aux_sym__declFields,
      sym_declField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1201), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4424), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [38253] = 10,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(4426), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 19,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kName,
      sym_kDelayed,
  [38314] = 7,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2983), 6,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kIn,
    ACTIONS(2985), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kElse,
  [38369] = 4,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2985), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38418] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      sym_kConst,
    ACTIONS(4428), 1,
      sym_kEnd,
    ACTIONS(4432), 1,
      sym_kResourcestring,
    ACTIONS(4434), 1,
      sym_kType,
    ACTIONS(4436), 1,
      sym_kProperty,
    ACTIONS(4438), 1,
      sym_kClass,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(4446), 1,
      sym_kOperator,
    ACTIONS(4450), 1,
      sym_kStrict,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    STATE(2695), 1,
      sym_declVariant,
    ACTIONS(4430), 2,
      sym_kVar,
      sym_kThreadvar,
    STATE(1661), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4448), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [38505] = 4,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2995), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2997), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38554] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3003), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3005), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38601] = 11,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4452), 1,
      sym_kGt,
    ACTIONS(4412), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4418), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kIn,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 19,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kElse,
  [38664] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2959), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2961), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38711] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3019), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3021), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [38758] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2975), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2977), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38805] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2963), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2965), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38852] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2907), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2909), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [38899] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3007), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3009), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38946] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3015), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3017), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [38993] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2999), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3001), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39040] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3023), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3025), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39087] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2975), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2977), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39134] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2971), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2973), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39181] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2943), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2945), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39228] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3007), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3009), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39275] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3015), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3017), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39322] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2999), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3001), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39369] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2935), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2937), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39416] = 19,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3093), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(1104), 2,
      aux_sym__declFields,
      sym_declField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1191), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4400), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [39495] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      sym_kConst,
    ACTIONS(4432), 1,
      sym_kResourcestring,
    ACTIONS(4434), 1,
      sym_kType,
    ACTIONS(4436), 1,
      sym_kProperty,
    ACTIONS(4438), 1,
      sym_kClass,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(4446), 1,
      sym_kOperator,
    ACTIONS(4450), 1,
      sym_kStrict,
    ACTIONS(4454), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    STATE(2500), 1,
      sym_declVariant,
    ACTIONS(4430), 2,
      sym_kVar,
      sym_kThreadvar,
    STATE(1675), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4448), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
  [39582] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3023), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3025), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39629] = 19,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3055), 1,
      sym_identifier,
    ACTIONS(3067), 1,
      sym_kType,
    ACTIONS(3069), 1,
      sym_kProperty,
    ACTIONS(3071), 1,
      sym_kClass,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3093), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1679), 1,
      sym_rttiAttributes,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3063), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3065), 2,
      sym_kConst,
      sym_kResourcestring,
    STATE(1244), 2,
      aux_sym__declFields,
      sym_declField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1197), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4456), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [39708] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2943), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2945), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39755] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2951), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2953), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39802] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2935), 5,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2937), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kName,
      sym_kDelayed,
  [39849] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3019), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(3021), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39896] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2971), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(2973), 29,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kElse,
  [39943] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    ACTIONS(4458), 1,
      anon_sym_COLON,
    STATE(529), 1,
      sym_asmTr,
    STATE(563), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1149), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40031] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    ACTIONS(4460), 1,
      anon_sym_COLON,
    STATE(876), 1,
      sym_blockTr,
    STATE(877), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1157), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40119] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    ACTIONS(4462), 1,
      anon_sym_COLON,
    STATE(646), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1300), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1163), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40207] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    STATE(529), 1,
      sym_asmTr,
    STATE(573), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1169), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40295] = 20,
    ACTIONS(4466), 1,
      anon_sym_LBRACK,
    ACTIONS(4469), 1,
      sym_kUses,
    ACTIONS(4477), 1,
      sym_kConst,
    ACTIONS(4480), 1,
      sym_kResourcestring,
    ACTIONS(4483), 1,
      sym_kType,
    ACTIONS(4486), 1,
      sym_kLabel,
    ACTIONS(4489), 1,
      sym_kExports,
    ACTIONS(4492), 1,
      sym_kProperty,
    ACTIONS(4495), 1,
      sym_kClass,
    ACTIONS(4498), 1,
      sym_kGeneric,
    ACTIONS(4504), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1481), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1714), 1,
      sym_rttiAttributes,
    ACTIONS(4474), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4501), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4472), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1114), 10,
      sym_declProcFwd,
      aux_sym__declarations,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declLabels,
      sym_declProp,
  [40375] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    ACTIONS(4507), 1,
      anon_sym_COLON,
    STATE(591), 1,
      sym_blockTr,
    STATE(1068), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1145), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40463] = 20,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(4511), 1,
      sym_kProperty,
    ACTIONS(4513), 1,
      sym_kClass,
    ACTIONS(4515), 1,
      sym_kGeneric,
    ACTIONS(4519), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1481), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1714), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4517), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4509), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1123), 10,
      sym_declProcFwd,
      aux_sym__declarations,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declLabels,
      sym_declProp,
  [40543] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    ACTIONS(4521), 1,
      anon_sym_COLON,
    STATE(588), 1,
      sym_blockTr,
    STATE(1070), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1137), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40631] = 25,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    ACTIONS(4523), 1,
      aux_sym_type_token1,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1628), 1,
      sym_blockTr,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2388), 1,
      sym_asmTr,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1174), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40721] = 21,
    ACTIONS(4315), 1,
      anon_sym_LBRACK,
    ACTIONS(4318), 1,
      sym_kUses,
    ACTIONS(4329), 1,
      sym_kConst,
    ACTIONS(4332), 1,
      sym_kResourcestring,
    ACTIONS(4335), 1,
      sym_kType,
    ACTIONS(4338), 1,
      sym_kLabel,
    ACTIONS(4341), 1,
      sym_kExports,
    ACTIONS(4344), 1,
      sym_kClass,
    ACTIONS(4347), 1,
      sym_kGeneric,
    ACTIONS(4353), 1,
      sym_kOperator,
    ACTIONS(4525), 1,
      sym_kBegin,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(4326), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4321), 3,
      ts_builtin_sym_end,
      sym_kEnd,
      sym_kAsm,
    ACTIONS(4350), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 11,
      sym_blockTr,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40803] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    ACTIONS(4528), 1,
      anon_sym_COLON,
    STATE(658), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1324), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1128), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40891] = 24,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    ACTIONS(4530), 1,
      anon_sym_COLON,
    STATE(688), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1396), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1151), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [40979] = 4,
    ACTIONS(4534), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4536), 8,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
      sym_kIn,
    ACTIONS(4532), 27,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
  [41027] = 20,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(4511), 1,
      sym_kProperty,
    ACTIONS(4513), 1,
      sym_kClass,
    ACTIONS(4515), 1,
      sym_kGeneric,
    ACTIONS(4519), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1481), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1714), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4517), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    ACTIONS(4538), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
    STATE(1114), 10,
      sym_declProcFwd,
      aux_sym__declarations,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declLabels,
      sym_declProp,
  [41107] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(518), 1,
      sym_asmTr,
    STATE(567), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1134), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41192] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(654), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1303), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41277] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(522), 1,
      sym_asmTr,
    STATE(565), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41362] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(655), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1266), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1129), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41447] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(667), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1270), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41532] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(662), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1279), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41617] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(664), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1306), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1131), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41702] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4311), 1,
      sym_kBegin,
    ACTIONS(4313), 1,
      sym_kAsm,
    STATE(644), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1285), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41787] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(526), 1,
      sym_asmTr,
    STATE(560), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1140), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [41872] = 4,
    ACTIONS(4540), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3923), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(3921), 28,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kOn,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [41919] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(516), 1,
      sym_asmTr,
    STATE(564), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42004] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(585), 1,
      sym_blockTr,
    STATE(1069), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42089] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(576), 1,
      sym_blockTr,
    STATE(1095), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1138), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42174] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(579), 1,
      sym_blockTr,
    STATE(1097), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42259] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(594), 1,
      sym_blockTr,
    STATE(1103), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42344] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(569), 1,
      sym_blockTr,
    STATE(1105), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1141), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42429] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(542), 1,
      sym_asmTr,
    STATE(566), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42514] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4362), 1,
      sym_kBegin,
    ACTIONS(4364), 1,
      sym_kAsm,
    STATE(584), 1,
      sym_blockTr,
    STATE(1107), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42599] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1620), 1,
      sym_blockTr,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2605), 1,
      sym_asmTr,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42684] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(590), 1,
      sym_blockTr,
    STATE(1065), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42769] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(592), 1,
      sym_blockTr,
    STATE(1109), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1146), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42854] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(593), 1,
      sym_blockTr,
    STATE(1090), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [42939] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(595), 1,
      sym_blockTr,
    STATE(1093), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43024] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(577), 1,
      sym_blockTr,
    STATE(1096), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1148), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43109] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4368), 1,
      sym_kBegin,
    ACTIONS(4370), 1,
      sym_kAsm,
    STATE(581), 1,
      sym_blockTr,
    STATE(1100), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43194] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(535), 1,
      sym_asmTr,
    STATE(562), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43279] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(687), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1395), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43364] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(691), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1401), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43449] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(692), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1404), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43534] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(693), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1405), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1154), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43619] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(694), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1406), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43704] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(872), 1,
      sym_blockTr,
    STATE(875), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43789] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(881), 1,
      sym_blockTr,
    STATE(882), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1158), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43874] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(883), 1,
      sym_blockTr,
    STATE(884), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [43959] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(778), 1,
      sym_blockTr,
    STATE(779), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44044] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(780), 1,
      sym_blockTr,
    STATE(781), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1160), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44129] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4382), 1,
      sym_kAsm,
    STATE(783), 1,
      sym_blockTr,
    STATE(784), 1,
      sym_asmTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44214] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(645), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1312), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44299] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(647), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1320), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1164), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44384] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(648), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1309), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44469] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(649), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1262), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44554] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(650), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1304), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1166), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44639] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4386), 1,
      sym_kBegin,
    ACTIONS(4388), 1,
      sym_kAsm,
    STATE(651), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1314), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44724] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(522), 1,
      sym_asmTr,
    STATE(572), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44809] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(526), 1,
      sym_asmTr,
    STATE(574), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1170), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44894] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(535), 1,
      sym_asmTr,
    STATE(575), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [44979] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(542), 1,
      sym_asmTr,
    STATE(568), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45064] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(518), 1,
      sym_asmTr,
    STATE(578), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1172), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45149] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(516), 1,
      sym_asmTr,
    STATE(580), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45234] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1637), 1,
      sym_blockTr,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2340), 1,
      sym_asmTr,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1175), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45319] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1625), 1,
      sym_blockTr,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2422), 1,
      sym_asmTr,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45404] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1622), 1,
      sym_blockTr,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2611), 1,
      sym_asmTr,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45489] = 4,
    ACTIONS(4534), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4536), 7,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4532), 27,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEnd,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kHat,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [45536] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4279), 1,
      sym_kAsm,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1631), 1,
      sym_blockTr,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    STATE(2445), 1,
      sym_asmTr,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1142), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45621] = 23,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4376), 1,
      sym_kBegin,
    ACTIONS(4378), 1,
      sym_kAsm,
    STATE(690), 1,
      sym_blockTr,
    STATE(1118), 1,
      sym_declProc,
    STATE(1400), 1,
      sym_asmTr,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1152), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45706] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4544), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4542), 28,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [45750] = 22,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4546), 1,
      sym_kEnd,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1617), 1,
      sym_blockTr,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1181), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45832] = 22,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4548), 1,
      sym_kEnd,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1616), 1,
      sym_blockTr,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [45914] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4552), 6,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEq,
    ACTIONS(4550), 28,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [45958] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4556), 6,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEq,
    ACTIONS(4554), 28,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [46002] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4560), 6,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEq,
    ACTIONS(4558), 28,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kClass,
      sym_kOf,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [46046] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4564), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4562), 28,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kElse,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [46090] = 21,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(4566), 1,
      ts_builtin_sym_end,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 11,
      sym_blockTr,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [46170] = 10,
    ACTIONS(4568), 1,
      ts_builtin_sym_end,
    ACTIONS(4570), 1,
      sym_identifier,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4577), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1936), 1,
      sym_rttiAttributes,
    STATE(1202), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1981), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4575), 22,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [46227] = 12,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4580), 1,
      anon_sym_SEMI,
    ACTIONS(4412), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4418), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4588), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(4582), 6,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
  [46288] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4590), 1,
      aux_sym__literalString_token1,
    ACTIONS(4593), 1,
      anon_sym_POUND,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    STATE(1189), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1626), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [46339] = 10,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4412), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4418), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(3469), 12,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
  [46396] = 17,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      sym_kConst,
    ACTIONS(4432), 1,
      sym_kResourcestring,
    ACTIONS(4434), 1,
      sym_kType,
    ACTIONS(4436), 1,
      sym_kProperty,
    ACTIONS(4438), 1,
      sym_kClass,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4446), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    ACTIONS(4430), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4596), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [46467] = 10,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4412), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4414), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4418), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4420), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(3465), 12,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
  [46524] = 4,
    ACTIONS(4602), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4600), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4598), 26,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [46569] = 4,
    ACTIONS(4604), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4600), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4598), 26,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [46614] = 21,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1639), 1,
      sym_blockTr,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1119), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [46693] = 6,
    ACTIONS(3109), 1,
      anon_sym_POUND,
    ACTIONS(4606), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1204), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1636), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [46742] = 17,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      sym_kConst,
    ACTIONS(4432), 1,
      sym_kResourcestring,
    ACTIONS(4434), 1,
      sym_kType,
    ACTIONS(4436), 1,
      sym_kProperty,
    ACTIONS(4438), 1,
      sym_kClass,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4446), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    ACTIONS(4430), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4608), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [46813] = 21,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(17), 1,
      sym_kUses,
    ACTIONS(19), 1,
      sym_kBegin,
    ACTIONS(23), 1,
      sym_kConst,
    ACTIONS(25), 1,
      sym_kResourcestring,
    ACTIONS(27), 1,
      sym_kType,
    ACTIONS(29), 1,
      sym_kLabel,
    ACTIONS(31), 1,
      sym_kExports,
    ACTIONS(33), 1,
      sym_kClass,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    STATE(1118), 1,
      sym_declProc,
    STATE(1596), 1,
      sym__declProc,
    STATE(1623), 1,
      sym_blockTr,
    STATE(1624), 1,
      sym__declOperator,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1782), 1,
      sym_rttiAttributes,
    ACTIONS(21), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1195), 10,
      aux_sym__definitions,
      sym__definition,
      sym_defProc,
      sym_declProcFwd,
      sym_declUses,
      sym_declExports,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declLabels,
  [46892] = 17,
    ACTIONS(4610), 1,
      anon_sym_LBRACK,
    ACTIONS(4618), 1,
      sym_kConst,
    ACTIONS(4621), 1,
      sym_kResourcestring,
    ACTIONS(4624), 1,
      sym_kType,
    ACTIONS(4627), 1,
      sym_kProperty,
    ACTIONS(4630), 1,
      sym_kClass,
    ACTIONS(4633), 1,
      sym_kGeneric,
    ACTIONS(4639), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    ACTIONS(4615), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4636), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4613), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [46963] = 10,
    ACTIONS(4642), 1,
      ts_builtin_sym_end,
    ACTIONS(4644), 1,
      sym_identifier,
    ACTIONS(4647), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1936), 1,
      sym_rttiAttributes,
    STATE(1200), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1981), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4650), 22,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47020] = 17,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      sym_kConst,
    ACTIONS(4432), 1,
      sym_kResourcestring,
    ACTIONS(4434), 1,
      sym_kType,
    ACTIONS(4436), 1,
      sym_kProperty,
    ACTIONS(4438), 1,
      sym_kClass,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4446), 1,
      sym_kOperator,
    STATE(1233), 1,
      sym__declOperator,
    STATE(1545), 1,
      sym__declProc,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1745), 1,
      sym_rttiAttributes,
    ACTIONS(4430), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
    STATE(1199), 6,
      aux_sym__classDeclarations,
      sym_declTypes,
      sym_declVars,
      sym_declConsts,
      sym_declProc,
      sym_declProp,
    ACTIONS(4655), 9,
      sym_kEnd,
      sym_kCase,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [47091] = 10,
    ACTIONS(4570), 1,
      sym_identifier,
    ACTIONS(4657), 1,
      ts_builtin_sym_end,
    ACTIONS(4659), 1,
      anon_sym_LBRACK,
    ACTIONS(4664), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1936), 1,
      sym_rttiAttributes,
    STATE(1200), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1981), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4662), 22,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47148] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3039), 1,
      anon_sym_POUND,
    ACTIONS(4667), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    STATE(1189), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1636), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [47199] = 6,
    ACTIONS(4669), 1,
      aux_sym__literalString_token1,
    ACTIONS(4672), 1,
      anon_sym_POUND,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1204), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1626), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [47248] = 6,
    ACTIONS(3129), 1,
      anon_sym_POUND,
    ACTIONS(4675), 1,
      aux_sym__literalString_token1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1208), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1634), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1636), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [47296] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4679), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(4677), 26,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFor,
      sym_kIf,
      sym_kWhile,
      sym_kRepeat,
      sym_kTry,
      sym_kRaise,
      sym_kCase,
      sym_kWith,
      sym_kGoto,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [47338] = 12,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4580), 1,
      anon_sym_SEMI,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4582), 5,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4681), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [47398] = 6,
    ACTIONS(4683), 1,
      aux_sym__literalString_token1,
    ACTIONS(4686), 1,
      anon_sym_POUND,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1208), 3,
      sym__literalString,
      sym_literalChar,
      aux_sym_literalString_repeat1,
    ACTIONS(1624), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(1626), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [47446] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(3469), 10,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
  [47499] = 10,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(4695), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4693), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [47554] = 9,
    ACTIONS(4697), 1,
      ts_builtin_sym_end,
    ACTIONS(4699), 1,
      sym_identifier,
    ACTIONS(4702), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2279), 1,
      sym_rttiAttributes,
    STATE(2300), 1,
      aux_sym_genericArg_repeat1,
    STATE(1211), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4705), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47607] = 9,
    ACTIONS(4707), 1,
      ts_builtin_sym_end,
    ACTIONS(4709), 1,
      sym_identifier,
    ACTIONS(4711), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2279), 1,
      sym_rttiAttributes,
    STATE(2300), 1,
      aux_sym_genericArg_repeat1,
    STATE(1211), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4714), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47660] = 10,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(4695), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4716), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [47715] = 9,
    ACTIONS(4709), 1,
      sym_identifier,
    ACTIONS(4718), 1,
      ts_builtin_sym_end,
    ACTIONS(4720), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2279), 1,
      sym_rttiAttributes,
    STATE(2300), 1,
      aux_sym_genericArg_repeat1,
    STATE(1217), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4723), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47768] = 9,
    ACTIONS(4659), 1,
      anon_sym_LBRACK,
    ACTIONS(4725), 1,
      sym_identifier,
    ACTIONS(4727), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1943), 1,
      sym_rttiAttributes,
    STATE(1216), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1984), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4662), 21,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [47821] = 9,
    ACTIONS(4647), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym_identifier,
    ACTIONS(4733), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1943), 1,
      sym_rttiAttributes,
    STATE(1216), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1984), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4650), 21,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [47874] = 9,
    ACTIONS(4709), 1,
      sym_identifier,
    ACTIONS(4736), 1,
      ts_builtin_sym_end,
    ACTIONS(4738), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2279), 1,
      sym_rttiAttributes,
    STATE(2300), 1,
      aux_sym_genericArg_repeat1,
    STATE(1211), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4741), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47927] = 9,
    ACTIONS(4709), 1,
      sym_identifier,
    ACTIONS(4736), 1,
      ts_builtin_sym_end,
    ACTIONS(4738), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2279), 1,
      sym_rttiAttributes,
    STATE(2300), 1,
      aux_sym_genericArg_repeat1,
    STATE(1212), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4741), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [47980] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(3465), 10,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
  [48033] = 9,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4725), 1,
      sym_identifier,
    ACTIONS(4743), 1,
      sym_kGeneric,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(1943), 1,
      sym_rttiAttributes,
    STATE(1215), 2,
      sym_declType,
      aux_sym_declTypes_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1984), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4575), 21,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [48086] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4746), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [48138] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2831), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2833), 26,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [48180] = 3,
    ACTIONS(4750), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4748), 29,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [48220] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2831), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2833), 25,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [48260] = 8,
    ACTIONS(4752), 1,
      ts_builtin_sym_end,
    ACTIONS(4754), 1,
      sym_identifier,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2337), 1,
      sym_rttiAttributes,
    STATE(1234), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4759), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [48310] = 8,
    ACTIONS(4754), 1,
      sym_identifier,
    ACTIONS(4761), 1,
      ts_builtin_sym_end,
    ACTIONS(4763), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2337), 1,
      sym_rttiAttributes,
    STATE(1230), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4766), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [48360] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4768), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [48412] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4770), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [48464] = 3,
    ACTIONS(4774), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4772), 29,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [48504] = 8,
    ACTIONS(4752), 1,
      ts_builtin_sym_end,
    ACTIONS(4754), 1,
      sym_identifier,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2337), 1,
      sym_rttiAttributes,
    STATE(1232), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4759), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [48554] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4776), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [48606] = 8,
    ACTIONS(4778), 1,
      ts_builtin_sym_end,
    ACTIONS(4780), 1,
      sym_identifier,
    ACTIONS(4783), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2337), 1,
      sym_rttiAttributes,
    STATE(1232), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4786), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [48656] = 3,
    ACTIONS(4790), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4788), 29,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [48696] = 8,
    ACTIONS(4754), 1,
      sym_identifier,
    ACTIONS(4792), 1,
      ts_builtin_sym_end,
    ACTIONS(4794), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2337), 1,
      sym_rttiAttributes,
    STATE(1232), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4797), 23,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [48746] = 8,
    ACTIONS(4738), 1,
      anon_sym_LBRACK,
    ACTIONS(4799), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2327), 1,
      sym_rttiAttributes,
    STATE(2328), 1,
      aux_sym_genericArg_repeat1,
    STATE(1241), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4741), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [48795] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2831), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2833), 25,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [48834] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(2008), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [48883] = 5,
    ACTIONS(5), 1,
      sym_pp,
    STATE(968), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3219), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3221), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [48926] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(2004), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [48975] = 8,
    ACTIONS(4738), 1,
      anon_sym_LBRACK,
    ACTIONS(4799), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2327), 1,
      sym_rttiAttributes,
    STATE(2328), 1,
      aux_sym_genericArg_repeat1,
    STATE(1243), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4741), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49024] = 8,
    ACTIONS(4702), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2327), 1,
      sym_rttiAttributes,
    STATE(2328), 1,
      aux_sym_genericArg_repeat1,
    STATE(1241), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4705), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49073] = 4,
    STATE(931), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3221), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49114] = 8,
    ACTIONS(4711), 1,
      anon_sym_LBRACK,
    ACTIONS(4799), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2327), 1,
      sym_rttiAttributes,
    STATE(2328), 1,
      aux_sym_genericArg_repeat1,
    STATE(1241), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4714), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49163] = 8,
    ACTIONS(4810), 1,
      sym_identifier,
    ACTIONS(4813), 1,
      anon_sym_LBRACK,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2168), 1,
      aux_sym_genericArg_repeat1,
    STATE(2248), 1,
      sym_rttiAttributes,
    STATE(1244), 2,
      aux_sym__declFields,
      sym_declField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4816), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49212] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4818), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2991), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(2993), 15,
      anon_sym_LPAREN,
      sym_kOf,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49255] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4820), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3265), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 15,
      anon_sym_LPAREN,
      sym_kOf,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49298] = 4,
    ACTIONS(4822), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49339] = 4,
    ACTIONS(4824), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2991), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(2993), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49380] = 8,
    ACTIONS(4720), 1,
      anon_sym_LBRACK,
    ACTIONS(4799), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2327), 1,
      sym_rttiAttributes,
    STATE(2328), 1,
      aux_sym_genericArg_repeat1,
    STATE(1235), 2,
      sym_declVar,
      aux_sym_declVars_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4723), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49429] = 9,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4826), 1,
      anon_sym_LBRACK,
    ACTIONS(4828), 1,
      anon_sym_LPAREN,
    ACTIONS(4830), 1,
      sym_kLt,
    STATE(968), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3209), 22,
      anon_sym_COMMA,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49480] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(1987), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [49529] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(2001), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [49578] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(1992), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [49627] = 8,
    ACTIONS(4832), 1,
      anon_sym_LBRACK,
    ACTIONS(4834), 1,
      anon_sym_LPAREN,
    ACTIONS(4836), 1,
      anon_sym_DOT,
    ACTIONS(4838), 1,
      sym_kLt,
    STATE(931), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49676] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4801), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1893), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    STATE(2007), 3,
      sym_operatorDot,
      sym__operatorName,
      sym_operatorName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [49725] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2963), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2965), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49765] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4842), 1,
      anon_sym_LPAREN,
    ACTIONS(4844), 1,
      sym_kLt,
    STATE(919), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 21,
      anon_sym_COMMA,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [49813] = 7,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4846), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2635), 1,
      sym_rttiAttributes,
    STATE(1263), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4759), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49859] = 7,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4846), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2635), 1,
      sym_rttiAttributes,
    STATE(1265), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4759), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [49905] = 8,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4850), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
    ACTIONS(4848), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 16,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
  [49953] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3019), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3021), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [49991] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3023), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3025), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50031] = 7,
    ACTIONS(4783), 1,
      anon_sym_LBRACK,
    ACTIONS(4856), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2635), 1,
      sym_rttiAttributes,
    STATE(1263), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4786), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [50077] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2999), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3001), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50115] = 7,
    ACTIONS(4794), 1,
      anon_sym_LBRACK,
    ACTIONS(4846), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2635), 1,
      sym_rttiAttributes,
    STATE(1263), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4797), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [50161] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2971), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2973), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50199] = 8,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [50247] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3027), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3029), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50285] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3027), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3029), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50325] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3007), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3009), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50363] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2907), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2909), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50403] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2556), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [50473] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3011), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3013), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50511] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2985), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50553] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2967), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2969), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50591] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3031), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3033), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50631] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2379), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [50701] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2373), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [50771] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3023), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3025), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [50809] = 4,
    ACTIONS(4873), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3265), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(3263), 16,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [50849] = 10,
    ACTIONS(4414), 1,
      sym_kFdiv,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4875), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4418), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4420), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4877), 6,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
  [50901] = 7,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 15,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
  [50947] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2448), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [51017] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3019), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3021), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51057] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2935), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2937), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51095] = 9,
    ACTIONS(4414), 1,
      sym_kFdiv,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4418), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4420), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4879), 7,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
  [51145] = 4,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2985), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51185] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3031), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3033), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51223] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2959), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2961), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51261] = 10,
    ACTIONS(4414), 1,
      sym_kFdiv,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4881), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4418), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4420), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4883), 6,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
  [51313] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2939), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2941), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51351] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2995), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2997), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51393] = 11,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(4850), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(4885), 1,
      sym_kGt,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2983), 2,
      anon_sym_LPAREN,
      sym_kLt,
    ACTIONS(4887), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4848), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [51447] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2947), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2949), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51487] = 4,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2995), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2997), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51527] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2698), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [51597] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3003), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3005), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51635] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3015), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3017), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51673] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2959), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2961), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51713] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2979), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2981), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51753] = 10,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(4889), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 10,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [51805] = 10,
    ACTIONS(4414), 1,
      sym_kFdiv,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4891), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4584), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4418), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4586), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4420), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4893), 6,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
  [51857] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2955), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2957), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51895] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2943), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2945), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [51935] = 7,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4897), 1,
      anon_sym_LBRACK,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(4901), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4895), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [51981] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2943), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2945), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52019] = 7,
    ACTIONS(4763), 1,
      anon_sym_LBRACK,
    ACTIONS(4846), 1,
      sym_identifier,
    STATE(1680), 1,
      aux_sym_rttiAttributes_repeat2,
    STATE(2635), 1,
      sym_rttiAttributes,
    STATE(1258), 2,
      sym_declConst,
      aux_sym_declConsts_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4766), 22,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [52065] = 7,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(4905), 1,
      anon_sym_LBRACK,
    ACTIONS(4907), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4903), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [52111] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3007), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3009), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52151] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2975), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2977), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52191] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3011), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3013), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52231] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2955), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2957), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52271] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3015), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3017), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52311] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2935), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2937), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52351] = 19,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3257), 1,
      sym_kHelper,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2552), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [52421] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2951), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2953), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52459] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3003), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3005), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52499] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2999), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3001), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52539] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2951), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2953), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52579] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2971), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2973), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52619] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2963), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2965), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52657] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2939), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2941), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52697] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2947), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2949), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52735] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2979), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2981), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52773] = 4,
    ACTIONS(4909), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2991), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
    ACTIONS(2993), 16,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [52813] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2967), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2969), 24,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52853] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2975), 5,
      anon_sym_LPAREN,
      anon_sym_DOT,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2977), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52891] = 9,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4850), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
    ACTIONS(4887), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4848), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [52941] = 4,
    ACTIONS(4911), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4536), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(4532), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [52981] = 4,
    STATE(919), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3219), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3221), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [53021] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2322), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53088] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2259), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53155] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1994), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53222] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1993), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53289] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1657), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53356] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1658), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53423] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1659), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53490] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1997), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53557] = 8,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4939), 1,
      sym_identifier,
    STATE(2111), 1,
      sym_kDot,
    STATE(2122), 1,
      sym_operatorName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1682), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
    ACTIONS(4805), 8,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(4803), 12,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
  [53604] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2123), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53671] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2033), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53738] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2036), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53805] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2162), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53872] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2165), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [53939] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2178), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54006] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2054), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54073] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2171), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54140] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1944), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54207] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1910), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54274] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2237), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54341] = 10,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    ACTIONS(4943), 1,
      anon_sym_RBRACK,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [54392] = 13,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4945), 1,
      anon_sym_COLON,
    ACTIONS(4947), 1,
      anon_sym_COMMA,
    STATE(1917), 1,
      aux_sym_legacyFormat_repeat1,
    STATE(2037), 1,
      sym_legacyFormat,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(4949), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [54449] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2282), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54516] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1669), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54583] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4917), 1,
      aux_sym_type_token1,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    STATE(2163), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2202), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54650] = 10,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    ACTIONS(4951), 1,
      anon_sym_RBRACK,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [54701] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2107), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54768] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4881), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4883), 5,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [54819] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2117), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [54886] = 10,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(3723), 1,
      anon_sym_RBRACK,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [54937] = 4,
    ACTIONS(4953), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4536), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(4532), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [54976] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4879), 6,
      anon_sym_SEMI,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [55025] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1945), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55092] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4580), 1,
      anon_sym_SEMI,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4681), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [55145] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1740), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55212] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4973), 1,
      sym_kDo,
    ACTIONS(2983), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
  [55263] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1977), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55330] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2010), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55397] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1651), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55464] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2161), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55531] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2026), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55598] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2027), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55665] = 8,
    ACTIONS(4979), 1,
      sym_kFdiv,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(4983), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
    ACTIONS(4975), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4977), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [55712] = 7,
    ACTIONS(4979), 1,
      sym_kFdiv,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(4983), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 3,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
    ACTIONS(4977), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 15,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [55757] = 4,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2983), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2985), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [55796] = 4,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2995), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2997), 22,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [55835] = 10,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(4979), 1,
      sym_kFdiv,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(4983), 1,
      sym_kAs,
    ACTIONS(4985), 1,
      sym_kGt,
    ACTIONS(2983), 2,
      anon_sym_LPAREN,
      sym_kLt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4975), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4977), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 10,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [55886] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2019), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [55953] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2136), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [56020] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2138), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [56087] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1705), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [56154] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1706), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [56221] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4875), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4877), 5,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [56272] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1662), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [56339] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2959), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2961), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56376] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2947), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2949), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56413] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2963), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2965), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56450] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2907), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2909), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56487] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3027), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3029), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56524] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3031), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3033), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56561] = 10,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    ACTIONS(4987), 1,
      anon_sym_RBRACK,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [56612] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2951), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2953), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56649] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3011), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3013), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56686] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2967), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2969), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56723] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2955), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2957), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56760] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2979), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2981), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56797] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3003), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3005), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56834] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3019), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3021), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56871] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2975), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2977), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56908] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2971), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2973), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56945] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3007), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3009), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [56982] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3015), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3017), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [57019] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2999), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3001), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [57056] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3023), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3025), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [57093] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2943), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2945), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [57130] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2935), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2937), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [57167] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2092), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57234] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1923), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57301] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2018), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57368] = 10,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    ACTIONS(4989), 1,
      anon_sym_RBRACK,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [57419] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4991), 1,
      sym_kDo,
    ACTIONS(2983), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
  [57470] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1657), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57537] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1658), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57604] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1659), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57671] = 13,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4945), 1,
      anon_sym_COLON,
    ACTIONS(4947), 1,
      anon_sym_COMMA,
    STATE(1917), 1,
      aux_sym_legacyFormat_repeat1,
    STATE(2047), 1,
      sym_legacyFormat,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(4993), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [57728] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1669), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57795] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1651), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57862] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1662), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57929] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1672), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [57996] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1650), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58063] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2217), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58130] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1729), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58197] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1730), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58264] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1672), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58331] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4995), 1,
      sym_kDo,
    ACTIONS(2983), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(2985), 11,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kIs,
      sym_kIn,
  [58382] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4891), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4893), 5,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [58433] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2003), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58500] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2035), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58567] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1743), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58634] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1960), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58701] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1963), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58768] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2042), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58835] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2044), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58902] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2045), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [58969] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1985), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59036] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(1650), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59103] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2050), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59170] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2051), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59237] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2053), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59304] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2056), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59371] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1691), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59438] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1694), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59505] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1695), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59572] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1698), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59639] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1699), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59706] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4957), 1,
      sym_kClass,
    ACTIONS(4959), 1,
      sym_kArray,
    ACTIONS(4961), 1,
      sym_kFile,
    ACTIONS(4963), 1,
      sym_kSet,
    ACTIONS(4965), 1,
      sym_kPacked,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    ACTIONS(4971), 1,
      sym_kReference,
    STATE(1702), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4969), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59773] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2073), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59840] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2076), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59907] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2078), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [59974] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2079), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60041] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2081), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60108] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2082), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60175] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2084), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60242] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2085), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60309] = 18,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_LPAREN,
    ACTIONS(4245), 1,
      aux_sym_type_token1,
    ACTIONS(4257), 1,
      sym_kArray,
    ACTIONS(4259), 1,
      sym_kFile,
    ACTIONS(4261), 1,
      sym_kString,
    ACTIONS(4263), 1,
      sym_kSet,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4273), 1,
      sym_kReference,
    ACTIONS(4869), 1,
      sym_kClass,
    ACTIONS(4871), 1,
      sym_kPacked,
    STATE(2251), 1,
      sym_type,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4271), 2,
      sym_kFunction,
      sym_kProcedure,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(1665), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [60376] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2939), 4,
      anon_sym_LPAREN,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(2941), 23,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
      sym_kTo,
      sym_kDownto,
  [60413] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4999), 1,
      sym_kIn,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4997), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [60465] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(5001), 1,
      sym_kIn,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4997), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [60517] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5003), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60565] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(4941), 1,
      anon_sym_COMMA,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60613] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5005), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60661] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5007), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60709] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5009), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60757] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5011), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60805] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5013), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60853] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5015), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60901] = 9,
    ACTIONS(3211), 1,
      anon_sym_LBRACK,
    ACTIONS(3213), 1,
      anon_sym_LPAREN,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      sym_kLt,
    ACTIONS(5017), 1,
      anon_sym_SEMI,
    STATE(889), 1,
      sym_kDot,
    ACTIONS(3207), 2,
      sym_kGt,
      sym_kFdiv,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3209), 18,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kHat,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kIs,
      sym_kAs,
      sym_kIn,
  [60949] = 11,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(5019), 1,
      sym_kIn,
    ACTIONS(4185), 2,
      sym_kAdd,
      sym_kSub,
    ACTIONS(4187), 2,
      sym_kMul,
      sym_kFdiv,
    ACTIONS(4189), 2,
      sym_kOr,
      sym_kXor,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4191), 5,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4997), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [61001] = 11,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(5021), 1,
      anon_sym_SEMI,
    ACTIONS(5025), 1,
      sym_kDelayed,
    ACTIONS(5023), 2,
      sym_kIndex,
      sym_kName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [61052] = 3,
    ACTIONS(5029), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5027), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61087] = 3,
    ACTIONS(5033), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5031), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61122] = 15,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2219), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [61181] = 3,
    ACTIONS(5037), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5035), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61216] = 11,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(5039), 1,
      anon_sym_SEMI,
    ACTIONS(5043), 1,
      sym_kDelayed,
    ACTIONS(5041), 2,
      sym_kIndex,
      sym_kName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [61267] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(5045), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61314] = 3,
    ACTIONS(5049), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5047), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61349] = 3,
    ACTIONS(5053), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5051), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61384] = 3,
    ACTIONS(5057), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5055), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61419] = 15,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2040), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [61478] = 15,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(4919), 1,
      sym_kClass,
    ACTIONS(4921), 1,
      sym_kArray,
    ACTIONS(4923), 1,
      sym_kFile,
    ACTIONS(4925), 1,
      sym_kString,
    ACTIONS(4927), 1,
      sym_kSet,
    ACTIONS(4929), 1,
      sym_kPacked,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(4937), 1,
      sym_kReference,
    ACTIONS(4935), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
    STATE(2096), 8,
      sym_typeref,
      sym_declEnum,
      sym_declSet,
      sym_declArray,
      sym_declFile,
      sym_declString,
      sym_declProcRef,
      sym_declMetaClass,
  [61537] = 6,
    ACTIONS(3203), 1,
      sym_kExternal,
    ACTIONS(5061), 1,
      sym_kConst,
    ACTIONS(5063), 1,
      sym_kForward,
    STATE(127), 1,
      sym_procExternal,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5059), 21,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61578] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(5065), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61625] = 12,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4945), 1,
      anon_sym_COLON,
    ACTIONS(4947), 1,
      anon_sym_COMMA,
    STATE(1917), 1,
      aux_sym_legacyFormat_repeat1,
    STATE(2602), 1,
      sym_legacyFormat,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61678] = 3,
    ACTIONS(5069), 2,
      anon_sym_SEMI,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5067), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [61713] = 3,
    ACTIONS(5073), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5071), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61748] = 9,
    ACTIONS(4406), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4689), 3,
      sym_kLt,
      sym_kGt,
      sym_kIn,
    ACTIONS(4402), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(5075), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      sym_kIndex,
      sym_kName,
    ACTIONS(4691), 5,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
    ACTIONS(4404), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [61795] = 3,
    ACTIONS(5079), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5077), 24,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [61830] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5083), 1,
      anon_sym_RBRACK,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61880] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5091), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(5065), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61928] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5093), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [61978] = 3,
    ACTIONS(5097), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5095), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [62012] = 3,
    ACTIONS(5101), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5099), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [62046] = 3,
    ACTIONS(5105), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5103), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [62080] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5107), 1,
      anon_sym_COLON,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62130] = 3,
    ACTIONS(5111), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5109), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [62164] = 3,
    ACTIONS(5115), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5113), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [62198] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5119), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62248] = 10,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4850), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5121), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3465), 3,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
    ACTIONS(4887), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4848), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5123), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62296] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5125), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62346] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5127), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62396] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5129), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62442] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5131), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62492] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5133), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62542] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5135), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62592] = 3,
    ACTIONS(5139), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5137), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [62626] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5141), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62672] = 3,
    ACTIONS(5145), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5143), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [62706] = 3,
    ACTIONS(5149), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5147), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [62740] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5151), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62790] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5153), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62840] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5155), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62890] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5157), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62940] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5159), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [62986] = 3,
    ACTIONS(5163), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5161), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63020] = 3,
    ACTIONS(5167), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5165), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63054] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5169), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63104] = 3,
    ACTIONS(5173), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5171), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63138] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5175), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63188] = 10,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4850), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5121), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3469), 3,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
    ACTIONS(4887), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4848), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5123), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63236] = 11,
    ACTIONS(3615), 1,
      anon_sym_RBRACK,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63286] = 3,
    ACTIONS(5179), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5177), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [63320] = 3,
    ACTIONS(5183), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5181), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63354] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5185), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63404] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5187), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63454] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5189), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63504] = 11,
    ACTIONS(3621), 1,
      anon_sym_RBRACK,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63554] = 3,
    ACTIONS(5193), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5191), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63588] = 3,
    ACTIONS(5197), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5195), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [63622] = 3,
    ACTIONS(5201), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5199), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [63656] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5203), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63706] = 3,
    ACTIONS(5207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5205), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [63740] = 3,
    ACTIONS(5211), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5209), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [63774] = 3,
    ACTIONS(5215), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5213), 23,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kConst,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
      sym_identifier,
  [63808] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5217), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63858] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5219), 1,
      anon_sym_COLON,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63908] = 11,
    ACTIONS(3625), 1,
      anon_sym_RBRACK,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [63958] = 11,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5221), 1,
      anon_sym_RBRACK,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64008] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5223), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64054] = 3,
    ACTIONS(5227), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5225), 23,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kBegin,
      sym_kEnd,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [64088] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5229), 1,
      anon_sym_SEMI,
    ACTIONS(5231), 1,
      sym_kDelayed,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64135] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5235), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64182] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5237), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64229] = 10,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64276] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5239), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64323] = 3,
    ACTIONS(5061), 1,
      sym_kConst,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5059), 22,
      anon_sym_LBRACK,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kCase,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kStrict,
      sym_kRequired,
      sym_kOptional,
  [64356] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5241), 1,
      anon_sym_SEMI,
    ACTIONS(5243), 1,
      sym_kDelayed,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64403] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5245), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4905), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kGt,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [64442] = 10,
    ACTIONS(4863), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5087), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4859), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4861), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5089), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64489] = 9,
    ACTIONS(4979), 1,
      sym_kFdiv,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(4983), 1,
      sym_kAs,
    ACTIONS(4879), 2,
      sym_kTo,
      sym_kDownto,
    ACTIONS(5247), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4975), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4977), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(5249), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64534] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5251), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64581] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5253), 1,
      anon_sym_SEMI,
    ACTIONS(5255), 1,
      sym_kDelayed,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64628] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5257), 1,
      anon_sym_SEMI,
    ACTIONS(5259), 1,
      sym_kDelayed,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64675] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5261), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64722] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5263), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4897), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kEnd,
      sym_kAbsolute,
      sym_kOf,
      sym_kEq,
      sym_kGt,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
      sym_kDo,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [64761] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(5265), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64808] = 5,
    ACTIONS(5273), 1,
      sym_kEnd,
    ACTIONS(5269), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5271), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5267), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [64844] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5275), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [64890] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5277), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [64936] = 7,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(4903), 1,
      sym_kConst,
    ACTIONS(5279), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4905), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [64976] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5281), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65020] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5283), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [65066] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5285), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65112] = 5,
    ACTIONS(5289), 1,
      sym_kEnd,
    ACTIONS(5287), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5271), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5267), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [65148] = 7,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4895), 1,
      sym_kConst,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5291), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4897), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [65188] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5293), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65232] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5091), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65276] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5295), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65320] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5297), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [65366] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5233), 1,
      anon_sym_COMMA,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65410] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5299), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65456] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5301), 1,
      sym_kThen,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65500] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5303), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65544] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5305), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65588] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5307), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [65634] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5309), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65680] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5311), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65724] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5313), 1,
      sym_kThen,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65768] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5315), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [65814] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5317), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65860] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5319), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65904] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5321), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [65950] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5323), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [65996] = 10,
    ACTIONS(2983), 1,
      sym_kLt,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5325), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(2985), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
  [66042] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5327), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66086] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5329), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66130] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5331), 1,
      sym_kOf,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66174] = 5,
    ACTIONS(5335), 1,
      sym_kEnd,
    ACTIONS(5333), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5271), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5267), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [66210] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4875), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66254] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5337), 1,
      sym_kOf,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66298] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5339), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66344] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5341), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66388] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5343), 1,
      sym_kDo,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66432] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4891), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66476] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4881), 1,
      anon_sym_SEMI,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66520] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5065), 1,
      anon_sym_SEMI,
    ACTIONS(5345), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66566] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3203), 1,
      sym_kExternal,
    ACTIONS(5061), 1,
      sym_kConst,
    ACTIONS(5063), 1,
      sym_kForward,
    STATE(127), 1,
      sym_procExternal,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5059), 18,
      anon_sym_LBRACK,
      aux_sym_type_token1,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [66606] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5347), 1,
      anon_sym_RBRACK,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66650] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5351), 9,
      anon_sym_DOT,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kAdd,
      sym_kSub,
      sym_kMul,
      sym_kAssign,
    ACTIONS(5349), 13,
      sym_kLt,
      sym_kGt,
      sym_kFdiv,
      sym_kOr,
      sym_kXor,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
      sym_kNot,
      sym_kIn,
      sym_identifier,
  [66682] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66726] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4695), 1,
      anon_sym_COMMA,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66770] = 5,
    ACTIONS(5355), 1,
      sym_kEnd,
    ACTIONS(5353), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5271), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5267), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [66806] = 10,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3281), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 1,
      sym_kLt,
    ACTIONS(5357), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66852] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5359), 1,
      anon_sym_RBRACK,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66896] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5361), 1,
      anon_sym_RPAREN,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66940] = 9,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5363), 1,
      sym_kThen,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [66984] = 8,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4408), 1,
      sym_kHat,
    ACTIONS(4410), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67025] = 8,
    ACTIONS(3887), 1,
      sym_kHat,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5365), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67066] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5369), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5367), 16,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kEnd,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kElse,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67097] = 8,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4865), 1,
      sym_kHat,
    ACTIONS(4867), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67138] = 8,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(5371), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67179] = 8,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4416), 1,
      sym_kHat,
    ACTIONS(4422), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67220] = 8,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4852), 1,
      sym_kHat,
    ACTIONS(4854), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67261] = 8,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4981), 1,
      sym_kHat,
    ACTIONS(4983), 1,
      sym_kAs,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67302] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5351), 7,
      anon_sym_COLON,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
      sym_kHat,
    ACTIONS(5349), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67333] = 8,
    ACTIONS(2987), 1,
      sym_kHat,
    ACTIONS(3585), 1,
      sym_kAs,
    ACTIONS(4187), 1,
      sym_kFdiv,
    ACTIONS(4283), 2,
      sym_kLt,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4189), 4,
      sym_kAdd,
      sym_kSub,
      sym_kOr,
      sym_kXor,
    ACTIONS(4191), 6,
      sym_kMul,
      sym_kDiv,
      sym_kMod,
      sym_kAnd,
      sym_kShl,
      sym_kShr,
    ACTIONS(4285), 6,
      sym_kEq,
      sym_kNeq,
      sym_kLte,
      sym_kGte,
      sym_kIs,
      sym_kIn,
  [67374] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2607), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67408] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2686), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kEnd,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67442] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5377), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5375), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67471] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5271), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5267), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67500] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5379), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67531] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5383), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5381), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67560] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5385), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67591] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2583), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 16,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67624] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4790), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4788), 18,
      anon_sym_LBRACK,
      aux_sym_type_token1,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67655] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5387), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67686] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5391), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5389), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67715] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5395), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5393), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67744] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5397), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67775] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5401), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5399), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67804] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4750), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4748), 18,
      anon_sym_LBRACK,
      aux_sym_type_token1,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67835] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5403), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67866] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(4774), 1,
      sym_kConst,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4772), 18,
      anon_sym_LBRACK,
      aux_sym_type_token1,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [67897] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5407), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5405), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67926] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5411), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5409), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67955] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5415), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5413), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [67984] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5419), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5417), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [68013] = 4,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5421), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 17,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kAsm,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [68044] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5425), 5,
      anon_sym_LBRACK,
      aux_sym__literalString_token1,
      anon_sym_POUND,
      aux_sym__literalInt_token2,
      sym_kAt,
    ACTIONS(5423), 14,
      anon_sym_LPAREN,
      aux_sym__literalInt_token1,
      aux_sym__literalFloat_token1,
      sym_kSpecialize,
      sym_kAdd,
      sym_kSub,
      sym_kNot,
      sym_kFunction,
      sym_kProcedure,
      sym_kInherited,
      sym_kNil,
      sym_kTrue,
      sym_kFalse,
      sym_identifier,
  [68073] = 5,
    ACTIONS(3163), 1,
      sym_kConst,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2595), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3161), 16,
      anon_sym_LBRACK,
      sym_kUses,
      sym_kBegin,
      sym_kVar,
      sym_kThreadvar,
      sym_kResourcestring,
      sym_kType,
      sym_kLabel,
      sym_kExports,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
  [68106] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5427), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4897), 12,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
  [68138] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5429), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4905), 12,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
      sym_kElse,
  [68170] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5433), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
    ACTIONS(5431), 10,
      anon_sym_SEMI,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [68195] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5435), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4905), 10,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
  [68225] = 3,
    ACTIONS(5439), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5437), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68249] = 3,
    ACTIONS(5443), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5441), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68273] = 3,
    ACTIONS(5447), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5445), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68297] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(5449), 1,
      sym_kDeprecated,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4897), 10,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kOf,
  [68327] = 3,
    ACTIONS(5453), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5451), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68351] = 3,
    ACTIONS(5457), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5455), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68375] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5459), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68396] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5461), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68417] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5463), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68438] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5465), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68459] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5467), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68480] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5469), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68501] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5471), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68522] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5473), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68543] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5475), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68564] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5477), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68585] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5479), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68606] = 8,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(4450), 1,
      sym_kStrict,
    ACTIONS(4454), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(2500), 1,
      sym_declVariant,
    STATE(1678), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4448), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
  [68639] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5481), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68660] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5483), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68681] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5485), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68702] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5487), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68723] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5489), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68744] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5491), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68765] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5493), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68786] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5495), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68807] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5497), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68828] = 6,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5501), 1,
      anon_sym_COLON,
    ACTIONS(5503), 1,
      sym_kOf,
    STATE(1683), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5499), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [68857] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5505), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68878] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5507), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [68899] = 6,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5509), 1,
      anon_sym_COLON,
    ACTIONS(5511), 1,
      sym_kOf,
    STATE(1681), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5479), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [68928] = 8,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(4450), 1,
      sym_kStrict,
    ACTIONS(5513), 1,
      sym_kEnd,
    STATE(1077), 1,
      sym__visibility,
    STATE(2546), 1,
      sym_declVariant,
    STATE(1678), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4448), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
  [68961] = 8,
    ACTIONS(4428), 1,
      sym_kEnd,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(4450), 1,
      sym_kStrict,
    STATE(1077), 1,
      sym__visibility,
    STATE(2695), 1,
      sym_declVariant,
    STATE(1678), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4448), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
  [68994] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5515), 13,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
      sym_kEq,
  [69015] = 6,
    ACTIONS(5522), 1,
      sym_kStrict,
    STATE(1077), 1,
      sym__visibility,
    ACTIONS(5517), 2,
      sym_kEnd,
      sym_kCase,
    STATE(1678), 2,
      sym_declSection,
      aux_sym__declClass_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5519), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
  [69043] = 10,
    ACTIONS(3073), 1,
      sym_kGeneric,
    ACTIONS(3093), 1,
      sym_kOperator,
    ACTIONS(5525), 1,
      sym_identifier,
    ACTIONS(5527), 1,
      sym_kProperty,
    ACTIONS(5529), 1,
      sym_kClass,
    STATE(1223), 1,
      sym__declProc,
    STATE(1229), 1,
      sym__declOperator,
    STATE(2199), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3091), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [69079] = 4,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    STATE(1684), 1,
      aux_sym_rttiAttributes_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5531), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [69102] = 4,
    ACTIONS(5535), 1,
      anon_sym_COLON,
    ACTIONS(5537), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5533), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [69125] = 5,
    ACTIONS(5543), 1,
      sym_kLt,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5539), 4,
      anon_sym_LPAREN,
      sym_kIndex,
      sym_kName,
      sym_identifier,
    ACTIONS(5541), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_DOT,
      sym_kEq,
  [69150] = 4,
    ACTIONS(5547), 1,
      anon_sym_COLON,
    ACTIONS(5549), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5545), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [69173] = 4,
    ACTIONS(5553), 1,
      anon_sym_LBRACK,
    STATE(1684), 1,
      aux_sym_rttiAttributes_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5551), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [69196] = 7,
    ACTIONS(5556), 1,
      sym_kInterface,
    ACTIONS(5559), 1,
      sym_kImplementation,
    ACTIONS(5562), 1,
      sym_kInitialization,
    ACTIONS(5565), 1,
      sym_kFinalization,
    ACTIONS(5568), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1685), 5,
      sym_interface,
      sym_implementation,
      sym_initialization,
      sym_finalization,
      aux_sym_unit_repeat1,
  [69224] = 3,
    ACTIONS(5572), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5570), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [69244] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5574), 1,
      anon_sym_RPAREN,
    STATE(1787), 1,
      aux_sym_declClass_repeat1,
    STATE(2256), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [69274] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5576), 1,
      anon_sym_RPAREN,
    STATE(1770), 1,
      aux_sym_declClass_repeat1,
    STATE(2260), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [69304] = 3,
    ACTIONS(5578), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5580), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [69324] = 3,
    ACTIONS(5582), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5584), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [69344] = 11,
    ACTIONS(5586), 1,
      anon_sym_SEMI,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5596), 1,
      sym_kNodefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    STATE(1693), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69380] = 3,
    ACTIONS(5604), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5606), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [69400] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5608), 1,
      anon_sym_SEMI,
    ACTIONS(5610), 1,
      sym_kNodefault,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69436] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5612), 1,
      anon_sym_SEMI,
    ACTIONS(5614), 1,
      sym_kNodefault,
    STATE(1696), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69472] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5616), 1,
      anon_sym_SEMI,
    ACTIONS(5618), 1,
      sym_kNodefault,
    STATE(1697), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69508] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5620), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69544] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5622), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69580] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5624), 1,
      anon_sym_SEMI,
    ACTIONS(5626), 1,
      sym_kNodefault,
    STATE(1700), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69616] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5628), 1,
      anon_sym_SEMI,
    ACTIONS(5630), 1,
      sym_kNodefault,
    STATE(1701), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69652] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5632), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69688] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5634), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69724] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5636), 1,
      anon_sym_SEMI,
    ACTIONS(5638), 1,
      sym_kNodefault,
    STATE(1703), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69760] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5640), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69796] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5642), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69832] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5644), 1,
      anon_sym_SEMI,
    ACTIONS(5646), 1,
      sym_kNodefault,
    STATE(1727), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69868] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5648), 1,
      anon_sym_SEMI,
    ACTIONS(5650), 1,
      sym_kNodefault,
    STATE(1728), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69904] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5652), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [69940] = 3,
    ACTIONS(5654), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5656), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [69960] = 7,
    ACTIONS(5658), 1,
      sym_kInterface,
    ACTIONS(5660), 1,
      sym_kImplementation,
    ACTIONS(5662), 1,
      sym_kInitialization,
    ACTIONS(5664), 1,
      sym_kFinalization,
    ACTIONS(5666), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1722), 5,
      sym_interface,
      sym_implementation,
      sym_initialization,
      sym_finalization,
      aux_sym_unit_repeat1,
  [69988] = 3,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5668), 4,
      anon_sym_LPAREN,
      sym_kIndex,
      sym_kName,
      sym_identifier,
    ACTIONS(5670), 6,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_DOT,
      sym_kLt,
      sym_kEq,
  [70008] = 3,
    ACTIONS(5672), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5674), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70028] = 3,
    ACTIONS(5676), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1259), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70048] = 7,
    ACTIONS(5680), 1,
      sym_kConst,
    ACTIONS(5682), 1,
      sym_kResourcestring,
    ACTIONS(5684), 1,
      sym_kProperty,
    ACTIONS(5688), 1,
      sym_kOperator,
    ACTIONS(5678), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5686), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [70076] = 8,
    ACTIONS(4515), 1,
      sym_kGeneric,
    ACTIONS(4519), 1,
      sym_kOperator,
    ACTIONS(5684), 1,
      sym_kProperty,
    ACTIONS(5690), 1,
      sym_kClass,
    STATE(1223), 1,
      sym__declProc,
    STATE(1229), 1,
      sym__declOperator,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4517), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [70106] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5692), 1,
      anon_sym_RPAREN,
    STATE(1760), 1,
      aux_sym_declClass_repeat1,
    STATE(2223), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [70136] = 3,
    ACTIONS(5694), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5696), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70156] = 3,
    ACTIONS(5698), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5700), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70176] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5702), 1,
      anon_sym_RPAREN,
    STATE(1778), 1,
      aux_sym_declClass_repeat1,
    STATE(2305), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [70206] = 3,
    ACTIONS(5704), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5551), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [70226] = 3,
    ACTIONS(5708), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5706), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [70246] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5710), 1,
      anon_sym_RPAREN,
    STATE(1767), 1,
      aux_sym_declClass_repeat1,
    STATE(2253), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [70276] = 7,
    ACTIONS(5658), 1,
      sym_kInterface,
    ACTIONS(5660), 1,
      sym_kImplementation,
    ACTIONS(5662), 1,
      sym_kInitialization,
    ACTIONS(5664), 1,
      sym_kFinalization,
    ACTIONS(5712), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1685), 5,
      sym_interface,
      sym_implementation,
      sym_initialization,
      sym_finalization,
      aux_sym_unit_repeat1,
  [70304] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5714), 1,
      anon_sym_RPAREN,
    STATE(1784), 1,
      aux_sym_declClass_repeat1,
    STATE(2222), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [70334] = 11,
    ACTIONS(5716), 1,
      anon_sym_SEMI,
    ACTIONS(5718), 1,
      sym_kRead,
    ACTIONS(5721), 1,
      sym_kWrite,
    ACTIONS(5724), 1,
      sym_kImplements,
    ACTIONS(5727), 1,
      sym_kDefault,
    ACTIONS(5730), 1,
      sym_kNodefault,
    ACTIONS(5733), 1,
      sym_kStored,
    ACTIONS(5736), 1,
      sym_kIndex,
    ACTIONS(5739), 1,
      sym_kDispId,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70370] = 3,
    ACTIONS(5742), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(1468), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70390] = 3,
    ACTIONS(5744), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5746), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70410] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5748), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70446] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5750), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70482] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5752), 1,
      anon_sym_SEMI,
    ACTIONS(5754), 1,
      sym_kNodefault,
    STATE(1749), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70518] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5756), 1,
      anon_sym_SEMI,
    ACTIONS(5758), 1,
      sym_kNodefault,
    STATE(1750), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70554] = 3,
    ACTIONS(5760), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(2953), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70574] = 3,
    ACTIONS(5764), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5762), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [70594] = 3,
    ACTIONS(5766), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5768), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70614] = 7,
    ACTIONS(5772), 1,
      sym_kConst,
    ACTIONS(5774), 1,
      sym_kResourcestring,
    ACTIONS(5776), 1,
      sym_kProperty,
    ACTIONS(5780), 1,
      sym_kOperator,
    ACTIONS(5770), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5778), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [70642] = 3,
    ACTIONS(5782), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3021), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70662] = 3,
    ACTIONS(5784), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5786), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70682] = 3,
    ACTIONS(5788), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5790), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70702] = 3,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5792), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [70722] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5796), 1,
      anon_sym_RPAREN,
    STATE(1753), 1,
      aux_sym_declClass_repeat1,
    STATE(2194), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [70752] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5798), 1,
      anon_sym_SEMI,
    ACTIONS(5800), 1,
      sym_kNodefault,
    STATE(1704), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70788] = 3,
    ACTIONS(5802), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5804), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70808] = 3,
    ACTIONS(5806), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5808), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70828] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5810), 1,
      anon_sym_SEMI,
    ACTIONS(5812), 1,
      sym_kNodefault,
    STATE(1707), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [70864] = 3,
    ACTIONS(5814), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5816), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70884] = 8,
    ACTIONS(4440), 1,
      sym_kGeneric,
    ACTIONS(4446), 1,
      sym_kOperator,
    ACTIONS(5776), 1,
      sym_kProperty,
    ACTIONS(5818), 1,
      sym_kClass,
    STATE(1223), 1,
      sym__declProc,
    STATE(1229), 1,
      sym__declOperator,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4444), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [70914] = 3,
    ACTIONS(5822), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5820), 9,
      sym_kProperty,
      sym_kClass,
      sym_kGeneric,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
      sym_kOperator,
      sym_identifier,
  [70934] = 3,
    ACTIONS(5824), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5826), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70954] = 3,
    ACTIONS(5828), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5830), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [70974] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5832), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71010] = 11,
    ACTIONS(5588), 1,
      sym_kRead,
    ACTIONS(5590), 1,
      sym_kWrite,
    ACTIONS(5592), 1,
      sym_kImplements,
    ACTIONS(5594), 1,
      sym_kDefault,
    ACTIONS(5598), 1,
      sym_kStored,
    ACTIONS(5600), 1,
      sym_kIndex,
    ACTIONS(5602), 1,
      sym_kDispId,
    ACTIONS(5610), 1,
      sym_kNodefault,
    ACTIONS(5834), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      aux_sym_declProp_repeat2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71046] = 8,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5836), 1,
      anon_sym_RPAREN,
    STATE(1759), 1,
      aux_sym_declClass_repeat1,
    STATE(2159), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71076] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5838), 1,
      anon_sym_SEMI,
    ACTIONS(5840), 1,
      anon_sym_COLON,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    STATE(1968), 1,
      sym_declArgs,
    STATE(2625), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71109] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2230), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71136] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5844), 1,
      anon_sym_SEMI,
    ACTIONS(5846), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1972), 1,
      sym_declArgs,
    STATE(2655), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71169] = 7,
    ACTIONS(5848), 1,
      sym_identifier,
    ACTIONS(5850), 1,
      anon_sym_RPAREN,
    STATE(1829), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2198), 1,
      sym_declArg,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [71196] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5854), 1,
      anon_sym_SEMI,
    ACTIONS(5856), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1980), 1,
      sym_declArgs,
    STATE(2514), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71229] = 7,
    ACTIONS(5848), 1,
      sym_identifier,
    ACTIONS(5858), 1,
      anon_sym_RPAREN,
    STATE(1807), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    STATE(2277), 1,
      sym_declArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [71256] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5860), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71273] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2247), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71300] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2255), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71327] = 7,
    ACTIONS(5862), 1,
      sym_identifier,
    ACTIONS(5865), 1,
      sym_kSpecialize,
    ACTIONS(5868), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2385), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71354] = 4,
    ACTIONS(5875), 1,
      sym_kArray,
    ACTIONS(5871), 2,
      sym_kInterface,
      sym_kDispInterface,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5873), 6,
      sym_kClass,
      sym_kObject,
      sym_kRecord,
      sym_kObjcclass,
      sym_kObjccategory,
      sym_kObjcprotocol,
  [71375] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5877), 1,
      anon_sym_SEMI,
    ACTIONS(5879), 1,
      anon_sym_COLON,
    STATE(1952), 1,
      sym_declArgs,
    STATE(1959), 1,
      sym_kDot,
    STATE(2683), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71408] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5881), 1,
      anon_sym_SEMI,
    ACTIONS(5883), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1964), 1,
      sym_declArgs,
    STATE(2636), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71441] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5885), 1,
      anon_sym_SEMI,
    ACTIONS(5887), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1978), 1,
      sym_declArgs,
    STATE(2696), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71474] = 6,
    ACTIONS(5680), 1,
      sym_kConst,
    ACTIONS(5682), 1,
      sym_kResourcestring,
    ACTIONS(5891), 1,
      sym_kOperator,
    ACTIONS(5678), 2,
      sym_kVar,
      sym_kThreadvar,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5889), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [71499] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2182), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71526] = 6,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5511), 1,
      sym_kOf,
    ACTIONS(5893), 1,
      anon_sym_COLON,
    STATE(1872), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5479), 5,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kEq,
  [71551] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5895), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71568] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2191), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71595] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5897), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71612] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5899), 1,
      anon_sym_SEMI,
    ACTIONS(5901), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1969), 1,
      sym_declArgs,
    STATE(2579), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71645] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5903), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [71662] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5905), 9,
      anon_sym_SEMI,
      sym_kRead,
      sym_kWrite,
      sym_kImplements,
      sym_kDefault,
      sym_kNodefault,
      sym_kStored,
      sym_kIndex,
      sym_kDispId,
  [71679] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5907), 1,
      anon_sym_SEMI,
    ACTIONS(5909), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(1988), 1,
      sym_declArgs,
    STATE(2559), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71712] = 7,
    ACTIONS(5848), 1,
      sym_identifier,
    ACTIONS(5911), 1,
      anon_sym_RBRACK,
    STATE(1862), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    STATE(2295), 1,
      sym_declArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [71739] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5913), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71756] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2293), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71783] = 10,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(5915), 1,
      anon_sym_SEMI,
    ACTIONS(5917), 1,
      anon_sym_COLON,
    STATE(1959), 1,
      sym_kDot,
    STATE(2012), 1,
      sym_declArgs,
    STATE(2564), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [71816] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5919), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71833] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5921), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71850] = 7,
    ACTIONS(35), 1,
      sym_kGeneric,
    ACTIONS(39), 1,
      sym_kOperator,
    ACTIONS(5923), 1,
      sym_kClass,
    STATE(1630), 1,
      sym__declProc,
    STATE(1632), 1,
      sym__declOperator,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(37), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [71877] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5925), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71894] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2296), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71921] = 6,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(5503), 1,
      sym_kOf,
    ACTIONS(5927), 1,
      anon_sym_COLON,
    STATE(1870), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5499), 5,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kEq,
  [71946] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5929), 9,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kElse,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [71963] = 7,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1761), 1,
      aux_sym_declClass_repeat1,
    STATE(2188), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [71990] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1171), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72014] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5935), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      sym_kSpecialize,
    STATE(802), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1305), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72038] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    STATE(1644), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72062] = 6,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5939), 1,
      sym_identifier,
    STATE(2478), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72086] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    STATE(1646), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72110] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5941), 1,
      sym_identifier,
    STATE(1879), 1,
      aux_sym_typerefArgs_repeat1,
    STATE(2539), 1,
      sym_typerefArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1909), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72134] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5943), 8,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [72150] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1924), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72174] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    STATE(1645), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72198] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2031), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72222] = 6,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5945), 1,
      sym_identifier,
    STATE(2468), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72246] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2627), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72270] = 7,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    STATE(1937), 1,
      aux_sym_declExport_repeat1,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(5947), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(5949), 2,
      sym_kIndex,
      sym_kName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [72296] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1949), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72320] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1127), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72344] = 6,
    ACTIONS(5951), 1,
      sym_identifier,
    STATE(1803), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    STATE(2438), 1,
      sym_declArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5954), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [72368] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2034), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72392] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1646), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72416] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1132), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72440] = 6,
    ACTIONS(5848), 1,
      sym_identifier,
    STATE(1803), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2143), 1,
      sym_declArg,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [72464] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1130), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72488] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2120), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72512] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1642), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72536] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2041), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72560] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2043), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72584] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5941), 1,
      sym_identifier,
    STATE(1879), 1,
      aux_sym_typerefArgs_repeat1,
    STATE(2333), 1,
      sym_typerefArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1909), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72608] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2048), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72632] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2049), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72656] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2052), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72680] = 6,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    STATE(2104), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72704] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1649), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72728] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5957), 1,
      sym_identifier,
    ACTIONS(5959), 1,
      sym_kSpecialize,
    STATE(1642), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1640), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72752] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2055), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72776] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1644), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72800] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2057), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72824] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2393), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72848] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2038), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72872] = 6,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    STATE(2061), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72896] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1645), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72920] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1136), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72944] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2072), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [72968] = 6,
    ACTIONS(5848), 1,
      sym_identifier,
    STATE(1803), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    STATE(2231), 1,
      sym_declArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [72992] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1139), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73016] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2075), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73040] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2077), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73064] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1973), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73088] = 6,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    STATE(2160), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73112] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2080), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73136] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5935), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      sym_kSpecialize,
    STATE(822), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1305), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73160] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2141), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73184] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    STATE(1656), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73208] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2661), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73232] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2086), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73256] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1144), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73280] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1124), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73304] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1147), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73328] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1178), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73352] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1153), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73376] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2101), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73400] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1156), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73424] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5935), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      sym_kSpecialize,
    STATE(830), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1305), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73448] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1159), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73472] = 9,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(5961), 1,
      sym_identifier,
    ACTIONS(5963), 1,
      anon_sym_SEMI,
    ACTIONS(5965), 1,
      anon_sym_RPAREN,
    STATE(1966), 1,
      aux_sym_declVariantClause_repeat1,
    STATE(2278), 1,
      sym_declVariant,
    STATE(2280), 1,
      sym_declVariantField,
    STATE(2288), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [73502] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1162), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73526] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1165), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73550] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5931), 1,
      sym_identifier,
    ACTIONS(5933), 1,
      sym_kSpecialize,
    STATE(1168), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1564), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73574] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(1656), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73598] = 6,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    STATE(2125), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73622] = 6,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5967), 1,
      sym_identifier,
    STATE(2362), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73646] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2132), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73670] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(4967), 1,
      sym_kSpecialize,
    STATE(1649), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1647), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73694] = 6,
    ACTIONS(4241), 1,
      sym_identifier,
    ACTIONS(4267), 1,
      sym_kSpecialize,
    ACTIONS(4269), 1,
      sym_kHat,
    STATE(2121), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1554), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73718] = 6,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(4931), 1,
      sym_kSpecialize,
    ACTIONS(4933), 1,
      sym_kHat,
    STATE(2028), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1880), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73742] = 6,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(5935), 1,
      sym_identifier,
    ACTIONS(5937), 1,
      sym_kSpecialize,
    STATE(818), 1,
      sym_typeref,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1305), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [73766] = 6,
    ACTIONS(5848), 1,
      sym_identifier,
    STATE(1803), 1,
      aux_sym_declPropArgs_repeat1,
    STATE(2181), 1,
      sym_declArg,
    STATE(2200), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5852), 4,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
  [73790] = 3,
    STATE(1101), 1,
      sym__visibility,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5969), 6,
      sym_kPublished,
      sym_kPublic,
      sym_kProtected,
      sym_kPrivate,
      sym_kRequired,
      sym_kOptional,
  [73807] = 4,
    ACTIONS(5), 1,
      sym_pp,
    STATE(1896), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3147), 6,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kLt,
      sym_kDeprecated,
  [73826] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5975), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2371), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [73849] = 4,
    ACTIONS(5), 1,
      sym_pp,
    STATE(1896), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3151), 6,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kLt,
      sym_kDeprecated,
  [73868] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5977), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2347), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [73891] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5979), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2640), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [73914] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5981), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2561), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [73937] = 4,
    ACTIONS(5549), 1,
      sym_kOf,
    ACTIONS(5983), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5545), 5,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kEq,
  [73956] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5985), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2519), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [73979] = 4,
    ACTIONS(5537), 1,
      sym_kOf,
    ACTIONS(5987), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5533), 5,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kEq,
  [73998] = 6,
    ACTIONS(5989), 1,
      sym_identifier,
    ACTIONS(5991), 1,
      anon_sym_SEMI,
    STATE(1890), 1,
      aux_sym_declExports_repeat1,
    STATE(2312), 1,
      sym_declExport,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1800), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [74021] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5993), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2463), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74044] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(5995), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2423), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74067] = 5,
    ACTIONS(5997), 1,
      sym_identifier,
    ACTIONS(6000), 1,
      sym_kHat,
    STATE(1876), 1,
      aux_sym_typerefArgs_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1976), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74088] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(6003), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2398), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74111] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(6005), 1,
      sym_kLt,
    ACTIONS(6007), 1,
      sym_kDeprecated,
    STATE(1896), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4905), 3,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
  [74136] = 5,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6009), 1,
      sym_identifier,
    STATE(1876), 1,
      aux_sym_typerefArgs_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1940), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74157] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(6005), 1,
      sym_kLt,
    ACTIONS(6011), 1,
      sym_kDeprecated,
    STATE(1896), 1,
      sym_kDot,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4897), 3,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
  [74182] = 6,
    ACTIONS(5973), 1,
      aux_sym_asmBody_token3,
    ACTIONS(6013), 1,
      sym_kEnd,
    STATE(1888), 1,
      aux_sym_asmBody_repeat1,
    STATE(2446), 1,
      sym_asmBody,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5971), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74205] = 5,
    ACTIONS(6018), 1,
      aux_sym_asmBody_token3,
    ACTIONS(6021), 1,
      sym_kEnd,
    STATE(1882), 1,
      aux_sym_asmBody_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6015), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74225] = 3,
    ACTIONS(6025), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6023), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
  [74241] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6027), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(557), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74259] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6029), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1547), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74277] = 3,
    ACTIONS(6031), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6033), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [74293] = 6,
    ACTIONS(6037), 1,
      anon_sym_COLON,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6041), 1,
      sym_kEq,
    STATE(2196), 1,
      sym_defaultValue,
    ACTIONS(6035), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [74315] = 5,
    ACTIONS(6045), 1,
      aux_sym_asmBody_token3,
    ACTIONS(6047), 1,
      sym_kEnd,
    STATE(1882), 1,
      aux_sym_asmBody_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6043), 3,
      aux_sym_asmBody_token1,
      aux_sym_asmBody_token2,
      sym_identifier,
  [74335] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6049), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(558), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74353] = 5,
    ACTIONS(5989), 1,
      sym_identifier,
    STATE(1892), 1,
      aux_sym_declExports_repeat1,
    STATE(2325), 1,
      sym_declExport,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1800), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [74373] = 3,
    ACTIONS(6051), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6033), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [74389] = 5,
    ACTIONS(6053), 1,
      sym_identifier,
    STATE(1892), 1,
      aux_sym_declExports_repeat1,
    STATE(2541), 1,
      sym_declExport,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1800), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [74409] = 6,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6058), 1,
      anon_sym_LPAREN,
    ACTIONS(6060), 1,
      anon_sym_DOT,
    STATE(1339), 1,
      sym_kDot,
    ACTIONS(6056), 2,
      anon_sym_COLON,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [74431] = 3,
    ACTIONS(6062), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6033), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [74447] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6064), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1643), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74465] = 4,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(6066), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1866), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74483] = 4,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(6068), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1864), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74501] = 3,
    ACTIONS(6070), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5762), 5,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kAbsolute,
      sym_kEq,
  [74517] = 4,
    ACTIONS(5780), 1,
      sym_kOperator,
    ACTIONS(6072), 1,
      sym_kProperty,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5778), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [74535] = 4,
    ACTIONS(5688), 1,
      sym_kOperator,
    ACTIONS(6074), 1,
      sym_kProperty,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5686), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [74553] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6076), 1,
      anon_sym_COLON,
    ACTIONS(6078), 1,
      anon_sym_LPAREN,
    ACTIONS(6080), 1,
      sym_kOf,
    STATE(1956), 1,
      sym_declArgs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5479), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [74577] = 7,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6078), 1,
      anon_sym_LPAREN,
    ACTIONS(6082), 1,
      anon_sym_COLON,
    ACTIONS(6084), 1,
      sym_kOf,
    STATE(1954), 1,
      sym_declArgs,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5499), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [74601] = 6,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6041), 1,
      sym_kEq,
    ACTIONS(6088), 1,
      anon_sym_COLON,
    STATE(2156), 1,
      sym_defaultValue,
    ACTIONS(6086), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [74623] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6090), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1641), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74641] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6092), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1559), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74659] = 4,
    ACTIONS(4933), 1,
      sym_kHat,
    ACTIONS(6094), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1878), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74677] = 4,
    ACTIONS(4269), 1,
      sym_kHat,
    ACTIONS(6096), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1308), 4,
      sym__typeref,
      sym_typerefDot,
      sym_typerefTpl,
      sym_typerefPtr,
  [74695] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(3155), 6,
      aux_sym_type_token2,
      aux_sym_type_token3,
      anon_sym_DOT,
      sym_kOf,
      sym_kLt,
      sym_kDeprecated,
  [74711] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(6098), 1,
      anon_sym_COMMA,
    ACTIONS(6100), 1,
      sym_kGt,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [74732] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2129), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6102), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [74749] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6104), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kGt,
  [74762] = 6,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6035), 1,
      anon_sym_SEMI,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6106), 1,
      anon_sym_COLON,
    STATE(2196), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [74783] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6108), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kGt,
  [74796] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6110), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
  [74809] = 4,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6114), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6112), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [74826] = 3,
    ACTIONS(6116), 1,
      sym_kClass,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5889), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [74841] = 4,
    ACTIONS(4945), 1,
      anon_sym_COLON,
    STATE(1932), 1,
      aux_sym_legacyFormat_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6118), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [74858] = 3,
    ACTIONS(6120), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6122), 4,
      anon_sym_DOT,
      sym_kLt,
      sym_kDo,
      sym_kDeprecated,
  [74873] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6124), 5,
      sym_kInterface,
      sym_kImplementation,
      sym_kInitialization,
      sym_kFinalization,
      sym_kEnd,
  [74886] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6126), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kGt,
  [74899] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6128), 5,
      sym_kVar,
      sym_kConst,
      sym_kConstref,
      sym_kOut,
      sym_identifier,
  [74912] = 4,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6132), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [74929] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2065), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6134), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [74946] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5433), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [74959] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4997), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [74972] = 3,
    ACTIONS(5891), 1,
      sym_kOperator,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5889), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [74987] = 4,
    STATE(1927), 1,
      aux_sym_declExport_repeat1,
    ACTIONS(5075), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(6136), 2,
      sym_kIndex,
      sym_kName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75004] = 6,
    ACTIONS(6139), 1,
      sym_identifier,
    STATE(2009), 1,
      aux_sym_genericArgs_repeat1,
    STATE(2235), 1,
      sym_genericArg,
    STATE(2238), 1,
      aux_sym_genericArg_repeat1,
    STATE(2332), 1,
      sym_genericArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75025] = 3,
    ACTIONS(6141), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6023), 4,
      sym_kEnd,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [75040] = 6,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6086), 1,
      anon_sym_SEMI,
    ACTIONS(6143), 1,
      anon_sym_COLON,
    STATE(2156), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75061] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6145), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kGt,
  [75074] = 4,
    ACTIONS(6147), 1,
      anon_sym_COLON,
    STATE(1932), 1,
      aux_sym_legacyFormat_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5045), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [75091] = 3,
    ACTIONS(6150), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6122), 4,
      anon_sym_DOT,
      sym_kLt,
      sym_kDo,
      sym_kDeprecated,
  [75106] = 3,
    ACTIONS(6152), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6122), 4,
      anon_sym_DOT,
      sym_kOf,
      sym_kLt,
      sym_kDeprecated,
  [75121] = 3,
    ACTIONS(6154), 1,
      sym_kClass,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5686), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [75136] = 4,
    ACTIONS(6156), 1,
      sym_identifier,
    ACTIONS(6158), 1,
      sym_kGeneric,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1948), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75153] = 4,
    STATE(1927), 1,
      aux_sym_declExport_repeat1,
    ACTIONS(5949), 2,
      sym_kIndex,
      sym_kName,
    ACTIONS(6160), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75170] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6162), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_kGt,
  [75183] = 3,
    ACTIONS(6164), 1,
      sym_kClass,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(5778), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [75198] = 6,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(6098), 1,
      anon_sym_COMMA,
    ACTIONS(6166), 1,
      sym_kGt,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75219] = 6,
    ACTIONS(6168), 1,
      sym_identifier,
    ACTIONS(6170), 1,
      anon_sym_SEMI,
    STATE(1971), 1,
      aux_sym_declUses_repeat1,
    STATE(2148), 1,
      sym_moduleName,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75240] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4681), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [75253] = 4,
    ACTIONS(6172), 1,
      sym_identifier,
    ACTIONS(6174), 1,
      sym_kGeneric,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1990), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75270] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2127), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6176), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [75287] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2062), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6178), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [75304] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(4588), 5,
      sym_kAssign,
      sym_kAssignAdd,
      sym_kAssignSub,
      sym_kAssignMul,
      sym_kAssignDiv,
  [75317] = 5,
    ACTIONS(6180), 1,
      sym_identifier,
    STATE(1947), 1,
      aux_sym_declVariantClause_repeat1,
    STATE(2288), 1,
      aux_sym_genericArg_repeat1,
    STATE(2628), 1,
      sym_declVariantField,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75335] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6183), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75353] = 4,
    ACTIONS(6041), 1,
      sym_kEq,
    STATE(2144), 1,
      sym_defaultValue,
    ACTIONS(6185), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75369] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4560), 4,
      anon_sym_COLON,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
  [75383] = 5,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(6187), 1,
      sym_identifier,
    ACTIONS(6189), 1,
      anon_sym_RPAREN,
    STATE(2267), 1,
      sym_declVariant,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75401] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6191), 1,
      anon_sym_SEMI,
    ACTIONS(6193), 1,
      anon_sym_COLON,
    STATE(2569), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75419] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6195), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [75431] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6197), 1,
      anon_sym_COLON,
    ACTIONS(6199), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5545), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [75449] = 3,
    ACTIONS(6201), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1779), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75463] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6203), 1,
      anon_sym_COLON,
    ACTIONS(6205), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5533), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [75481] = 3,
    ACTIONS(6207), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1775), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75495] = 4,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    STATE(2492), 1,
      sym_kDot,
    ACTIONS(6209), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75511] = 3,
    ACTIONS(6211), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1682), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75525] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6213), 1,
      anon_sym_SEMI,
    ACTIONS(6215), 1,
      sym_kAbsolute,
    STATE(2366), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75543] = 4,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    STATE(2492), 1,
      sym_kDot,
    ACTIONS(6217), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75559] = 3,
    ACTIONS(6219), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(2011), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75573] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6221), 1,
      anon_sym_SEMI,
    ACTIONS(6223), 1,
      sym_kAbsolute,
    STATE(2370), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75591] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6225), 1,
      anon_sym_SEMI,
    ACTIONS(6227), 1,
      anon_sym_COLON,
    STATE(2671), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75609] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4552), 4,
      anon_sym_COLON,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
  [75623] = 5,
    ACTIONS(6229), 1,
      sym_identifier,
    STATE(1947), 1,
      aux_sym_declVariantClause_repeat1,
    STATE(2208), 1,
      sym_declVariantField,
    STATE(2288), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75641] = 3,
    ACTIONS(6231), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1756), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75655] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6233), 1,
      anon_sym_SEMI,
    ACTIONS(6235), 1,
      anon_sym_COLON,
    STATE(2591), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75673] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6237), 1,
      anon_sym_SEMI,
    ACTIONS(6239), 1,
      anon_sym_COLON,
    STATE(2408), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75691] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(4556), 4,
      anon_sym_COLON,
      aux_sym_type_token2,
      aux_sym_type_token3,
      sym_kOf,
  [75705] = 5,
    ACTIONS(6168), 1,
      sym_identifier,
    STATE(1999), 1,
      aux_sym_declUses_repeat1,
    STATE(2169), 1,
      sym_moduleName,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75723] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6241), 1,
      anon_sym_SEMI,
    ACTIONS(6243), 1,
      anon_sym_COLON,
    STATE(2691), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75741] = 4,
    ACTIONS(6041), 1,
      sym_kEq,
    STATE(2243), 1,
      sym_defaultValue,
    ACTIONS(6245), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75757] = 3,
    ACTIONS(6247), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1752), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75771] = 3,
    ACTIONS(6249), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1763), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75785] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(4899), 1,
      sym_kLt,
    ACTIONS(6098), 1,
      anon_sym_COMMA,
    STATE(1889), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75803] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6251), 1,
      anon_sym_SEMI,
    ACTIONS(6253), 1,
      sym_kAbsolute,
    STATE(2701), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75821] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6255), 1,
      anon_sym_SEMI,
    ACTIONS(6257), 1,
      anon_sym_COLON,
    STATE(2342), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75839] = 3,
    ACTIONS(6259), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1948), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75853] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6261), 1,
      anon_sym_SEMI,
    ACTIONS(6263), 1,
      anon_sym_COLON,
    STATE(2515), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75871] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6265), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75889] = 3,
    ACTIONS(6267), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1772), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75903] = 3,
    ACTIONS(6269), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1765), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [75917] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6271), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75935] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6273), 1,
      anon_sym_SEMI,
    ACTIONS(6275), 1,
      sym_kAbsolute,
    STATE(2444), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75953] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6277), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [75965] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6279), 1,
      sym_identifier,
    ACTIONS(6281), 1,
      anon_sym_COLON,
    STATE(2309), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [75983] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6283), 1,
      anon_sym_SEMI,
    ACTIONS(6285), 1,
      anon_sym_COLON,
    STATE(2484), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76001] = 5,
    ACTIONS(6287), 1,
      sym_kEnd,
    ACTIONS(6289), 1,
      sym_kElse,
    ACTIONS(6291), 1,
      sym_kOn,
    STATE(2482), 1,
      sym_exceptionElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76019] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6293), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76037] = 5,
    ACTIONS(6289), 1,
      sym_kElse,
    ACTIONS(6291), 1,
      sym_kOn,
    ACTIONS(6295), 1,
      sym_kEnd,
    STATE(2416), 1,
      sym_exceptionElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76055] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6297), 1,
      sym_identifier,
    ACTIONS(6299), 1,
      anon_sym_COLON,
    STATE(2311), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76073] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2180), 1,
      sym_defaultValue,
    ACTIONS(6301), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76089] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2318), 1,
      sym_defaultValue,
    ACTIONS(6303), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76105] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6305), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76123] = 5,
    ACTIONS(6307), 1,
      sym_kOn,
    STATE(1991), 1,
      sym_exceptionHandler,
    STATE(2109), 1,
      sym_exceptionHandlerTr,
    STATE(2110), 1,
      aux_sym__exceptionHandlersTr_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76141] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6309), 1,
      anon_sym_SEMI,
    ACTIONS(6311), 1,
      sym_kAbsolute,
    STATE(2466), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76159] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6313), 4,
      sym_kEnd,
      sym_kUntil,
      sym_kExcept,
      sym_kFinally,
  [76171] = 5,
    ACTIONS(6315), 1,
      sym_identifier,
    STATE(1999), 1,
      aux_sym_declUses_repeat1,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    STATE(2557), 1,
      sym_moduleName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76189] = 5,
    ACTIONS(6318), 1,
      sym_identifier,
    STATE(2000), 1,
      aux_sym_genericArgs_repeat1,
    STATE(2252), 1,
      aux_sym_genericArg_repeat1,
    STATE(2576), 1,
      sym_genericArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76207] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6321), 1,
      sym_identifier,
    ACTIONS(6323), 1,
      anon_sym_COLON,
    STATE(2142), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76225] = 5,
    ACTIONS(3089), 1,
      sym_kCase,
    ACTIONS(6187), 1,
      sym_identifier,
    ACTIONS(6325), 1,
      anon_sym_RPAREN,
    STATE(2145), 1,
      sym_declVariant,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76243] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6327), 1,
      anon_sym_SEMI,
    ACTIONS(6329), 1,
      sym_kAbsolute,
    STATE(2527), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76261] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6331), 1,
      sym_identifier,
    ACTIONS(6333), 1,
      anon_sym_COLON,
    STATE(2271), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76279] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2265), 1,
      sym_defaultValue,
    ACTIONS(6335), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76295] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6337), 4,
      sym_kFunction,
      sym_kProcedure,
      sym_kConstructor,
      sym_kDestructor,
  [76307] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6339), 1,
      sym_identifier,
    ACTIONS(6341), 1,
      anon_sym_COLON,
    STATE(2321), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76325] = 5,
    ACTIONS(4277), 1,
      anon_sym_LPAREN,
    ACTIONS(6343), 1,
      sym_identifier,
    ACTIONS(6345), 1,
      anon_sym_COLON,
    STATE(2323), 1,
      sym_declArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76343] = 5,
    ACTIONS(6139), 1,
      sym_identifier,
    STATE(2000), 1,
      aux_sym_genericArgs_repeat1,
    STATE(2238), 1,
      aux_sym_genericArg_repeat1,
    STATE(2241), 1,
      sym_genericArg,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76361] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6347), 1,
      anon_sym_SEMI,
    ACTIONS(6349), 1,
      sym_kAbsolute,
    STATE(2711), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76379] = 5,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    ACTIONS(5543), 1,
      sym_kLt,
    ACTIONS(6351), 1,
      sym_kEq,
    STATE(1959), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76397] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6353), 1,
      anon_sym_SEMI,
    ACTIONS(6355), 1,
      anon_sym_COLON,
    STATE(2378), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76415] = 3,
    ACTIONS(6357), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1990), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [76429] = 3,
    ACTIONS(6359), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1764), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [76443] = 3,
    ACTIONS(6361), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1995), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [76457] = 3,
    ACTIONS(6363), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    STATE(1754), 3,
      sym_genericDot,
      sym_genericTpl,
      sym__genericName,
  [76471] = 3,
    ACTIONS(6365), 1,
      sym_kName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3575), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [76485] = 5,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6367), 1,
      anon_sym_SEMI,
    ACTIONS(6369), 1,
      sym_kAbsolute,
    STATE(2544), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76503] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6371), 1,
      anon_sym_SEMI,
    STATE(2685), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76518] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6375), 1,
      aux_sym_type_token3,
    STATE(2058), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [76535] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6377), 1,
      anon_sym_COLON,
    STATE(2381), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76550] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6379), 1,
      aux_sym_type_token3,
    STATE(2059), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [76567] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6381), 1,
      aux_sym_type_token3,
    STATE(2060), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [76584] = 3,
    ACTIONS(6383), 1,
      anon_sym_SEMI,
    ACTIONS(6385), 2,
      anon_sym_RPAREN,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76597] = 4,
    ACTIONS(6168), 1,
      sym_identifier,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    STATE(2554), 1,
      sym_moduleName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76612] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6387), 1,
      anon_sym_SEMI,
    STATE(2402), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76627] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6389), 1,
      anon_sym_SEMI,
    STATE(2409), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76642] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6391), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5455), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [76657] = 3,
    STATE(1224), 1,
      sym__literalInt,
    ACTIONS(6393), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76670] = 4,
    ACTIONS(6287), 1,
      sym_kEnd,
    ACTIONS(6289), 1,
      sym_kElse,
    STATE(2482), 1,
      sym_exceptionElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76685] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6395), 1,
      anon_sym_SEMI,
    STATE(2563), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76700] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6397), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [76711] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6399), 1,
      anon_sym_SEMI,
    STATE(2570), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76726] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6401), 1,
      anon_sym_SEMI,
    STATE(2610), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76741] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6403), 1,
      anon_sym_SEMI,
    STATE(2624), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76756] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6405), 1,
      anon_sym_SEMI,
    STATE(2573), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76771] = 3,
    ACTIONS(6407), 1,
      anon_sym_COMMA,
    ACTIONS(4993), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76784] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6409), 1,
      anon_sym_SEMI,
    STATE(2578), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76799] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [76810] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6413), 1,
      aux_sym_type_token2,
    ACTIONS(6415), 1,
      aux_sym_type_token3,
    STATE(2046), 1,
      aux_sym_type_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [76827] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6417), 1,
      anon_sym_SEMI,
    STATE(2384), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76842] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6419), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76857] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6421), 1,
      anon_sym_SEMI,
    STATE(2412), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76872] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6423), 1,
      anon_sym_SEMI,
    STATE(2414), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76887] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6425), 1,
      anon_sym_SEMI,
    STATE(2418), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76902] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6413), 1,
      aux_sym_type_token2,
    ACTIONS(6427), 1,
      aux_sym_type_token3,
    STATE(2095), 1,
      aux_sym_type_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [76919] = 3,
    ACTIONS(6407), 1,
      anon_sym_COMMA,
    ACTIONS(6429), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76932] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6245), 1,
      anon_sym_SEMI,
    STATE(2243), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76947] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6431), 1,
      anon_sym_SEMI,
    STATE(2459), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76962] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6433), 1,
      anon_sym_SEMI,
    STATE(2462), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76977] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6435), 1,
      anon_sym_SEMI,
    STATE(2467), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [76992] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6437), 1,
      anon_sym_SEMI,
    STATE(2469), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77007] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6439), 1,
      anon_sym_SEMI,
    STATE(2474), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77022] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6441), 1,
      anon_sym_SEMI,
    STATE(2599), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77037] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6185), 1,
      anon_sym_SEMI,
    STATE(2144), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77052] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6443), 1,
      anon_sym_SEMI,
    STATE(2503), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77067] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6445), 1,
      anon_sym_SEMI,
    STATE(2505), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77082] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6447), 1,
      aux_sym_type_token2,
    ACTIONS(6450), 1,
      aux_sym_type_token3,
    STATE(2058), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77099] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6452), 1,
      aux_sym_type_token3,
    STATE(2058), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77116] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6454), 1,
      aux_sym_type_token3,
    STATE(2058), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77133] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6456), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5437), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [77148] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6458), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [77159] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6460), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [77170] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6462), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5762), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [77185] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6464), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [77196] = 3,
    STATE(1020), 1,
      sym__literalInt,
    ACTIONS(6466), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77209] = 4,
    ACTIONS(6468), 1,
      anon_sym_COLON,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    STATE(2613), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77224] = 4,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    ACTIONS(6472), 1,
      anon_sym_COLON,
    STATE(2631), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77239] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6474), 3,
      sym_kEnd,
      sym_kElse,
      sym_kOn,
  [77250] = 4,
    ACTIONS(6476), 1,
      sym_identifier,
    STATE(2093), 1,
      aux_sym_declEnum_repeat1,
    STATE(2209), 1,
      sym_declEnumValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77265] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6478), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5451), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [77280] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6480), 1,
      anon_sym_SEMI,
    STATE(2700), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77295] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6482), 1,
      anon_sym_SEMI,
    STATE(2709), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77310] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6484), 3,
      sym_kEnd,
      sym_kElse,
      sym_kOn,
  [77321] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6486), 1,
      anon_sym_SEMI,
    STATE(2336), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77336] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6488), 1,
      anon_sym_SEMI,
    STATE(2338), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77351] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6490), 1,
      anon_sym_SEMI,
    STATE(2344), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77366] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6492), 1,
      anon_sym_SEMI,
    STATE(2345), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77381] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6494), 1,
      anon_sym_SEMI,
    STATE(2346), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77396] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6496), 1,
      anon_sym_SEMI,
    STATE(2348), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77411] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6498), 1,
      anon_sym_SEMI,
    STATE(2349), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77426] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6500), 1,
      anon_sym_SEMI,
    STATE(2350), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77441] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6502), 1,
      aux_sym_type_token3,
    STATE(2058), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77458] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6504), 1,
      anon_sym_SEMI,
    STATE(2355), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77473] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6506), 1,
      anon_sym_SEMI,
    STATE(2356), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77488] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6508), 1,
      anon_sym_SEMI,
    STATE(2357), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77503] = 3,
    STATE(1018), 1,
      sym__literalInt,
    ACTIONS(6510), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77516] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6512), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [77527] = 3,
    STATE(1236), 1,
      sym__literalInt,
    ACTIONS(6514), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77540] = 3,
    ACTIONS(6516), 1,
      anon_sym_SEMI,
    ACTIONS(5287), 2,
      anon_sym_RPAREN,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77553] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6518), 1,
      anon_sym_COLON,
    STATE(2461), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77568] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6520), 1,
      anon_sym_SEMI,
    STATE(2612), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77583] = 4,
    ACTIONS(6476), 1,
      sym_identifier,
    STATE(2115), 1,
      aux_sym_declEnum_repeat1,
    STATE(2268), 1,
      sym_declEnumValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77598] = 3,
    STATE(678), 1,
      sym__literalInt,
    ACTIONS(6522), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77611] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6524), 1,
      aux_sym_type_token2,
    ACTIONS(6527), 1,
      aux_sym_type_token3,
    STATE(2095), 1,
      aux_sym_type_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77628] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6413), 1,
      aux_sym_type_token2,
    ACTIONS(6529), 1,
      aux_sym_type_token3,
    STATE(2116), 1,
      aux_sym_type_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77645] = 3,
    STATE(1222), 1,
      sym__literalInt,
    ACTIONS(6531), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77658] = 3,
    ACTIONS(6533), 1,
      anon_sym_SEMI,
    ACTIONS(5353), 2,
      anon_sym_RPAREN,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77671] = 4,
    ACTIONS(6535), 1,
      sym_identifier,
    STATE(2131), 1,
      aux_sym_declLabels_repeat1,
    STATE(2257), 1,
      sym_declLabel,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77686] = 4,
    ACTIONS(6168), 1,
      sym_identifier,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    STATE(2642), 1,
      sym_moduleName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77701] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6537), 1,
      anon_sym_SEMI,
    STATE(2597), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77716] = 4,
    ACTIONS(6168), 1,
      sym_identifier,
    STATE(2301), 1,
      aux_sym_moduleName_repeat1,
    STATE(2436), 1,
      sym_moduleName,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77731] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6539), 1,
      anon_sym_COLON,
    STATE(2498), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77746] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6541), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5445), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [77761] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6543), 1,
      anon_sym_COLON,
    STATE(2674), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77776] = 3,
    ACTIONS(6547), 1,
      sym_kHat,
    ACTIONS(6545), 2,
      sym_kSpecialize,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77789] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6549), 1,
      anon_sym_SEMI,
    STATE(2513), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77804] = 4,
    ACTIONS(6476), 1,
      sym_identifier,
    STATE(2112), 1,
      aux_sym_declEnum_repeat1,
    STATE(2147), 1,
      sym_declEnumValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77819] = 4,
    ACTIONS(6289), 1,
      sym_kElse,
    ACTIONS(6295), 1,
      sym_kEnd,
    STATE(2416), 1,
      sym_exceptionElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77834] = 3,
    ACTIONS(6551), 1,
      sym_kOn,
    STATE(2110), 2,
      sym_exceptionHandler,
      aux_sym__exceptionHandlersTr_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77847] = 3,
    ACTIONS(6556), 1,
      anon_sym_LPAREN,
    ACTIONS(6554), 2,
      anon_sym_COLON,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77860] = 4,
    ACTIONS(6476), 1,
      sym_identifier,
    STATE(2115), 1,
      aux_sym_declEnum_repeat1,
    STATE(2155), 1,
      sym_declEnumValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77875] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6558), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [77886] = 3,
    ACTIONS(6560), 1,
      anon_sym_SEMI,
    ACTIONS(6562), 2,
      anon_sym_RPAREN,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77899] = 4,
    ACTIONS(6564), 1,
      sym_identifier,
    STATE(2115), 1,
      aux_sym_declEnum_repeat1,
    STATE(2417), 1,
      sym_declEnumValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77914] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6413), 1,
      aux_sym_type_token2,
    ACTIONS(6567), 1,
      aux_sym_type_token3,
    STATE(2095), 1,
      aux_sym_type_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [77931] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6569), 1,
      anon_sym_SEMI,
    STATE(2593), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77946] = 4,
    ACTIONS(4442), 1,
      sym_kCase,
    ACTIONS(6571), 1,
      anon_sym_RPAREN,
    STATE(2224), 1,
      sym_declVariant,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77961] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6573), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      sym_kEnd,
  [77972] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6575), 1,
      anon_sym_SEMI,
    STATE(2479), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [77987] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6577), 1,
      anon_sym_SEMI,
    STATE(2639), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78002] = 3,
    ACTIONS(6581), 1,
      anon_sym_LPAREN,
    ACTIONS(6579), 2,
      anon_sym_COLON,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78015] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6583), 1,
      anon_sym_SEMI,
    STATE(2675), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78030] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6585), 1,
      aux_sym_type_token3,
    STATE(2083), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [78047] = 4,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6587), 1,
      sym_kOf,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5441), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78062] = 5,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(6373), 1,
      aux_sym_type_token2,
    ACTIONS(6589), 1,
      aux_sym_type_token3,
    STATE(2020), 1,
      aux_sym_defProc_repeat1,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
  [78079] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6591), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [78090] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(3575), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [78101] = 2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
    ACTIONS(6593), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [78112] = 4,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    ACTIONS(6595), 1,
      anon_sym_COLON,
    STATE(2604), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78127] = 4,
    ACTIONS(6597), 1,
      sym_identifier,
    STATE(2131), 1,
      aux_sym_declLabels_repeat1,
    STATE(2522), 1,
      sym_declLabel,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78142] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6600), 1,
      anon_sym_SEMI,
    STATE(2586), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78157] = 4,
    ACTIONS(6602), 1,
      anon_sym_SEMI,
    ACTIONS(6604), 1,
      anon_sym_COMMA,
    ACTIONS(6606), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78172] = 4,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_COLON,
    STATE(2673), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78187] = 4,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    ACTIONS(6610), 1,
      anon_sym_COLON,
    STATE(2678), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78202] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6612), 1,
      anon_sym_SEMI,
    STATE(2364), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78217] = 4,
    ACTIONS(6470), 1,
      anon_sym_LBRACK,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    STATE(2682), 1,
      sym_declPropArgs,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78232] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6616), 1,
      anon_sym_SEMI,
    STATE(2430), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78247] = 4,
    ACTIONS(6535), 1,
      sym_identifier,
    STATE(2099), 1,
      aux_sym_declLabels_repeat1,
    STATE(2179), 1,
      sym_declLabel,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78262] = 3,
    STATE(476), 1,
      sym__literalInt,
    ACTIONS(6618), 2,
      aux_sym__literalInt_token1,
      aux_sym__literalInt_token2,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78275] = 4,
    ACTIONS(5842), 1,
      sym_kEq,
    ACTIONS(6620), 1,
      anon_sym_SEMI,
    STATE(2352), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78290] = 3,
    ACTIONS(6622), 1,
      sym_identifier,
    ACTIONS(6624), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78302] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6628), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78314] = 2,
    ACTIONS(6630), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78324] = 3,
    ACTIONS(6632), 1,
      anon_sym_SEMI,
    ACTIONS(6634), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78336] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6636), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78348] = 3,
    ACTIONS(6638), 1,
      anon_sym_COMMA,
    ACTIONS(6640), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78360] = 3,
    ACTIONS(6642), 1,
      anon_sym_SEMI,
    ACTIONS(6644), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78372] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6648), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78384] = 3,
    ACTIONS(6650), 1,
      anon_sym_LBRACK,
    ACTIONS(6652), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78396] = 2,
    ACTIONS(6654), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78406] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6656), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78418] = 3,
    ACTIONS(6658), 1,
      sym_identifier,
    STATE(2153), 1,
      aux_sym_moduleName_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78430] = 3,
    ACTIONS(6661), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78442] = 3,
    ACTIONS(6638), 1,
      anon_sym_COMMA,
    ACTIONS(6664), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78454] = 2,
    ACTIONS(6666), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78464] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5467), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78476] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5469), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78488] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6670), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78500] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5471), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78512] = 3,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2705), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78524] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5473), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78536] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5459), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78548] = 3,
    ACTIONS(6672), 1,
      sym_identifier,
    STATE(2212), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78560] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5475), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78572] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5489), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78584] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5491), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78596] = 3,
    ACTIONS(6674), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78608] = 3,
    ACTIONS(6644), 1,
      anon_sym_COMMA,
    ACTIONS(6676), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78620] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5493), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78632] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5495), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78644] = 2,
    ACTIONS(6678), 2,
      sym_kHat,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78654] = 2,
    ACTIONS(6680), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78664] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(6682), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78676] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(6684), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78688] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5485), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78700] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5497), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78712] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5477), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78724] = 3,
    ACTIONS(6686), 1,
      anon_sym_SEMI,
    ACTIONS(6688), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78736] = 2,
    ACTIONS(6690), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78746] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6692), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78758] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6694), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78770] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5125), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78782] = 2,
    ACTIONS(6696), 2,
      sym_kEnd,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78792] = 2,
    ACTIONS(6602), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78802] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5127), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78814] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6698), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78826] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6700), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78838] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5479), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [78850] = 2,
    ACTIONS(6702), 2,
      sym_kEnd,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78860] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6704), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78872] = 3,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6708), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78884] = 3,
    ACTIONS(6710), 1,
      anon_sym_SEMI,
    ACTIONS(6712), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78896] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6714), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78908] = 3,
    ACTIONS(6716), 1,
      sym_kExcept,
    ACTIONS(6718), 1,
      sym_kFinally,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78920] = 2,
    ACTIONS(6720), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78930] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6722), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78942] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6724), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78954] = 3,
    ACTIONS(6726), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78966] = 3,
    ACTIONS(6728), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78978] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5131), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [78990] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5487), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79002] = 3,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2601), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79014] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6730), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79026] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5133), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79038] = 3,
    ACTIONS(6732), 1,
      anon_sym_LPAREN,
    ACTIONS(6734), 1,
      sym_kFor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79050] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6736), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79062] = 3,
    ACTIONS(6189), 1,
      anon_sym_RPAREN,
    ACTIONS(6738), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79074] = 3,
    ACTIONS(6638), 1,
      anon_sym_COMMA,
    ACTIONS(6740), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79086] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79098] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5135), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79110] = 3,
    ACTIONS(6744), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79122] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5083), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79134] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5203), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79146] = 3,
    ACTIONS(6746), 1,
      sym_kEnd,
    ACTIONS(6748), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79158] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6752), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79170] = 3,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2619), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79182] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5151), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79194] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(6527), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79206] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6754), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79218] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5153), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79230] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6756), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79242] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6758), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79254] = 3,
    ACTIONS(6189), 1,
      anon_sym_RPAREN,
    ACTIONS(6760), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79266] = 3,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2659), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79278] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5187), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79290] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5169), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79302] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5155), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79314] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6762), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79326] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6764), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79338] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6766), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79350] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5157), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79362] = 2,
    ACTIONS(6768), 2,
      sym_kEnd,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79372] = 3,
    ACTIONS(6770), 1,
      sym_kEnd,
    ACTIONS(6772), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79384] = 3,
    ACTIONS(6774), 1,
      anon_sym_SEMI,
    ACTIONS(6776), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79396] = 3,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6780), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79408] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5461), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79420] = 3,
    ACTIONS(6782), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79432] = 2,
    ACTIONS(6784), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79442] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5463), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79454] = 3,
    ACTIONS(6774), 1,
      anon_sym_SEMI,
    ACTIONS(6786), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79466] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6788), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79478] = 2,
    ACTIONS(6790), 2,
      anon_sym_SEMI,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79488] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5107), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79500] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5175), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79512] = 2,
    ACTIONS(6792), 2,
      sym_kTo,
      sym_kDownto,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79522] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6794), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79534] = 3,
    ACTIONS(6796), 1,
      sym_identifier,
    STATE(2199), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79546] = 3,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79558] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6802), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79570] = 3,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2548), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79582] = 3,
    ACTIONS(6804), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79594] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6806), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79606] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6808), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79618] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6810), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79630] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6812), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79642] = 3,
    ACTIONS(6688), 1,
      anon_sym_COMMA,
    ACTIONS(6814), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79654] = 3,
    ACTIONS(6816), 1,
      anon_sym_LBRACK,
    ACTIONS(6818), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79666] = 3,
    ACTIONS(5842), 1,
      sym_kEq,
    STATE(2372), 1,
      sym_defaultValue,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79678] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6820), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79690] = 2,
    ACTIONS(6822), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79700] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6824), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79712] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6826), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79724] = 3,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(6828), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79736] = 2,
    ACTIONS(6830), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79746] = 3,
    ACTIONS(3615), 1,
      anon_sym_RBRACK,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79758] = 3,
    ACTIONS(6325), 1,
      anon_sym_RPAREN,
    ACTIONS(6832), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79770] = 3,
    ACTIONS(6638), 1,
      anon_sym_COMMA,
    ACTIONS(6834), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79782] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6836), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79794] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5185), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79806] = 3,
    ACTIONS(6838), 1,
      sym_identifier,
    ACTIONS(6840), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79818] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5093), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79830] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5189), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79842] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6842), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79854] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6844), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79866] = 2,
    ACTIONS(6846), 2,
      sym_kTo,
      sym_kDownto,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79876] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6848), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79888] = 3,
    ACTIONS(6571), 1,
      anon_sym_RPAREN,
    ACTIONS(6850), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79900] = 3,
    ACTIONS(6852), 1,
      sym_identifier,
    STATE(2294), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79912] = 3,
    ACTIONS(6571), 1,
      anon_sym_RPAREN,
    ACTIONS(6854), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79924] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6856), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79936] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5481), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79948] = 3,
    ACTIONS(3621), 1,
      anon_sym_RBRACK,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79960] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6858), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [79972] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(6860), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79984] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(6862), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [79996] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6864), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80008] = 3,
    ACTIONS(6866), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80020] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5483), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [80032] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5515), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [80044] = 3,
    ACTIONS(3215), 1,
      anon_sym_DOT,
    STATE(2492), 1,
      sym_kDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80056] = 3,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(6868), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80068] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6870), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80080] = 3,
    ACTIONS(6872), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80092] = 3,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(6874), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80104] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6876), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80116] = 3,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2681), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80128] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6878), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80140] = 3,
    ACTIONS(6604), 1,
      anon_sym_COMMA,
    ACTIONS(6880), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80152] = 3,
    ACTIONS(6882), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80164] = 3,
    ACTIONS(6884), 1,
      sym_identifier,
    STATE(2153), 1,
      aux_sym_moduleName_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80176] = 2,
    ACTIONS(6886), 2,
      sym_kTo,
      sym_kDownto,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80186] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6888), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80198] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6890), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80210] = 3,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(6892), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80222] = 3,
    ACTIONS(6894), 1,
      sym_kExcept,
    ACTIONS(6896), 1,
      sym_kFinally,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80234] = 3,
    ACTIONS(6898), 1,
      sym_kEnd,
    ACTIONS(6900), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80246] = 3,
    ACTIONS(6902), 1,
      anon_sym_LBRACK,
    ACTIONS(6904), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80258] = 3,
    ACTIONS(6906), 1,
      sym_identifier,
    ACTIONS(6908), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80270] = 3,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(6910), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80282] = 3,
    ACTIONS(6912), 1,
      sym_identifier,
    ACTIONS(6914), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80294] = 3,
    ACTIONS(6916), 1,
      anon_sym_SEMI,
    ACTIONS(6918), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80306] = 2,
    ACTIONS(6920), 2,
      sym_kFunction,
      sym_kProcedure,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80316] = 3,
    ACTIONS(3625), 1,
      anon_sym_RBRACK,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80328] = 3,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(5219), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80340] = 3,
    ACTIONS(6922), 1,
      sym_kEnd,
    ACTIONS(6924), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80352] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5221), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80364] = 2,
    ACTIONS(6926), 2,
      anon_sym_SEMI,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80374] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5119), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80386] = 3,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(5217), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80398] = 3,
    ACTIONS(6928), 1,
      sym_identifier,
    ACTIONS(6930), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80410] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5505), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [80422] = 3,
    ACTIONS(6932), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80434] = 3,
    ACTIONS(6710), 1,
      anon_sym_SEMI,
    ACTIONS(6936), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80446] = 3,
    ACTIONS(6918), 1,
      anon_sym_COMMA,
    ACTIONS(6938), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80458] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5507), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [80470] = 3,
    ACTIONS(6940), 1,
      sym_identifier,
    STATE(2329), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80482] = 3,
    ACTIONS(6942), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80494] = 3,
    ACTIONS(6944), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_genericArg_repeat1,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80506] = 3,
    ACTIONS(5373), 1,
      anon_sym_DOT,
    STATE(2426), 1,
      sym_kEndDot,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80518] = 3,
    ACTIONS(5), 1,
      sym_pp,
    ACTIONS(3), 2,
      sym__space,
      sym_comment,
    ACTIONS(5465), 2,
      aux_sym_type_token2,
      aux_sym_type_token3,
  [80530] = 2,
    ACTIONS(6946), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80539] = 2,
    ACTIONS(6948), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80548] = 2,
    ACTIONS(6950), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80557] = 2,
    ACTIONS(6952), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80566] = 2,
    ACTIONS(6954), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80575] = 2,
    ACTIONS(6956), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80584] = 2,
    ACTIONS(6958), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80593] = 2,
    ACTIONS(6960), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80602] = 2,
    ACTIONS(6962), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80611] = 2,
    ACTIONS(6964), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80620] = 2,
    ACTIONS(6966), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80629] = 2,
    ACTIONS(6968), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80638] = 2,
    ACTIONS(6970), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80647] = 2,
    ACTIONS(6972), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80656] = 2,
    ACTIONS(6974), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80665] = 2,
    ACTIONS(6976), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80674] = 2,
    ACTIONS(6978), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80683] = 2,
    ACTIONS(6980), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80692] = 2,
    ACTIONS(6982), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80701] = 2,
    ACTIONS(4428), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80710] = 2,
    ACTIONS(6984), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80719] = 2,
    ACTIONS(6986), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80728] = 2,
    ACTIONS(6988), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80737] = 2,
    ACTIONS(6990), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80746] = 2,
    ACTIONS(6992), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80755] = 2,
    ACTIONS(6994), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80764] = 2,
    ACTIONS(6996), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80773] = 2,
    ACTIONS(5241), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80782] = 2,
    ACTIONS(6998), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80791] = 2,
    ACTIONS(7000), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80800] = 2,
    ACTIONS(7002), 1,
      sym_kDo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80809] = 2,
    ACTIONS(7004), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80818] = 2,
    ACTIONS(7006), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80827] = 2,
    ACTIONS(7008), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80836] = 2,
    ACTIONS(7010), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80845] = 2,
    ACTIONS(7012), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80854] = 2,
    ACTIONS(7014), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80863] = 2,
    ACTIONS(5875), 1,
      sym_kArray,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80872] = 2,
    ACTIONS(7016), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80881] = 2,
    ACTIONS(7018), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80890] = 2,
    ACTIONS(7020), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80899] = 2,
    ACTIONS(7022), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80908] = 2,
    ACTIONS(7024), 1,
      sym_kTo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80917] = 2,
    ACTIONS(7026), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80926] = 2,
    ACTIONS(7028), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80935] = 2,
    ACTIONS(7030), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80944] = 2,
    ACTIONS(7032), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80953] = 2,
    ACTIONS(7034), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80962] = 2,
    ACTIONS(7036), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80971] = 2,
    ACTIONS(7038), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80980] = 2,
    ACTIONS(7040), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80989] = 2,
    ACTIONS(7042), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [80998] = 2,
    ACTIONS(7044), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81007] = 2,
    ACTIONS(6668), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81016] = 2,
    ACTIONS(7046), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81025] = 2,
    ACTIONS(7048), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81034] = 2,
    ACTIONS(7050), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81043] = 2,
    ACTIONS(7052), 1,
      sym_kElse,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81052] = 2,
    ACTIONS(7054), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81061] = 2,
    ACTIONS(3341), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81070] = 2,
    ACTIONS(5744), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81079] = 2,
    ACTIONS(7056), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81088] = 2,
    ACTIONS(5784), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81097] = 2,
    ACTIONS(7058), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81106] = 2,
    ACTIONS(5788), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81115] = 2,
    ACTIONS(7060), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81124] = 2,
    ACTIONS(7062), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81133] = 2,
    ACTIONS(7064), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81142] = 2,
    ACTIONS(7066), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81151] = 2,
    ACTIONS(5806), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81160] = 2,
    ACTIONS(7068), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81169] = 2,
    ACTIONS(7070), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81178] = 2,
    ACTIONS(7072), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81187] = 2,
    ACTIONS(7074), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81196] = 2,
    ACTIONS(7076), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81205] = 2,
    ACTIONS(5814), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81214] = 2,
    ACTIONS(7078), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81223] = 2,
    ACTIONS(7080), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81232] = 2,
    ACTIONS(7082), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81241] = 2,
    ACTIONS(6039), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81250] = 2,
    ACTIONS(7084), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81259] = 2,
    ACTIONS(7086), 1,
      sym_kFor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81268] = 2,
    ACTIONS(7088), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81277] = 2,
    ACTIONS(7090), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81286] = 2,
    ACTIONS(7092), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81295] = 2,
    ACTIONS(6638), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81304] = 2,
    ACTIONS(7094), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81313] = 2,
    ACTIONS(7096), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81322] = 2,
    ACTIONS(7098), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81331] = 2,
    ACTIONS(7100), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81340] = 2,
    ACTIONS(7102), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81349] = 2,
    ACTIONS(7104), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81358] = 2,
    ACTIONS(7106), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81367] = 2,
    ACTIONS(7108), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81376] = 2,
    ACTIONS(7110), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81385] = 2,
    ACTIONS(7112), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81394] = 2,
    ACTIONS(7114), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81403] = 2,
    ACTIONS(7116), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81412] = 2,
    ACTIONS(7118), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81421] = 2,
    ACTIONS(7120), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81430] = 2,
    ACTIONS(7122), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81439] = 2,
    ACTIONS(7124), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81448] = 2,
    ACTIONS(7126), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81457] = 2,
    ACTIONS(7128), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81466] = 2,
    ACTIONS(7130), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81475] = 2,
    ACTIONS(7132), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81484] = 2,
    ACTIONS(6626), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81493] = 2,
    ACTIONS(7134), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81502] = 2,
    ACTIONS(7136), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81511] = 2,
    ACTIONS(5672), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81520] = 2,
    ACTIONS(7138), 1,
      sym_kUntil,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81529] = 2,
    ACTIONS(7140), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81538] = 2,
    ACTIONS(7142), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81547] = 2,
    ACTIONS(7144), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81556] = 2,
    ACTIONS(7146), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81565] = 2,
    ACTIONS(6634), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81574] = 2,
    ACTIONS(7148), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81583] = 2,
    ACTIONS(7150), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81592] = 2,
    ACTIONS(7152), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81601] = 2,
    ACTIONS(7154), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81610] = 2,
    ACTIONS(7156), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81619] = 2,
    ACTIONS(6189), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81628] = 2,
    ACTIONS(7158), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81637] = 2,
    ACTIONS(6770), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81646] = 2,
    ACTIONS(7160), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81655] = 2,
    ACTIONS(3529), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81664] = 2,
    ACTIONS(5021), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81673] = 2,
    ACTIONS(7162), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81682] = 2,
    ACTIONS(4566), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81691] = 2,
    ACTIONS(7164), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81700] = 2,
    ACTIONS(7166), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81709] = 2,
    ACTIONS(7168), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81718] = 2,
    ACTIONS(7170), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81727] = 2,
    ACTIONS(7172), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81736] = 2,
    ACTIONS(7174), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81745] = 2,
    ACTIONS(7176), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81754] = 2,
    ACTIONS(7178), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81763] = 2,
    ACTIONS(7180), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81772] = 2,
    ACTIONS(7182), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81781] = 2,
    ACTIONS(7184), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81790] = 2,
    ACTIONS(5766), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81799] = 2,
    ACTIONS(6710), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81808] = 2,
    ACTIONS(7186), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81817] = 2,
    ACTIONS(6604), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81826] = 2,
    ACTIONS(7188), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81835] = 2,
    ACTIONS(7190), 1,
      sym_kUntil,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81844] = 2,
    ACTIONS(7192), 1,
      sym_kDo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81853] = 2,
    ACTIONS(7194), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81862] = 2,
    ACTIONS(7196), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81871] = 2,
    ACTIONS(7198), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81880] = 2,
    ACTIONS(6295), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81889] = 2,
    ACTIONS(7200), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81898] = 2,
    ACTIONS(7202), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81907] = 2,
    ACTIONS(7204), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81916] = 2,
    ACTIONS(7206), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81925] = 2,
    ACTIONS(7208), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81934] = 2,
    ACTIONS(7210), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81943] = 2,
    ACTIONS(7212), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81952] = 2,
    ACTIONS(7214), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81961] = 2,
    ACTIONS(7216), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81970] = 2,
    ACTIONS(7218), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81979] = 2,
    ACTIONS(7220), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81988] = 2,
    ACTIONS(5742), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [81997] = 2,
    ACTIONS(5782), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82006] = 2,
    ACTIONS(7222), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82015] = 2,
    ACTIONS(7224), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82024] = 2,
    ACTIONS(7226), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82033] = 2,
    ACTIONS(7228), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82042] = 2,
    ACTIONS(5513), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82051] = 2,
    ACTIONS(5760), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82060] = 2,
    ACTIONS(7230), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82069] = 2,
    ACTIONS(7232), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82078] = 2,
    ACTIONS(7234), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82087] = 2,
    ACTIONS(7236), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82096] = 2,
    ACTIONS(7238), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82105] = 2,
    ACTIONS(7240), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82114] = 2,
    ACTIONS(7242), 1,
      sym_kArray,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82123] = 2,
    ACTIONS(7244), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82132] = 2,
    ACTIONS(7246), 1,
      sym_kTo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82141] = 2,
    ACTIONS(7248), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82150] = 2,
    ACTIONS(7250), 1,
      sym_kFor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82159] = 2,
    ACTIONS(7252), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82168] = 2,
    ACTIONS(7254), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82177] = 2,
    ACTIONS(7256), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82186] = 2,
    ACTIONS(7258), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82195] = 2,
    ACTIONS(7260), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82204] = 2,
    ACTIONS(7262), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82213] = 2,
    ACTIONS(7264), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82222] = 2,
    ACTIONS(5578), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82231] = 2,
    ACTIONS(7266), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82240] = 2,
    ACTIONS(6688), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82249] = 2,
    ACTIONS(5802), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82258] = 2,
    ACTIONS(7268), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82267] = 2,
    ACTIONS(7270), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82276] = 2,
    ACTIONS(7272), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82285] = 2,
    ACTIONS(7274), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82294] = 2,
    ACTIONS(5039), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82303] = 2,
    ACTIONS(7276), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82312] = 2,
    ACTIONS(7278), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82321] = 2,
    ACTIONS(7280), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82330] = 2,
    ACTIONS(5582), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82339] = 2,
    ACTIONS(7282), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82348] = 2,
    ACTIONS(6325), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82357] = 2,
    ACTIONS(7284), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82366] = 2,
    ACTIONS(7286), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82375] = 2,
    ACTIONS(7288), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82384] = 2,
    ACTIONS(7290), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82393] = 2,
    ACTIONS(7292), 1,
      sym_kGt,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82402] = 2,
    ACTIONS(7294), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82411] = 2,
    ACTIONS(6918), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82420] = 2,
    ACTIONS(7296), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82429] = 2,
    ACTIONS(7298), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82438] = 2,
    ACTIONS(7300), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82447] = 2,
    ACTIONS(6750), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82456] = 2,
    ACTIONS(7302), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82465] = 2,
    ACTIONS(7304), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82474] = 2,
    ACTIONS(7306), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82483] = 2,
    ACTIONS(7308), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82492] = 2,
    ACTIONS(7310), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82501] = 2,
    ACTIONS(7312), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82510] = 2,
    ACTIONS(7314), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82519] = 2,
    ACTIONS(7316), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82528] = 2,
    ACTIONS(7318), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82537] = 2,
    ACTIONS(7320), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82546] = 2,
    ACTIONS(7322), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82555] = 2,
    ACTIONS(6644), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82564] = 2,
    ACTIONS(7324), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82573] = 2,
    ACTIONS(7326), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82582] = 2,
    ACTIONS(7328), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82591] = 2,
    ACTIONS(7330), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82600] = 2,
    ACTIONS(7332), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82609] = 2,
    ACTIONS(7334), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82618] = 2,
    ACTIONS(7336), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82627] = 2,
    ACTIONS(7338), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82636] = 2,
    ACTIONS(7340), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82645] = 2,
    ACTIONS(7342), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82654] = 2,
    ACTIONS(7344), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82663] = 2,
    ACTIONS(7346), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82672] = 2,
    ACTIONS(7348), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82681] = 2,
    ACTIONS(7350), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82690] = 2,
    ACTIONS(7352), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82699] = 2,
    ACTIONS(7354), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82708] = 2,
    ACTIONS(7356), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82717] = 2,
    ACTIONS(7358), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82726] = 2,
    ACTIONS(6774), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82735] = 2,
    ACTIONS(7360), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82744] = 2,
    ACTIONS(7362), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82753] = 2,
    ACTIONS(7364), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82762] = 2,
    ACTIONS(7366), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82771] = 2,
    ACTIONS(7368), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82780] = 2,
    ACTIONS(7370), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82789] = 2,
    ACTIONS(7372), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82798] = 2,
    ACTIONS(7374), 1,
      sym_kUntil,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82807] = 2,
    ACTIONS(7376), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82816] = 2,
    ACTIONS(7378), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82825] = 2,
    ACTIONS(6646), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82834] = 2,
    ACTIONS(7380), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82843] = 2,
    ACTIONS(7382), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82852] = 2,
    ACTIONS(7384), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82861] = 2,
    ACTIONS(7386), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82870] = 2,
    ACTIONS(7388), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82879] = 2,
    ACTIONS(7390), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82888] = 2,
    ACTIONS(7392), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82897] = 2,
    ACTIONS(7394), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82906] = 2,
    ACTIONS(7396), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82915] = 2,
    ACTIONS(7398), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82924] = 2,
    ACTIONS(7400), 1,
      sym_kFor,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82933] = 2,
    ACTIONS(7402), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82942] = 2,
    ACTIONS(5604), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82951] = 2,
    ACTIONS(7404), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82960] = 2,
    ACTIONS(6407), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82969] = 2,
    ACTIONS(7406), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82978] = 2,
    ACTIONS(7408), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82987] = 2,
    ACTIONS(7410), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [82996] = 2,
    ACTIONS(7412), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83005] = 2,
    ACTIONS(7414), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83014] = 2,
    ACTIONS(7416), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83023] = 2,
    ACTIONS(7418), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83032] = 2,
    ACTIONS(7420), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83041] = 2,
    ACTIONS(7422), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83050] = 2,
    ACTIONS(7424), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83059] = 2,
    ACTIONS(7426), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83068] = 2,
    ACTIONS(7428), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83077] = 2,
    ACTIONS(7430), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83086] = 2,
    ACTIONS(7432), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83095] = 2,
    ACTIONS(7434), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83104] = 2,
    ACTIONS(7436), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83113] = 2,
    ACTIONS(7438), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83122] = 2,
    ACTIONS(7440), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83131] = 2,
    ACTIONS(7442), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83140] = 2,
    ACTIONS(7444), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83149] = 2,
    ACTIONS(7446), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83158] = 2,
    ACTIONS(7448), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83167] = 2,
    ACTIONS(7450), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83176] = 2,
    ACTIONS(7452), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83185] = 2,
    ACTIONS(7454), 1,
      sym_kDo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83194] = 2,
    ACTIONS(7456), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83203] = 2,
    ACTIONS(7458), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83212] = 2,
    ACTIONS(7460), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83221] = 2,
    ACTIONS(7462), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83230] = 2,
    ACTIONS(7464), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83239] = 2,
    ACTIONS(7466), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83248] = 2,
    ACTIONS(7468), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83257] = 2,
    ACTIONS(7470), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83266] = 2,
    ACTIONS(7472), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83275] = 2,
    ACTIONS(5253), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83284] = 2,
    ACTIONS(7474), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83293] = 2,
    ACTIONS(7476), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83302] = 2,
    ACTIONS(7478), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83311] = 2,
    ACTIONS(7480), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83320] = 2,
    ACTIONS(7482), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83329] = 2,
    ACTIONS(5081), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83338] = 2,
    ACTIONS(5257), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83347] = 2,
    ACTIONS(7484), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83356] = 2,
    ACTIONS(7486), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83365] = 2,
    ACTIONS(7488), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83374] = 2,
    ACTIONS(7490), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83383] = 2,
    ACTIONS(7492), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83392] = 2,
    ACTIONS(7494), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83401] = 2,
    ACTIONS(7496), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83410] = 2,
    ACTIONS(7498), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83419] = 2,
    ACTIONS(6365), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83428] = 2,
    ACTIONS(7500), 1,
      sym_kArray,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83437] = 2,
    ACTIONS(7502), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83446] = 2,
    ACTIONS(7504), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83455] = 2,
    ACTIONS(5824), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83464] = 2,
    ACTIONS(7506), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83473] = 2,
    ACTIONS(7508), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83482] = 2,
    ACTIONS(7510), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83491] = 2,
    ACTIONS(7512), 1,
      sym_kDo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83500] = 2,
    ACTIONS(5828), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83509] = 2,
    ACTIONS(5229), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83518] = 2,
    ACTIONS(7514), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83527] = 2,
    ACTIONS(7516), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83536] = 2,
    ACTIONS(5698), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83545] = 2,
    ACTIONS(7518), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83554] = 2,
    ACTIONS(6922), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83563] = 2,
    ACTIONS(7520), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83572] = 2,
    ACTIONS(7522), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83581] = 2,
    ACTIONS(7524), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83590] = 2,
    ACTIONS(3515), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83599] = 2,
    ACTIONS(7526), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83608] = 2,
    ACTIONS(7528), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83617] = 2,
    ACTIONS(7530), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83626] = 2,
    ACTIONS(5694), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83635] = 2,
    ACTIONS(7532), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83644] = 2,
    ACTIONS(7534), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83653] = 2,
    ACTIONS(7536), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83662] = 2,
    ACTIONS(7538), 1,
      sym_kOf,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83671] = 2,
    ACTIONS(7540), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83680] = 2,
    ACTIONS(7542), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83689] = 2,
    ACTIONS(7544), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83698] = 2,
    ACTIONS(5117), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83707] = 2,
    ACTIONS(7546), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83716] = 2,
    ACTIONS(7548), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83725] = 2,
    ACTIONS(7550), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83734] = 2,
    ACTIONS(7552), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83743] = 2,
    ACTIONS(3057), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83752] = 2,
    ACTIONS(7554), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83761] = 2,
    ACTIONS(7556), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83770] = 2,
    ACTIONS(7558), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83779] = 2,
    ACTIONS(7560), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83788] = 2,
    ACTIONS(7562), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83797] = 2,
    ACTIONS(4454), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83806] = 2,
    ACTIONS(7564), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83815] = 2,
    ACTIONS(7566), 1,
      sym_kObject,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83824] = 2,
    ACTIONS(7568), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83833] = 2,
    ACTIONS(7570), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83842] = 2,
    ACTIONS(7572), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83851] = 2,
    ACTIONS(7574), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83860] = 2,
    ACTIONS(7576), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83869] = 2,
    ACTIONS(5676), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83878] = 2,
    ACTIONS(7578), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83887] = 2,
    ACTIONS(7580), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83896] = 2,
    ACTIONS(7582), 1,
      sym_kTo,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83905] = 2,
    ACTIONS(7584), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83914] = 2,
    ACTIONS(7586), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83923] = 2,
    ACTIONS(7588), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83932] = 2,
    ACTIONS(7590), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83941] = 2,
    ACTIONS(7592), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83950] = 2,
    ACTIONS(7594), 1,
      sym_kEnd,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83959] = 2,
    ACTIONS(5654), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
  [83968] = 2,
    ACTIONS(3099), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__space,
      sym_pp,
      sym_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(560)] = 0,
  [SMALL_STATE(561)] = 75,
  [SMALL_STATE(562)] = 150,
  [SMALL_STATE(563)] = 225,
  [SMALL_STATE(564)] = 300,
  [SMALL_STATE(565)] = 375,
  [SMALL_STATE(566)] = 450,
  [SMALL_STATE(567)] = 525,
  [SMALL_STATE(568)] = 600,
  [SMALL_STATE(569)] = 666,
  [SMALL_STATE(570)] = 734,
  [SMALL_STATE(571)] = 798,
  [SMALL_STATE(572)] = 864,
  [SMALL_STATE(573)] = 930,
  [SMALL_STATE(574)] = 996,
  [SMALL_STATE(575)] = 1062,
  [SMALL_STATE(576)] = 1128,
  [SMALL_STATE(577)] = 1196,
  [SMALL_STATE(578)] = 1264,
  [SMALL_STATE(579)] = 1330,
  [SMALL_STATE(580)] = 1398,
  [SMALL_STATE(581)] = 1464,
  [SMALL_STATE(582)] = 1532,
  [SMALL_STATE(583)] = 1600,
  [SMALL_STATE(584)] = 1664,
  [SMALL_STATE(585)] = 1732,
  [SMALL_STATE(586)] = 1800,
  [SMALL_STATE(587)] = 1864,
  [SMALL_STATE(588)] = 1932,
  [SMALL_STATE(589)] = 2000,
  [SMALL_STATE(590)] = 2064,
  [SMALL_STATE(591)] = 2132,
  [SMALL_STATE(592)] = 2200,
  [SMALL_STATE(593)] = 2268,
  [SMALL_STATE(594)] = 2336,
  [SMALL_STATE(595)] = 2404,
  [SMALL_STATE(596)] = 2472,
  [SMALL_STATE(597)] = 2567,
  [SMALL_STATE(598)] = 2645,
  [SMALL_STATE(599)] = 2723,
  [SMALL_STATE(600)] = 2793,
  [SMALL_STATE(601)] = 2855,
  [SMALL_STATE(602)] = 2925,
  [SMALL_STATE(603)] = 3000,
  [SMALL_STATE(604)] = 3117,
  [SMALL_STATE(605)] = 3176,
  [SMALL_STATE(606)] = 3277,
  [SMALL_STATE(607)] = 3354,
  [SMALL_STATE(608)] = 3425,
  [SMALL_STATE(609)] = 3500,
  [SMALL_STATE(610)] = 3601,
  [SMALL_STATE(611)] = 3702,
  [SMALL_STATE(612)] = 3803,
  [SMALL_STATE(613)] = 3870,
  [SMALL_STATE(614)] = 3947,
  [SMALL_STATE(615)] = 4061,
  [SMALL_STATE(616)] = 4157,
  [SMALL_STATE(617)] = 4231,
  [SMALL_STATE(618)] = 4301,
  [SMALL_STATE(619)] = 4375,
  [SMALL_STATE(620)] = 4441,
  [SMALL_STATE(621)] = 4515,
  [SMALL_STATE(622)] = 4589,
  [SMALL_STATE(623)] = 4700,
  [SMALL_STATE(624)] = 4811,
  [SMALL_STATE(625)] = 4882,
  [SMALL_STATE(626)] = 4945,
  [SMALL_STATE(627)] = 5016,
  [SMALL_STATE(628)] = 5079,
  [SMALL_STATE(629)] = 5150,
  [SMALL_STATE(630)] = 5221,
  [SMALL_STATE(631)] = 5316,
  [SMALL_STATE(632)] = 5410,
  [SMALL_STATE(633)] = 5502,
  [SMALL_STATE(634)] = 5594,
  [SMALL_STATE(635)] = 5688,
  [SMALL_STATE(636)] = 5782,
  [SMALL_STATE(637)] = 5876,
  [SMALL_STATE(638)] = 5970,
  [SMALL_STATE(639)] = 6024,
  [SMALL_STATE(640)] = 6089,
  [SMALL_STATE(641)] = 6160,
  [SMALL_STATE(642)] = 6231,
  [SMALL_STATE(643)] = 6318,
  [SMALL_STATE(644)] = 6379,
  [SMALL_STATE(645)] = 6438,
  [SMALL_STATE(646)] = 6499,
  [SMALL_STATE(647)] = 6560,
  [SMALL_STATE(648)] = 6621,
  [SMALL_STATE(649)] = 6682,
  [SMALL_STATE(650)] = 6743,
  [SMALL_STATE(651)] = 6804,
  [SMALL_STATE(652)] = 6865,
  [SMALL_STATE(653)] = 6922,
  [SMALL_STATE(654)] = 6979,
  [SMALL_STATE(655)] = 7038,
  [SMALL_STATE(656)] = 7097,
  [SMALL_STATE(657)] = 7152,
  [SMALL_STATE(658)] = 7207,
  [SMALL_STATE(659)] = 7266,
  [SMALL_STATE(660)] = 7373,
  [SMALL_STATE(661)] = 7462,
  [SMALL_STATE(662)] = 7569,
  [SMALL_STATE(663)] = 7628,
  [SMALL_STATE(664)] = 7735,
  [SMALL_STATE(665)] = 7794,
  [SMALL_STATE(666)] = 7901,
  [SMALL_STATE(667)] = 7954,
  [SMALL_STATE(668)] = 8013,
  [SMALL_STATE(669)] = 8102,
  [SMALL_STATE(670)] = 8167,
  [SMALL_STATE(671)] = 8224,
  [SMALL_STATE(672)] = 8281,
  [SMALL_STATE(673)] = 8340,
  [SMALL_STATE(674)] = 8427,
  [SMALL_STATE(675)] = 8531,
  [SMALL_STATE(676)] = 8635,
  [SMALL_STATE(677)] = 8723,
  [SMALL_STATE(678)] = 8811,
  [SMALL_STATE(679)] = 8865,
  [SMALL_STATE(680)] = 8919,
  [SMALL_STATE(681)] = 9023,
  [SMALL_STATE(682)] = 9077,
  [SMALL_STATE(683)] = 9181,
  [SMALL_STATE(684)] = 9269,
  [SMALL_STATE(685)] = 9353,
  [SMALL_STATE(686)] = 9441,
  [SMALL_STATE(687)] = 9499,
  [SMALL_STATE(688)] = 9557,
  [SMALL_STATE(689)] = 9615,
  [SMALL_STATE(690)] = 9719,
  [SMALL_STATE(691)] = 9777,
  [SMALL_STATE(692)] = 9835,
  [SMALL_STATE(693)] = 9893,
  [SMALL_STATE(694)] = 9951,
  [SMALL_STATE(695)] = 10009,
  [SMALL_STATE(696)] = 10097,
  [SMALL_STATE(697)] = 10201,
  [SMALL_STATE(698)] = 10289,
  [SMALL_STATE(699)] = 10373,
  [SMALL_STATE(700)] = 10457,
  [SMALL_STATE(701)] = 10523,
  [SMALL_STATE(702)] = 10585,
  [SMALL_STATE(703)] = 10655,
  [SMALL_STATE(704)] = 10739,
  [SMALL_STATE(705)] = 10827,
  [SMALL_STATE(706)] = 10931,
  [SMALL_STATE(707)] = 11019,
  [SMALL_STATE(708)] = 11107,
  [SMALL_STATE(709)] = 11195,
  [SMALL_STATE(710)] = 11283,
  [SMALL_STATE(711)] = 11371,
  [SMALL_STATE(712)] = 11459,
  [SMALL_STATE(713)] = 11547,
  [SMALL_STATE(714)] = 11635,
  [SMALL_STATE(715)] = 11723,
  [SMALL_STATE(716)] = 11811,
  [SMALL_STATE(717)] = 11899,
  [SMALL_STATE(718)] = 12003,
  [SMALL_STATE(719)] = 12091,
  [SMALL_STATE(720)] = 12179,
  [SMALL_STATE(721)] = 12267,
  [SMALL_STATE(722)] = 12355,
  [SMALL_STATE(723)] = 12443,
  [SMALL_STATE(724)] = 12528,
  [SMALL_STATE(725)] = 12629,
  [SMALL_STATE(726)] = 12730,
  [SMALL_STATE(727)] = 12815,
  [SMALL_STATE(728)] = 12900,
  [SMALL_STATE(729)] = 13001,
  [SMALL_STATE(730)] = 13102,
  [SMALL_STATE(731)] = 13203,
  [SMALL_STATE(732)] = 13288,
  [SMALL_STATE(733)] = 13389,
  [SMALL_STATE(734)] = 13490,
  [SMALL_STATE(735)] = 13591,
  [SMALL_STATE(736)] = 13692,
  [SMALL_STATE(737)] = 13793,
  [SMALL_STATE(738)] = 13878,
  [SMALL_STATE(739)] = 13979,
  [SMALL_STATE(740)] = 14064,
  [SMALL_STATE(741)] = 14151,
  [SMALL_STATE(742)] = 14252,
  [SMALL_STATE(743)] = 14339,
  [SMALL_STATE(744)] = 14440,
  [SMALL_STATE(745)] = 14541,
  [SMALL_STATE(746)] = 14642,
  [SMALL_STATE(747)] = 14727,
  [SMALL_STATE(748)] = 14828,
  [SMALL_STATE(749)] = 14913,
  [SMALL_STATE(750)] = 14998,
  [SMALL_STATE(751)] = 15099,
  [SMALL_STATE(752)] = 15200,
  [SMALL_STATE(753)] = 15285,
  [SMALL_STATE(754)] = 15340,
  [SMALL_STATE(755)] = 15425,
  [SMALL_STATE(756)] = 15510,
  [SMALL_STATE(757)] = 15565,
  [SMALL_STATE(758)] = 15650,
  [SMALL_STATE(759)] = 15735,
  [SMALL_STATE(760)] = 15820,
  [SMALL_STATE(761)] = 15905,
  [SMALL_STATE(762)] = 15990,
  [SMALL_STATE(763)] = 16053,
  [SMALL_STATE(764)] = 16138,
  [SMALL_STATE(765)] = 16223,
  [SMALL_STATE(766)] = 16324,
  [SMALL_STATE(767)] = 16425,
  [SMALL_STATE(768)] = 16526,
  [SMALL_STATE(769)] = 16611,
  [SMALL_STATE(770)] = 16696,
  [SMALL_STATE(771)] = 16781,
  [SMALL_STATE(772)] = 16882,
  [SMALL_STATE(773)] = 16937,
  [SMALL_STATE(774)] = 17022,
  [SMALL_STATE(775)] = 17107,
  [SMALL_STATE(776)] = 17208,
  [SMALL_STATE(777)] = 17260,
  [SMALL_STATE(778)] = 17312,
  [SMALL_STATE(779)] = 17364,
  [SMALL_STATE(780)] = 17416,
  [SMALL_STATE(781)] = 17468,
  [SMALL_STATE(782)] = 17520,
  [SMALL_STATE(783)] = 17602,
  [SMALL_STATE(784)] = 17654,
  [SMALL_STATE(785)] = 17706,
  [SMALL_STATE(786)] = 17788,
  [SMALL_STATE(787)] = 17840,
  [SMALL_STATE(788)] = 17892,
  [SMALL_STATE(789)] = 17974,
  [SMALL_STATE(790)] = 18026,
  [SMALL_STATE(791)] = 18078,
  [SMALL_STATE(792)] = 18130,
  [SMALL_STATE(793)] = 18182,
  [SMALL_STATE(794)] = 18234,
  [SMALL_STATE(795)] = 18296,
  [SMALL_STATE(796)] = 18356,
  [SMALL_STATE(797)] = 18410,
  [SMALL_STATE(798)] = 18464,
  [SMALL_STATE(799)] = 18530,
  [SMALL_STATE(800)] = 18582,
  [SMALL_STATE(801)] = 18634,
  [SMALL_STATE(802)] = 18686,
  [SMALL_STATE(803)] = 18784,
  [SMALL_STATE(804)] = 18866,
  [SMALL_STATE(805)] = 18918,
  [SMALL_STATE(806)] = 18970,
  [SMALL_STATE(807)] = 19052,
  [SMALL_STATE(808)] = 19104,
  [SMALL_STATE(809)] = 19156,
  [SMALL_STATE(810)] = 19238,
  [SMALL_STATE(811)] = 19290,
  [SMALL_STATE(812)] = 19342,
  [SMALL_STATE(813)] = 19394,
  [SMALL_STATE(814)] = 19476,
  [SMALL_STATE(815)] = 19558,
  [SMALL_STATE(816)] = 19610,
  [SMALL_STATE(817)] = 19662,
  [SMALL_STATE(818)] = 19714,
  [SMALL_STATE(819)] = 19812,
  [SMALL_STATE(820)] = 19864,
  [SMALL_STATE(821)] = 19916,
  [SMALL_STATE(822)] = 19968,
  [SMALL_STATE(823)] = 20066,
  [SMALL_STATE(824)] = 20148,
  [SMALL_STATE(825)] = 20230,
  [SMALL_STATE(826)] = 20312,
  [SMALL_STATE(827)] = 20364,
  [SMALL_STATE(828)] = 20416,
  [SMALL_STATE(829)] = 20468,
  [SMALL_STATE(830)] = 20520,
  [SMALL_STATE(831)] = 20618,
  [SMALL_STATE(832)] = 20700,
  [SMALL_STATE(833)] = 20752,
  [SMALL_STATE(834)] = 20834,
  [SMALL_STATE(835)] = 20916,
  [SMALL_STATE(836)] = 20968,
  [SMALL_STATE(837)] = 21020,
  [SMALL_STATE(838)] = 21072,
  [SMALL_STATE(839)] = 21124,
  [SMALL_STATE(840)] = 21176,
  [SMALL_STATE(841)] = 21228,
  [SMALL_STATE(842)] = 21310,
  [SMALL_STATE(843)] = 21392,
  [SMALL_STATE(844)] = 21450,
  [SMALL_STATE(845)] = 21502,
  [SMALL_STATE(846)] = 21554,
  [SMALL_STATE(847)] = 21636,
  [SMALL_STATE(848)] = 21694,
  [SMALL_STATE(849)] = 21776,
  [SMALL_STATE(850)] = 21858,
  [SMALL_STATE(851)] = 21940,
  [SMALL_STATE(852)] = 21998,
  [SMALL_STATE(853)] = 22080,
  [SMALL_STATE(854)] = 22132,
  [SMALL_STATE(855)] = 22214,
  [SMALL_STATE(856)] = 22296,
  [SMALL_STATE(857)] = 22348,
  [SMALL_STATE(858)] = 22430,
  [SMALL_STATE(859)] = 22482,
  [SMALL_STATE(860)] = 22540,
  [SMALL_STATE(861)] = 22622,
  [SMALL_STATE(862)] = 22674,
  [SMALL_STATE(863)] = 22726,
  [SMALL_STATE(864)] = 22778,
  [SMALL_STATE(865)] = 22860,
  [SMALL_STATE(866)] = 22912,
  [SMALL_STATE(867)] = 22964,
  [SMALL_STATE(868)] = 23046,
  [SMALL_STATE(869)] = 23128,
  [SMALL_STATE(870)] = 23180,
  [SMALL_STATE(871)] = 23262,
  [SMALL_STATE(872)] = 23314,
  [SMALL_STATE(873)] = 23366,
  [SMALL_STATE(874)] = 23448,
  [SMALL_STATE(875)] = 23530,
  [SMALL_STATE(876)] = 23582,
  [SMALL_STATE(877)] = 23634,
  [SMALL_STATE(878)] = 23686,
  [SMALL_STATE(879)] = 23768,
  [SMALL_STATE(880)] = 23850,
  [SMALL_STATE(881)] = 23902,
  [SMALL_STATE(882)] = 23954,
  [SMALL_STATE(883)] = 24006,
  [SMALL_STATE(884)] = 24058,
  [SMALL_STATE(885)] = 24110,
  [SMALL_STATE(886)] = 24192,
  [SMALL_STATE(887)] = 24255,
  [SMALL_STATE(888)] = 24322,
  [SMALL_STATE(889)] = 24401,
  [SMALL_STATE(890)] = 24480,
  [SMALL_STATE(891)] = 24559,
  [SMALL_STATE(892)] = 24638,
  [SMALL_STATE(893)] = 24717,
  [SMALL_STATE(894)] = 24796,
  [SMALL_STATE(895)] = 24875,
  [SMALL_STATE(896)] = 24954,
  [SMALL_STATE(897)] = 25033,
  [SMALL_STATE(898)] = 25112,
  [SMALL_STATE(899)] = 25191,
  [SMALL_STATE(900)] = 25270,
  [SMALL_STATE(901)] = 25349,
  [SMALL_STATE(902)] = 25428,
  [SMALL_STATE(903)] = 25507,
  [SMALL_STATE(904)] = 25586,
  [SMALL_STATE(905)] = 25665,
  [SMALL_STATE(906)] = 25744,
  [SMALL_STATE(907)] = 25823,
  [SMALL_STATE(908)] = 25902,
  [SMALL_STATE(909)] = 25981,
  [SMALL_STATE(910)] = 26060,
  [SMALL_STATE(911)] = 26139,
  [SMALL_STATE(912)] = 26218,
  [SMALL_STATE(913)] = 26277,
  [SMALL_STATE(914)] = 26356,
  [SMALL_STATE(915)] = 26435,
  [SMALL_STATE(916)] = 26514,
  [SMALL_STATE(917)] = 26593,
  [SMALL_STATE(918)] = 26672,
  [SMALL_STATE(919)] = 26751,
  [SMALL_STATE(920)] = 26830,
  [SMALL_STATE(921)] = 26909,
  [SMALL_STATE(922)] = 26988,
  [SMALL_STATE(923)] = 27067,
  [SMALL_STATE(924)] = 27146,
  [SMALL_STATE(925)] = 27225,
  [SMALL_STATE(926)] = 27304,
  [SMALL_STATE(927)] = 27383,
  [SMALL_STATE(928)] = 27462,
  [SMALL_STATE(929)] = 27541,
  [SMALL_STATE(930)] = 27620,
  [SMALL_STATE(931)] = 27715,
  [SMALL_STATE(932)] = 27794,
  [SMALL_STATE(933)] = 27873,
  [SMALL_STATE(934)] = 27952,
  [SMALL_STATE(935)] = 28031,
  [SMALL_STATE(936)] = 28110,
  [SMALL_STATE(937)] = 28189,
  [SMALL_STATE(938)] = 28268,
  [SMALL_STATE(939)] = 28347,
  [SMALL_STATE(940)] = 28426,
  [SMALL_STATE(941)] = 28505,
  [SMALL_STATE(942)] = 28584,
  [SMALL_STATE(943)] = 28663,
  [SMALL_STATE(944)] = 28742,
  [SMALL_STATE(945)] = 28821,
  [SMALL_STATE(946)] = 28900,
  [SMALL_STATE(947)] = 28979,
  [SMALL_STATE(948)] = 29058,
  [SMALL_STATE(949)] = 29137,
  [SMALL_STATE(950)] = 29216,
  [SMALL_STATE(951)] = 29295,
  [SMALL_STATE(952)] = 29374,
  [SMALL_STATE(953)] = 29453,
  [SMALL_STATE(954)] = 29532,
  [SMALL_STATE(955)] = 29611,
  [SMALL_STATE(956)] = 29690,
  [SMALL_STATE(957)] = 29769,
  [SMALL_STATE(958)] = 29848,
  [SMALL_STATE(959)] = 29927,
  [SMALL_STATE(960)] = 30006,
  [SMALL_STATE(961)] = 30085,
  [SMALL_STATE(962)] = 30164,
  [SMALL_STATE(963)] = 30243,
  [SMALL_STATE(964)] = 30322,
  [SMALL_STATE(965)] = 30401,
  [SMALL_STATE(966)] = 30480,
  [SMALL_STATE(967)] = 30559,
  [SMALL_STATE(968)] = 30638,
  [SMALL_STATE(969)] = 30717,
  [SMALL_STATE(970)] = 30796,
  [SMALL_STATE(971)] = 30875,
  [SMALL_STATE(972)] = 30954,
  [SMALL_STATE(973)] = 31033,
  [SMALL_STATE(974)] = 31112,
  [SMALL_STATE(975)] = 31191,
  [SMALL_STATE(976)] = 31270,
  [SMALL_STATE(977)] = 31349,
  [SMALL_STATE(978)] = 31428,
  [SMALL_STATE(979)] = 31507,
  [SMALL_STATE(980)] = 31586,
  [SMALL_STATE(981)] = 31665,
  [SMALL_STATE(982)] = 31744,
  [SMALL_STATE(983)] = 31823,
  [SMALL_STATE(984)] = 31902,
  [SMALL_STATE(985)] = 31981,
  [SMALL_STATE(986)] = 32060,
  [SMALL_STATE(987)] = 32139,
  [SMALL_STATE(988)] = 32218,
  [SMALL_STATE(989)] = 32297,
  [SMALL_STATE(990)] = 32376,
  [SMALL_STATE(991)] = 32455,
  [SMALL_STATE(992)] = 32534,
  [SMALL_STATE(993)] = 32613,
  [SMALL_STATE(994)] = 32692,
  [SMALL_STATE(995)] = 32771,
  [SMALL_STATE(996)] = 32850,
  [SMALL_STATE(997)] = 32929,
  [SMALL_STATE(998)] = 33008,
  [SMALL_STATE(999)] = 33087,
  [SMALL_STATE(1000)] = 33166,
  [SMALL_STATE(1001)] = 33245,
  [SMALL_STATE(1002)] = 33324,
  [SMALL_STATE(1003)] = 33403,
  [SMALL_STATE(1004)] = 33482,
  [SMALL_STATE(1005)] = 33561,
  [SMALL_STATE(1006)] = 33640,
  [SMALL_STATE(1007)] = 33719,
  [SMALL_STATE(1008)] = 33798,
  [SMALL_STATE(1009)] = 33877,
  [SMALL_STATE(1010)] = 33956,
  [SMALL_STATE(1011)] = 34035,
  [SMALL_STATE(1012)] = 34114,
  [SMALL_STATE(1013)] = 34193,
  [SMALL_STATE(1014)] = 34272,
  [SMALL_STATE(1015)] = 34351,
  [SMALL_STATE(1016)] = 34403,
  [SMALL_STATE(1017)] = 34455,
  [SMALL_STATE(1018)] = 34518,
  [SMALL_STATE(1019)] = 34567,
  [SMALL_STATE(1020)] = 34630,
  [SMALL_STATE(1021)] = 34679,
  [SMALL_STATE(1022)] = 34765,
  [SMALL_STATE(1023)] = 34859,
  [SMALL_STATE(1024)] = 34909,
  [SMALL_STATE(1025)] = 34971,
  [SMALL_STATE(1026)] = 35029,
  [SMALL_STATE(1027)] = 35079,
  [SMALL_STATE(1028)] = 35129,
  [SMALL_STATE(1029)] = 35179,
  [SMALL_STATE(1030)] = 35237,
  [SMALL_STATE(1031)] = 35323,
  [SMALL_STATE(1032)] = 35373,
  [SMALL_STATE(1033)] = 35467,
  [SMALL_STATE(1034)] = 35551,
  [SMALL_STATE(1035)] = 35601,
  [SMALL_STATE(1036)] = 35687,
  [SMALL_STATE(1037)] = 35737,
  [SMALL_STATE(1038)] = 35787,
  [SMALL_STATE(1039)] = 35881,
  [SMALL_STATE(1040)] = 35975,
  [SMALL_STATE(1041)] = 36061,
  [SMALL_STATE(1042)] = 36155,
  [SMALL_STATE(1043)] = 36249,
  [SMALL_STATE(1044)] = 36343,
  [SMALL_STATE(1045)] = 36437,
  [SMALL_STATE(1046)] = 36521,
  [SMALL_STATE(1047)] = 36607,
  [SMALL_STATE(1048)] = 36669,
  [SMALL_STATE(1049)] = 36753,
  [SMALL_STATE(1050)] = 36839,
  [SMALL_STATE(1051)] = 36886,
  [SMALL_STATE(1052)] = 36933,
  [SMALL_STATE(1053)] = 36980,
  [SMALL_STATE(1054)] = 37027,
  [SMALL_STATE(1055)] = 37074,
  [SMALL_STATE(1056)] = 37121,
  [SMALL_STATE(1057)] = 37168,
  [SMALL_STATE(1058)] = 37215,
  [SMALL_STATE(1059)] = 37262,
  [SMALL_STATE(1060)] = 37309,
  [SMALL_STATE(1061)] = 37356,
  [SMALL_STATE(1062)] = 37435,
  [SMALL_STATE(1063)] = 37482,
  [SMALL_STATE(1064)] = 37529,
  [SMALL_STATE(1065)] = 37576,
  [SMALL_STATE(1066)] = 37623,
  [SMALL_STATE(1067)] = 37670,
  [SMALL_STATE(1068)] = 37717,
  [SMALL_STATE(1069)] = 37764,
  [SMALL_STATE(1070)] = 37811,
  [SMALL_STATE(1071)] = 37858,
  [SMALL_STATE(1072)] = 37915,
  [SMALL_STATE(1073)] = 37970,
  [SMALL_STATE(1074)] = 38019,
  [SMALL_STATE(1075)] = 38068,
  [SMALL_STATE(1076)] = 38127,
  [SMALL_STATE(1077)] = 38174,
  [SMALL_STATE(1078)] = 38253,
  [SMALL_STATE(1079)] = 38314,
  [SMALL_STATE(1080)] = 38369,
  [SMALL_STATE(1081)] = 38418,
  [SMALL_STATE(1082)] = 38505,
  [SMALL_STATE(1083)] = 38554,
  [SMALL_STATE(1084)] = 38601,
  [SMALL_STATE(1085)] = 38664,
  [SMALL_STATE(1086)] = 38711,
  [SMALL_STATE(1087)] = 38758,
  [SMALL_STATE(1088)] = 38805,
  [SMALL_STATE(1089)] = 38852,
  [SMALL_STATE(1090)] = 38899,
  [SMALL_STATE(1091)] = 38946,
  [SMALL_STATE(1092)] = 38993,
  [SMALL_STATE(1093)] = 39040,
  [SMALL_STATE(1094)] = 39087,
  [SMALL_STATE(1095)] = 39134,
  [SMALL_STATE(1096)] = 39181,
  [SMALL_STATE(1097)] = 39228,
  [SMALL_STATE(1098)] = 39275,
  [SMALL_STATE(1099)] = 39322,
  [SMALL_STATE(1100)] = 39369,
  [SMALL_STATE(1101)] = 39416,
  [SMALL_STATE(1102)] = 39495,
  [SMALL_STATE(1103)] = 39582,
  [SMALL_STATE(1104)] = 39629,
  [SMALL_STATE(1105)] = 39708,
  [SMALL_STATE(1106)] = 39755,
  [SMALL_STATE(1107)] = 39802,
  [SMALL_STATE(1108)] = 39849,
  [SMALL_STATE(1109)] = 39896,
  [SMALL_STATE(1110)] = 39943,
  [SMALL_STATE(1111)] = 40031,
  [SMALL_STATE(1112)] = 40119,
  [SMALL_STATE(1113)] = 40207,
  [SMALL_STATE(1114)] = 40295,
  [SMALL_STATE(1115)] = 40375,
  [SMALL_STATE(1116)] = 40463,
  [SMALL_STATE(1117)] = 40543,
  [SMALL_STATE(1118)] = 40631,
  [SMALL_STATE(1119)] = 40721,
  [SMALL_STATE(1120)] = 40803,
  [SMALL_STATE(1121)] = 40891,
  [SMALL_STATE(1122)] = 40979,
  [SMALL_STATE(1123)] = 41027,
  [SMALL_STATE(1124)] = 41107,
  [SMALL_STATE(1125)] = 41192,
  [SMALL_STATE(1126)] = 41277,
  [SMALL_STATE(1127)] = 41362,
  [SMALL_STATE(1128)] = 41447,
  [SMALL_STATE(1129)] = 41532,
  [SMALL_STATE(1130)] = 41617,
  [SMALL_STATE(1131)] = 41702,
  [SMALL_STATE(1132)] = 41787,
  [SMALL_STATE(1133)] = 41872,
  [SMALL_STATE(1134)] = 41919,
  [SMALL_STATE(1135)] = 42004,
  [SMALL_STATE(1136)] = 42089,
  [SMALL_STATE(1137)] = 42174,
  [SMALL_STATE(1138)] = 42259,
  [SMALL_STATE(1139)] = 42344,
  [SMALL_STATE(1140)] = 42429,
  [SMALL_STATE(1141)] = 42514,
  [SMALL_STATE(1142)] = 42599,
  [SMALL_STATE(1143)] = 42684,
  [SMALL_STATE(1144)] = 42769,
  [SMALL_STATE(1145)] = 42854,
  [SMALL_STATE(1146)] = 42939,
  [SMALL_STATE(1147)] = 43024,
  [SMALL_STATE(1148)] = 43109,
  [SMALL_STATE(1149)] = 43194,
  [SMALL_STATE(1150)] = 43279,
  [SMALL_STATE(1151)] = 43364,
  [SMALL_STATE(1152)] = 43449,
  [SMALL_STATE(1153)] = 43534,
  [SMALL_STATE(1154)] = 43619,
  [SMALL_STATE(1155)] = 43704,
  [SMALL_STATE(1156)] = 43789,
  [SMALL_STATE(1157)] = 43874,
  [SMALL_STATE(1158)] = 43959,
  [SMALL_STATE(1159)] = 44044,
  [SMALL_STATE(1160)] = 44129,
  [SMALL_STATE(1161)] = 44214,
  [SMALL_STATE(1162)] = 44299,
  [SMALL_STATE(1163)] = 44384,
  [SMALL_STATE(1164)] = 44469,
  [SMALL_STATE(1165)] = 44554,
  [SMALL_STATE(1166)] = 44639,
  [SMALL_STATE(1167)] = 44724,
  [SMALL_STATE(1168)] = 44809,
  [SMALL_STATE(1169)] = 44894,
  [SMALL_STATE(1170)] = 44979,
  [SMALL_STATE(1171)] = 45064,
  [SMALL_STATE(1172)] = 45149,
  [SMALL_STATE(1173)] = 45234,
  [SMALL_STATE(1174)] = 45319,
  [SMALL_STATE(1175)] = 45404,
  [SMALL_STATE(1176)] = 45489,
  [SMALL_STATE(1177)] = 45536,
  [SMALL_STATE(1178)] = 45621,
  [SMALL_STATE(1179)] = 45706,
  [SMALL_STATE(1180)] = 45750,
  [SMALL_STATE(1181)] = 45832,
  [SMALL_STATE(1182)] = 45914,
  [SMALL_STATE(1183)] = 45958,
  [SMALL_STATE(1184)] = 46002,
  [SMALL_STATE(1185)] = 46046,
  [SMALL_STATE(1186)] = 46090,
  [SMALL_STATE(1187)] = 46170,
  [SMALL_STATE(1188)] = 46227,
  [SMALL_STATE(1189)] = 46288,
  [SMALL_STATE(1190)] = 46339,
  [SMALL_STATE(1191)] = 46396,
  [SMALL_STATE(1192)] = 46467,
  [SMALL_STATE(1193)] = 46524,
  [SMALL_STATE(1194)] = 46569,
  [SMALL_STATE(1195)] = 46614,
  [SMALL_STATE(1196)] = 46693,
  [SMALL_STATE(1197)] = 46742,
  [SMALL_STATE(1198)] = 46813,
  [SMALL_STATE(1199)] = 46892,
  [SMALL_STATE(1200)] = 46963,
  [SMALL_STATE(1201)] = 47020,
  [SMALL_STATE(1202)] = 47091,
  [SMALL_STATE(1203)] = 47148,
  [SMALL_STATE(1204)] = 47199,
  [SMALL_STATE(1205)] = 47248,
  [SMALL_STATE(1206)] = 47296,
  [SMALL_STATE(1207)] = 47338,
  [SMALL_STATE(1208)] = 47398,
  [SMALL_STATE(1209)] = 47446,
  [SMALL_STATE(1210)] = 47499,
  [SMALL_STATE(1211)] = 47554,
  [SMALL_STATE(1212)] = 47607,
  [SMALL_STATE(1213)] = 47660,
  [SMALL_STATE(1214)] = 47715,
  [SMALL_STATE(1215)] = 47768,
  [SMALL_STATE(1216)] = 47821,
  [SMALL_STATE(1217)] = 47874,
  [SMALL_STATE(1218)] = 47927,
  [SMALL_STATE(1219)] = 47980,
  [SMALL_STATE(1220)] = 48033,
  [SMALL_STATE(1221)] = 48086,
  [SMALL_STATE(1222)] = 48138,
  [SMALL_STATE(1223)] = 48180,
  [SMALL_STATE(1224)] = 48220,
  [SMALL_STATE(1225)] = 48260,
  [SMALL_STATE(1226)] = 48310,
  [SMALL_STATE(1227)] = 48360,
  [SMALL_STATE(1228)] = 48412,
  [SMALL_STATE(1229)] = 48464,
  [SMALL_STATE(1230)] = 48504,
  [SMALL_STATE(1231)] = 48554,
  [SMALL_STATE(1232)] = 48606,
  [SMALL_STATE(1233)] = 48656,
  [SMALL_STATE(1234)] = 48696,
  [SMALL_STATE(1235)] = 48746,
  [SMALL_STATE(1236)] = 48795,
  [SMALL_STATE(1237)] = 48834,
  [SMALL_STATE(1238)] = 48883,
  [SMALL_STATE(1239)] = 48926,
  [SMALL_STATE(1240)] = 48975,
  [SMALL_STATE(1241)] = 49024,
  [SMALL_STATE(1242)] = 49073,
  [SMALL_STATE(1243)] = 49114,
  [SMALL_STATE(1244)] = 49163,
  [SMALL_STATE(1245)] = 49212,
  [SMALL_STATE(1246)] = 49255,
  [SMALL_STATE(1247)] = 49298,
  [SMALL_STATE(1248)] = 49339,
  [SMALL_STATE(1249)] = 49380,
  [SMALL_STATE(1250)] = 49429,
  [SMALL_STATE(1251)] = 49480,
  [SMALL_STATE(1252)] = 49529,
  [SMALL_STATE(1253)] = 49578,
  [SMALL_STATE(1254)] = 49627,
  [SMALL_STATE(1255)] = 49676,
  [SMALL_STATE(1256)] = 49725,
  [SMALL_STATE(1257)] = 49765,
  [SMALL_STATE(1258)] = 49813,
  [SMALL_STATE(1259)] = 49859,
  [SMALL_STATE(1260)] = 49905,
  [SMALL_STATE(1261)] = 49953,
  [SMALL_STATE(1262)] = 49991,
  [SMALL_STATE(1263)] = 50031,
  [SMALL_STATE(1264)] = 50077,
  [SMALL_STATE(1265)] = 50115,
  [SMALL_STATE(1266)] = 50161,
  [SMALL_STATE(1267)] = 50199,
  [SMALL_STATE(1268)] = 50247,
  [SMALL_STATE(1269)] = 50285,
  [SMALL_STATE(1270)] = 50325,
  [SMALL_STATE(1271)] = 50363,
  [SMALL_STATE(1272)] = 50403,
  [SMALL_STATE(1273)] = 50473,
  [SMALL_STATE(1274)] = 50511,
  [SMALL_STATE(1275)] = 50553,
  [SMALL_STATE(1276)] = 50591,
  [SMALL_STATE(1277)] = 50631,
  [SMALL_STATE(1278)] = 50701,
  [SMALL_STATE(1279)] = 50771,
  [SMALL_STATE(1280)] = 50809,
  [SMALL_STATE(1281)] = 50849,
  [SMALL_STATE(1282)] = 50901,
  [SMALL_STATE(1283)] = 50947,
  [SMALL_STATE(1284)] = 51017,
  [SMALL_STATE(1285)] = 51057,
  [SMALL_STATE(1286)] = 51095,
  [SMALL_STATE(1287)] = 51145,
  [SMALL_STATE(1288)] = 51185,
  [SMALL_STATE(1289)] = 51223,
  [SMALL_STATE(1290)] = 51261,
  [SMALL_STATE(1291)] = 51313,
  [SMALL_STATE(1292)] = 51351,
  [SMALL_STATE(1293)] = 51393,
  [SMALL_STATE(1294)] = 51447,
  [SMALL_STATE(1295)] = 51487,
  [SMALL_STATE(1296)] = 51527,
  [SMALL_STATE(1297)] = 51597,
  [SMALL_STATE(1298)] = 51635,
  [SMALL_STATE(1299)] = 51673,
  [SMALL_STATE(1300)] = 51713,
  [SMALL_STATE(1301)] = 51753,
  [SMALL_STATE(1302)] = 51805,
  [SMALL_STATE(1303)] = 51857,
  [SMALL_STATE(1304)] = 51895,
  [SMALL_STATE(1305)] = 51935,
  [SMALL_STATE(1306)] = 51981,
  [SMALL_STATE(1307)] = 52019,
  [SMALL_STATE(1308)] = 52065,
  [SMALL_STATE(1309)] = 52111,
  [SMALL_STATE(1310)] = 52151,
  [SMALL_STATE(1311)] = 52191,
  [SMALL_STATE(1312)] = 52231,
  [SMALL_STATE(1313)] = 52271,
  [SMALL_STATE(1314)] = 52311,
  [SMALL_STATE(1315)] = 52351,
  [SMALL_STATE(1316)] = 52421,
  [SMALL_STATE(1317)] = 52459,
  [SMALL_STATE(1318)] = 52499,
  [SMALL_STATE(1319)] = 52539,
  [SMALL_STATE(1320)] = 52579,
  [SMALL_STATE(1321)] = 52619,
  [SMALL_STATE(1322)] = 52657,
  [SMALL_STATE(1323)] = 52697,
  [SMALL_STATE(1324)] = 52735,
  [SMALL_STATE(1325)] = 52773,
  [SMALL_STATE(1326)] = 52813,
  [SMALL_STATE(1327)] = 52853,
  [SMALL_STATE(1328)] = 52891,
  [SMALL_STATE(1329)] = 52941,
  [SMALL_STATE(1330)] = 52981,
  [SMALL_STATE(1331)] = 53021,
  [SMALL_STATE(1332)] = 53088,
  [SMALL_STATE(1333)] = 53155,
  [SMALL_STATE(1334)] = 53222,
  [SMALL_STATE(1335)] = 53289,
  [SMALL_STATE(1336)] = 53356,
  [SMALL_STATE(1337)] = 53423,
  [SMALL_STATE(1338)] = 53490,
  [SMALL_STATE(1339)] = 53557,
  [SMALL_STATE(1340)] = 53604,
  [SMALL_STATE(1341)] = 53671,
  [SMALL_STATE(1342)] = 53738,
  [SMALL_STATE(1343)] = 53805,
  [SMALL_STATE(1344)] = 53872,
  [SMALL_STATE(1345)] = 53939,
  [SMALL_STATE(1346)] = 54006,
  [SMALL_STATE(1347)] = 54073,
  [SMALL_STATE(1348)] = 54140,
  [SMALL_STATE(1349)] = 54207,
  [SMALL_STATE(1350)] = 54274,
  [SMALL_STATE(1351)] = 54341,
  [SMALL_STATE(1352)] = 54392,
  [SMALL_STATE(1353)] = 54449,
  [SMALL_STATE(1354)] = 54516,
  [SMALL_STATE(1355)] = 54583,
  [SMALL_STATE(1356)] = 54650,
  [SMALL_STATE(1357)] = 54701,
  [SMALL_STATE(1358)] = 54768,
  [SMALL_STATE(1359)] = 54819,
  [SMALL_STATE(1360)] = 54886,
  [SMALL_STATE(1361)] = 54937,
  [SMALL_STATE(1362)] = 54976,
  [SMALL_STATE(1363)] = 55025,
  [SMALL_STATE(1364)] = 55092,
  [SMALL_STATE(1365)] = 55145,
  [SMALL_STATE(1366)] = 55212,
  [SMALL_STATE(1367)] = 55263,
  [SMALL_STATE(1368)] = 55330,
  [SMALL_STATE(1369)] = 55397,
  [SMALL_STATE(1370)] = 55464,
  [SMALL_STATE(1371)] = 55531,
  [SMALL_STATE(1372)] = 55598,
  [SMALL_STATE(1373)] = 55665,
  [SMALL_STATE(1374)] = 55712,
  [SMALL_STATE(1375)] = 55757,
  [SMALL_STATE(1376)] = 55796,
  [SMALL_STATE(1377)] = 55835,
  [SMALL_STATE(1378)] = 55886,
  [SMALL_STATE(1379)] = 55953,
  [SMALL_STATE(1380)] = 56020,
  [SMALL_STATE(1381)] = 56087,
  [SMALL_STATE(1382)] = 56154,
  [SMALL_STATE(1383)] = 56221,
  [SMALL_STATE(1384)] = 56272,
  [SMALL_STATE(1385)] = 56339,
  [SMALL_STATE(1386)] = 56376,
  [SMALL_STATE(1387)] = 56413,
  [SMALL_STATE(1388)] = 56450,
  [SMALL_STATE(1389)] = 56487,
  [SMALL_STATE(1390)] = 56524,
  [SMALL_STATE(1391)] = 56561,
  [SMALL_STATE(1392)] = 56612,
  [SMALL_STATE(1393)] = 56649,
  [SMALL_STATE(1394)] = 56686,
  [SMALL_STATE(1395)] = 56723,
  [SMALL_STATE(1396)] = 56760,
  [SMALL_STATE(1397)] = 56797,
  [SMALL_STATE(1398)] = 56834,
  [SMALL_STATE(1399)] = 56871,
  [SMALL_STATE(1400)] = 56908,
  [SMALL_STATE(1401)] = 56945,
  [SMALL_STATE(1402)] = 56982,
  [SMALL_STATE(1403)] = 57019,
  [SMALL_STATE(1404)] = 57056,
  [SMALL_STATE(1405)] = 57093,
  [SMALL_STATE(1406)] = 57130,
  [SMALL_STATE(1407)] = 57167,
  [SMALL_STATE(1408)] = 57234,
  [SMALL_STATE(1409)] = 57301,
  [SMALL_STATE(1410)] = 57368,
  [SMALL_STATE(1411)] = 57419,
  [SMALL_STATE(1412)] = 57470,
  [SMALL_STATE(1413)] = 57537,
  [SMALL_STATE(1414)] = 57604,
  [SMALL_STATE(1415)] = 57671,
  [SMALL_STATE(1416)] = 57728,
  [SMALL_STATE(1417)] = 57795,
  [SMALL_STATE(1418)] = 57862,
  [SMALL_STATE(1419)] = 57929,
  [SMALL_STATE(1420)] = 57996,
  [SMALL_STATE(1421)] = 58063,
  [SMALL_STATE(1422)] = 58130,
  [SMALL_STATE(1423)] = 58197,
  [SMALL_STATE(1424)] = 58264,
  [SMALL_STATE(1425)] = 58331,
  [SMALL_STATE(1426)] = 58382,
  [SMALL_STATE(1427)] = 58433,
  [SMALL_STATE(1428)] = 58500,
  [SMALL_STATE(1429)] = 58567,
  [SMALL_STATE(1430)] = 58634,
  [SMALL_STATE(1431)] = 58701,
  [SMALL_STATE(1432)] = 58768,
  [SMALL_STATE(1433)] = 58835,
  [SMALL_STATE(1434)] = 58902,
  [SMALL_STATE(1435)] = 58969,
  [SMALL_STATE(1436)] = 59036,
  [SMALL_STATE(1437)] = 59103,
  [SMALL_STATE(1438)] = 59170,
  [SMALL_STATE(1439)] = 59237,
  [SMALL_STATE(1440)] = 59304,
  [SMALL_STATE(1441)] = 59371,
  [SMALL_STATE(1442)] = 59438,
  [SMALL_STATE(1443)] = 59505,
  [SMALL_STATE(1444)] = 59572,
  [SMALL_STATE(1445)] = 59639,
  [SMALL_STATE(1446)] = 59706,
  [SMALL_STATE(1447)] = 59773,
  [SMALL_STATE(1448)] = 59840,
  [SMALL_STATE(1449)] = 59907,
  [SMALL_STATE(1450)] = 59974,
  [SMALL_STATE(1451)] = 60041,
  [SMALL_STATE(1452)] = 60108,
  [SMALL_STATE(1453)] = 60175,
  [SMALL_STATE(1454)] = 60242,
  [SMALL_STATE(1455)] = 60309,
  [SMALL_STATE(1456)] = 60376,
  [SMALL_STATE(1457)] = 60413,
  [SMALL_STATE(1458)] = 60465,
  [SMALL_STATE(1459)] = 60517,
  [SMALL_STATE(1460)] = 60565,
  [SMALL_STATE(1461)] = 60613,
  [SMALL_STATE(1462)] = 60661,
  [SMALL_STATE(1463)] = 60709,
  [SMALL_STATE(1464)] = 60757,
  [SMALL_STATE(1465)] = 60805,
  [SMALL_STATE(1466)] = 60853,
  [SMALL_STATE(1467)] = 60901,
  [SMALL_STATE(1468)] = 60949,
  [SMALL_STATE(1469)] = 61001,
  [SMALL_STATE(1470)] = 61052,
  [SMALL_STATE(1471)] = 61087,
  [SMALL_STATE(1472)] = 61122,
  [SMALL_STATE(1473)] = 61181,
  [SMALL_STATE(1474)] = 61216,
  [SMALL_STATE(1475)] = 61267,
  [SMALL_STATE(1476)] = 61314,
  [SMALL_STATE(1477)] = 61349,
  [SMALL_STATE(1478)] = 61384,
  [SMALL_STATE(1479)] = 61419,
  [SMALL_STATE(1480)] = 61478,
  [SMALL_STATE(1481)] = 61537,
  [SMALL_STATE(1482)] = 61578,
  [SMALL_STATE(1483)] = 61625,
  [SMALL_STATE(1484)] = 61678,
  [SMALL_STATE(1485)] = 61713,
  [SMALL_STATE(1486)] = 61748,
  [SMALL_STATE(1487)] = 61795,
  [SMALL_STATE(1488)] = 61830,
  [SMALL_STATE(1489)] = 61880,
  [SMALL_STATE(1490)] = 61928,
  [SMALL_STATE(1491)] = 61978,
  [SMALL_STATE(1492)] = 62012,
  [SMALL_STATE(1493)] = 62046,
  [SMALL_STATE(1494)] = 62080,
  [SMALL_STATE(1495)] = 62130,
  [SMALL_STATE(1496)] = 62164,
  [SMALL_STATE(1497)] = 62198,
  [SMALL_STATE(1498)] = 62248,
  [SMALL_STATE(1499)] = 62296,
  [SMALL_STATE(1500)] = 62346,
  [SMALL_STATE(1501)] = 62396,
  [SMALL_STATE(1502)] = 62442,
  [SMALL_STATE(1503)] = 62492,
  [SMALL_STATE(1504)] = 62542,
  [SMALL_STATE(1505)] = 62592,
  [SMALL_STATE(1506)] = 62626,
  [SMALL_STATE(1507)] = 62672,
  [SMALL_STATE(1508)] = 62706,
  [SMALL_STATE(1509)] = 62740,
  [SMALL_STATE(1510)] = 62790,
  [SMALL_STATE(1511)] = 62840,
  [SMALL_STATE(1512)] = 62890,
  [SMALL_STATE(1513)] = 62940,
  [SMALL_STATE(1514)] = 62986,
  [SMALL_STATE(1515)] = 63020,
  [SMALL_STATE(1516)] = 63054,
  [SMALL_STATE(1517)] = 63104,
  [SMALL_STATE(1518)] = 63138,
  [SMALL_STATE(1519)] = 63188,
  [SMALL_STATE(1520)] = 63236,
  [SMALL_STATE(1521)] = 63286,
  [SMALL_STATE(1522)] = 63320,
  [SMALL_STATE(1523)] = 63354,
  [SMALL_STATE(1524)] = 63404,
  [SMALL_STATE(1525)] = 63454,
  [SMALL_STATE(1526)] = 63504,
  [SMALL_STATE(1527)] = 63554,
  [SMALL_STATE(1528)] = 63588,
  [SMALL_STATE(1529)] = 63622,
  [SMALL_STATE(1530)] = 63656,
  [SMALL_STATE(1531)] = 63706,
  [SMALL_STATE(1532)] = 63740,
  [SMALL_STATE(1533)] = 63774,
  [SMALL_STATE(1534)] = 63808,
  [SMALL_STATE(1535)] = 63858,
  [SMALL_STATE(1536)] = 63908,
  [SMALL_STATE(1537)] = 63958,
  [SMALL_STATE(1538)] = 64008,
  [SMALL_STATE(1539)] = 64054,
  [SMALL_STATE(1540)] = 64088,
  [SMALL_STATE(1541)] = 64135,
  [SMALL_STATE(1542)] = 64182,
  [SMALL_STATE(1543)] = 64229,
  [SMALL_STATE(1544)] = 64276,
  [SMALL_STATE(1545)] = 64323,
  [SMALL_STATE(1546)] = 64356,
  [SMALL_STATE(1547)] = 64403,
  [SMALL_STATE(1548)] = 64442,
  [SMALL_STATE(1549)] = 64489,
  [SMALL_STATE(1550)] = 64534,
  [SMALL_STATE(1551)] = 64581,
  [SMALL_STATE(1552)] = 64628,
  [SMALL_STATE(1553)] = 64675,
  [SMALL_STATE(1554)] = 64722,
  [SMALL_STATE(1555)] = 64761,
  [SMALL_STATE(1556)] = 64808,
  [SMALL_STATE(1557)] = 64844,
  [SMALL_STATE(1558)] = 64890,
  [SMALL_STATE(1559)] = 64936,
  [SMALL_STATE(1560)] = 64976,
  [SMALL_STATE(1561)] = 65020,
  [SMALL_STATE(1562)] = 65066,
  [SMALL_STATE(1563)] = 65112,
  [SMALL_STATE(1564)] = 65148,
  [SMALL_STATE(1565)] = 65188,
  [SMALL_STATE(1566)] = 65232,
  [SMALL_STATE(1567)] = 65276,
  [SMALL_STATE(1568)] = 65320,
  [SMALL_STATE(1569)] = 65366,
  [SMALL_STATE(1570)] = 65410,
  [SMALL_STATE(1571)] = 65456,
  [SMALL_STATE(1572)] = 65500,
  [SMALL_STATE(1573)] = 65544,
  [SMALL_STATE(1574)] = 65588,
  [SMALL_STATE(1575)] = 65634,
  [SMALL_STATE(1576)] = 65680,
  [SMALL_STATE(1577)] = 65724,
  [SMALL_STATE(1578)] = 65768,
  [SMALL_STATE(1579)] = 65814,
  [SMALL_STATE(1580)] = 65860,
  [SMALL_STATE(1581)] = 65904,
  [SMALL_STATE(1582)] = 65950,
  [SMALL_STATE(1583)] = 65996,
  [SMALL_STATE(1584)] = 66042,
  [SMALL_STATE(1585)] = 66086,
  [SMALL_STATE(1586)] = 66130,
  [SMALL_STATE(1587)] = 66174,
  [SMALL_STATE(1588)] = 66210,
  [SMALL_STATE(1589)] = 66254,
  [SMALL_STATE(1590)] = 66298,
  [SMALL_STATE(1591)] = 66344,
  [SMALL_STATE(1592)] = 66388,
  [SMALL_STATE(1593)] = 66432,
  [SMALL_STATE(1594)] = 66476,
  [SMALL_STATE(1595)] = 66520,
  [SMALL_STATE(1596)] = 66566,
  [SMALL_STATE(1597)] = 66606,
  [SMALL_STATE(1598)] = 66650,
  [SMALL_STATE(1599)] = 66682,
  [SMALL_STATE(1600)] = 66726,
  [SMALL_STATE(1601)] = 66770,
  [SMALL_STATE(1602)] = 66806,
  [SMALL_STATE(1603)] = 66852,
  [SMALL_STATE(1604)] = 66896,
  [SMALL_STATE(1605)] = 66940,
  [SMALL_STATE(1606)] = 66984,
  [SMALL_STATE(1607)] = 67025,
  [SMALL_STATE(1608)] = 67066,
  [SMALL_STATE(1609)] = 67097,
  [SMALL_STATE(1610)] = 67138,
  [SMALL_STATE(1611)] = 67179,
  [SMALL_STATE(1612)] = 67220,
  [SMALL_STATE(1613)] = 67261,
  [SMALL_STATE(1614)] = 67302,
  [SMALL_STATE(1615)] = 67333,
  [SMALL_STATE(1616)] = 67374,
  [SMALL_STATE(1617)] = 67408,
  [SMALL_STATE(1618)] = 67442,
  [SMALL_STATE(1619)] = 67471,
  [SMALL_STATE(1620)] = 67500,
  [SMALL_STATE(1621)] = 67531,
  [SMALL_STATE(1622)] = 67560,
  [SMALL_STATE(1623)] = 67591,
  [SMALL_STATE(1624)] = 67624,
  [SMALL_STATE(1625)] = 67655,
  [SMALL_STATE(1626)] = 67686,
  [SMALL_STATE(1627)] = 67715,
  [SMALL_STATE(1628)] = 67744,
  [SMALL_STATE(1629)] = 67775,
  [SMALL_STATE(1630)] = 67804,
  [SMALL_STATE(1631)] = 67835,
  [SMALL_STATE(1632)] = 67866,
  [SMALL_STATE(1633)] = 67897,
  [SMALL_STATE(1634)] = 67926,
  [SMALL_STATE(1635)] = 67955,
  [SMALL_STATE(1636)] = 67984,
  [SMALL_STATE(1637)] = 68013,
  [SMALL_STATE(1638)] = 68044,
  [SMALL_STATE(1639)] = 68073,
  [SMALL_STATE(1640)] = 68106,
  [SMALL_STATE(1641)] = 68138,
  [SMALL_STATE(1642)] = 68170,
  [SMALL_STATE(1643)] = 68195,
  [SMALL_STATE(1644)] = 68225,
  [SMALL_STATE(1645)] = 68249,
  [SMALL_STATE(1646)] = 68273,
  [SMALL_STATE(1647)] = 68297,
  [SMALL_STATE(1648)] = 68327,
  [SMALL_STATE(1649)] = 68351,
  [SMALL_STATE(1650)] = 68375,
  [SMALL_STATE(1651)] = 68396,
  [SMALL_STATE(1652)] = 68417,
  [SMALL_STATE(1653)] = 68438,
  [SMALL_STATE(1654)] = 68459,
  [SMALL_STATE(1655)] = 68480,
  [SMALL_STATE(1656)] = 68501,
  [SMALL_STATE(1657)] = 68522,
  [SMALL_STATE(1658)] = 68543,
  [SMALL_STATE(1659)] = 68564,
  [SMALL_STATE(1660)] = 68585,
  [SMALL_STATE(1661)] = 68606,
  [SMALL_STATE(1662)] = 68639,
  [SMALL_STATE(1663)] = 68660,
  [SMALL_STATE(1664)] = 68681,
  [SMALL_STATE(1665)] = 68702,
  [SMALL_STATE(1666)] = 68723,
  [SMALL_STATE(1667)] = 68744,
  [SMALL_STATE(1668)] = 68765,
  [SMALL_STATE(1669)] = 68786,
  [SMALL_STATE(1670)] = 68807,
  [SMALL_STATE(1671)] = 68828,
  [SMALL_STATE(1672)] = 68857,
  [SMALL_STATE(1673)] = 68878,
  [SMALL_STATE(1674)] = 68899,
  [SMALL_STATE(1675)] = 68928,
  [SMALL_STATE(1676)] = 68961,
  [SMALL_STATE(1677)] = 68994,
  [SMALL_STATE(1678)] = 69015,
  [SMALL_STATE(1679)] = 69043,
  [SMALL_STATE(1680)] = 69079,
  [SMALL_STATE(1681)] = 69102,
  [SMALL_STATE(1682)] = 69125,
  [SMALL_STATE(1683)] = 69150,
  [SMALL_STATE(1684)] = 69173,
  [SMALL_STATE(1685)] = 69196,
  [SMALL_STATE(1686)] = 69224,
  [SMALL_STATE(1687)] = 69244,
  [SMALL_STATE(1688)] = 69274,
  [SMALL_STATE(1689)] = 69304,
  [SMALL_STATE(1690)] = 69324,
  [SMALL_STATE(1691)] = 69344,
  [SMALL_STATE(1692)] = 69380,
  [SMALL_STATE(1693)] = 69400,
  [SMALL_STATE(1694)] = 69436,
  [SMALL_STATE(1695)] = 69472,
  [SMALL_STATE(1696)] = 69508,
  [SMALL_STATE(1697)] = 69544,
  [SMALL_STATE(1698)] = 69580,
  [SMALL_STATE(1699)] = 69616,
  [SMALL_STATE(1700)] = 69652,
  [SMALL_STATE(1701)] = 69688,
  [SMALL_STATE(1702)] = 69724,
  [SMALL_STATE(1703)] = 69760,
  [SMALL_STATE(1704)] = 69796,
  [SMALL_STATE(1705)] = 69832,
  [SMALL_STATE(1706)] = 69868,
  [SMALL_STATE(1707)] = 69904,
  [SMALL_STATE(1708)] = 69940,
  [SMALL_STATE(1709)] = 69960,
  [SMALL_STATE(1710)] = 69988,
  [SMALL_STATE(1711)] = 70008,
  [SMALL_STATE(1712)] = 70028,
  [SMALL_STATE(1713)] = 70048,
  [SMALL_STATE(1714)] = 70076,
  [SMALL_STATE(1715)] = 70106,
  [SMALL_STATE(1716)] = 70136,
  [SMALL_STATE(1717)] = 70156,
  [SMALL_STATE(1718)] = 70176,
  [SMALL_STATE(1719)] = 70206,
  [SMALL_STATE(1720)] = 70226,
  [SMALL_STATE(1721)] = 70246,
  [SMALL_STATE(1722)] = 70276,
  [SMALL_STATE(1723)] = 70304,
  [SMALL_STATE(1724)] = 70334,
  [SMALL_STATE(1725)] = 70370,
  [SMALL_STATE(1726)] = 70390,
  [SMALL_STATE(1727)] = 70410,
  [SMALL_STATE(1728)] = 70446,
  [SMALL_STATE(1729)] = 70482,
  [SMALL_STATE(1730)] = 70518,
  [SMALL_STATE(1731)] = 70554,
  [SMALL_STATE(1732)] = 70574,
  [SMALL_STATE(1733)] = 70594,
  [SMALL_STATE(1734)] = 70614,
  [SMALL_STATE(1735)] = 70642,
  [SMALL_STATE(1736)] = 70662,
  [SMALL_STATE(1737)] = 70682,
  [SMALL_STATE(1738)] = 70702,
  [SMALL_STATE(1739)] = 70722,
  [SMALL_STATE(1740)] = 70752,
  [SMALL_STATE(1741)] = 70788,
  [SMALL_STATE(1742)] = 70808,
  [SMALL_STATE(1743)] = 70828,
  [SMALL_STATE(1744)] = 70864,
  [SMALL_STATE(1745)] = 70884,
  [SMALL_STATE(1746)] = 70914,
  [SMALL_STATE(1747)] = 70934,
  [SMALL_STATE(1748)] = 70954,
  [SMALL_STATE(1749)] = 70974,
  [SMALL_STATE(1750)] = 71010,
  [SMALL_STATE(1751)] = 71046,
  [SMALL_STATE(1752)] = 71076,
  [SMALL_STATE(1753)] = 71109,
  [SMALL_STATE(1754)] = 71136,
  [SMALL_STATE(1755)] = 71169,
  [SMALL_STATE(1756)] = 71196,
  [SMALL_STATE(1757)] = 71229,
  [SMALL_STATE(1758)] = 71256,
  [SMALL_STATE(1759)] = 71273,
  [SMALL_STATE(1760)] = 71300,
  [SMALL_STATE(1761)] = 71327,
  [SMALL_STATE(1762)] = 71354,
  [SMALL_STATE(1763)] = 71375,
  [SMALL_STATE(1764)] = 71408,
  [SMALL_STATE(1765)] = 71441,
  [SMALL_STATE(1766)] = 71474,
  [SMALL_STATE(1767)] = 71499,
  [SMALL_STATE(1768)] = 71526,
  [SMALL_STATE(1769)] = 71551,
  [SMALL_STATE(1770)] = 71568,
  [SMALL_STATE(1771)] = 71595,
  [SMALL_STATE(1772)] = 71612,
  [SMALL_STATE(1773)] = 71645,
  [SMALL_STATE(1774)] = 71662,
  [SMALL_STATE(1775)] = 71679,
  [SMALL_STATE(1776)] = 71712,
  [SMALL_STATE(1777)] = 71739,
  [SMALL_STATE(1778)] = 71756,
  [SMALL_STATE(1779)] = 71783,
  [SMALL_STATE(1780)] = 71816,
  [SMALL_STATE(1781)] = 71833,
  [SMALL_STATE(1782)] = 71850,
  [SMALL_STATE(1783)] = 71877,
  [SMALL_STATE(1784)] = 71894,
  [SMALL_STATE(1785)] = 71921,
  [SMALL_STATE(1786)] = 71946,
  [SMALL_STATE(1787)] = 71963,
  [SMALL_STATE(1788)] = 71990,
  [SMALL_STATE(1789)] = 72014,
  [SMALL_STATE(1790)] = 72038,
  [SMALL_STATE(1791)] = 72062,
  [SMALL_STATE(1792)] = 72086,
  [SMALL_STATE(1793)] = 72110,
  [SMALL_STATE(1794)] = 72134,
  [SMALL_STATE(1795)] = 72150,
  [SMALL_STATE(1796)] = 72174,
  [SMALL_STATE(1797)] = 72198,
  [SMALL_STATE(1798)] = 72222,
  [SMALL_STATE(1799)] = 72246,
  [SMALL_STATE(1800)] = 72270,
  [SMALL_STATE(1801)] = 72296,
  [SMALL_STATE(1802)] = 72320,
  [SMALL_STATE(1803)] = 72344,
  [SMALL_STATE(1804)] = 72368,
  [SMALL_STATE(1805)] = 72392,
  [SMALL_STATE(1806)] = 72416,
  [SMALL_STATE(1807)] = 72440,
  [SMALL_STATE(1808)] = 72464,
  [SMALL_STATE(1809)] = 72488,
  [SMALL_STATE(1810)] = 72512,
  [SMALL_STATE(1811)] = 72536,
  [SMALL_STATE(1812)] = 72560,
  [SMALL_STATE(1813)] = 72584,
  [SMALL_STATE(1814)] = 72608,
  [SMALL_STATE(1815)] = 72632,
  [SMALL_STATE(1816)] = 72656,
  [SMALL_STATE(1817)] = 72680,
  [SMALL_STATE(1818)] = 72704,
  [SMALL_STATE(1819)] = 72728,
  [SMALL_STATE(1820)] = 72752,
  [SMALL_STATE(1821)] = 72776,
  [SMALL_STATE(1822)] = 72800,
  [SMALL_STATE(1823)] = 72824,
  [SMALL_STATE(1824)] = 72848,
  [SMALL_STATE(1825)] = 72872,
  [SMALL_STATE(1826)] = 72896,
  [SMALL_STATE(1827)] = 72920,
  [SMALL_STATE(1828)] = 72944,
  [SMALL_STATE(1829)] = 72968,
  [SMALL_STATE(1830)] = 72992,
  [SMALL_STATE(1831)] = 73016,
  [SMALL_STATE(1832)] = 73040,
  [SMALL_STATE(1833)] = 73064,
  [SMALL_STATE(1834)] = 73088,
  [SMALL_STATE(1835)] = 73112,
  [SMALL_STATE(1836)] = 73136,
  [SMALL_STATE(1837)] = 73160,
  [SMALL_STATE(1838)] = 73184,
  [SMALL_STATE(1839)] = 73208,
  [SMALL_STATE(1840)] = 73232,
  [SMALL_STATE(1841)] = 73256,
  [SMALL_STATE(1842)] = 73280,
  [SMALL_STATE(1843)] = 73304,
  [SMALL_STATE(1844)] = 73328,
  [SMALL_STATE(1845)] = 73352,
  [SMALL_STATE(1846)] = 73376,
  [SMALL_STATE(1847)] = 73400,
  [SMALL_STATE(1848)] = 73424,
  [SMALL_STATE(1849)] = 73448,
  [SMALL_STATE(1850)] = 73472,
  [SMALL_STATE(1851)] = 73502,
  [SMALL_STATE(1852)] = 73526,
  [SMALL_STATE(1853)] = 73550,
  [SMALL_STATE(1854)] = 73574,
  [SMALL_STATE(1855)] = 73598,
  [SMALL_STATE(1856)] = 73622,
  [SMALL_STATE(1857)] = 73646,
  [SMALL_STATE(1858)] = 73670,
  [SMALL_STATE(1859)] = 73694,
  [SMALL_STATE(1860)] = 73718,
  [SMALL_STATE(1861)] = 73742,
  [SMALL_STATE(1862)] = 73766,
  [SMALL_STATE(1863)] = 73790,
  [SMALL_STATE(1864)] = 73807,
  [SMALL_STATE(1865)] = 73826,
  [SMALL_STATE(1866)] = 73849,
  [SMALL_STATE(1867)] = 73868,
  [SMALL_STATE(1868)] = 73891,
  [SMALL_STATE(1869)] = 73914,
  [SMALL_STATE(1870)] = 73937,
  [SMALL_STATE(1871)] = 73956,
  [SMALL_STATE(1872)] = 73979,
  [SMALL_STATE(1873)] = 73998,
  [SMALL_STATE(1874)] = 74021,
  [SMALL_STATE(1875)] = 74044,
  [SMALL_STATE(1876)] = 74067,
  [SMALL_STATE(1877)] = 74088,
  [SMALL_STATE(1878)] = 74111,
  [SMALL_STATE(1879)] = 74136,
  [SMALL_STATE(1880)] = 74157,
  [SMALL_STATE(1881)] = 74182,
  [SMALL_STATE(1882)] = 74205,
  [SMALL_STATE(1883)] = 74225,
  [SMALL_STATE(1884)] = 74241,
  [SMALL_STATE(1885)] = 74259,
  [SMALL_STATE(1886)] = 74277,
  [SMALL_STATE(1887)] = 74293,
  [SMALL_STATE(1888)] = 74315,
  [SMALL_STATE(1889)] = 74335,
  [SMALL_STATE(1890)] = 74353,
  [SMALL_STATE(1891)] = 74373,
  [SMALL_STATE(1892)] = 74389,
  [SMALL_STATE(1893)] = 74409,
  [SMALL_STATE(1894)] = 74431,
  [SMALL_STATE(1895)] = 74447,
  [SMALL_STATE(1896)] = 74465,
  [SMALL_STATE(1897)] = 74483,
  [SMALL_STATE(1898)] = 74501,
  [SMALL_STATE(1899)] = 74517,
  [SMALL_STATE(1900)] = 74535,
  [SMALL_STATE(1901)] = 74553,
  [SMALL_STATE(1902)] = 74577,
  [SMALL_STATE(1903)] = 74601,
  [SMALL_STATE(1904)] = 74623,
  [SMALL_STATE(1905)] = 74641,
  [SMALL_STATE(1906)] = 74659,
  [SMALL_STATE(1907)] = 74677,
  [SMALL_STATE(1908)] = 74695,
  [SMALL_STATE(1909)] = 74711,
  [SMALL_STATE(1910)] = 74732,
  [SMALL_STATE(1911)] = 74749,
  [SMALL_STATE(1912)] = 74762,
  [SMALL_STATE(1913)] = 74783,
  [SMALL_STATE(1914)] = 74796,
  [SMALL_STATE(1915)] = 74809,
  [SMALL_STATE(1916)] = 74826,
  [SMALL_STATE(1917)] = 74841,
  [SMALL_STATE(1918)] = 74858,
  [SMALL_STATE(1919)] = 74873,
  [SMALL_STATE(1920)] = 74886,
  [SMALL_STATE(1921)] = 74899,
  [SMALL_STATE(1922)] = 74912,
  [SMALL_STATE(1923)] = 74929,
  [SMALL_STATE(1924)] = 74946,
  [SMALL_STATE(1925)] = 74959,
  [SMALL_STATE(1926)] = 74972,
  [SMALL_STATE(1927)] = 74987,
  [SMALL_STATE(1928)] = 75004,
  [SMALL_STATE(1929)] = 75025,
  [SMALL_STATE(1930)] = 75040,
  [SMALL_STATE(1931)] = 75061,
  [SMALL_STATE(1932)] = 75074,
  [SMALL_STATE(1933)] = 75091,
  [SMALL_STATE(1934)] = 75106,
  [SMALL_STATE(1935)] = 75121,
  [SMALL_STATE(1936)] = 75136,
  [SMALL_STATE(1937)] = 75153,
  [SMALL_STATE(1938)] = 75170,
  [SMALL_STATE(1939)] = 75183,
  [SMALL_STATE(1940)] = 75198,
  [SMALL_STATE(1941)] = 75219,
  [SMALL_STATE(1942)] = 75240,
  [SMALL_STATE(1943)] = 75253,
  [SMALL_STATE(1944)] = 75270,
  [SMALL_STATE(1945)] = 75287,
  [SMALL_STATE(1946)] = 75304,
  [SMALL_STATE(1947)] = 75317,
  [SMALL_STATE(1948)] = 75335,
  [SMALL_STATE(1949)] = 75353,
  [SMALL_STATE(1950)] = 75369,
  [SMALL_STATE(1951)] = 75383,
  [SMALL_STATE(1952)] = 75401,
  [SMALL_STATE(1953)] = 75419,
  [SMALL_STATE(1954)] = 75431,
  [SMALL_STATE(1955)] = 75449,
  [SMALL_STATE(1956)] = 75463,
  [SMALL_STATE(1957)] = 75481,
  [SMALL_STATE(1958)] = 75495,
  [SMALL_STATE(1959)] = 75511,
  [SMALL_STATE(1960)] = 75525,
  [SMALL_STATE(1961)] = 75543,
  [SMALL_STATE(1962)] = 75559,
  [SMALL_STATE(1963)] = 75573,
  [SMALL_STATE(1964)] = 75591,
  [SMALL_STATE(1965)] = 75609,
  [SMALL_STATE(1966)] = 75623,
  [SMALL_STATE(1967)] = 75641,
  [SMALL_STATE(1968)] = 75655,
  [SMALL_STATE(1969)] = 75673,
  [SMALL_STATE(1970)] = 75691,
  [SMALL_STATE(1971)] = 75705,
  [SMALL_STATE(1972)] = 75723,
  [SMALL_STATE(1973)] = 75741,
  [SMALL_STATE(1974)] = 75757,
  [SMALL_STATE(1975)] = 75771,
  [SMALL_STATE(1976)] = 75785,
  [SMALL_STATE(1977)] = 75803,
  [SMALL_STATE(1978)] = 75821,
  [SMALL_STATE(1979)] = 75839,
  [SMALL_STATE(1980)] = 75853,
  [SMALL_STATE(1981)] = 75871,
  [SMALL_STATE(1982)] = 75889,
  [SMALL_STATE(1983)] = 75903,
  [SMALL_STATE(1984)] = 75917,
  [SMALL_STATE(1985)] = 75935,
  [SMALL_STATE(1986)] = 75953,
  [SMALL_STATE(1987)] = 75965,
  [SMALL_STATE(1988)] = 75983,
  [SMALL_STATE(1989)] = 76001,
  [SMALL_STATE(1990)] = 76019,
  [SMALL_STATE(1991)] = 76037,
  [SMALL_STATE(1992)] = 76055,
  [SMALL_STATE(1993)] = 76073,
  [SMALL_STATE(1994)] = 76089,
  [SMALL_STATE(1995)] = 76105,
  [SMALL_STATE(1996)] = 76123,
  [SMALL_STATE(1997)] = 76141,
  [SMALL_STATE(1998)] = 76159,
  [SMALL_STATE(1999)] = 76171,
  [SMALL_STATE(2000)] = 76189,
  [SMALL_STATE(2001)] = 76207,
  [SMALL_STATE(2002)] = 76225,
  [SMALL_STATE(2003)] = 76243,
  [SMALL_STATE(2004)] = 76261,
  [SMALL_STATE(2005)] = 76279,
  [SMALL_STATE(2006)] = 76295,
  [SMALL_STATE(2007)] = 76307,
  [SMALL_STATE(2008)] = 76325,
  [SMALL_STATE(2009)] = 76343,
  [SMALL_STATE(2010)] = 76361,
  [SMALL_STATE(2011)] = 76379,
  [SMALL_STATE(2012)] = 76397,
  [SMALL_STATE(2013)] = 76415,
  [SMALL_STATE(2014)] = 76429,
  [SMALL_STATE(2015)] = 76443,
  [SMALL_STATE(2016)] = 76457,
  [SMALL_STATE(2017)] = 76471,
  [SMALL_STATE(2018)] = 76485,
  [SMALL_STATE(2019)] = 76503,
  [SMALL_STATE(2020)] = 76518,
  [SMALL_STATE(2021)] = 76535,
  [SMALL_STATE(2022)] = 76550,
  [SMALL_STATE(2023)] = 76567,
  [SMALL_STATE(2024)] = 76584,
  [SMALL_STATE(2025)] = 76597,
  [SMALL_STATE(2026)] = 76612,
  [SMALL_STATE(2027)] = 76627,
  [SMALL_STATE(2028)] = 76642,
  [SMALL_STATE(2029)] = 76657,
  [SMALL_STATE(2030)] = 76670,
  [SMALL_STATE(2031)] = 76685,
  [SMALL_STATE(2032)] = 76700,
  [SMALL_STATE(2033)] = 76711,
  [SMALL_STATE(2034)] = 76726,
  [SMALL_STATE(2035)] = 76741,
  [SMALL_STATE(2036)] = 76756,
  [SMALL_STATE(2037)] = 76771,
  [SMALL_STATE(2038)] = 76784,
  [SMALL_STATE(2039)] = 76799,
  [SMALL_STATE(2040)] = 76810,
  [SMALL_STATE(2041)] = 76827,
  [SMALL_STATE(2042)] = 76842,
  [SMALL_STATE(2043)] = 76857,
  [SMALL_STATE(2044)] = 76872,
  [SMALL_STATE(2045)] = 76887,
  [SMALL_STATE(2046)] = 76902,
  [SMALL_STATE(2047)] = 76919,
  [SMALL_STATE(2048)] = 76932,
  [SMALL_STATE(2049)] = 76947,
  [SMALL_STATE(2050)] = 76962,
  [SMALL_STATE(2051)] = 76977,
  [SMALL_STATE(2052)] = 76992,
  [SMALL_STATE(2053)] = 77007,
  [SMALL_STATE(2054)] = 77022,
  [SMALL_STATE(2055)] = 77037,
  [SMALL_STATE(2056)] = 77052,
  [SMALL_STATE(2057)] = 77067,
  [SMALL_STATE(2058)] = 77082,
  [SMALL_STATE(2059)] = 77099,
  [SMALL_STATE(2060)] = 77116,
  [SMALL_STATE(2061)] = 77133,
  [SMALL_STATE(2062)] = 77148,
  [SMALL_STATE(2063)] = 77159,
  [SMALL_STATE(2064)] = 77170,
  [SMALL_STATE(2065)] = 77185,
  [SMALL_STATE(2066)] = 77196,
  [SMALL_STATE(2067)] = 77209,
  [SMALL_STATE(2068)] = 77224,
  [SMALL_STATE(2069)] = 77239,
  [SMALL_STATE(2070)] = 77250,
  [SMALL_STATE(2071)] = 77265,
  [SMALL_STATE(2072)] = 77280,
  [SMALL_STATE(2073)] = 77295,
  [SMALL_STATE(2074)] = 77310,
  [SMALL_STATE(2075)] = 77321,
  [SMALL_STATE(2076)] = 77336,
  [SMALL_STATE(2077)] = 77351,
  [SMALL_STATE(2078)] = 77366,
  [SMALL_STATE(2079)] = 77381,
  [SMALL_STATE(2080)] = 77396,
  [SMALL_STATE(2081)] = 77411,
  [SMALL_STATE(2082)] = 77426,
  [SMALL_STATE(2083)] = 77441,
  [SMALL_STATE(2084)] = 77458,
  [SMALL_STATE(2085)] = 77473,
  [SMALL_STATE(2086)] = 77488,
  [SMALL_STATE(2087)] = 77503,
  [SMALL_STATE(2088)] = 77516,
  [SMALL_STATE(2089)] = 77527,
  [SMALL_STATE(2090)] = 77540,
  [SMALL_STATE(2091)] = 77553,
  [SMALL_STATE(2092)] = 77568,
  [SMALL_STATE(2093)] = 77583,
  [SMALL_STATE(2094)] = 77598,
  [SMALL_STATE(2095)] = 77611,
  [SMALL_STATE(2096)] = 77628,
  [SMALL_STATE(2097)] = 77645,
  [SMALL_STATE(2098)] = 77658,
  [SMALL_STATE(2099)] = 77671,
  [SMALL_STATE(2100)] = 77686,
  [SMALL_STATE(2101)] = 77701,
  [SMALL_STATE(2102)] = 77716,
  [SMALL_STATE(2103)] = 77731,
  [SMALL_STATE(2104)] = 77746,
  [SMALL_STATE(2105)] = 77761,
  [SMALL_STATE(2106)] = 77776,
  [SMALL_STATE(2107)] = 77789,
  [SMALL_STATE(2108)] = 77804,
  [SMALL_STATE(2109)] = 77819,
  [SMALL_STATE(2110)] = 77834,
  [SMALL_STATE(2111)] = 77847,
  [SMALL_STATE(2112)] = 77860,
  [SMALL_STATE(2113)] = 77875,
  [SMALL_STATE(2114)] = 77886,
  [SMALL_STATE(2115)] = 77899,
  [SMALL_STATE(2116)] = 77914,
  [SMALL_STATE(2117)] = 77931,
  [SMALL_STATE(2118)] = 77946,
  [SMALL_STATE(2119)] = 77961,
  [SMALL_STATE(2120)] = 77972,
  [SMALL_STATE(2121)] = 77987,
  [SMALL_STATE(2122)] = 78002,
  [SMALL_STATE(2123)] = 78015,
  [SMALL_STATE(2124)] = 78030,
  [SMALL_STATE(2125)] = 78047,
  [SMALL_STATE(2126)] = 78062,
  [SMALL_STATE(2127)] = 78079,
  [SMALL_STATE(2128)] = 78090,
  [SMALL_STATE(2129)] = 78101,
  [SMALL_STATE(2130)] = 78112,
  [SMALL_STATE(2131)] = 78127,
  [SMALL_STATE(2132)] = 78142,
  [SMALL_STATE(2133)] = 78157,
  [SMALL_STATE(2134)] = 78172,
  [SMALL_STATE(2135)] = 78187,
  [SMALL_STATE(2136)] = 78202,
  [SMALL_STATE(2137)] = 78217,
  [SMALL_STATE(2138)] = 78232,
  [SMALL_STATE(2139)] = 78247,
  [SMALL_STATE(2140)] = 78262,
  [SMALL_STATE(2141)] = 78275,
  [SMALL_STATE(2142)] = 78290,
  [SMALL_STATE(2143)] = 78302,
  [SMALL_STATE(2144)] = 78314,
  [SMALL_STATE(2145)] = 78324,
  [SMALL_STATE(2146)] = 78336,
  [SMALL_STATE(2147)] = 78348,
  [SMALL_STATE(2148)] = 78360,
  [SMALL_STATE(2149)] = 78372,
  [SMALL_STATE(2150)] = 78384,
  [SMALL_STATE(2151)] = 78396,
  [SMALL_STATE(2152)] = 78406,
  [SMALL_STATE(2153)] = 78418,
  [SMALL_STATE(2154)] = 78430,
  [SMALL_STATE(2155)] = 78442,
  [SMALL_STATE(2156)] = 78454,
  [SMALL_STATE(2157)] = 78464,
  [SMALL_STATE(2158)] = 78476,
  [SMALL_STATE(2159)] = 78488,
  [SMALL_STATE(2160)] = 78500,
  [SMALL_STATE(2161)] = 78512,
  [SMALL_STATE(2162)] = 78524,
  [SMALL_STATE(2163)] = 78536,
  [SMALL_STATE(2164)] = 78548,
  [SMALL_STATE(2165)] = 78560,
  [SMALL_STATE(2166)] = 78572,
  [SMALL_STATE(2167)] = 78584,
  [SMALL_STATE(2168)] = 78596,
  [SMALL_STATE(2169)] = 78608,
  [SMALL_STATE(2170)] = 78620,
  [SMALL_STATE(2171)] = 78632,
  [SMALL_STATE(2172)] = 78644,
  [SMALL_STATE(2173)] = 78654,
  [SMALL_STATE(2174)] = 78664,
  [SMALL_STATE(2175)] = 78676,
  [SMALL_STATE(2176)] = 78688,
  [SMALL_STATE(2177)] = 78700,
  [SMALL_STATE(2178)] = 78712,
  [SMALL_STATE(2179)] = 78724,
  [SMALL_STATE(2180)] = 78736,
  [SMALL_STATE(2181)] = 78746,
  [SMALL_STATE(2182)] = 78758,
  [SMALL_STATE(2183)] = 78770,
  [SMALL_STATE(2184)] = 78782,
  [SMALL_STATE(2185)] = 78792,
  [SMALL_STATE(2186)] = 78802,
  [SMALL_STATE(2187)] = 78814,
  [SMALL_STATE(2188)] = 78826,
  [SMALL_STATE(2189)] = 78838,
  [SMALL_STATE(2190)] = 78850,
  [SMALL_STATE(2191)] = 78860,
  [SMALL_STATE(2192)] = 78872,
  [SMALL_STATE(2193)] = 78884,
  [SMALL_STATE(2194)] = 78896,
  [SMALL_STATE(2195)] = 78908,
  [SMALL_STATE(2196)] = 78920,
  [SMALL_STATE(2197)] = 78930,
  [SMALL_STATE(2198)] = 78942,
  [SMALL_STATE(2199)] = 78954,
  [SMALL_STATE(2200)] = 78966,
  [SMALL_STATE(2201)] = 78978,
  [SMALL_STATE(2202)] = 78990,
  [SMALL_STATE(2203)] = 79002,
  [SMALL_STATE(2204)] = 79014,
  [SMALL_STATE(2205)] = 79026,
  [SMALL_STATE(2206)] = 79038,
  [SMALL_STATE(2207)] = 79050,
  [SMALL_STATE(2208)] = 79062,
  [SMALL_STATE(2209)] = 79074,
  [SMALL_STATE(2210)] = 79086,
  [SMALL_STATE(2211)] = 79098,
  [SMALL_STATE(2212)] = 79110,
  [SMALL_STATE(2213)] = 79122,
  [SMALL_STATE(2214)] = 79134,
  [SMALL_STATE(2215)] = 79146,
  [SMALL_STATE(2216)] = 79158,
  [SMALL_STATE(2217)] = 79170,
  [SMALL_STATE(2218)] = 79182,
  [SMALL_STATE(2219)] = 79194,
  [SMALL_STATE(2220)] = 79206,
  [SMALL_STATE(2221)] = 79218,
  [SMALL_STATE(2222)] = 79230,
  [SMALL_STATE(2223)] = 79242,
  [SMALL_STATE(2224)] = 79254,
  [SMALL_STATE(2225)] = 79266,
  [SMALL_STATE(2226)] = 79278,
  [SMALL_STATE(2227)] = 79290,
  [SMALL_STATE(2228)] = 79302,
  [SMALL_STATE(2229)] = 79314,
  [SMALL_STATE(2230)] = 79326,
  [SMALL_STATE(2231)] = 79338,
  [SMALL_STATE(2232)] = 79350,
  [SMALL_STATE(2233)] = 79362,
  [SMALL_STATE(2234)] = 79372,
  [SMALL_STATE(2235)] = 79384,
  [SMALL_STATE(2236)] = 79396,
  [SMALL_STATE(2237)] = 79408,
  [SMALL_STATE(2238)] = 79420,
  [SMALL_STATE(2239)] = 79432,
  [SMALL_STATE(2240)] = 79442,
  [SMALL_STATE(2241)] = 79454,
  [SMALL_STATE(2242)] = 79466,
  [SMALL_STATE(2243)] = 79478,
  [SMALL_STATE(2244)] = 79488,
  [SMALL_STATE(2245)] = 79500,
  [SMALL_STATE(2246)] = 79512,
  [SMALL_STATE(2247)] = 79522,
  [SMALL_STATE(2248)] = 79534,
  [SMALL_STATE(2249)] = 79546,
  [SMALL_STATE(2250)] = 79558,
  [SMALL_STATE(2251)] = 79570,
  [SMALL_STATE(2252)] = 79582,
  [SMALL_STATE(2253)] = 79594,
  [SMALL_STATE(2254)] = 79606,
  [SMALL_STATE(2255)] = 79618,
  [SMALL_STATE(2256)] = 79630,
  [SMALL_STATE(2257)] = 79642,
  [SMALL_STATE(2258)] = 79654,
  [SMALL_STATE(2259)] = 79666,
  [SMALL_STATE(2260)] = 79678,
  [SMALL_STATE(2261)] = 79690,
  [SMALL_STATE(2262)] = 79700,
  [SMALL_STATE(2263)] = 79712,
  [SMALL_STATE(2264)] = 79724,
  [SMALL_STATE(2265)] = 79736,
  [SMALL_STATE(2266)] = 79746,
  [SMALL_STATE(2267)] = 79758,
  [SMALL_STATE(2268)] = 79770,
  [SMALL_STATE(2269)] = 79782,
  [SMALL_STATE(2270)] = 79794,
  [SMALL_STATE(2271)] = 79806,
  [SMALL_STATE(2272)] = 79818,
  [SMALL_STATE(2273)] = 79830,
  [SMALL_STATE(2274)] = 79842,
  [SMALL_STATE(2275)] = 79854,
  [SMALL_STATE(2276)] = 79866,
  [SMALL_STATE(2277)] = 79876,
  [SMALL_STATE(2278)] = 79888,
  [SMALL_STATE(2279)] = 79900,
  [SMALL_STATE(2280)] = 79912,
  [SMALL_STATE(2281)] = 79924,
  [SMALL_STATE(2282)] = 79936,
  [SMALL_STATE(2283)] = 79948,
  [SMALL_STATE(2284)] = 79960,
  [SMALL_STATE(2285)] = 79972,
  [SMALL_STATE(2286)] = 79984,
  [SMALL_STATE(2287)] = 79996,
  [SMALL_STATE(2288)] = 80008,
  [SMALL_STATE(2289)] = 80020,
  [SMALL_STATE(2290)] = 80032,
  [SMALL_STATE(2291)] = 80044,
  [SMALL_STATE(2292)] = 80056,
  [SMALL_STATE(2293)] = 80068,
  [SMALL_STATE(2294)] = 80080,
  [SMALL_STATE(2295)] = 80092,
  [SMALL_STATE(2296)] = 80104,
  [SMALL_STATE(2297)] = 80116,
  [SMALL_STATE(2298)] = 80128,
  [SMALL_STATE(2299)] = 80140,
  [SMALL_STATE(2300)] = 80152,
  [SMALL_STATE(2301)] = 80164,
  [SMALL_STATE(2302)] = 80176,
  [SMALL_STATE(2303)] = 80186,
  [SMALL_STATE(2304)] = 80198,
  [SMALL_STATE(2305)] = 80210,
  [SMALL_STATE(2306)] = 80222,
  [SMALL_STATE(2307)] = 80234,
  [SMALL_STATE(2308)] = 80246,
  [SMALL_STATE(2309)] = 80258,
  [SMALL_STATE(2310)] = 80270,
  [SMALL_STATE(2311)] = 80282,
  [SMALL_STATE(2312)] = 80294,
  [SMALL_STATE(2313)] = 80306,
  [SMALL_STATE(2314)] = 80316,
  [SMALL_STATE(2315)] = 80328,
  [SMALL_STATE(2316)] = 80340,
  [SMALL_STATE(2317)] = 80352,
  [SMALL_STATE(2318)] = 80364,
  [SMALL_STATE(2319)] = 80374,
  [SMALL_STATE(2320)] = 80386,
  [SMALL_STATE(2321)] = 80398,
  [SMALL_STATE(2322)] = 80410,
  [SMALL_STATE(2323)] = 80422,
  [SMALL_STATE(2324)] = 80434,
  [SMALL_STATE(2325)] = 80446,
  [SMALL_STATE(2326)] = 80458,
  [SMALL_STATE(2327)] = 80470,
  [SMALL_STATE(2328)] = 80482,
  [SMALL_STATE(2329)] = 80494,
  [SMALL_STATE(2330)] = 80506,
  [SMALL_STATE(2331)] = 80518,
  [SMALL_STATE(2332)] = 80530,
  [SMALL_STATE(2333)] = 80539,
  [SMALL_STATE(2334)] = 80548,
  [SMALL_STATE(2335)] = 80557,
  [SMALL_STATE(2336)] = 80566,
  [SMALL_STATE(2337)] = 80575,
  [SMALL_STATE(2338)] = 80584,
  [SMALL_STATE(2339)] = 80593,
  [SMALL_STATE(2340)] = 80602,
  [SMALL_STATE(2341)] = 80611,
  [SMALL_STATE(2342)] = 80620,
  [SMALL_STATE(2343)] = 80629,
  [SMALL_STATE(2344)] = 80638,
  [SMALL_STATE(2345)] = 80647,
  [SMALL_STATE(2346)] = 80656,
  [SMALL_STATE(2347)] = 80665,
  [SMALL_STATE(2348)] = 80674,
  [SMALL_STATE(2349)] = 80683,
  [SMALL_STATE(2350)] = 80692,
  [SMALL_STATE(2351)] = 80701,
  [SMALL_STATE(2352)] = 80710,
  [SMALL_STATE(2353)] = 80719,
  [SMALL_STATE(2354)] = 80728,
  [SMALL_STATE(2355)] = 80737,
  [SMALL_STATE(2356)] = 80746,
  [SMALL_STATE(2357)] = 80755,
  [SMALL_STATE(2358)] = 80764,
  [SMALL_STATE(2359)] = 80773,
  [SMALL_STATE(2360)] = 80782,
  [SMALL_STATE(2361)] = 80791,
  [SMALL_STATE(2362)] = 80800,
  [SMALL_STATE(2363)] = 80809,
  [SMALL_STATE(2364)] = 80818,
  [SMALL_STATE(2365)] = 80827,
  [SMALL_STATE(2366)] = 80836,
  [SMALL_STATE(2367)] = 80845,
  [SMALL_STATE(2368)] = 80854,
  [SMALL_STATE(2369)] = 80863,
  [SMALL_STATE(2370)] = 80872,
  [SMALL_STATE(2371)] = 80881,
  [SMALL_STATE(2372)] = 80890,
  [SMALL_STATE(2373)] = 80899,
  [SMALL_STATE(2374)] = 80908,
  [SMALL_STATE(2375)] = 80917,
  [SMALL_STATE(2376)] = 80926,
  [SMALL_STATE(2377)] = 80935,
  [SMALL_STATE(2378)] = 80944,
  [SMALL_STATE(2379)] = 80953,
  [SMALL_STATE(2380)] = 80962,
  [SMALL_STATE(2381)] = 80971,
  [SMALL_STATE(2382)] = 80980,
  [SMALL_STATE(2383)] = 80989,
  [SMALL_STATE(2384)] = 80998,
  [SMALL_STATE(2385)] = 81007,
  [SMALL_STATE(2386)] = 81016,
  [SMALL_STATE(2387)] = 81025,
  [SMALL_STATE(2388)] = 81034,
  [SMALL_STATE(2389)] = 81043,
  [SMALL_STATE(2390)] = 81052,
  [SMALL_STATE(2391)] = 81061,
  [SMALL_STATE(2392)] = 81070,
  [SMALL_STATE(2393)] = 81079,
  [SMALL_STATE(2394)] = 81088,
  [SMALL_STATE(2395)] = 81097,
  [SMALL_STATE(2396)] = 81106,
  [SMALL_STATE(2397)] = 81115,
  [SMALL_STATE(2398)] = 81124,
  [SMALL_STATE(2399)] = 81133,
  [SMALL_STATE(2400)] = 81142,
  [SMALL_STATE(2401)] = 81151,
  [SMALL_STATE(2402)] = 81160,
  [SMALL_STATE(2403)] = 81169,
  [SMALL_STATE(2404)] = 81178,
  [SMALL_STATE(2405)] = 81187,
  [SMALL_STATE(2406)] = 81196,
  [SMALL_STATE(2407)] = 81205,
  [SMALL_STATE(2408)] = 81214,
  [SMALL_STATE(2409)] = 81223,
  [SMALL_STATE(2410)] = 81232,
  [SMALL_STATE(2411)] = 81241,
  [SMALL_STATE(2412)] = 81250,
  [SMALL_STATE(2413)] = 81259,
  [SMALL_STATE(2414)] = 81268,
  [SMALL_STATE(2415)] = 81277,
  [SMALL_STATE(2416)] = 81286,
  [SMALL_STATE(2417)] = 81295,
  [SMALL_STATE(2418)] = 81304,
  [SMALL_STATE(2419)] = 81313,
  [SMALL_STATE(2420)] = 81322,
  [SMALL_STATE(2421)] = 81331,
  [SMALL_STATE(2422)] = 81340,
  [SMALL_STATE(2423)] = 81349,
  [SMALL_STATE(2424)] = 81358,
  [SMALL_STATE(2425)] = 81367,
  [SMALL_STATE(2426)] = 81376,
  [SMALL_STATE(2427)] = 81385,
  [SMALL_STATE(2428)] = 81394,
  [SMALL_STATE(2429)] = 81403,
  [SMALL_STATE(2430)] = 81412,
  [SMALL_STATE(2431)] = 81421,
  [SMALL_STATE(2432)] = 81430,
  [SMALL_STATE(2433)] = 81439,
  [SMALL_STATE(2434)] = 81448,
  [SMALL_STATE(2435)] = 81457,
  [SMALL_STATE(2436)] = 81466,
  [SMALL_STATE(2437)] = 81475,
  [SMALL_STATE(2438)] = 81484,
  [SMALL_STATE(2439)] = 81493,
  [SMALL_STATE(2440)] = 81502,
  [SMALL_STATE(2441)] = 81511,
  [SMALL_STATE(2442)] = 81520,
  [SMALL_STATE(2443)] = 81529,
  [SMALL_STATE(2444)] = 81538,
  [SMALL_STATE(2445)] = 81547,
  [SMALL_STATE(2446)] = 81556,
  [SMALL_STATE(2447)] = 81565,
  [SMALL_STATE(2448)] = 81574,
  [SMALL_STATE(2449)] = 81583,
  [SMALL_STATE(2450)] = 81592,
  [SMALL_STATE(2451)] = 81601,
  [SMALL_STATE(2452)] = 81610,
  [SMALL_STATE(2453)] = 81619,
  [SMALL_STATE(2454)] = 81628,
  [SMALL_STATE(2455)] = 81637,
  [SMALL_STATE(2456)] = 81646,
  [SMALL_STATE(2457)] = 81655,
  [SMALL_STATE(2458)] = 81664,
  [SMALL_STATE(2459)] = 81673,
  [SMALL_STATE(2460)] = 81682,
  [SMALL_STATE(2461)] = 81691,
  [SMALL_STATE(2462)] = 81700,
  [SMALL_STATE(2463)] = 81709,
  [SMALL_STATE(2464)] = 81718,
  [SMALL_STATE(2465)] = 81727,
  [SMALL_STATE(2466)] = 81736,
  [SMALL_STATE(2467)] = 81745,
  [SMALL_STATE(2468)] = 81754,
  [SMALL_STATE(2469)] = 81763,
  [SMALL_STATE(2470)] = 81772,
  [SMALL_STATE(2471)] = 81781,
  [SMALL_STATE(2472)] = 81790,
  [SMALL_STATE(2473)] = 81799,
  [SMALL_STATE(2474)] = 81808,
  [SMALL_STATE(2475)] = 81817,
  [SMALL_STATE(2476)] = 81826,
  [SMALL_STATE(2477)] = 81835,
  [SMALL_STATE(2478)] = 81844,
  [SMALL_STATE(2479)] = 81853,
  [SMALL_STATE(2480)] = 81862,
  [SMALL_STATE(2481)] = 81871,
  [SMALL_STATE(2482)] = 81880,
  [SMALL_STATE(2483)] = 81889,
  [SMALL_STATE(2484)] = 81898,
  [SMALL_STATE(2485)] = 81907,
  [SMALL_STATE(2486)] = 81916,
  [SMALL_STATE(2487)] = 81925,
  [SMALL_STATE(2488)] = 81934,
  [SMALL_STATE(2489)] = 81943,
  [SMALL_STATE(2490)] = 81952,
  [SMALL_STATE(2491)] = 81961,
  [SMALL_STATE(2492)] = 81970,
  [SMALL_STATE(2493)] = 81979,
  [SMALL_STATE(2494)] = 81988,
  [SMALL_STATE(2495)] = 81997,
  [SMALL_STATE(2496)] = 82006,
  [SMALL_STATE(2497)] = 82015,
  [SMALL_STATE(2498)] = 82024,
  [SMALL_STATE(2499)] = 82033,
  [SMALL_STATE(2500)] = 82042,
  [SMALL_STATE(2501)] = 82051,
  [SMALL_STATE(2502)] = 82060,
  [SMALL_STATE(2503)] = 82069,
  [SMALL_STATE(2504)] = 82078,
  [SMALL_STATE(2505)] = 82087,
  [SMALL_STATE(2506)] = 82096,
  [SMALL_STATE(2507)] = 82105,
  [SMALL_STATE(2508)] = 82114,
  [SMALL_STATE(2509)] = 82123,
  [SMALL_STATE(2510)] = 82132,
  [SMALL_STATE(2511)] = 82141,
  [SMALL_STATE(2512)] = 82150,
  [SMALL_STATE(2513)] = 82159,
  [SMALL_STATE(2514)] = 82168,
  [SMALL_STATE(2515)] = 82177,
  [SMALL_STATE(2516)] = 82186,
  [SMALL_STATE(2517)] = 82195,
  [SMALL_STATE(2518)] = 82204,
  [SMALL_STATE(2519)] = 82213,
  [SMALL_STATE(2520)] = 82222,
  [SMALL_STATE(2521)] = 82231,
  [SMALL_STATE(2522)] = 82240,
  [SMALL_STATE(2523)] = 82249,
  [SMALL_STATE(2524)] = 82258,
  [SMALL_STATE(2525)] = 82267,
  [SMALL_STATE(2526)] = 82276,
  [SMALL_STATE(2527)] = 82285,
  [SMALL_STATE(2528)] = 82294,
  [SMALL_STATE(2529)] = 82303,
  [SMALL_STATE(2530)] = 82312,
  [SMALL_STATE(2531)] = 82321,
  [SMALL_STATE(2532)] = 82330,
  [SMALL_STATE(2533)] = 82339,
  [SMALL_STATE(2534)] = 82348,
  [SMALL_STATE(2535)] = 82357,
  [SMALL_STATE(2536)] = 82366,
  [SMALL_STATE(2537)] = 82375,
  [SMALL_STATE(2538)] = 82384,
  [SMALL_STATE(2539)] = 82393,
  [SMALL_STATE(2540)] = 82402,
  [SMALL_STATE(2541)] = 82411,
  [SMALL_STATE(2542)] = 82420,
  [SMALL_STATE(2543)] = 82429,
  [SMALL_STATE(2544)] = 82438,
  [SMALL_STATE(2545)] = 82447,
  [SMALL_STATE(2546)] = 82456,
  [SMALL_STATE(2547)] = 82465,
  [SMALL_STATE(2548)] = 82474,
  [SMALL_STATE(2549)] = 82483,
  [SMALL_STATE(2550)] = 82492,
  [SMALL_STATE(2551)] = 82501,
  [SMALL_STATE(2552)] = 82510,
  [SMALL_STATE(2553)] = 82519,
  [SMALL_STATE(2554)] = 82528,
  [SMALL_STATE(2555)] = 82537,
  [SMALL_STATE(2556)] = 82546,
  [SMALL_STATE(2557)] = 82555,
  [SMALL_STATE(2558)] = 82564,
  [SMALL_STATE(2559)] = 82573,
  [SMALL_STATE(2560)] = 82582,
  [SMALL_STATE(2561)] = 82591,
  [SMALL_STATE(2562)] = 82600,
  [SMALL_STATE(2563)] = 82609,
  [SMALL_STATE(2564)] = 82618,
  [SMALL_STATE(2565)] = 82627,
  [SMALL_STATE(2566)] = 82636,
  [SMALL_STATE(2567)] = 82645,
  [SMALL_STATE(2568)] = 82654,
  [SMALL_STATE(2569)] = 82663,
  [SMALL_STATE(2570)] = 82672,
  [SMALL_STATE(2571)] = 82681,
  [SMALL_STATE(2572)] = 82690,
  [SMALL_STATE(2573)] = 82699,
  [SMALL_STATE(2574)] = 82708,
  [SMALL_STATE(2575)] = 82717,
  [SMALL_STATE(2576)] = 82726,
  [SMALL_STATE(2577)] = 82735,
  [SMALL_STATE(2578)] = 82744,
  [SMALL_STATE(2579)] = 82753,
  [SMALL_STATE(2580)] = 82762,
  [SMALL_STATE(2581)] = 82771,
  [SMALL_STATE(2582)] = 82780,
  [SMALL_STATE(2583)] = 82789,
  [SMALL_STATE(2584)] = 82798,
  [SMALL_STATE(2585)] = 82807,
  [SMALL_STATE(2586)] = 82816,
  [SMALL_STATE(2587)] = 82825,
  [SMALL_STATE(2588)] = 82834,
  [SMALL_STATE(2589)] = 82843,
  [SMALL_STATE(2590)] = 82852,
  [SMALL_STATE(2591)] = 82861,
  [SMALL_STATE(2592)] = 82870,
  [SMALL_STATE(2593)] = 82879,
  [SMALL_STATE(2594)] = 82888,
  [SMALL_STATE(2595)] = 82897,
  [SMALL_STATE(2596)] = 82906,
  [SMALL_STATE(2597)] = 82915,
  [SMALL_STATE(2598)] = 82924,
  [SMALL_STATE(2599)] = 82933,
  [SMALL_STATE(2600)] = 82942,
  [SMALL_STATE(2601)] = 82951,
  [SMALL_STATE(2602)] = 82960,
  [SMALL_STATE(2603)] = 82969,
  [SMALL_STATE(2604)] = 82978,
  [SMALL_STATE(2605)] = 82987,
  [SMALL_STATE(2606)] = 82996,
  [SMALL_STATE(2607)] = 83005,
  [SMALL_STATE(2608)] = 83014,
  [SMALL_STATE(2609)] = 83023,
  [SMALL_STATE(2610)] = 83032,
  [SMALL_STATE(2611)] = 83041,
  [SMALL_STATE(2612)] = 83050,
  [SMALL_STATE(2613)] = 83059,
  [SMALL_STATE(2614)] = 83068,
  [SMALL_STATE(2615)] = 83077,
  [SMALL_STATE(2616)] = 83086,
  [SMALL_STATE(2617)] = 83095,
  [SMALL_STATE(2618)] = 83104,
  [SMALL_STATE(2619)] = 83113,
  [SMALL_STATE(2620)] = 83122,
  [SMALL_STATE(2621)] = 83131,
  [SMALL_STATE(2622)] = 83140,
  [SMALL_STATE(2623)] = 83149,
  [SMALL_STATE(2624)] = 83158,
  [SMALL_STATE(2625)] = 83167,
  [SMALL_STATE(2626)] = 83176,
  [SMALL_STATE(2627)] = 83185,
  [SMALL_STATE(2628)] = 83194,
  [SMALL_STATE(2629)] = 83203,
  [SMALL_STATE(2630)] = 83212,
  [SMALL_STATE(2631)] = 83221,
  [SMALL_STATE(2632)] = 83230,
  [SMALL_STATE(2633)] = 83239,
  [SMALL_STATE(2634)] = 83248,
  [SMALL_STATE(2635)] = 83257,
  [SMALL_STATE(2636)] = 83266,
  [SMALL_STATE(2637)] = 83275,
  [SMALL_STATE(2638)] = 83284,
  [SMALL_STATE(2639)] = 83293,
  [SMALL_STATE(2640)] = 83302,
  [SMALL_STATE(2641)] = 83311,
  [SMALL_STATE(2642)] = 83320,
  [SMALL_STATE(2643)] = 83329,
  [SMALL_STATE(2644)] = 83338,
  [SMALL_STATE(2645)] = 83347,
  [SMALL_STATE(2646)] = 83356,
  [SMALL_STATE(2647)] = 83365,
  [SMALL_STATE(2648)] = 83374,
  [SMALL_STATE(2649)] = 83383,
  [SMALL_STATE(2650)] = 83392,
  [SMALL_STATE(2651)] = 83401,
  [SMALL_STATE(2652)] = 83410,
  [SMALL_STATE(2653)] = 83419,
  [SMALL_STATE(2654)] = 83428,
  [SMALL_STATE(2655)] = 83437,
  [SMALL_STATE(2656)] = 83446,
  [SMALL_STATE(2657)] = 83455,
  [SMALL_STATE(2658)] = 83464,
  [SMALL_STATE(2659)] = 83473,
  [SMALL_STATE(2660)] = 83482,
  [SMALL_STATE(2661)] = 83491,
  [SMALL_STATE(2662)] = 83500,
  [SMALL_STATE(2663)] = 83509,
  [SMALL_STATE(2664)] = 83518,
  [SMALL_STATE(2665)] = 83527,
  [SMALL_STATE(2666)] = 83536,
  [SMALL_STATE(2667)] = 83545,
  [SMALL_STATE(2668)] = 83554,
  [SMALL_STATE(2669)] = 83563,
  [SMALL_STATE(2670)] = 83572,
  [SMALL_STATE(2671)] = 83581,
  [SMALL_STATE(2672)] = 83590,
  [SMALL_STATE(2673)] = 83599,
  [SMALL_STATE(2674)] = 83608,
  [SMALL_STATE(2675)] = 83617,
  [SMALL_STATE(2676)] = 83626,
  [SMALL_STATE(2677)] = 83635,
  [SMALL_STATE(2678)] = 83644,
  [SMALL_STATE(2679)] = 83653,
  [SMALL_STATE(2680)] = 83662,
  [SMALL_STATE(2681)] = 83671,
  [SMALL_STATE(2682)] = 83680,
  [SMALL_STATE(2683)] = 83689,
  [SMALL_STATE(2684)] = 83698,
  [SMALL_STATE(2685)] = 83707,
  [SMALL_STATE(2686)] = 83716,
  [SMALL_STATE(2687)] = 83725,
  [SMALL_STATE(2688)] = 83734,
  [SMALL_STATE(2689)] = 83743,
  [SMALL_STATE(2690)] = 83752,
  [SMALL_STATE(2691)] = 83761,
  [SMALL_STATE(2692)] = 83770,
  [SMALL_STATE(2693)] = 83779,
  [SMALL_STATE(2694)] = 83788,
  [SMALL_STATE(2695)] = 83797,
  [SMALL_STATE(2696)] = 83806,
  [SMALL_STATE(2697)] = 83815,
  [SMALL_STATE(2698)] = 83824,
  [SMALL_STATE(2699)] = 83833,
  [SMALL_STATE(2700)] = 83842,
  [SMALL_STATE(2701)] = 83851,
  [SMALL_STATE(2702)] = 83860,
  [SMALL_STATE(2703)] = 83869,
  [SMALL_STATE(2704)] = 83878,
  [SMALL_STATE(2705)] = 83887,
  [SMALL_STATE(2706)] = 83896,
  [SMALL_STATE(2707)] = 83905,
  [SMALL_STATE(2708)] = 83914,
  [SMALL_STATE(2709)] = 83923,
  [SMALL_STATE(2710)] = 83932,
  [SMALL_STATE(2711)] = 83941,
  [SMALL_STATE(2712)] = 83950,
  [SMALL_STATE(2713)] = 83959,
  [SMALL_STATE(2714)] = 83968,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_root, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1874),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2497),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(531),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1737),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2520),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2396),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finalization, 1, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2632),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initialization, 1, 0, 0),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifTr, 3, 0, 25),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_whileTr, 3, 0, 25),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_withTr, 3, 0, 29),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifElseTr, 4, 0, 25),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_withTr, 4, 0, 59),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_forTr, 5, 0, 84),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreachTr, 5, 0, 85),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifElseTr, 5, 0, 50),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1717),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1716),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1690),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2523),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2532),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2703),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2713),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exceptionHandlerTr, 5, 0, 159),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caseCaseTr, 1, 0, 57),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exceptionHandlerTr, 3, 0, 13),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprTpl, 4, 0, 47),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprTpl, 4, 0, 47),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprTpl, 5, 0, 82),
  [279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprTpl, 5, 0, 82),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 109),
  [313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 109),
  [315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 109), SHIFT(597),
  [318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2128),
  [320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2017),
  [324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 164),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 164),
  [338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 164), SHIFT(597),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 95),
  [343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 95),
  [345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 95), SHIFT(597),
  [348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 165),
  [350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 165),
  [352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 165), SHIFT(597),
  [355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 94),
  [357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 94),
  [359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 94), SHIFT(597),
  [362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 163),
  [364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 163),
  [366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 163), SHIFT(597),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 191),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 191),
  [373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 191), SHIFT(597),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 130),
  [378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 130),
  [380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 130), SHIFT(597),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 192),
  [385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 192),
  [387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 192), SHIFT(597),
  [390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 193),
  [392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 193),
  [394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 193), SHIFT(597),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 71),
  [399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 71),
  [401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 71), SHIFT(597),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 9, 0, 217),
  [406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 9, 0, 217),
  [408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 9, 0, 217), SHIFT(597),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 131),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 131),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 131), SHIFT(597),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 132),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 132),
  [422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 132), SHIFT(597),
  [425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 130),
  [427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 130),
  [429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 130), SHIFT(597),
  [432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 4, 0, 61),
  [434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 4, 0, 61),
  [436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 4, 0, 61), SHIFT(597),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 95),
  [441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 95),
  [443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 95), SHIFT(597),
  [446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 129),
  [448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 129),
  [450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 129), SHIFT(597),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 161),
  [455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 161),
  [457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 161), SHIFT(597),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 71),
  [462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 71),
  [464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 71), SHIFT(597),
  [467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41),
  [471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(597),
  [474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(2128),
  [477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(1010),
  [480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(2017),
  [483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(668),
  [486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(814),
  [489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(698),
  [492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(2653),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 93),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 93),
  [502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 93), SHIFT(597),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 162),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 162),
  [509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 162), SHIFT(597),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 61),
  [514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 61),
  [516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 61), SHIFT(597),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 128),
  [521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 128),
  [523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 128), SHIFT(597),
  [526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 64),
  [528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 4, 0, 64),
  [530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 64), SHIFT(597),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 94),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 5, 0, 94),
  [537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 94), SHIFT(597),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(597),
  [547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(2128),
  [550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(1010),
  [553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(2017),
  [556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(814),
  [559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(698),
  [562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(2653),
  [568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 96),
  [570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 5, 0, 96),
  [572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 96), SHIFT(597),
  [575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 5, 0, 71),
  [577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 5, 0, 71),
  [579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 71), SHIFT(597),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 4, 0, 61),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 4, 0, 61),
  [586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 4, 0, 61), SHIFT(597),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 5, 0, 93),
  [591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 5, 0, 93),
  [593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 93), SHIFT(597),
  [596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procExternal, 5, 0, 0),
  [598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procExternal, 5, 0, 0),
  [600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 7, 0, 162),
  [602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 7, 0, 162),
  [604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 7, 0, 162), SHIFT(597),
  [607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 7, 0, 166),
  [609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 7, 0, 166),
  [611] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 166), SHIFT(597),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 7, 0, 174),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 7, 0, 174),
  [618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 174), SHIFT(597),
  [621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 7, 0, 141),
  [623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 7, 0, 141),
  [625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 141), SHIFT(597),
  [628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procExternal, 3, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procExternal, 3, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 8, 0, 199),
  [634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 8, 0, 199),
  [636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 8, 0, 199), SHIFT(597),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 3, 0, 31),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 3, 0, 31),
  [643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 3, 0, 31), SHIFT(597),
  [646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(1176),
  [649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(110),
  [652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(41),
  [673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(1869),
  [676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(2497),
  [679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(697),
  [691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(909),
  [694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(920),
  [697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(32),
  [700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(923),
  [706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(924),
  [709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(2562),
  [715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procExternal, 2, 0, 0),
  [726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procExternal, 2, 0, 0),
  [728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 63),
  [730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 4, 0, 63),
  [732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 63), SHIFT(597),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procExternal, 4, 0, 0),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procExternal, 4, 0, 0),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 128),
  [761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 6, 0, 128),
  [763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 128), SHIFT(597),
  [766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 129),
  [768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConst, 6, 0, 129),
  [770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 129), SHIFT(597),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 6, 0, 134),
  [775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 6, 0, 134),
  [777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 134), SHIFT(597),
  [780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 6, 0, 109),
  [782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 6, 0, 109),
  [784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 109), SHIFT(597),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 6, 0, 139),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 6, 0, 139),
  [791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 139), SHIFT(597),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 6, 0, 102),
  [796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 6, 0, 102),
  [798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 102), SHIFT(597),
  [801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procExternal, 6, 0, 0),
  [803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procExternal, 6, 0, 0),
  [805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declType, 5, 0, 100),
  [807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declType, 5, 0, 100),
  [809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 100), SHIFT(597),
  [812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcFwd, 2, 0, 1),
  [814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProcFwd, 2, 0, 1), SHIFT(597),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProcFwd, 2, 0, 1),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(128),
  [837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(41),
  [858] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(1869),
  [861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(2497),
  [864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(697),
  [876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(909),
  [879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(920),
  [882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(32),
  [885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(923),
  [891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(924),
  [894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(2562),
  [900] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 4, 0, 61), SHIFT(598),
  [909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 4, 0, 61), SHIFT(2017),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcFwd, 3, 0, 1),
  [916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProcFwd, 3, 0, 1), SHIFT(597),
  [919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProcFwd, 3, 0, 1),
  [921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcFwd, 3, 0, 18),
  [923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProcFwd, 3, 0, 18), SHIFT(597),
  [926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProcFwd, 3, 0, 18),
  [928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 93), SHIFT(598),
  [931] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 93), SHIFT(2017),
  [934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 94), SHIFT(598),
  [937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 94), SHIFT(2017),
  [940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 71), SHIFT(598),
  [943] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 71), SHIFT(2017),
  [946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 5, 0, 95), SHIFT(598),
  [949] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 5, 0, 95), SHIFT(2017),
  [952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(598),
  [955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 2, 0, 41), SHIFT_REPEAT(660),
  [958] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 61), SHIFT(598),
  [961] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 61), SHIFT(2017),
  [964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 128), SHIFT(598),
  [967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 128), SHIFT(2017),
  [970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 109), SHIFT(598),
  [973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 109), SHIFT(2017),
  [976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 129), SHIFT(598),
  [979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 129), SHIFT(2017),
  [982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 130), SHIFT(598),
  [985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 130), SHIFT(2017),
  [988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 131), SHIFT(598),
  [991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 131), SHIFT(2017),
  [994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 6, 0, 132), SHIFT(598),
  [997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 6, 0, 132), SHIFT(2017),
  [1000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 161), SHIFT(598),
  [1003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 161), SHIFT(2017),
  [1006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 71), SHIFT(598),
  [1009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 71), SHIFT(2017),
  [1012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 162), SHIFT(598),
  [1015] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 162), SHIFT(2017),
  [1018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 163), SHIFT(598),
  [1021] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 163), SHIFT(2017),
  [1024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 164), SHIFT(598),
  [1027] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 164), SHIFT(2017),
  [1030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 95), SHIFT(598),
  [1033] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 95), SHIFT(2017),
  [1036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 7, 0, 165), SHIFT(598),
  [1039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 7, 0, 165), SHIFT(2017),
  [1042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 191), SHIFT(598),
  [1045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 191), SHIFT(2017),
  [1048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 130), SHIFT(598),
  [1051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 130), SHIFT(2017),
  [1054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 192), SHIFT(598),
  [1057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 192), SHIFT(2017),
  [1060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 8, 0, 193), SHIFT(598),
  [1063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 8, 0, 193), SHIFT(2017),
  [1066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVar, 9, 0, 217), SHIFT(598),
  [1069] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declVar, 9, 0, 217), SHIFT(2017),
  [1072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcFwd, 4, 0, 38),
  [1074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProcFwd, 4, 0, 38), SHIFT(597),
  [1077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProcFwd, 4, 0, 38),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(923),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2562),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [1105] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 151), SHIFT(618),
  [1108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 151),
  [1110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 151),
  [1112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 112), SHIFT(618),
  [1115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 112),
  [1117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 112),
  [1119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 69), SHIFT(618),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 69),
  [1124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 69),
  [1126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 70), SHIFT(618),
  [1129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 70),
  [1131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 70),
  [1133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(618),
  [1136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41),
  [1138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41),
  [1140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(2128),
  [1143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(1010),
  [1146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(2017),
  [1149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(814),
  [1152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(698),
  [1155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [1158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(2653),
  [1161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 71), SHIFT(618),
  [1164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 71),
  [1166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 71),
  [1168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 72), SHIFT(618),
  [1171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 72),
  [1173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 72),
  [1175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 73), SHIFT(618),
  [1178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 73),
  [1180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 73),
  [1182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 74), SHIFT(618),
  [1185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 74),
  [1187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 74),
  [1189] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 141), SHIFT(618),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 141),
  [1194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 141),
  [1196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 142), SHIFT(618),
  [1199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 142),
  [1201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 142),
  [1203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 143), SHIFT(618),
  [1206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 143),
  [1208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 143),
  [1210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 144), SHIFT(618),
  [1213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 144),
  [1215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 144),
  [1217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 146), SHIFT(618),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 146),
  [1222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 146),
  [1224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 147), SHIFT(618),
  [1227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 147),
  [1229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 147),
  [1231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 148), SHIFT(618),
  [1234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 148),
  [1236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 148),
  [1238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 149), SHIFT(618),
  [1241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 149),
  [1243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 149),
  [1245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 150), SHIFT(618),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 150),
  [1250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 150),
  [1252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 152), SHIFT(618),
  [1255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 152),
  [1257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 7, 0, 152),
  [1259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blockTr, 2, 0, 0),
  [1261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blockTr, 2, 0, 0),
  [1263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 34), SHIFT(618),
  [1266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 34),
  [1268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 4, 0, 34),
  [1270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 35), SHIFT(618),
  [1273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 35),
  [1275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 4, 0, 35),
  [1277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declVar_repeat1, 1, 0, 17),
  [1279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declVar_repeat1, 1, 0, 17),
  [1281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 67), SHIFT(618),
  [1284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 67),
  [1286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 67),
  [1288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 68), SHIFT(618),
  [1291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 68),
  [1293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 5, 0, 68),
  [1295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 102), SHIFT(618),
  [1298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 102),
  [1300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 102),
  [1302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 175), SHIFT(618),
  [1305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 175),
  [1307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 175),
  [1309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 176), SHIFT(618),
  [1312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 176),
  [1314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 176),
  [1316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 177), SHIFT(618),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 177),
  [1321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 177),
  [1323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 181), SHIFT(618),
  [1326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 181),
  [1328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 181),
  [1330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 182), SHIFT(618),
  [1333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 182),
  [1335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 182),
  [1337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 183), SHIFT(618),
  [1340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 183),
  [1342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 183),
  [1344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 184), SHIFT(618),
  [1347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 184),
  [1349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 184),
  [1351] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 185), SHIFT(618),
  [1354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 185),
  [1356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 8, 0, 185),
  [1358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 33), SHIFT(618),
  [1361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 33),
  [1363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 4, 0, 33),
  [1365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 103), SHIFT(618),
  [1368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 103),
  [1370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 103),
  [1372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 104), SHIFT(618),
  [1375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 104),
  [1377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 104),
  [1379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 105), SHIFT(618),
  [1382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 105),
  [1384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 105),
  [1386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 106), SHIFT(618),
  [1389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 106),
  [1391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 106),
  [1393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 200), SHIFT(618),
  [1396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 200),
  [1398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 9, 0, 200),
  [1400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 204), SHIFT(618),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 204),
  [1405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 9, 0, 204),
  [1407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 205), SHIFT(618),
  [1410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 205),
  [1412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 9, 0, 205),
  [1414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 206), SHIFT(618),
  [1417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 206),
  [1419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 9, 0, 206),
  [1421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 107), SHIFT(618),
  [1424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 107),
  [1426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 107),
  [1428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 10, 0, 224), SHIFT(618),
  [1431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 10, 0, 224),
  [1433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 10, 0, 224),
  [1435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttribute, 2, 0, 40),
  [1437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttribute, 2, 0, 40),
  [1439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttribute, 3, 0, 0),
  [1441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttribute, 3, 0, 0),
  [1443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttribute, 4, 0, 119),
  [1445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttribute, 4, 0, 119),
  [1447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 3, 0, 14), SHIFT(618),
  [1450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 3, 0, 14),
  [1452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 3, 0, 14),
  [1454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 108), SHIFT(618),
  [1457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 108),
  [1459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 108),
  [1461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 109), SHIFT(618),
  [1464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 109),
  [1466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 109),
  [1468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blockTr, 3, 0, 0),
  [1470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blockTr, 3, 0, 0),
  [1472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 32), SHIFT(618),
  [1475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 32),
  [1477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 4, 0, 32),
  [1479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttribute, 5, 0, 158),
  [1481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttribute, 5, 0, 158),
  [1483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 110), SHIFT(618),
  [1486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 110),
  [1488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 110),
  [1490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 111), SHIFT(618),
  [1493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 111),
  [1495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declProc, 6, 0, 111),
  [1497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 63), SHIFT(598),
  [1500] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 4, 0, 63), SHIFT(2017),
  [1503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 8, 0, 199), SHIFT(598),
  [1506] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 8, 0, 199), SHIFT(2017),
  [1509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProcFwd_repeat1, 1, 0, 17),
  [1511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declProcFwd_repeat1, 1, 0, 17),
  [1513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 3, 0, 31), SHIFT(598),
  [1516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 3, 0, 31), SHIFT(2017),
  [1519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProcFwd_repeat1, 2, 0, 41), SHIFT_REPEAT(598),
  [1522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 4, 0, 64), SHIFT(598),
  [1525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 4, 0, 64), SHIFT(2017),
  [1528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 4, 0, 61), SHIFT(598),
  [1531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 4, 0, 61), SHIFT(2017),
  [1534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 94), SHIFT(598),
  [1537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 5, 0, 94), SHIFT(2017),
  [1540] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 5, 0, 96), SHIFT(598),
  [1543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 5, 0, 96), SHIFT(2017),
  [1546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 71), SHIFT(598),
  [1549] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 5, 0, 71), SHIFT(2017),
  [1552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 100), SHIFT(598),
  [1555] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 5, 0, 100), SHIFT(2017),
  [1558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 5, 0, 93), SHIFT(598),
  [1561] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 5, 0, 93), SHIFT(2017),
  [1564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 128), SHIFT(598),
  [1567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 6, 0, 128), SHIFT(2017),
  [1570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 6, 0, 129), SHIFT(598),
  [1573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 6, 0, 129), SHIFT(2017),
  [1576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 134), SHIFT(598),
  [1579] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 6, 0, 134), SHIFT(2017),
  [1582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 109), SHIFT(598),
  [1585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 6, 0, 109), SHIFT(2017),
  [1588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 139), SHIFT(598),
  [1591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 6, 0, 139), SHIFT(2017),
  [1594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 6, 0, 102), SHIFT(598),
  [1597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 6, 0, 102), SHIFT(2017),
  [1600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConst, 7, 0, 162), SHIFT(598),
  [1603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declConst, 7, 0, 162), SHIFT(2017),
  [1606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 166), SHIFT(598),
  [1609] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 7, 0, 166), SHIFT(2017),
  [1612] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 174), SHIFT(598),
  [1615] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 7, 0, 174), SHIFT(2017),
  [1618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declType, 7, 0, 141), SHIFT(598),
  [1621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declType, 7, 0, 141), SHIFT(2017),
  [1624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0),
  [1626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0),
  [1628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [1631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [1634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literalString, 1, 0, 0),
  [1636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literalString, 1, 0, 0),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [1640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 188), SHIFT(618),
  [1643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 188),
  [1645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 188),
  [1647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 234), SHIFT(597),
  [1650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 234),
  [1652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 234),
  [1654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 183), SHIFT(597),
  [1657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 183),
  [1659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 183),
  [1661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 236), SHIFT(597),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 236),
  [1666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 9, 0, 236),
  [1668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 237), SHIFT(597),
  [1671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 237),
  [1673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 9, 0, 237),
  [1675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 205), SHIFT(597),
  [1678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 205),
  [1680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 9, 0, 205),
  [1682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 238), SHIFT(597),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 238),
  [1687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 9, 0, 238),
  [1689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 10, 0, 239), SHIFT(597),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 10, 0, 239),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 10, 0, 239),
  [1696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 5, 0, 71), SHIFT(618),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 5, 0, 71),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 5, 0, 71),
  [1703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 109), SHIFT(597),
  [1706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 109),
  [1708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 6, 0, 109),
  [1710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 215), SHIFT(597),
  [1713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 215),
  [1715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 6, 0, 215),
  [1717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 111), SHIFT(597),
  [1720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 111),
  [1722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 6, 0, 111),
  [1724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 102), SHIFT(597),
  [1727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 102),
  [1729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 6, 0, 102),
  [1731] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 102), SHIFT(618),
  [1734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 102),
  [1736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 6, 0, 102),
  [1738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 109), SHIFT(618),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 109),
  [1743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 6, 0, 109),
  [1745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 110), SHIFT(618),
  [1748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 110),
  [1750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 6, 0, 110),
  [1752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 113), SHIFT(618),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 113),
  [1757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 6, 0, 113),
  [1759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 111), SHIFT(618),
  [1762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 111),
  [1764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 6, 0, 111),
  [1766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 226), SHIFT(597),
  [1769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 226),
  [1771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 226),
  [1773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 151), SHIFT(597),
  [1776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 151),
  [1778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 151),
  [1780] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 227), SHIFT(597),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 227),
  [1785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 227),
  [1787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 141), SHIFT(597),
  [1790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 141),
  [1792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 141),
  [1794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 228), SHIFT(597),
  [1797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 228),
  [1799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 228),
  [1801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 141), SHIFT(618),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 141),
  [1806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 141),
  [1808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 142), SHIFT(618),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 142),
  [1813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 142),
  [1815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 145), SHIFT(618),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 145),
  [1820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 145),
  [1822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 143), SHIFT(618),
  [1825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 143),
  [1827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 143),
  [1829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 150), SHIFT(618),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 150),
  [1834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 150),
  [1836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 153), SHIFT(618),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 153),
  [1841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 153),
  [1843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 154), SHIFT(618),
  [1846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 154),
  [1848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 154),
  [1850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 151), SHIFT(618),
  [1853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 151),
  [1855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 151),
  [1857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 152), SHIFT(618),
  [1860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 152),
  [1862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 152),
  [1864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 155), SHIFT(618),
  [1867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 155),
  [1869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 7, 0, 155),
  [1871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 143), SHIFT(597),
  [1874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 143),
  [1876] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 143),
  [1878] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 146), SHIFT(597),
  [1881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 146),
  [1883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 7, 0, 146),
  [1885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 231), SHIFT(597),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 231),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 231),
  [1892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 232), SHIFT(597),
  [1895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 232),
  [1897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 232),
  [1899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 176), SHIFT(597),
  [1902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 176),
  [1904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 176),
  [1906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 175), SHIFT(618),
  [1909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 175),
  [1911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 175),
  [1913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 178), SHIFT(618),
  [1916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 178),
  [1918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 178),
  [1920] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 179), SHIFT(618),
  [1923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 179),
  [1925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 179),
  [1927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 176), SHIFT(618),
  [1930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 176),
  [1932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 176),
  [1934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 177), SHIFT(618),
  [1937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 177),
  [1939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 177),
  [1941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 180), SHIFT(618),
  [1944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 180),
  [1946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 180),
  [1948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 186), SHIFT(618),
  [1951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 186),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 186),
  [1955] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 185), SHIFT(618),
  [1958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 185),
  [1960] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 185),
  [1962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 187), SHIFT(618),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 187),
  [1967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 8, 0, 187),
  [1969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 5, 0, 71), SHIFT(598),
  [1972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 5, 0, 71),
  [1974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 5, 0, 71),
  [1976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 5, 0, 71), SHIFT(2017),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 233), SHIFT(597),
  [1984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 233),
  [1986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 233),
  [1988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 181), SHIFT(597),
  [1991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 181),
  [1993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProp, 8, 0, 181),
  [1995] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 201), SHIFT(618),
  [1998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 201),
  [2000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 9, 0, 201),
  [2002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 200), SHIFT(618),
  [2005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 200),
  [2007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 9, 0, 200),
  [2009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 202), SHIFT(618),
  [2012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 202),
  [2014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 9, 0, 202),
  [2016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 203), SHIFT(618),
  [2019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 203),
  [2021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 9, 0, 203),
  [2023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 207), SHIFT(618),
  [2026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 207),
  [2028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 9, 0, 207),
  [2030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 109), SHIFT(598),
  [2033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 109), SHIFT(2017),
  [2036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 215), SHIFT(598),
  [2039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 215), SHIFT(2017),
  [2042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 111), SHIFT(598),
  [2045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 111), SHIFT(2017),
  [2048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 102), SHIFT(598),
  [2051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 6, 0, 102), SHIFT(2017),
  [2054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 10, 0, 223), SHIFT(618),
  [2057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declOperator, 10, 0, 223),
  [2059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declOperator, 10, 0, 223),
  [2061] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 226), SHIFT(598),
  [2064] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 226), SHIFT(2017),
  [2067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 151), SHIFT(598),
  [2070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 151), SHIFT(2017),
  [2073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 227), SHIFT(598),
  [2076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 227), SHIFT(2017),
  [2079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 141), SHIFT(598),
  [2082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 141), SHIFT(2017),
  [2085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 5, 0, 71), SHIFT(597),
  [2088] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 143), SHIFT(598),
  [2091] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 143), SHIFT(2017),
  [2094] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 146), SHIFT(598),
  [2097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 146), SHIFT(2017),
  [2100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 231), SHIFT(598),
  [2103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 231), SHIFT(2017),
  [2106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 232), SHIFT(598),
  [2109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 232), SHIFT(2017),
  [2112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 176), SHIFT(598),
  [2115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 176), SHIFT(2017),
  [2118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 233), SHIFT(598),
  [2121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 233), SHIFT(2017),
  [2124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 181), SHIFT(598),
  [2127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 181), SHIFT(2017),
  [2130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 234), SHIFT(598),
  [2133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 234), SHIFT(2017),
  [2136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 183), SHIFT(598),
  [2139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 8, 0, 183), SHIFT(2017),
  [2142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 236), SHIFT(598),
  [2145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 236), SHIFT(2017),
  [2148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 237), SHIFT(598),
  [2151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 237), SHIFT(2017),
  [2154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 205), SHIFT(598),
  [2157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 205), SHIFT(2017),
  [2160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 238), SHIFT(598),
  [2163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 9, 0, 238), SHIFT(2017),
  [2166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 10, 0, 239), SHIFT(598),
  [2169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 10, 0, 239), SHIFT(2017),
  [2172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 3, 0, 14), SHIFT(621),
  [2175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 3, 0, 14), SHIFT(2017),
  [2178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 32), SHIFT(621),
  [2181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 32), SHIFT(2017),
  [2184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 33), SHIFT(621),
  [2187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 33), SHIFT(2017),
  [2190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 34), SHIFT(621),
  [2193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 34), SHIFT(2017),
  [2196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 35), SHIFT(621),
  [2199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 35), SHIFT(2017),
  [2202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 67), SHIFT(621),
  [2205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 67), SHIFT(2017),
  [2208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 68), SHIFT(621),
  [2211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 68), SHIFT(2017),
  [2214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 69), SHIFT(621),
  [2217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 69), SHIFT(2017),
  [2220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 70), SHIFT(621),
  [2223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 70), SHIFT(2017),
  [2226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(621),
  [2229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [2232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 71), SHIFT(621),
  [2235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 71), SHIFT(2017),
  [2238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 72), SHIFT(621),
  [2241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 72), SHIFT(2017),
  [2244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 73), SHIFT(621),
  [2247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 73), SHIFT(2017),
  [2250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 74), SHIFT(621),
  [2253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 74), SHIFT(2017),
  [2256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 5, 0, 71), SHIFT(621),
  [2259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 5, 0, 71), SHIFT(2017),
  [2262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 102), SHIFT(621),
  [2265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 102), SHIFT(2017),
  [2268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 103), SHIFT(621),
  [2271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 103), SHIFT(2017),
  [2274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 104), SHIFT(621),
  [2277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 104), SHIFT(2017),
  [2280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 105), SHIFT(621),
  [2283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 105), SHIFT(2017),
  [2286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 102), SHIFT(621),
  [2289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 102), SHIFT(2017),
  [2292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 106), SHIFT(621),
  [2295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 106), SHIFT(2017),
  [2298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 107), SHIFT(621),
  [2301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 107), SHIFT(2017),
  [2304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 108), SHIFT(621),
  [2307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 108), SHIFT(2017),
  [2310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 109), SHIFT(621),
  [2313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 109), SHIFT(2017),
  [2316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 110), SHIFT(621),
  [2319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 110), SHIFT(2017),
  [2322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 111), SHIFT(621),
  [2325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 111), SHIFT(2017),
  [2328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 112), SHIFT(621),
  [2331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 112), SHIFT(2017),
  [2334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 109), SHIFT(621),
  [2337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 109), SHIFT(2017),
  [2340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 110), SHIFT(621),
  [2343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 110), SHIFT(2017),
  [2346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 113), SHIFT(621),
  [2349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 113), SHIFT(2017),
  [2352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 111), SHIFT(621),
  [2355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 111), SHIFT(2017),
  [2358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 141), SHIFT(621),
  [2361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 141), SHIFT(2017),
  [2364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 142), SHIFT(621),
  [2367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 142), SHIFT(2017),
  [2370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 143), SHIFT(621),
  [2373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 143), SHIFT(2017),
  [2376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 144), SHIFT(621),
  [2379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 144), SHIFT(2017),
  [2382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 141), SHIFT(621),
  [2385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 141), SHIFT(2017),
  [2388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 142), SHIFT(621),
  [2391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 142), SHIFT(2017),
  [2394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 145), SHIFT(621),
  [2397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 145), SHIFT(2017),
  [2400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 143), SHIFT(621),
  [2403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 143), SHIFT(2017),
  [2406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 146), SHIFT(621),
  [2409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 146), SHIFT(2017),
  [2412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 147), SHIFT(621),
  [2415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 147), SHIFT(2017),
  [2418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 148), SHIFT(621),
  [2421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 148), SHIFT(2017),
  [2424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 149), SHIFT(621),
  [2427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 149), SHIFT(2017),
  [2430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 150), SHIFT(621),
  [2433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 150), SHIFT(2017),
  [2436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 151), SHIFT(621),
  [2439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 151), SHIFT(2017),
  [2442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 152), SHIFT(621),
  [2445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 152), SHIFT(2017),
  [2448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 150), SHIFT(621),
  [2451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 150), SHIFT(2017),
  [2454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 153), SHIFT(621),
  [2457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 153), SHIFT(2017),
  [2460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 154), SHIFT(621),
  [2463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 154), SHIFT(2017),
  [2466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 151), SHIFT(621),
  [2469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 151), SHIFT(2017),
  [2472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 152), SHIFT(621),
  [2475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 152), SHIFT(2017),
  [2478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 155), SHIFT(621),
  [2481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 155), SHIFT(2017),
  [2484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 175), SHIFT(621),
  [2487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 175), SHIFT(2017),
  [2490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 176), SHIFT(621),
  [2493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 176), SHIFT(2017),
  [2496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 177), SHIFT(621),
  [2499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 177), SHIFT(2017),
  [2502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 175), SHIFT(621),
  [2505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 175), SHIFT(2017),
  [2508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 178), SHIFT(621),
  [2511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 178), SHIFT(2017),
  [2514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 179), SHIFT(621),
  [2517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 179), SHIFT(2017),
  [2520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 176), SHIFT(621),
  [2523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 176), SHIFT(2017),
  [2526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 177), SHIFT(621),
  [2529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 177), SHIFT(2017),
  [2532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 180), SHIFT(621),
  [2535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 180), SHIFT(2017),
  [2538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 181), SHIFT(621),
  [2541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 181), SHIFT(2017),
  [2544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 182), SHIFT(621),
  [2547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 182), SHIFT(2017),
  [2550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 183), SHIFT(621),
  [2553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 183), SHIFT(2017),
  [2556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 184), SHIFT(621),
  [2559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 184), SHIFT(2017),
  [2562] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 185), SHIFT(621),
  [2565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 185), SHIFT(2017),
  [2568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 186), SHIFT(621),
  [2571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 186), SHIFT(2017),
  [2574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 185), SHIFT(621),
  [2577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 185), SHIFT(2017),
  [2580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 187), SHIFT(621),
  [2583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 187), SHIFT(2017),
  [2586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 188), SHIFT(621),
  [2589] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 188), SHIFT(2017),
  [2592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 200), SHIFT(621),
  [2595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 200), SHIFT(2017),
  [2598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 201), SHIFT(621),
  [2601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 201), SHIFT(2017),
  [2604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 200), SHIFT(621),
  [2607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 200), SHIFT(2017),
  [2610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 202), SHIFT(621),
  [2613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 202), SHIFT(2017),
  [2616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 203), SHIFT(621),
  [2619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 203), SHIFT(2017),
  [2622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 204), SHIFT(621),
  [2625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 204), SHIFT(2017),
  [2628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 205), SHIFT(621),
  [2631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 205), SHIFT(2017),
  [2634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 206), SHIFT(621),
  [2637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 206), SHIFT(2017),
  [2640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 207), SHIFT(621),
  [2643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 207), SHIFT(2017),
  [2646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 10, 0, 223), SHIFT(621),
  [2649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 10, 0, 223), SHIFT(2017),
  [2652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 10, 0, 224), SHIFT(621),
  [2655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 10, 0, 224), SHIFT(2017),
  [2658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 228), SHIFT(598),
  [2661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declProp, 7, 0, 228), SHIFT(2017),
  [2664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttributeNoExt, 2, 0, 40),
  [2666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttributeNoExt, 2, 0, 40),
  [2668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 1, 0, 17),
  [2670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declProc_repeat1, 1, 0, 17),
  [2672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 3, 0, 14), SHIFT(616),
  [2675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 108), SHIFT(616),
  [2678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 32), SHIFT(616),
  [2681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 73), SHIFT(616),
  [2684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 74), SHIFT(616),
  [2687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 33), SHIFT(616),
  [2690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 34), SHIFT(616),
  [2693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 141), SHIFT(616),
  [2696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 142), SHIFT(616),
  [2699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 143), SHIFT(616),
  [2702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 144), SHIFT(616),
  [2705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 10, 0, 224), SHIFT(616),
  [2708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 4, 0, 35), SHIFT(616),
  [2711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 109), SHIFT(616),
  [2714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 204), SHIFT(616),
  [2717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 110), SHIFT(616),
  [2720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 146), SHIFT(616),
  [2723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 111), SHIFT(616),
  [2726] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 112), SHIFT(616),
  [2729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 205), SHIFT(616),
  [2732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 206), SHIFT(616),
  [2735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 147), SHIFT(616),
  [2738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 148), SHIFT(616),
  [2741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 149), SHIFT(616),
  [2744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttributeNoExt, 4, 0, 119),
  [2746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttributeNoExt, 4, 0, 119),
  [2748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 150), SHIFT(616),
  [2751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 151), SHIFT(616),
  [2754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 7, 0, 152), SHIFT(616),
  [2757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 185), SHIFT(616),
  [2760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 107), SHIFT(616),
  [2763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 104), SHIFT(616),
  [2766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 105), SHIFT(616),
  [2769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 102), SHIFT(616),
  [2772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 67), SHIFT(616),
  [2775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 106), SHIFT(616),
  [2778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 68), SHIFT(616),
  [2781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 69), SHIFT(616),
  [2784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 70), SHIFT(616),
  [2787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttributeNoExt, 3, 0, 0),
  [2789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttributeNoExt, 3, 0, 0),
  [2791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declProc_repeat1, 2, 0, 41), SHIFT_REPEAT(616),
  [2794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procAttributeNoExt, 5, 0, 158),
  [2796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procAttributeNoExt, 5, 0, 158),
  [2798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 71), SHIFT(616),
  [2801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 5, 0, 72), SHIFT(616),
  [2804] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 9, 0, 200), SHIFT(616),
  [2807] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 175), SHIFT(616),
  [2810] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 176), SHIFT(616),
  [2813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 177), SHIFT(616),
  [2816] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 181), SHIFT(616),
  [2819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 182), SHIFT(616),
  [2822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 183), SHIFT(616),
  [2825] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 8, 0, 184), SHIFT(616),
  [2828] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declProc, 6, 0, 103), SHIFT(616),
  [2831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literalChar, 2, 0, 0),
  [2833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literalChar, 2, 0, 0),
  [2835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 207), SHIFT(616),
  [2838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 187), SHIFT(616),
  [2841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 141), SHIFT(616),
  [2844] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 102), SHIFT(616),
  [2847] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 142), SHIFT(616),
  [2850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 145), SHIFT(616),
  [2853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 143), SHIFT(616),
  [2856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 10, 0, 223), SHIFT(616),
  [2859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 201), SHIFT(616),
  [2862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 200), SHIFT(616),
  [2865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 202), SHIFT(616),
  [2868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 9, 0, 203), SHIFT(616),
  [2871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 188), SHIFT(616),
  [2874] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 150), SHIFT(616),
  [2877] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 186), SHIFT(616),
  [2880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 154), SHIFT(616),
  [2883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 151), SHIFT(616),
  [2886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 152), SHIFT(616),
  [2889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 155), SHIFT(616),
  [2892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 5, 0, 71), SHIFT(616),
  [2895] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 109), SHIFT(616),
  [2898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 110), SHIFT(616),
  [2901] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 113), SHIFT(616),
  [2904] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 6, 0, 111), SHIFT(616),
  [2907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprUnary, 2, 0, 9),
  [2909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprUnary, 2, 0, 9),
  [2911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 185), SHIFT(616),
  [2914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 175), SHIFT(616),
  [2917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 178), SHIFT(616),
  [2920] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 179), SHIFT(616),
  [2923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 176), SHIFT(616),
  [2926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 177), SHIFT(616),
  [2929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 8, 0, 180), SHIFT(616),
  [2932] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declOperator, 7, 0, 153), SHIFT(616),
  [2935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 6, 0, 121),
  [2937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 6, 0, 121),
  [2939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprDeref, 2, 0, 12),
  [2941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprDeref, 2, 0, 12),
  [2943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 81),
  [2945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 81),
  [2947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprBrackets, 2, 0, 0),
  [2949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprBrackets, 2, 0, 0),
  [2951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asmTr, 2, 0, 0),
  [2953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asmTr, 2, 0, 0),
  [2955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 3, 0, 20),
  [2957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, 0, 20),
  [2959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literalNumber, 1, 0, 0),
  [2961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literalNumber, 1, 0, 0),
  [2963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ref, 2, 0, 0),
  [2965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ref, 2, 0, 0),
  [2967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprParens, 3, 0, 0),
  [2969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprParens, 3, 0, 0),
  [2971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 44),
  [2973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 44),
  [2975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprBrackets, 4, 0, 0),
  [2977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprBrackets, 4, 0, 0),
  [2979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 3, 0, 22),
  [2981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, 0, 22),
  [2983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprBinary, 3, 0, 23),
  [2985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprBinary, 3, 0, 23),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [2991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inherited, 1, 0, 0),
  [2993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inherited, 1, 0, 0),
  [2995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprAs, 3, 0, 23),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprAs, 3, 0, 23),
  [2999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprCall, 4, 0, 47),
  [3001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprCall, 4, 0, 47),
  [3003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprCall, 3, 0, 24),
  [3005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprCall, 3, 0, 24),
  [3007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 46),
  [3009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 46),
  [3011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprBrackets, 3, 0, 0),
  [3013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprBrackets, 3, 0, 0),
  [3015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprSubscript, 4, 0, 47),
  [3017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprSubscript, 4, 0, 47),
  [3019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asmTr, 3, 0, 0),
  [3021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asmTr, 3, 0, 0),
  [3023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 78),
  [3025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 78),
  [3027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 2, 0, 11),
  [3029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 2, 0, 11),
  [3031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inherited, 2, 0, 0),
  [3033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inherited, 2, 0, 0),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [3037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [3039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [3053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [3055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [3057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 0),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [3061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2450),
  [3063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [3065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [3067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [3069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2707),
  [3071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1734),
  [3073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1939),
  [3075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [3077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [3079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [3081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1798),
  [3091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [3093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [3095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [3097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1863),
  [3099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 4, 0, 0),
  [3101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1723),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [3105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [3111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [3115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [3135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [3143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [3145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typerefPtr, 2, 0, 9),
  [3147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typerefPtr, 2, 0, 9),
  [3149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typerefDot, 3, 0, 23),
  [3151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typerefDot, 3, 0, 23),
  [3153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typerefTpl, 4, 0, 47),
  [3155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typerefTpl, 4, 0, 47),
  [3157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 43),
  [3159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 43),
  [3161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition, 1, 0, 0),
  [3163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__definition, 1, 0, 0),
  [3165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 2, 0, 10),
  [3167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 2, 0, 10),
  [3169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 45),
  [3171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 45),
  [3173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, 0, 21),
  [3175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 3, 0, 21),
  [3177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 6, 0, 120),
  [3179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 6, 0, 120),
  [3181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, 0, 19),
  [3183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 3, 0, 19),
  [3185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 77),
  [3187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 77),
  [3189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 80),
  [3191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 80),
  [3193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 1, 0, 0),
  [3195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [3197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [3199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declProp_repeat2, 1, 0, 0),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [3207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expr, 1, 0, 0),
  [3209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expr, 1, 0, 0),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [3213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [3217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [3219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exprDot, 3, 0, 23),
  [3221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprDot, 3, 0, 23),
  [3223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [3225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(2128),
  [3228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(1010),
  [3231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(2017),
  [3234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(668),
  [3237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(814),
  [3240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(698),
  [3243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [3246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 41), SHIFT_REPEAT(2653),
  [3249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 1, 0, 0),
  [3251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1715),
  [3253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [3255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [3257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2206),
  [3259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [3261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [3263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ref, 1, 0, 3),
  [3265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ref, 1, 0, 3),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [3269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [3271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [3275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [3277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [3279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [3281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [3283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [3285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1744),
  [3287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [3289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2407),
  [3291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [3293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [3295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1254),
  [3298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [3301] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [3304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [3307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [3310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0),
  [3318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1247),
  [3321] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1032),
  [3330] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [3333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [3335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [3337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [3341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 2, 0, 0),
  [3343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [3345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2457),
  [3347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [3349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [3351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [3353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [3356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2094),
  [3359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(2128),
  [3362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(1010),
  [3365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(2017),
  [3368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(814),
  [3371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(698),
  [3374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(1013),
  [3377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 41), SHIFT_REPEAT(2653),
  [3380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [3382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [3384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(1329),
  [3387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [3390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(630),
  [3393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [3396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [3399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [3408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [3417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [3420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [3423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1254),
  [3426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [3429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [3432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [3435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [3438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3444] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1247),
  [3447] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1032),
  [3456] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [3459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__procAttribute_repeat1, 2, 0, 40),
  [3461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [3463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeref, 3, 0, 0),
  [3465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeref, 3, 0, 0),
  [3467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeref, 4, 0, 42),
  [3469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeref, 4, 0, 42),
  [3471] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [3474] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [3477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(630),
  [3480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [3483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [3486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [3495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [3504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [3507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [3509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [3511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [3513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2528),
  [3515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 2, 0, 0),
  [3517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [3519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1688),
  [3521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2502),
  [3523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 1, 0, 0),
  [3525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1751),
  [3527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2672),
  [3529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 3, 0, 0),
  [3531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [3533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [3535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [3537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__procAttributeNoExt_repeat1, 2, 0, 40),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [3541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [3543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2458),
  [3545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [3547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [3549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 3, 0, 99),
  [3551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2489),
  [3553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 4, 0, 140),
  [3555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2704),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [3559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2481),
  [3561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 169),
  [3563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [3565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 171),
  [3567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2435),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [3575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procAttribute, 1, 0, 0),
  [3577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [3579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [3587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [3591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 4, 0, 138),
  [3593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2614),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [3609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [3617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 195),
  [3619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2630),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [3629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 222),
  [3631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2516),
  [3633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 3, 0, 99),
  [3635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2521),
  [3637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1254),
  [3640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [3643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [3646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [3649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [3652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3658] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1247),
  [3661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3667] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1032),
  [3670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [3673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1254),
  [3676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [3679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [3682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [3685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [3688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [3694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1247),
  [3697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [3703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1032),
  [3706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [3709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 169),
  [3711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2420),
  [3713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 171),
  [3715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2421),
  [3717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 172),
  [3719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2432),
  [3721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [3723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [3725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 8, 0, 229),
  [3727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2531),
  [3729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 4, 0, 137),
  [3731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [3733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 194),
  [3735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2553),
  [3737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 173),
  [3739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2443),
  [3741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 8, 0, 230),
  [3743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2419),
  [3745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 9, 0, 235),
  [3747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2367),
  [3749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [3751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [3753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [3755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 219),
  [3757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2542),
  [3759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [3761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 7, 0, 220),
  [3763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [3765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 3, 0, 101),
  [3767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2538),
  [3769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 2, 0, 66),
  [3771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [3773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 168),
  [3775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2380),
  [3777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 196),
  [3779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2621),
  [3781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 197),
  [3783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2626),
  [3785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [3787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [3789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [3791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [3793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [3795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 198),
  [3797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2634),
  [3799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 221),
  [3801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [3803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 4, 0, 138),
  [3805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [3807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 4, 0, 140),
  [3809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2645),
  [3811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 195),
  [3813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2620),
  [3815] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [3818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [3821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [3824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [3827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [3830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [3839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [3848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [3851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [3853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [3855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asm, 4, 0, 0),
  [3857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asm, 4, 0, 0),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [3861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [3863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [3865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 7, 0, 0),
  [3867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 7, 0, 0),
  [3869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 8, 0, 0),
  [3871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 8, 0, 0),
  [3873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if, 4, 0, 50),
  [3875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if, 4, 0, 50),
  [3877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while, 4, 0, 51),
  [3879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while, 4, 0, 51),
  [3881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [3883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [3885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [3887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [3889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [3891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [3893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat, 4, 0, 26),
  [3895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat, 4, 0, 26),
  [3897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 4, 0, 27),
  [3899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 4, 0, 27),
  [3901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2615),
  [3903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 4, 0, 28),
  [3905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 4, 0, 28),
  [3907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2, 0, 0),
  [3909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 0),
  [3911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1044),
  [3913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [3915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [3917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for, 6, 0, 122),
  [3919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for, 6, 0, 122),
  [3921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 4),
  [3923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 4),
  [3925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with, 4, 0, 58),
  [3927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with, 4, 0, 58),
  [3929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach, 6, 0, 123),
  [3931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach, 6, 0, 123),
  [3933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [3935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifElse, 6, 0, 124),
  [3937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifElse, 6, 0, 124),
  [3939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 9, 0, 0),
  [3941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 9, 0, 0),
  [3943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asm, 3, 0, 0),
  [3945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asm, 3, 0, 0),
  [3947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2464),
  [3949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 6, 0, 87),
  [3951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 6, 0, 87),
  [3953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 6, 0, 88),
  [3955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 6, 0, 88),
  [3957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 6, 0, 0),
  [3959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 6, 0, 0),
  [3961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2617),
  [3963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [3966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [3969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [3972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [3975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [3978] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [3984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [3987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [3993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [3996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [3999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifElse, 5, 0, 86),
  [4001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifElse, 5, 0, 86),
  [4003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 2, 0, 0),
  [4005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 2, 0, 0),
  [4007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat, 5, 0, 52),
  [4009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat, 5, 0, 52),
  [4011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 10, 0, 0),
  [4013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 10, 0, 0),
  [4015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2594),
  [4017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [4019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [4021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 5, 0, 53),
  [4023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 5, 0, 53),
  [4025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 5, 0, 54),
  [4027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 5, 0, 54),
  [4029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 5, 0, 55),
  [4031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 5, 0, 55),
  [4033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try, 5, 0, 56),
  [4035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try, 5, 0, 56),
  [4037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raise, 3, 0, 13),
  [4039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise, 3, 0, 13),
  [4041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case, 5, 0, 0),
  [4043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case, 5, 0, 0),
  [4045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(669),
  [4048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(685),
  [4051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(894),
  [4054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(249),
  [4057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(2140),
  [4060] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(523),
  [4063] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(523),
  [4066] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(670),
  [4069] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(890),
  [4072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(890),
  [4075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(1022),
  [4078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 30), SHIFT_REPEAT(531),
  [4081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [4083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with, 5, 0, 90),
  [4085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with, 5, 0, 90),
  [4087] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(847),
  [4090] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2087),
  [4093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1360),
  [4095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [4097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto, 3, 0, 0),
  [4099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto, 3, 0, 0),
  [4101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1460),
  [4104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [4107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [4110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [4113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [4116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [4119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [4122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [4125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [4128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [4131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [4134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [4137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(859),
  [4140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2066),
  [4143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [4145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [4147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [4149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [4152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [4155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(894),
  [4158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [4161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(2140),
  [4164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [4167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [4170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [4173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [4176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(890),
  [4179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [4182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [4185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [4187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [4189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [4191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [4193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [4195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [4197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [4199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [4201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [4203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [4205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2670),
  [4207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [4209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [4211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [4213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [4215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [4217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [4219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [4221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [4223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [4225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1465),
  [4227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [4229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__statementsTr_repeat1, 1, 0, 0),
  [4231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__statementsTr_repeat1, 1, 0, 0),
  [4233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statementsTr, 2, 0, 0),
  [4235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statementsTr, 1, 0, 0),
  [4237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [4239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [4241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1554),
  [4243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [4245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [4247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [4249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [4251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [4253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [4255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [4257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2192),
  [4259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1898),
  [4261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [4263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2365),
  [4265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1762),
  [4267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1885),
  [4269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [4271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1785),
  [4273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [4275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [4277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1755),
  [4279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [4281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [4283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [4285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [4287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [4289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [4291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [4293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [4295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [4297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1058),
  [4299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [4301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [4303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [4305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [4307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [4309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [4311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [4313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [4315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(742),
  [4318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1941),
  [4321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0),
  [4323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(40),
  [4326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1214),
  [4329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1226),
  [4332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1226),
  [4335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1187),
  [4338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(2139),
  [4341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1873),
  [4344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1766),
  [4347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1916),
  [4350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1974),
  [4353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(1252),
  [4356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [4358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [4360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [4368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [4370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [4372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [4380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [4382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [4388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [4390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [4392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implementation, 1, 0, 0),
  [4394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [4396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implementation, 2, 0, 0),
  [4398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [4400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declSection, 2, 0, 0),
  [4402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [4404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [4406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [4408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [4410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [4412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [4414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [4416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [4418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [4420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [4422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [4424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declSection, 1, 0, 0),
  [4426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [4428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [4430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [4432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [4434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [4436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [4438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [4440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [4442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [4444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [4446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [4448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [4450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [4452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [4454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [4456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declSection, 3, 0, 0),
  [4458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [4460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [4462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [4464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [4466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(742),
  [4469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1941),
  [4472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0),
  [4474] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1214),
  [4477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1226),
  [4480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1226),
  [4483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1187),
  [4486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(2139),
  [4489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1873),
  [4492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(2375),
  [4495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1713),
  [4498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1935),
  [4501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1967),
  [4504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declarations, 2, 0, 0), SHIFT_REPEAT(1251),
  [4507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [4509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 1, 0, 0),
  [4511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [4513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [4515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1935),
  [4517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [4519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [4521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [4523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [4525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__definitions, 2, 0, 0), SHIFT_REPEAT(39),
  [4528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [4530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [4532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ref, 1, 0, 0),
  [4534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [4536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ref, 1, 0, 0),
  [4538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 2, 0, 0),
  [4540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [4542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caseLabel, 2, 0, 0),
  [4544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseLabel, 2, 0, 0),
  [4546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [4550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declArgs, 2, 0, 0),
  [4552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArgs, 2, 0, 0),
  [4554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declArgs, 3, 0, 0),
  [4556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArgs, 3, 0, 0),
  [4558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declArgs, 4, 0, 0),
  [4560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArgs, 4, 0, 0),
  [4562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caseLabel, 3, 0, 0),
  [4564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseLabel, 3, 0, 0),
  [4566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_root, 1, 0, 0),
  [4568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declTypes, 1, 0, 0),
  [4570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [4572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declTypes, 1, 0, 0), SHIFT(742),
  [4575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declTypes, 1, 0, 0),
  [4577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declTypes, 1, 0, 0), SHIFT(1979),
  [4580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [4582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statementTr, 1, 0, 0),
  [4584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [4586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [4588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [4590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(1189),
  [4593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2097),
  [4596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declSection, 3, 0, 0),
  [4598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_exceptionElse_repeat1, 1, 0, 0),
  [4600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exceptionElse_repeat1, 1, 0, 0),
  [4602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exceptionElse, 3, 0, 0),
  [4604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exceptionElse, 2, 0, 0),
  [4606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [4608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declSection, 4, 0, 0),
  [4610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(742),
  [4613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0),
  [4615] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1249),
  [4618] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1307),
  [4621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1307),
  [4624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1220),
  [4627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(2707),
  [4630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1734),
  [4633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1939),
  [4636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(2014),
  [4639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__classDeclarations, 2, 0, 0), SHIFT_REPEAT(1255),
  [4642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0),
  [4644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0), SHIFT_REPEAT(1981),
  [4647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0), SHIFT_REPEAT(742),
  [4650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0),
  [4652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0), SHIFT_REPEAT(1979),
  [4655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declSection, 2, 0, 0),
  [4657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declTypes, 2, 0, 0),
  [4659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declTypes, 2, 0, 0), SHIFT(742),
  [4662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declTypes, 2, 0, 0),
  [4664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declTypes, 2, 0, 0), SHIFT(1979),
  [4667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [4669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(1204),
  [4672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [4675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [4677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label, 2, 0, 0),
  [4679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label, 2, 0, 0),
  [4681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [4683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(1208),
  [4686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literalString_repeat1, 2, 0, 0), SHIFT_REPEAT(2089),
  [4689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [4691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [4693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 3, 0, 225),
  [4695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [4697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declVars_repeat1, 2, 0, 0),
  [4699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVars_repeat1, 2, 0, 0), SHIFT_REPEAT(2274),
  [4702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVars_repeat1, 2, 0, 0), SHIFT_REPEAT(742),
  [4705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declVars_repeat1, 2, 0, 0),
  [4707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVars, 3, 0, 0),
  [4709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [4711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVars, 3, 0, 0), SHIFT(742),
  [4714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVars, 3, 0, 0),
  [4716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 210),
  [4718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVars, 1, 0, 0),
  [4720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVars, 1, 0, 0), SHIFT(742),
  [4723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVars, 1, 0, 0),
  [4725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [4727] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declTypes, 2, 0, 0), SHIFT(2013),
  [4730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0), SHIFT_REPEAT(1984),
  [4733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declTypes_repeat1, 2, 0, 0), SHIFT_REPEAT(2013),
  [4736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVars, 2, 0, 0),
  [4738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declVars, 2, 0, 0), SHIFT(742),
  [4741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVars, 2, 0, 0),
  [4743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_declTypes, 1, 0, 0), SHIFT(2013),
  [4746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 213),
  [4748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProc, 2, 0, 7),
  [4750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProc, 2, 0, 7),
  [4752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConsts, 2, 0, 0),
  [4754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [4756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConsts, 2, 0, 0), SHIFT(742),
  [4759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConsts, 2, 0, 0),
  [4761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConsts, 1, 0, 0),
  [4763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConsts, 1, 0, 0), SHIFT(742),
  [4766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConsts, 1, 0, 0),
  [4768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 211),
  [4770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 212),
  [4772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProc, 2, 0, 8),
  [4774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProc, 2, 0, 8),
  [4776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 214),
  [4778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declConsts_repeat1, 2, 0, 0),
  [4780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declConsts_repeat1, 2, 0, 0), SHIFT_REPEAT(2021),
  [4783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declConsts_repeat1, 2, 0, 0), SHIFT_REPEAT(742),
  [4786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declConsts_repeat1, 2, 0, 0),
  [4788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProc, 1, 0, 2),
  [4790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProc, 1, 0, 2),
  [4792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declConsts, 3, 0, 0),
  [4794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_declConsts, 3, 0, 0), SHIFT(742),
  [4797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declConsts, 3, 0, 0),
  [4799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [4801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [4803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [4807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declVars_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [4810] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declFields, 2, 0, 0), SHIFT_REPEAT(2152),
  [4813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declFields, 2, 0, 0), SHIFT_REPEAT(742),
  [4816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declFields, 2, 0, 0),
  [4818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [4820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [4822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [4824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [4826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [4828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [4830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [4832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [4834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [4836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [4838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [4840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [4842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [4844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [4846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2103),
  [4848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [4850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [4852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [4854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [4856] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declConsts_repeat1, 2, 0, 0), SHIFT_REPEAT(2103),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [4863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [4869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [4871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2369),
  [4873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [4877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raiseTr, 2, 0, 13),
  [4879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, 0, 23),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [4883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeatTr, 3, 0, 26),
  [4885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [4889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [4893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeatTr, 4, 0, 52),
  [4895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeref, 1, 0, 0),
  [4897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeref, 1, 0, 0),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [4901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [4903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeref, 2, 0, 42),
  [4905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeref, 2, 0, 42),
  [4907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [4909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [4911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [4913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [4915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [4919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2638),
  [4921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [4923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [4925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [4927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2656),
  [4929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2508),
  [4931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [4933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [4935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [4937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [4939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1682),
  [4941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [4945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [4947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [4949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprArgs, 1, 0, 0),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [4953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [4955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1647),
  [4957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2504),
  [4959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2249),
  [4961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [4963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2507),
  [4965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2654),
  [4967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [4969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [4971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [4973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [4975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [4979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [4983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [4985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [4993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprArgs, 2, 0, 0),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [4999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [5001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [5003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [5005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [5007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [5009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [5011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [5013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [5015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [5017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [5019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [5021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [5023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [5025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [5027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declExports, 3, 0, 0),
  [5029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declExports, 3, 0, 0),
  [5031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declUses, 2, 0, 0),
  [5033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declUses, 2, 0, 0),
  [5035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declUses, 4, 0, 0),
  [5037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declUses, 4, 0, 0),
  [5039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [5041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [5043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [5045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_legacyFormat_repeat1, 2, 0, 0),
  [5047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declUses, 3, 0, 0),
  [5049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declUses, 3, 0, 0),
  [5051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declExports, 2, 0, 0),
  [5053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declExports, 2, 0, 0),
  [5055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declLabels, 3, 0, 0),
  [5057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declLabels, 3, 0, 0),
  [5059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProc, 1, 0, 1),
  [5061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declProc, 1, 0, 1),
  [5063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [5065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__initializer, 1, 0, 0),
  [5067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_guid, 3, 0, 0),
  [5069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guid, 3, 0, 0),
  [5071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declLabels, 4, 0, 0),
  [5073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declLabels, 4, 0, 0),
  [5075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declExport_repeat1, 2, 0, 0),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declExports, 4, 0, 0),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declExports, 4, 0, 0),
  [5081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [5083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [5085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [5087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [5095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 3, 0, 15),
  [5097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 3, 0, 15),
  [5099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 3, 0, 16),
  [5101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 3, 0, 16),
  [5103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 7, 0, 157),
  [5105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 7, 0, 157),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [5109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 4, 0, 36),
  [5111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 4, 0, 36),
  [5113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 4, 0, 37),
  [5115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 4, 0, 37),
  [5117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [5119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [5121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [5123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [5125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [5127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [5129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procAttribute, 2, 0, 0),
  [5131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [5133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [5135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [5137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 5, 0, 94),
  [5139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 5, 0, 94),
  [5141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procAttribute, 3, 0, 0),
  [5143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 5, 0, 71),
  [5145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 5, 0, 71),
  [5147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 5, 0, 95),
  [5149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 5, 0, 95),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [5155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [5157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [5159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [5161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 6, 0, 114),
  [5163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 6, 0, 114),
  [5165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 6, 0, 116),
  [5167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 6, 0, 116),
  [5169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [5171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 6, 0, 118),
  [5173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 6, 0, 118),
  [5175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [5177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 7, 0, 164),
  [5179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 7, 0, 164),
  [5181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 5, 0, 75),
  [5183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 5, 0, 75),
  [5185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [5187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [5191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 5, 0, 76),
  [5193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 5, 0, 76),
  [5195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 4, 0, 61),
  [5197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 4, 0, 61),
  [5199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 7, 0, 156),
  [5201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 7, 0, 156),
  [5203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [5205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 6, 0, 129),
  [5207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 6, 0, 129),
  [5209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 6, 0, 130),
  [5211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 6, 0, 130),
  [5213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declField, 6, 0, 132),
  [5215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declField, 6, 0, 132),
  [5217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [5219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [5221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [5223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procAttribute, 2, 0, 39),
  [5225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defProc, 6, 0, 117),
  [5227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defProc, 6, 0, 117),
  [5229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [5231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2637),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [5235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [5237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [5239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [5241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [5243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2644),
  [5245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [5247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [5249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [5251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [5253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [5257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [5259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [5261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [5263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [5265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [5267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0),
  [5269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 6, 0, 170),
  [5271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declVariant_repeat1, 2, 0, 0),
  [5273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVariant, 6, 0, 170),
  [5275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [5281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [5283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [5285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [5287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 5, 0, 170),
  [5289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVariant, 5, 0, 170),
  [5291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [5293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [5295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [5297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [5299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [5301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [5303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [5305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [5307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(555),
  [5309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [5311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [5313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [5315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [5317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [5319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [5321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [5323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [5325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [5327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [5329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [5331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [5333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 8, 0, 218),
  [5335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVariant, 8, 0, 218),
  [5337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [5339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [5341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [5343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [5345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__initializer, 1, 0, 0),
  [5347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [5349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kDot, 1, 0, 0),
  [5351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kDot, 1, 0, 0),
  [5353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 7, 0, 218),
  [5355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declVariant, 7, 0, 218),
  [5357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [5359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [5361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [5363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [5365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [5367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caseCase, 2, 0, 89),
  [5369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseCase, 2, 0, 89),
  [5371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [5373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [5375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0),
  [5377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 2, 0, 0),
  [5379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [5381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0),
  [5383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declArray_repeat1, 2, 0, 0),
  [5385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [5387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [5389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0),
  [5391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_recInitializer_repeat1, 2, 0, 0),
  [5393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_with_repeat1, 2, 0, 24),
  [5395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_with_repeat1, 2, 0, 24),
  [5397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [5399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0),
  [5401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arrInitializer_repeat1, 2, 0, 0),
  [5403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [5405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0),
  [5407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat1, 2, 0, 0),
  [5409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0),
  [5411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exprTpl_repeat1, 2, 0, 0),
  [5413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0),
  [5415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat1, 2, 0, 0),
  [5417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_exprArgs_repeat1, 3, 0, 0),
  [5419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exprArgs_repeat1, 3, 0, 0),
  [5421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [5423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0),
  [5425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_caseLabel_repeat1, 2, 0, 0),
  [5427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [5429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [5431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_varDef, 4, 0, 49),
  [5433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_varAssignDef, 4, 0, 49),
  [5435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [5437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 4, 0, 126),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [5441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 6, 0, 190),
  [5443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [5445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 5, 0, 160),
  [5447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [5449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [5451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declString, 1, 0, 0),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [5455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 3, 0, 92),
  [5457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [5459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 8, 0, 0),
  [5461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 5, 0, 0),
  [5463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 5, 0, 92),
  [5465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 5, 0, 0),
  [5467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declEnum, 3, 0, 0),
  [5469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 3, 0, 0),
  [5471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declMetaClass, 3, 0, 0),
  [5473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 3, 0, 0),
  [5475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declFile, 3, 0, 0),
  [5477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declSet, 3, 0, 0),
  [5479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 3, 0, 0),
  [5481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 6, 0, 0),
  [5483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 6, 0, 126),
  [5485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 8, 0, 190),
  [5487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [5489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declEnum, 4, 0, 0),
  [5491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 4, 0, 0),
  [5493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declString, 4, 0, 0),
  [5495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 4, 0, 0),
  [5497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 4, 0, 60),
  [5499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 1, 0, 0),
  [5501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [5503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [5505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArray, 7, 0, 0),
  [5507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 7, 0, 160),
  [5509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [5511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [5513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [5515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 6, 0, 127),
  [5517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declClass_repeat1, 2, 0, 0),
  [5519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declClass_repeat1, 2, 0, 0), SHIFT_REPEAT(1077),
  [5522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declClass_repeat1, 2, 0, 0), SHIFT_REPEAT(1863),
  [5525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2197),
  [5527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [5529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [5531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rttiAttributes, 1, 0, 0),
  [5533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 4, 0, 127),
  [5535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [5537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [5539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_genericDot, 3, 0, 23),
  [5541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericDot, 3, 0, 23),
  [5543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [5545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declProcRef, 2, 0, 60),
  [5547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [5551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat2, 2, 0, 0),
  [5553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 2, 0, 0), SHIFT_REPEAT(742),
  [5556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1116),
  [5559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1045),
  [5562] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [5565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6),
  [5568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0),
  [5570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat2, 3, 0, 0),
  [5572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 3, 0, 0),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [5576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [5578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [5580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 3, 0, 27),
  [5582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [5584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 3, 0, 28),
  [5586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [5588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [5590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [5594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [5596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [5602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [5606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statementTr, 1, 0, 0),
  [5608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [5610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [5612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [5614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [5618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [5620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [5624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [5626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [5630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [5632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [5636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [5638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [5640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [5644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [5646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [5648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [5650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [5652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [5654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [5656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 8, 0, 0),
  [5658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [5660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [5662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [5664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [5666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [5668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_genericTpl, 4, 0, 47),
  [5670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericTpl, 4, 0, 47),
  [5672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [5674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gotoTr, 2, 0, 0),
  [5676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [5678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [5680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [5682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [5684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [5686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [5688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [5690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [5692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [5694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [5696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 6, 0, 0),
  [5698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [5700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 5, 0, 0),
  [5702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [5704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 2, 0, 0),
  [5706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat2, 6, 0, 0),
  [5708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 6, 0, 0),
  [5710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [5712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [5714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [5716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216),
  [5718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(2566),
  [5721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(2568),
  [5724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(596),
  [5727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(957),
  [5730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(1724),
  [5733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(958),
  [5736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(972),
  [5739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 216), SHIFT_REPEAT(975),
  [5742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [5744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [5746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 4, 0, 53),
  [5748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [5750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [5752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [5754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [5756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [5758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [5760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [5762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declFile, 1, 0, 0),
  [5764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [5766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [5768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 9, 0, 0),
  [5770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [5772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [5774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [5776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2708),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [5782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [5784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [5786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 4, 0, 54),
  [5788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [5790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 4, 0, 55),
  [5792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat2, 5, 0, 0),
  [5794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 5, 0, 0),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [5798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [5800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [5802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [5804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 7, 0, 0),
  [5806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [5808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 4, 0, 56),
  [5810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [5812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [5814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [5816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseTr, 4, 0, 0),
  [5818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [5820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_rttiAttributes_repeat2, 4, 0, 0),
  [5822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rttiAttributes_repeat2, 4, 0, 0),
  [5824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [5826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 5, 0, 87),
  [5828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [5830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tryTr, 5, 0, 88),
  [5832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [5834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [5836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [5838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [5842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [5846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [5848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [5850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [5852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [5854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [5856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [5858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [5860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statementTr, 1, 0, 5),
  [5862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declClass_repeat1, 2, 0, 0), SHIFT_REPEAT(1554),
  [5865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declClass_repeat1, 2, 0, 0), SHIFT_REPEAT(1885),
  [5868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declClass_repeat1, 2, 0, 0), SHIFT_REPEAT(1884),
  [5871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [5873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [5875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [5877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [5879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [5881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [5883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [5885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [5887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [5889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [5891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [5893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [5895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifElseTr, 5, 0, 86),
  [5897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_whileTr, 4, 0, 51),
  [5899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [5901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [5903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 208),
  [5905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declProp_repeat2, 2, 0, 209),
  [5907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [5909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [5911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [5913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_forTr, 6, 0, 122),
  [5915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [5917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [5919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreachTr, 6, 0, 123),
  [5921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifElseTr, 6, 0, 124),
  [5923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [5925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_withTr, 4, 0, 58),
  [5927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [5929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_withTr, 5, 0, 90),
  [5931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [5933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1905),
  [5935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [5937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1907),
  [5939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1933),
  [5941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [5943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statementsTr, 2, 0, 0),
  [5945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [5947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declExport, 1, 0, 0),
  [5949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [5951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declPropArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(2187),
  [5954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declPropArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(2164),
  [5957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1640),
  [5959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1904),
  [5961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2275),
  [5963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [5965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [5967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1918),
  [5969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [5971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1888),
  [5973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [5975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [5977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [5979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [5981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2501),
  [5983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [5985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [5987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [5989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [5991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [5993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [5995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [5997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_typerefArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(1976),
  [6000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_typerefArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(1884),
  [6003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [6005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [6007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [6009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [6011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [6013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [6015] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_asmBody_repeat1, 2, 0, 0), SHIFT_REPEAT(1882),
  [6018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_asmBody_repeat1, 2, 0, 0), SHIFT_REPEAT(1882),
  [6021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_asmBody_repeat1, 2, 0, 0),
  [6023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifTr, 4, 0, 50),
  [6025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [6027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [6029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [6031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [6033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_varAssignDef, 2, 0, 0),
  [6035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 1, 0, 6),
  [6037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [6039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [6041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [6043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [6045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [6047] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asmBody, 1, 0, 0),
  [6049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [6051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [6053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declExports_repeat1, 2, 0, 0), SHIFT_REPEAT(1800),
  [6056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__operatorName, 1, 0, 0),
  [6058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__operatorName, 1, 0, 0),
  [6060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [6062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1810),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [6070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [6074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [6076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [6078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1757),
  [6080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [6082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [6084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [6086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 2, 0, 65),
  [6088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [6090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [6092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [6094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [6096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [6098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [6100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typerefArgs, 1, 0, 0),
  [6102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 4, 0, 95),
  [6104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recInitializer, 4, 0, 0),
  [6106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [6108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrInitializer, 4, 0, 0),
  [6110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initialization, 2, 0, 0),
  [6112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 2, 0, 14),
  [6114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [6116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [6118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_legacyFormat, 1, 0, 0),
  [6120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [6122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__typeref, 1, 0, 0),
  [6124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finalization, 2, 0, 0),
  [6126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrInitializer, 3, 0, 0),
  [6128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declPropArgs_repeat1, 2, 0, 0),
  [6130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 3, 0, 79),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [6134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 3, 0, 61),
  [6136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declExport_repeat1, 2, 0, 0), SHIFT_REPEAT(980),
  [6139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [6141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [6143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [6145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recInitializer, 3, 0, 0),
  [6147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_legacyFormat_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [6150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [6152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [6154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [6156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [6158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [6160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declExport, 2, 0, 0),
  [6162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defaultValue, 2, 0, 0),
  [6164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [6166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typerefArgs, 2, 0, 0),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1961),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [6172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1990),
  [6174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [6176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 4, 0, 71),
  [6178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 5, 0, 130),
  [6180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declVariantClause_repeat1, 2, 0, 0), SHIFT_REPEAT(2275),
  [6183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [6185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 4, 0, 136),
  [6187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declVariantClause_repeat1, 2, 0, 0),
  [6189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [6191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [6193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [6195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [6197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [6199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [6201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [6203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [6205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [6207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [6209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_moduleName, 2, 0, 0),
  [6211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [6213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [6215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [6217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_moduleName, 1, 0, 0),
  [6219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [6221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [6223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [6225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [6227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [6229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [6231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [6233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [6235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [6237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [6239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [6241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [6243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [6245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 3, 0, 97),
  [6247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [6249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [6251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [6253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [6255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [6257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [6259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [6261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [6263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [6265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [6267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [6269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [6271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [6273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [6275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [6277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [6279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [6281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [6283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [6285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [6287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exceptionHandlersTr, 1, 0, 0),
  [6289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [6291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__exceptionHandlersTr_repeat1, 1, 0, 0),
  [6293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [6295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exceptionHandlersTr, 2, 0, 0),
  [6297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [6299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [6301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantField, 4, 0, 95),
  [6303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantField, 3, 0, 61),
  [6305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [6307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [6309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [6311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [6313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statementsTr, 1, 0, 0),
  [6315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declUses_repeat1, 2, 0, 0), SHIFT_REPEAT(1961),
  [6318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_genericArgs_repeat1, 2, 0, 0), SHIFT_REPEAT(1912),
  [6321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [6323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [6325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [6327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [6329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [6331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [6333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [6335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declEnumValue, 1, 0, 6),
  [6337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [6339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [6341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [6343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [6345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [6347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [6349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [6351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [6353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [6355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [6357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [6359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [6361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [6363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [6365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [6367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [6369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [6371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [6373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [6375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [6377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [6379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [6381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [6383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [6385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 4, 0, 170),
  [6387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [6389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [6391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [6393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [6395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [6397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 6, 0, 0),
  [6399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [6401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [6403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [6405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [6407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [6409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [6411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 4, 0, 0),
  [6413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [6415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [6417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [6419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [6421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [6423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [6425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [6427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [6429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exprArgs, 3, 0, 0),
  [6431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [6433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [6435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [6437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [6439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [6441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [6443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [6445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [6447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 2, 0, 115), SHIFT_REPEAT(1177),
  [6450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 2, 0, 115),
  [6452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [6454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [6456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [6458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 6, 0, 164),
  [6460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 7, 0, 0),
  [6462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [6464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 4, 0, 94),
  [6466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [6468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [6470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [6472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [6474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exceptionHandler, 6, 0, 189),
  [6476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [6478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [6480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [6482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [6484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exceptionHandler, 4, 0, 125),
  [6486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [6488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [6490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [6492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [6494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [6496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [6498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [6500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [6502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [6504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [6506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [6508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [6510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [6512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 8, 0, 0),
  [6514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [6516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [6518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [6520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [6522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [6524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1472),
  [6527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_repeat1, 2, 0, 0),
  [6529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [6531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [6533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [6535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [6537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [6539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [6541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [6543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [6545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declClass_repeat1, 2, 0, 0),
  [6547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declClass_repeat1, 2, 0, 0),
  [6549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [6551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__exceptionHandlersTr_repeat1, 2, 0, 0), SHIFT_REPEAT(1856),
  [6554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operatorName, 1, 0, 0),
  [6556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operatorName, 1, 0, 0),
  [6558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 5, 0, 0),
  [6560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [6562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariant, 6, 0, 218),
  [6564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declEnum_repeat1, 2, 0, 0), SHIFT_REPEAT(2005),
  [6567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [6569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [6571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [6573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantClause, 3, 0, 0),
  [6575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [6577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [6579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operatorDot, 3, 0, 23),
  [6581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operatorDot, 3, 0, 23),
  [6583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [6585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [6589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [6591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 5, 0, 129),
  [6593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declArg, 5, 0, 132),
  [6595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [6597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declLabels_repeat1, 2, 0, 0), SHIFT_REPEAT(2173),
  [6600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [6602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recInitializerField, 1, 0, 62),
  [6604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [6606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [6608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [6610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [6612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [6614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [6616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [6618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [6620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [6622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [6624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [6626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [6628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [6630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 5, 0, 167),
  [6632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [6634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [6636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [6638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [6642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [6644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [6646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [6648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [6650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [6652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [6654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [6656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [6658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_moduleName_repeat1, 2, 0, 0), SHIFT_REPEAT(2291),
  [6661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_genericArg_repeat1, 2, 0, 0), SHIFT_REPEAT(2411),
  [6664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [6666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 3, 0, 98),
  [6668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [6670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [6672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [6674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [6676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [6678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_typerefArgs_repeat1, 2, 0, 0),
  [6680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declLabel, 1, 0, 6),
  [6682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 4, 0, 19),
  [6684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 4, 0, 20),
  [6686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [6688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [6690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantField, 5, 0, 132),
  [6692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [6694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [6696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exceptionHandlerTr, 6, 0, 189),
  [6698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [6700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [6702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exceptionHandlerTr, 4, 0, 125),
  [6704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [6706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [6708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [6710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [6712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [6714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [6716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [6718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [6720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 2, 0, 31),
  [6722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [6724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2250),
  [6728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [6730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [6732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [6734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [6736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [6738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [6740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [6742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [6744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [6746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2666),
  [6748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [6750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [6752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [6754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [6756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [6758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [6760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [6762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [6764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [6766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [6768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caseCaseTr, 2, 0, 89),
  [6770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [6772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [6774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [6776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArgs, 1, 0, 0),
  [6778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [6780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [6784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recInitializerField, 3, 0, 133),
  [6786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArgs, 2, 0, 0),
  [6788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2406),
  [6790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_genericArg, 4, 0, 135),
  [6792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [6794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [6796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [6798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [6800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [6802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [6804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [6806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [6808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [6810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [6812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [6814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [6816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [6818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [6820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [6822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [6824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [6826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [6828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [6830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declEnumValue, 2, 0, 91),
  [6832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [6836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [6840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [6842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [6846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [6848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1970),
  [6850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [6852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [6854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [6856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [6858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [6860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 3, 0, 10),
  [6862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defProc_repeat1, 3, 0, 11),
  [6864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [6866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [6868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [6870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [6872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [6874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [6876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [6882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [6884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [6886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [6888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [6890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [6896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [6898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [6900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [6902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [6904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [6906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [6908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [6910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [6916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [6918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [6920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [6926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declVariantField, 4, 0, 94),
  [6928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [6940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2303),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [6950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 137),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [6956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [6960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 3, 0, 66),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [6964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [6980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [6982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [6984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [6988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [6992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [6996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [7002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [7004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [7008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [7012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 10, 0, 235),
  [7014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [7016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [7018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [7020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [7022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [7024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [7028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [7030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [7032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [7034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [7036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 168),
  [7038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [7040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [7042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 169),
  [7044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [7046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [7048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 8, 0, 221),
  [7050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [7052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [7054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [7056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [7058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [7060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declClass, 5, 0, 0),
  [7062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [7064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2657),
  [7066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1850),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [7070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [7072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [7074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2662),
  [7076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [7078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [7080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [7082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [7084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [7086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [7090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [7092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exceptionHandlersTr, 3, 0, 0),
  [7094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [7096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 9, 0, 230),
  [7098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 169),
  [7100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 171),
  [7102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [7106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [7108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [7110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 5, 0, 0),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [7114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [7118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [7122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 172),
  [7124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [7126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2240),
  [7128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 6, 0, 171),
  [7130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [7132] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2331),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [7140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 173),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [7148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [7152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 6, 0, 0),
  [7154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [7156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [7158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_genericArgs_repeat1, 2, 0, 0),
  [7160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [7162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [7164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [7168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [7170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declHelper, 8, 0, 171),
  [7172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [7174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [7182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [7184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [7186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [7188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declUses_repeat1, 2, 0, 0),
  [7190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [7194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [7196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declLabels_repeat1, 2, 0, 0),
  [7198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [7200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [7202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [7204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [7206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [7208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declPropArgs, 4, 0, 0),
  [7210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2290),
  [7212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 4, 0, 99),
  [7214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [7216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [7218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_moduleName_repeat1, 2, 0, 0),
  [7220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [7222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [7226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [7228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declClass, 3, 0, 0),
  [7230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 3, 0, 0),
  [7232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [7234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [7236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [7238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [7240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [7242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [7248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [7250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [7256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [7258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 8, 0, 222),
  [7260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declClass, 4, 0, 0),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [7264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [7266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 4, 0, 99),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [7270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [7274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [7276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [7278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [7280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 9, 0, 229),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [7286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declVariantClause_repeat1, 2, 0, 0),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [7290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 4, 0, 101),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [7294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [7296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 8, 0, 219),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [7308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [7310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [7312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declEnum_repeat1, 2, 0, 0),
  [7314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [7316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 7, 0, 194),
  [7318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [7322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [7326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [7328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [7334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [7338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [7340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [7342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [7344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [7346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [7348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [7350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 8, 0, 220),
  [7352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [7354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [7356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [7358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [7360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_genericArg_repeat1, 2, 0, 0),
  [7362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [7364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [7366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [7368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [7370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kEndDot, 1, 0, 0),
  [7372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 5, 0, 48),
  [7374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [7376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [7378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [7380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declPropArgs, 3, 0, 0),
  [7382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [7384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [7386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [7388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [7390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [7392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declHelper, 9, 0, 195),
  [7394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 6, 0, 83),
  [7396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [7398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [7400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [7402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [7404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_library, 6, 0, 0),
  [7406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [7408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [7410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [7412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [7414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_library, 6, 0, 83),
  [7416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [7418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [7424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [7428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 138),
  [7430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declHelper, 7, 0, 140),
  [7432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [7434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declHelper, 5, 0, 0),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [7438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [7440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 195),
  [7442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 196),
  [7444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declPropArgs, 2, 0, 0),
  [7446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 138),
  [7448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [7450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [7452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 7, 0, 197),
  [7454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [7458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [7460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 7, 0, 195),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [7464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [7466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [7468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 7, 0, 198),
  [7470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [7472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [7474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [7478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [7482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [7484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declClass, 5, 0, 140),
  [7486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [7488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [7490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [7494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [7508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 6, 0, 0),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [7518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [7522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declClass, 2, 0, 0),
  [7524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [7526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [7528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [7530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [7532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [7538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [7540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_library, 5, 0, 0),
  [7542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [7546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [7548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_library, 5, 0, 48),
  [7550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [7554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [7556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [7558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [7560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [7562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declExports_repeat1, 2, 0, 0),
  [7564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [7566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [7568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [7570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [7572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [7574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [7576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [7578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declIntf, 5, 0, 140),
  [7580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [7582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [7584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [7586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [7588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [7590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [7592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [7594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2494),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_pascal(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
